#
# spec file for package kernel-vanilla
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
# needssslcertforbuild


%define srcversion 5.0
%define patchversion 5.0.5
%define variant %{nil}
%define vanilla_only 0

%include %_sourcedir/kernel-spec-macros

%define build_flavor	vanilla
%define build_default	("%build_flavor" == "default")
%define build_vanilla	("%build_flavor" == "vanilla")

%if ! %build_vanilla
%define src_install_dir /usr/src/linux-%kernelrelease%variant
%else
%define src_install_dir /usr/src/linux-%kernelrelease-vanilla
%endif
%define obj_install_dir /usr/src/linux-%kernelrelease%variant-obj
%define rpm_install_dir %buildroot%obj_install_dir
%define kernel_build_dir %my_builddir/linux-%srcversion/linux-obj

%if 0%{?_project:1} && %(echo %_project | egrep -x -f %_sourcedir/release-projects | grep -v ^PTF | grep -vc openSUSE)
	%define klp_symbols 1
%endif

%(chmod +x %_sourcedir/{guards,apply-patches,check-for-config-changes,group-source-files.pl,split-modules,modversions,kabi.pl,mkspec,compute-PATCHVERSION.sh,arch-symbols,log.sh,try-disable-staging-driver,compress-vmlinux.sh,mkspec-dtb,check-module-license,klp-symbols,splitflist,mergedep,moddep,modflist,kernel-subpackage-build})

%global cpu_arch %(%_sourcedir/arch-symbols %_target_cpu)
%define cpu_arch_flavor %cpu_arch/%build_flavor

# Define some CONFIG variables as rpm macros as well. (rpm cannot handle
# defining them all at once.)
%define config_vars CONFIG_MODULES CONFIG_MODULE_SIG CONFIG_KMSG_IDS CONFIG_SUSE_KERNEL_SUPPORTED CONFIG_EFI_STUB
%{expand:%(eval "$(test -n "%cpu_arch_flavor" && tar -xjf %_sourcedir/config.tar.bz2 --to-stdout config/%cpu_arch_flavor)"; for config in %config_vars; do echo "%%global $config ${!config:-n}"; done)}
%define split_extra (%CONFIG_MODULES == "y" && %CONFIG_SUSE_KERNEL_SUPPORTED == "y")

%ifarch %ix86 x86_64
%define install_vdso 1
%else
%define install_vdso 0
%endif

Name:           kernel-vanilla
Summary:        The Standard Kernel - without any SUSE patches
License:        GPL-2.0
Group:          System/Kernel
Version:        5.0.5
%if 0%{?is_kotd}
Release:        171.1.ge11ab6a
%else
Release:        171.1
%endif
Url:            http://www.kernel.org/
BuildRequires:  bc
BuildRequires:  bison
BuildRequires:  coreutils
BuildRequires:  fdupes
BuildRequires:  flex
# Cannot test %%CONFIG_GCC_PLUGINS here because the buildservice parser
# does not expand %%(...)
%if "%build_flavor" == "syzkaller"
# Needed by scripts/gcc-plugin.sh
BuildRequires:  gcc-c++
BuildRequires:  gcc-devel
%endif
%if 0%{?suse_version} > 1310
BuildRequires:  hmaccalc
%endif
BuildRequires:  libopenssl-devel
BuildRequires:  modutils
# Used to sign the kernel in the buildservice
BuildRequires:  openssl
BuildRequires:  pesign-obs-integration
# for objtool
BuildRequires:  libelf-devel
Provides:       %name = %version-%source_rel
# bnc#901925
Provides:       %name-%version-%source_rel
Provides:       %{name}_%_target_cpu = %version-%source_rel
Provides:       kernel-base = %version-%source_rel
Provides:       multiversion(kernel)
# In SLE11, kernel-$flavor complemented kernel-$flavor-base. With SLE12,
# kernel-$flavor itself contains all the needed files and kernel-$flavor-base
# is a subset that can replace kernel-$flavor in some scenarios. We need to
# obsolete the -base subpackage from SLE11, so that the base files are not
# owned by multiple packages now. The dependency is not correct wrt openSUSE
# 11.2 - 11.4, but we primarily care about the supported upgrade path.
Obsoletes:      %name-base < 3.1
Recommends: kernel-firmware
# The following is copied to the -base subpackage as well
# BEGIN COMMON DEPS
Requires(pre):  coreutils awk
# For /usr/lib/module-init-tools/weak-modules2
Requires(post): suse-module-tools
# For depmod (modutils is a dependency provided by both module-init-tools and
# kmod-compat)
Requires(post): modutils
# This Requires is wrong, because the post/postun scripts have a
# test -x update-bootloader, having perl-Bootloader is not a hard requirement.
# But, there is no way to tell rpm or yast to schedule the installation
# of perl-Bootloader before kernel-binary.rpm if both are in the list of
# packages to install/update. Likewise, this is true for mkinitrd.
# Need a perl-Bootloader with /usr/lib/bootloader/bootloader_entry
Requires(post): perl-Bootloader >= 0.4.15
%if %build_vanilla
Requires(post): mkinitrd
%else
# Require a mkinitrd that can handle usbhid/hid-generic built-in (bnc#773559)
Requires(post): mkinitrd >= 2.7.1
%endif
# Install the package providing /etc/SuSE-release early enough, so that
# the grub entry has correct title (bnc#757565)
Requires(post): distribution-release
# Do not install p-b and mkinitrd for the install check, the %post script is
# able to handle this
#!BuildIgnore: perl-Bootloader mkinitrd distribution-release
# Remove some packages that are installed automatically by the build system,
# but are not needed to build the kernel
#!BuildIgnore: autoconf automake gettext-runtime libtool cvs gettext-tools udev insserv

%ifarch s390 s390x
%if %build_vanilla && 0%{?suse_version} < 1130
BuildRequires:  dwarfextract
%endif
%endif
%ifarch %arm
BuildRequires:  u-boot-tools
%endif

Obsoletes:      microcode_ctl

# Force bzip2 instead of lzma compression to
# 1) allow install on older dist versions, and
# 2) decrease build times (bsc#962356)
%define _binary_payload w9.bzdio
# Do not recompute the build-id of vmlinux in find-debuginfo.sh (bsc#964063)
%undefine _unique_build_ids
%define _no_recompute_build_ids 1
# prevent usr/lib/debug/boot/vmlinux-4.12.14-11.10-default-4.12.14-11.10.ppc64le.debug
%undefine _unique_debug_names
# dead network if installed on SLES10, otherwise it will work (mostly)
Conflicts:      sysfsutils < 2.0
Conflicts:      apparmor-profiles <= 2.1
Conflicts:      apparmor-parser < 2.3
# root-lvm only works with newer udevs
Conflicts:      udev < 118
Conflicts:      lvm2 < 2.02.33
# Interface to hv_kvp_daemon changed
Conflicts:      hyper-v < 4
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
Provides:       kernel = %version-%source_rel
Provides:       kernel-%build_flavor-base-srchash-e11ab6a4e9f35fffffc76fd2bfb35a897898d3ed
Provides:       kernel-srchash-e11ab6a4e9f35fffffc76fd2bfb35a897898d3ed
# END COMMON DEPS
Provides:       %name-srchash-e11ab6a4e9f35fffffc76fd2bfb35a897898d3ed
%obsolete_rebuilds %name
Source0:        http://www.kernel.org/pub/linux/kernel/v5.x/linux-%srcversion.tar.xz
Source2:        source-post.sh
Source3:        kernel-source.rpmlintrc
Source8:        devel-pre.sh
Source9:        devel-post.sh
Source10:       preun.sh
Source11:       postun.sh
Source12:       pre.sh
Source13:       post.sh
Source14:       series.conf
Source16:       guards
Source17:       apply-patches
Source21:       config.conf
Source23:       supported.conf
Source33:       check-for-config-changes
Source35:       group-source-files.pl
Source36:       README.PATCH-POLICY.SUSE
Source37:       README.SUSE
Source38:       README.KSYMS
Source39:       config-options.changes.txt
Source40:       source-timestamp
Source46:       split-modules
Source47:       modversions
Source48:       macros.kernel-source
Source49:       kernel-module-subpackage
Source50:       kabi.pl
Source51:       mkspec
Source52:       kernel-source%variant.changes
Source53:       kernel-source.spec.in
Source54:       kernel-binary.spec.in
Source55:       kernel-syms.spec.in
Source56:       kernel-docs.spec.in
Source57:       kernel-cert-subpackage
Source58:       constraints.in
Source60:       config.sh
Source61:       compute-PATCHVERSION.sh
Source62:       old-flavors
Source63:       arch-symbols
Source64:       package-descriptions
Source65:       kernel-spec-macros
Source67:       log.sh
Source68:       host-memcpy-hack.h
Source69:       try-disable-staging-driver
Source70:       kernel-obs-build.spec.in
Source71:       kernel-obs-qa.spec.in
Source72:       compress-vmlinux.sh
Source73:       dtb.spec.in.in
Source74:       mkspec-dtb
Source75:       release-projects
Source76:       check-module-license
Source77:       klp-symbols
Source78:       modules.fips
Source79:       splitflist
Source80:       mergedep
Source81:       moddep
Source82:       modflist
Source83:       kernel-subpackage-build
Source84:       kernel-subpackage-spec
Source85:       kernel-default-base.spec.txt
Source100:      config.tar.bz2
Source101:      config.addon.tar.bz2
Source102:      patches.arch.tar.bz2
Source103:      patches.drivers.tar.bz2
Source104:      patches.fixes.tar.bz2
Source105:      patches.rpmify.tar.bz2
Source106:      patches.suse.tar.bz2
Source108:      patches.addon.tar.bz2
Source109:      patches.kernel.org.tar.bz2
Source110:      patches.apparmor.tar.bz2
Source111:      patches.rt.tar.bz2
Source113:      patches.kabi.tar.bz2
Source120:      kabi.tar.bz2
Source121:      sysctl.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  aarch64 armv6hl armv7hl %ix86 ppc64 ppc64le s390x x86_64
%define kmp_target_cpu %_target_cpu
%ifarch %ix86
# Only i386/default supports i586, mark other flavors' packages as i686
%if ! %build_default
BuildArch:      i686
# KMPs are always built as i586, because rpm does not allow to build
# subpackages for different architectures. Therefore, we change the
# /usr/src/linux-obj/<arch> symlink to i586.
%define kmp_target_cpu i586
%endif
%endif

# These files are found in the kernel-source package:
NoSource:       0
NoSource:       2
NoSource:       3
NoSource:       8
NoSource:       9
NoSource:       10
NoSource:       11
NoSource:       12
NoSource:       13
NoSource:       14
NoSource:       16
NoSource:       17
NoSource:       21
NoSource:       23
NoSource:       33
NoSource:       35
NoSource:       36
NoSource:       37
NoSource:       38
NoSource:       39
NoSource:       40
NoSource:       46
NoSource:       47
NoSource:       48
NoSource:       49
NoSource:       50
NoSource:       51
NoSource:       52
NoSource:       53
NoSource:       54
NoSource:       55
NoSource:       56
NoSource:       57
NoSource:       58
NoSource:       60
NoSource:       61
NoSource:       62
NoSource:       63
NoSource:       64
NoSource:       65
NoSource:       67
NoSource:       68
NoSource:       69
NoSource:       70
NoSource:       71
NoSource:       72
NoSource:       73
NoSource:       74
NoSource:       75
NoSource:       76
NoSource:       77
NoSource:       78
NoSource:       79
NoSource:       80
NoSource:       81
NoSource:       82
NoSource:       83
NoSource:       84
NoSource:       85
NoSource:       100
NoSource:       101
NoSource:       102
NoSource:       103
NoSource:       104
NoSource:       105
NoSource:       106
NoSource:       108
NoSource:       109
NoSource:       110
NoSource:       111
NoSource:       113
NoSource:       120
NoSource:       121

# The following KMPs have been integrated into the kernel package,
# grouped by the last product that contained them.
# Usage: obsolete_kmp <basename> <upper bound of shipped versions>
# Note that KMPs embed the version of the kernel built against, that's why
# the _3 suffix for 2.6.x-based KMPs
%define obsolete_kmp() Obsoletes: %1-kmp-%build_flavor <= %2 \
Provides: %1-kmp = %2 \
Provides: %1-kmp-%build_flavor = %2
# sles10 / 10.3
%obsolete_kmp iwlwifi 1.3.27_3
%obsolete_kmp ipw3945 1.2.2_3
# sled10 / 11.0
%obsolete_kmp uvcvideo r200_3
# sle11-ga
%obsolete_kmp enic 0.0.1_3
%obsolete_kmp fnic 1.0.0_3
%obsolete_kmp brocade-bfa 1.1.0.2_3
%obsolete_kmp kvm 78.2.6.30.1_3
%obsolete_kmp perfmon 2_3
%obsolete_kmp iwlagn-2-6-27 1.0_3
%obsolete_kmp msi-wmi 1.0_3
# 11.1
%obsolete_kmp quickcam 0.6.7
# sle11-sp1
%obsolete_kmp   wacom 0.8.1_3
%obsolete_kmp   btrfs 0_3
%obsolete_kmp   brocade-bna 2.1.0.0_3
%obsolete_kmp   hyper-v 0_3
%obsolete_kmp   intel-e1000e 2.2.14
Obsoletes:      firewire <= 3.0
Provides:       firewire = 3.0
%obsolete_kmp   firewire 3.0
%obsolete_kmp   iwlagn 3.0
Obsoletes:      compat-ath9k <= 3.0
Provides:       compat-ath9k = 3.0
%obsolete_kmp   compat-ath9k 3.0
%obsolete_kmp   realtek-r8192ce_pci 2.6.0005_3
%obsolete_kmp   realtek-r8192se_pci 2.6.0019.1207.2010_3
%obsolete_kmp   rt3090 2.4.0.4_3
%obsolete_kmp   rt3592 2.4.1.1_3
%obsolete_kmp   rt5390 2.4.0.4_3
%obsolete_kmp   ath3k 1.0_3
%obsolete_kmp	compat-wireless 3.12
%obsolete_kmp	rts5229 1.08
%obsolete_kmp	rts_pstor 1.11
# sle12-sp1 / Leap 42.1
%obsolete_kmp	xen 4.6.1
%obsolete_kmp	compat-wireless 4.4
# TW 4.8
%obsolete_kmp	ftsteutates 20160601
# SLE12-SP3 / Leap 42.3
%obsolete_kmp   drm 4.12

# Will modules not listed in supported.conf abort the kernel build (0/1)?
%define supported_modules_check 0

%description
The standard kernel - without any SUSE patches


%source_timestamp
%prep
if ! [ -e %{S:0} ]; then
    echo "The %name-%version.nosrc.rpm package does not contain the" \
	 "complete sources. Please install kernel-source-%version.src.rpm."
    exit 1
fi

SYMBOLS=
if test -e %_sourcedir/extra-symbols; then
	SYMBOLS=$(cat %_sourcedir/extra-symbols)
	echo "extra symbol(s):" $SYMBOLS
fi

# Unpack all sources and patches
%setup -q -c -T -a 0 -a 100 -a 101 -a 102 -a 103 -a 104 -a 105 -a 106 -a 108 -a 109 -a 110 -a 111 -a 113 -a 120 -a 121

mkdir -p %kernel_build_dir

# Generate a list of modules with their support status marking
%_sourcedir/guards --list --with-guards <%_sourcedir/supported.conf | \
awk '
	/\+external / {
		print $(NF) " external";
		next;
	}
	/^-/ {
		print $(NF) " no";
		next;
	}
	{
		print $(NF);
	}
' >%kernel_build_dir/Module.supported
subpackages=(
	base
%if %CONFIG_SUSE_KERNEL_SUPPORTED == "y"
	cluster-md-kmp dlm-kmp gfs2-kmp kselftests-kmp ocfs2-kmp
%endif
)
for package in "${subpackages[@]}"; do
	%_sourcedir/guards --default=0 "$package" \
		<%_sourcedir/supported.conf | sed 's,.*/,,; s,\.ko$,,' | \
		sort -u >%kernel_build_dir/Module."$package"
done

cd linux-%srcversion

%_sourcedir/apply-patches \
%if %{build_vanilla}
	--vanilla \
%endif
	%_sourcedir/series.conf .. $SYMBOLS

cd %kernel_build_dir

# Override the timestamp 'uname -v' reports with the source timestamp and
# the commit hash.
date=$(head -n 1 %_sourcedir/source-timestamp)
commit=$(sed -n 's/GIT Revision: //p' %_sourcedir/source-timestamp)
cat > .kernel-binary.spec.buildenv <<EOF
export KBUILD_BUILD_TIMESTAMP="$(LANG=C date -d "$date") (${commit:0:7})"
export KBUILD_VERBOSE=0
export KBUILD_SYMTYPES=1
export KBUILD_OVERRIDE=1
export KBUILD_BUILD_USER=geeko
export KBUILD_BUILD_HOST=buildhost
export HOST_EXTRACFLAGS="-include %_sourcedir/host-memcpy-hack.h"
EOF
source .kernel-binary.spec.buildenv

if [ -f %_sourcedir/localversion ] ; then
    cat %_sourcedir/localversion > localversion
fi

vanilla_base="default"
%ifarch %ix86
vanilla_base="pae"
%endif
if ! grep -q CONFIG_MMU= "%my_builddir/config/%cpu_arch_flavor"; then
cp "%my_builddir/config/%cpu_arch/$vanilla_base" .config
../scripts/kconfig/merge_config.sh -m .config \
                                   %my_builddir/config/%cpu_arch_flavor
else
cp %my_builddir/config/%cpu_arch_flavor .config
fi
if test -e %my_builddir/config.addon/%cpu_arch_flavor; then
	# FIXME: config.addon doesn't affect the %CONFIG_ macros defined at
	# the top of the specfile
	../scripts/kconfig/merge_config.sh -m .config %my_builddir/config.addon/%cpu_arch_flavor
fi

CONFIG_SUSE_KERNEL_RELEASED="--disable CONFIG_SUSE_KERNEL_RELEASED"
%if 0%{?_project:1}
if echo %_project | egrep -qx -f %_sourcedir/release-projects; then
	CONFIG_SUSE_KERNEL_RELEASED="--enable CONFIG_SUSE_KERNEL_RELEASED"
fi
%endif

../scripts/config \
	--set-str CONFIG_LOCALVERSION -%source_rel-%build_flavor \
	--enable  CONFIG_SUSE_KERNEL \
	$CONFIG_SUSE_KERNEL_RELEASED \
%if 0%{?__debug_package:1}
	--enable  CONFIG_DEBUG_INFO
%else
	--disable CONFIG_DEBUG_INFO
%endif

case %cpu_arch in
    x86_64 | i386)
        MAKE_ARGS="$MAKE_ARGS ARCH=x86"
        ;;
    ppc*)
        MAKE_ARGS="$MAKE_ARGS ARCH=powerpc"
        ;;
    s390x)
        MAKE_ARGS="$MAKE_ARGS ARCH=s390"
        ;;
    arm64)
        MAKE_ARGS="$MAKE_ARGS ARCH=arm64"
        ;;
    armv*)
        MAKE_ARGS="$MAKE_ARGS ARCH=arm"
        ;;
    *)
        MAKE_ARGS="$MAKE_ARGS ARCH=%cpu_arch"
        ;;
esac

makeoutputsync=
if make --output-sync --help >/dev/null 2>&1 ; then
        makeoutputsync=--output-sync
else
        echo make does not support --output-sync flag. Build messages may be mangled. 1>&2
fi
MAKE_ARGS="$MAKE_ARGS $makeoutputsync %{?_smp_mflags}"
echo export MAKE_ARGS=\""$MAKE_ARGS"\" >> .kernel-binary.spec.buildenv

KERN_DIRS="-C .. O=$PWD"
if test -e %_sourcedir/TOLERATE-UNKNOWN-NEW-CONFIG-OPTIONS; then
    yes '' | make oldconfig $MAKE_ARGS $KERN_DIRS
else
    cp .config .config.orig
    if test -f ../scripts/kconfig/Makefile && \
       grep -q syncconfig ../scripts/kconfig/Makefile; then
        syncconfig="syncconfig"
    else
        syncconfig="silentoldconfig"
    fi
    make $syncconfig $MAKE_ARGS $KERN_DIRS < /dev/null
    %_sourcedir/check-for-config-changes .config.orig .config
    rm .config.orig
fi

make prepare $MAKE_ARGS
make scripts $MAKE_ARGS
krel=$(make -s kernelrelease $MAKE_ARGS)

if [ "$krel" != "%kernelrelease-%build_flavor" ]; then
    echo "Kernel release mismatch: $krel != %kernelrelease-%build_flavor" >&2
    exit 1
fi

make clean $MAKE_ARGS

rm -f source
find . ! -type d ! -name 'Module.base' ! -name 'Module.*-kmp' -printf '%%P\n' \
	> %my_builddir/obj-files

%build
cd %kernel_build_dir
source .kernel-binary.spec.buildenv

# create *.symref files in the tree
if test -e %my_builddir/kabi/%cpu_arch/symtypes-%build_flavor; then
    %_sourcedir/modversions --unpack . < $_
fi

# copy module signing certificate(s). We use the default path and trick
# certs/Makefile to not regenerate the certificate. It is done this way so
# that the kernel-source package can be rebuilt even without the certificate
mkdir -p certs
for f in %_sourcedir/*.crt; do
    if ! test -e "$f"; then
        continue
    fi
    touch certs/x509.genkey
    cat "$f" >>certs/signing_key.pem
done

%if %CONFIG_KMSG_IDS == "y"
    chmod +x ../scripts/kmsg-doc
    MAKE_ARGS="$MAKE_ARGS D=2"
%endif

mkdir -p %_topdir/OTHER
log=%_topdir/OTHER/make-stderr.log
while true; do
    make all $MAKE_ARGS 2> >(tee "$log")
    if test "${PIPESTATUS[0]}" -eq 0; then
        break
    fi
    # In the linux-next and vanilla branches, we try harder to build a
    # package.
    if test 0%vanilla_only -gt 0 &&
			%_sourcedir/try-disable-staging-driver "$log"; then
        echo "Retrying make"
    else
        exit 1
    fi
done

# Generate list of symbols that are used to create kernel livepatches
%if 0%{?klp_symbols}
	%_sourcedir/klp-symbols . Symbols.list
%endif

%install

# sign the modules, firmware and possibly the kernel in the buildservice
BRP_PESIGN_FILES=""
%if %CONFIG_EFI_STUB == "y"
BRP_PESIGN_FILES="/boot/vmlinuz-%kernelrelease-%build_flavor"
%endif
%if %CONFIG_MODULE_SIG == "y"
BRP_PESIGN_FILES="$BRP_PESIGN_FILES *.ko"
%endif
%ifarch %ix86
# XXX: do not sign on x86, as the repackaging changes kernel-pae
# from i686 to i586
BRP_PESIGN_FILES=""
%endif
export BRP_PESIGN_FILES

# get rid of /usr/lib/rpm/brp-strip-debug
# strip removes too much from the vmlinux ELF binary
export NO_BRP_STRIP_DEBUG=true
export STRIP_KEEP_SYMTAB='*/vmlinux-*'

# /lib/modules/%kernelrelease-%build_flavor/source points to the source
# directory installed by kernel-devel. The kernel-%build_flavor-devel package
# has a correct dependency on kernel-devel, but the brp check does not see
# kernel-devel during build.
export NO_BRP_STALE_LINK_ERROR=yes

cd %kernel_build_dir
source .kernel-binary.spec.buildenv

mkdir -p %buildroot/boot
# (Could strip out non-public symbols.)
cp -p System.map %buildroot/boot/System.map-%kernelrelease-%build_flavor

add_vmlinux()
{
    local vmlinux=boot/vmlinux-%kernelrelease-%build_flavor

    cp vmlinux %buildroot/$vmlinux
    # make sure that find-debuginfo.sh picks it up. In the filelist, we
    # mark the file 0644 again
    chmod +x %buildroot/$vmlinux
    if test $1 == "--compressed"; then
        # avoid using the gzip -n option to make kdump happy (bnc#880848#c20)
        ts="$(head -n1 %_sourcedir/source-timestamp)"
        touch -d "$ts" %buildroot/$vmlinux
        touch %buildroot/$vmlinux.gz
%if 0%{?__debug_package:1}
        # compress the vmlinux image after find-debuginfo.sh has processed it
%global __debug_install_post %__debug_install_post \
%_sourcedir/compress-vmlinux.sh %buildroot/boot/vmlinux-%kernelrelease-%build_flavor
%else
        %_sourcedir/compress-vmlinux.sh %buildroot/$vmlinux
%endif
        ghost_vmlinux=true
    else
        ghost_vmlinux=false
    fi
}

# architecture specifics
%ifarch %ix86 x86_64
    add_vmlinux --compressed
    image=bzImage
    cp -p arch/x86/boot/$image %buildroot/boot/vmlinuz-%kernelrelease-%build_flavor
    image=vmlinuz
%endif
%ifarch ppc ppc64 ppc64le
    add_vmlinux
    image=vmlinux
%endif
%ifarch s390 s390x
    add_vmlinux --compressed
    image=image
    if test ! -f arch/s390/boot/$image; then
        image=bzImage
    fi
    cp -p arch/s390/boot/$image %buildroot/boot/image-%kernelrelease-%build_flavor
    image=image
    if test -e arch/s390/boot/kerntypes.o; then
        cp -p arch/s390/boot/kerntypes.o %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor
    elif test -x "$(which dwarfextract 2>/dev/null)"; then
	dwarfextract vmlinux %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor || echo "dwarfextract failed ($?)"
    fi
%if %CONFIG_KMSG_IDS == "y"
    mkdir -p %buildroot/usr/share/man/man9
    find man -name '*.9' -exec install -m 644 -D '{}' %buildroot/usr/share/man/man9/ ';'
%endif
%endif
%ifarch %arm
    add_vmlinux --compressed
    image=zImage
    cp -p arch/arm/boot/$image %buildroot/boot/$image-%kernelrelease-%build_flavor
%endif
%ifarch aarch64
    add_vmlinux --compressed
    image=Image
    cp -p arch/arm64/boot/$image %buildroot/boot/$image-%kernelrelease-%build_flavor
%endif

if test -x /usr/lib/rpm/pesign/gen-hmac; then
	$_ -r %buildroot /boot/$image-%kernelrelease-%build_flavor
fi

# Package the compiled-in certificates as DER files in /etc/uefi/certs
# and have mokutil enroll them when the kernel is installed
certs=()
if test %CONFIG_MODULE_SIG = "y"; then
    for f in %_sourcedir/*.crt; do
            if ! test -s "$f"; then
                    continue
            fi
            h=$(openssl x509 -inform PEM -fingerprint -noout -in "$f")
            test -n "$h"
            cert=/etc/uefi/certs/$(echo "$h" | \
                sed -rn 's/^SHA1 Fingerprint=//; T; s/://g; s/(.{8}).*/\1/p').crt
            if test -e %buildroot/"$cert"; then
                    continue
            fi
            mkdir -p %buildroot/etc/uefi/certs
            openssl x509 -inform PEM -in "$f" -outform DER -out %buildroot/"$cert"
            certs=("${certs[@]}" "$cert")
    done
fi

for sub in '' '-extra'; do
    case "$sub" in
    '') base_package=1 ;;
    *) base_package=0 ;;
    esac
    for script in preun postun pre post devel-pre devel-post; do
        if test %build_flavor = "zfcpdump"; then
            : >%my_builddir/$script$sub.sh
            continue
        fi
        sed -e "s:@KERNELRELEASE@:%kernelrelease:g" \
            -e "s:@IMAGE@:$image:g" \
            -e "s:@FLAVOR""@:%build_flavor:g" \
            -e "s:@SUBPACKAGE@:%name$sub:g" \
            -e "s:@BASE_PACKAGE@:$base_package:g" \
            -e "s:@RPM_VERSION_RELEASE@:%version-%release:g" \
            -e "s:@RPM_TARGET_CPU@:%_target_cpu:g" \
	    -e "s:@CPU_ARCH_FLAVOR@:%cpu_arch_flavor:g" \
            -e "s:@SRCVARIANT@:%variant:g" \
            %_sourcedir/$script.sh > %my_builddir/$script$sub.sh
        if test "$base_package" -eq 1 -a "${#certs[@]}" -gt 0; then
            case "$script" in
            preun | postun | post)
                # Copy the respective scriptlet from kernel-cert-subpackage
                sed "1,/^%%$script / d; /^%%[^%%]/,\$ d; s:@CERTS@:${certs[*]}:g" \
                    %_sourcedir/kernel-cert-subpackage \
                    >>"%my_builddir/$script$sub.sh"
            esac
        fi
	# Do an exit 0 at the end of each scriptlet. If the last real command
	# in the scriptlet (e.g. update-bootloader call, see bnc#809617)
	# returns an error, we do not want to amplify the damage by leaving
	# the system in an inconsistent state.
	echo "exit 0" >>"%my_builddir/$script$sub.sh"
    done
done

%if %build_vanilla
# keep this -suffix list in sync with post.sh and postun.sh
suffix=-%build_flavor
%endif
ln -s $image$suffix %buildroot/boot/$image$suffix
ln -s initrd$suffix %buildroot/boot/initrd$suffix

cp -p .config %buildroot/boot/config-%kernelrelease-%build_flavor
sysctl_file=%buildroot/boot/sysctl.conf-%kernelrelease-%build_flavor
for file in %my_builddir/sysctl/{defaults,%cpu_arch/arch-defaults,%cpu_arch_flavor}; do
	if [ -f "$file" ]; then
		cat "$file"
	fi
done | sed '1i # Generated file - do not edit.' >$sysctl_file
if [ ! -s $sysctl_file ]; then
	rm $sysctl_file
fi

%if %install_vdso
# Install the unstripped vdso's that are linked in the kernel image
make vdso_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot
rm -rf %buildroot/lib/modules/%kernelrelease-%build_flavor/vdso/.build-id
%endif

# Create a dummy initrd with roughly the size the real one will have.
# That way, YaST will know that this package requires some additional
# space in /boot.
dd if=/dev/zero of=%buildroot/boot/initrd-%kernelrelease-%build_flavor \
	bs=1024 seek=2047 count=1
# Also reserve some space for the kdump initrd
cp %buildroot/boot/initrd-%kernelrelease-%build_flavor{,-kdump}
%if 0%{?suse_version} >= 1500
# Use same permissions as dracut
chmod 0600 %buildroot/boot/initrd-%kernelrelease-%build_flavor{,-kdump}
%endif

if [ %CONFIG_MODULES = y ]; then
    mkdir -p %rpm_install_dir/%cpu_arch_flavor
    mkdir -p %buildroot/usr/src/linux-obj/%cpu_arch
    ln -s %build_flavor %buildroot/usr/src/linux-obj/%cpu_arch_flavor
    install -m 755 -D -t %rpm_install_dir/%cpu_arch_flavor/scripts/mod/ scripts/mod/ksym-provides

    gzip -n -c9 < Module.symvers > %buildroot/boot/symvers-%kernelrelease-%build_flavor.gz

    make modules_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot

%ifarch s390 s390x
    if test -e arch/s390/boot/kerntypes.o; then
        :
    elif test -x "$(which dwarfextract 2>/dev/null)" -a \
	-f %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor; then
	find %buildroot -name "*.ko" > kofiles.list
	dwarfextract %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor -C kofiles.list || echo "dwarfextract failed ($?)"
    fi
%endif

    # Also put the resulting file in %rpm_install_dir/%cpu_arch/%build_flavor
    # so that kernel-devel + kernel-%build_flavor is sufficient for building
    # modules that have modversions as well.
    mkdir -p %rpm_install_dir/%cpu_arch/%build_flavor
    cp Module.symvers %rpm_install_dir/%cpu_arch/%build_flavor

    # List of symbols that are used to generate kernel livepatches
    %if 0%{?klp_symbols}
        cp Symbols.list %rpm_install_dir/%cpu_arch/%build_flavor
    %endif

    # Table of types used in exported symbols (for modversion debugging).
    %_sourcedir/modversions --pack . > %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    if [ -s %buildroot/boot/symtypes-%kernelrelease-%build_flavor ]; then
	gzip -n -9 %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    else
	rm -f %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    fi

    # Some architecture's $(uname -m) output is different from the ARCH
    # parameter that needs to be passed to kbuild. Create symlinks from
    # $(uname -m) to the ARCH directory.
    if [ ! -e %rpm_install_dir/%kmp_target_cpu ]; then
        ln -sf %cpu_arch %rpm_install_dir/%kmp_target_cpu
        ln -sf %cpu_arch %buildroot/usr/src/linux-obj/%kmp_target_cpu
    fi

    # We were building in %my_builddir/linux-%srcversion, but the sources will
    # later be installed in /usr/src/linux-%srcversion-%source_rel. Fix up the
    # build symlink.
    rm -f %buildroot/lib/modules/%kernelrelease-%build_flavor/{source,build}
    ln -s %src_install_dir \
	%buildroot/lib/modules/%kernelrelease-%build_flavor/source
    ln -s %obj_install_dir/%cpu_arch/%build_flavor \
	%buildroot/lib/modules/%kernelrelease-%build_flavor/build

    # Abort if there are any undefined symbols
    msg="$(/sbin/depmod -F %buildroot/boot/System.map-%kernelrelease-%build_flavor \
			-b %buildroot -ae %kernelrelease-%build_flavor 2>&1)"
    if [ $? -ne 0 ] || echo "$msg" | grep  'needs unknown symbol'; then
	exit 1
    fi

    %_sourcedir/split-modules -d %buildroot \
	-o %my_builddir \
	-b %kernel_build_dir \
%if %CONFIG_SUSE_KERNEL_SUPPORTED == "y"
	-e \
%endif
%if ! %supported_modules_check
	-i \
%endif
	%nil
%if ! %split_extra
    cat %my_builddir/unsupported-modules >>%my_builddir/main-modules
%endif

    # The modules.dep file is sorted randomly which produces strange file
    # checksums. As the file is not included in the resulting RPM, it's
    # pointless to rely on its contents. Replacing by zeros to make the
    # checksums always the same for several builds of the same package.
    test -s %buildroot/lib/modules/%kernelrelease-%build_flavor/modules.dep && \
    dd if=/dev/zero of=%buildroot/lib/modules/%kernelrelease-%build_flavor/modules.dep ibs=`stat -c%s %buildroot/lib/modules/%kernelrelease-%build_flavor/modules.dep` count=1

    res=0
    if test -e %my_builddir/kabi/%cpu_arch/symvers-%build_flavor; then
        # check for kabi changes
        %_sourcedir/kabi.pl --rules %my_builddir/kabi/severities \
            %my_builddir/kabi/%cpu_arch/symvers-%build_flavor \
            Module.symvers || res=$?
    fi
    if [ $res -ne 0 ]; then
	# %ignore_kabi_badness is defined in the Kernel:* projects in the
	# OBS to be able to build the KOTD in spite of kabi errors
	if [ 0%{?ignore_kabi_badness} -eq 0 -a \
	     ! -e %my_builddir/kabi/%cpu_arch/ignore-%build_flavor -a \
	     ! -e %_sourcedir/IGNORE-KABI-BADNESS ]; then
	    echo "Create a file IGNORE-KABI-BADNESS in the kernel-source" \
		 "directory to build this kernel even though its badness is" \
		 "higher than allowed for an official kernel."
	   exit 1
	fi
    fi

    # Check the license in each module
    if ! sh %_sourcedir/check-module-license %buildroot; then
	echo "Please fix the missing licenses!"
%if %CONFIG_SUSE_KERNEL_SUPPORTED == "y"
	exit 1
%endif
    fi

    # These files are required for building external modules
    for FILE in arch/powerpc/lib/crtsavres.o arch/arm64/kernel/ftrace-mod.o arch/*/kernel/macros.s; do
	    if [ -f %kernel_build_dir/$FILE ]; then
		echo $FILE >> %my_builddir/obj-files
	    fi
    done

    tar -cf - -T %my_builddir/obj-files | \
	tar -xf - -C %rpm_install_dir/%cpu_arch_flavor
    # bnc#507084
    find %rpm_install_dir/%cpu_arch_flavor/scripts -type f -perm -111 | \
        while read f; do
            case "$(file -b "$f")" in
            ELF\ *\ executable*)
                strip "$f"
            esac
        done
    # Recreate the generated Makefile with correct path
    sh ../scripts/mkmakefile ../../../%{basename:%src_install_dir} \
        %rpm_install_dir/%cpu_arch_flavor \
        $(echo %srcversion | sed -r 's/^([0-9]+)\.([0-9]+).*/\1 \2/')
fi

rm -rf %{buildroot}/lib/firmware

add_dirs_to_filelist() {
    sed -rn '
        # print file name
        p
        # remove filelist macros
        s:%%[a-z]+(\([^)]+\))? ?::g
        # add %%dir prefix
        s:^:%%dir :
        # print all parents
        :a
            # skip directories owned by other packages
            s:^%%dir (/boot|/etc|/lib/(modules|firmware)|/usr/src)/[^/]+$::
            s:/[^/]+$::p
        ta
    ' "$@" | sort -u
}

# Collect the file lists.
shopt -s nullglob dotglob
> %my_builddir/kernel-devel.files
for file in %buildroot/boot/symtypes* %buildroot/lib/modules/*/{build,source}; do
	f=${file##%buildroot}
	echo "$f"
done | add_dirs_to_filelist >%my_builddir/kernel-devel.files

{   cd %buildroot
    for f in boot/*; do
        if test -L "$f"; then
            echo "%%ghost /$f"
            continue
        elif test ! -f "$f"; then
            continue
        fi
        case "$f" in
        boot/initrd-*)
            echo "%%ghost /$f"
            continue
            ;;
        boot/vmlinux-*.gz)
            ;;
        boot/vmlinux-*)
            if $ghost_vmlinux; then
                echo "%%ghost /$f"
                continue
            fi
            ;;
        boot/symtypes*)
            continue
            ;;
        esac
        echo "%%attr(0644, root, root) /$f"
    done

    if [ %CONFIG_MODULES = y ]; then
	find lib/modules/%kernelrelease-%build_flavor \
	    -type d -o \
	    \( -path '*/modules.*' ! -path '*/modules.order' \
	     ! -path '*/modules.builtin' \) -printf '%%%%ghost /%%p\n' \
	       -o -name '*.ko' -prune -o -type f -printf '/%%p\n'
	cat %my_builddir/base-modules
    fi
    if test %CONFIG_MODULE_SIG = "y" -a -d etc/uefi/certs; then
        find etc/uefi/certs -type f -printf '/%%p\n'
    fi
    if test -d lib/firmware/%kernelrelease-%build_flavor; then
        echo "%%dir /lib/firmware/%kernelrelease-%build_flavor"
        cat %my_builddir/base-firmware
    fi
    if [ -e .%_docdir/%name ]; then
	echo "%%doc %_docdir/%name"
    fi
} | sort -u | add_dirs_to_filelist >%my_builddir/kernel-base.files

{
    add_dirs_to_filelist %my_builddir/{kernel-base.files,main-modules}
    if test -d %buildroot/lib/firmware/%kernelrelease-%build_flavor; then
	echo "/lib/firmware/%kernelrelease-%build_flavor"
    fi
} > %my_builddir/kernel-main.files
%if %split_extra
    add_dirs_to_filelist %my_builddir/unsupported-modules > %my_builddir/kernel-extra.files

%if 0%{?sle_version} >= 150000
    # By default, loading unsupported modules is disabled on SLE through
    # /etc/modprobe.d/10-unsupported-modules.conf from the suse-module-tools
    # package.
    # modules in kernel-$flavor-extra don't have the supported flag set,
    # yet loading them should be possible if the package is installed.
    # CAUTION PACKAGERS: The file content below must not change between
    # kernel versions, otherwise file conflicts might arise with
    # multiversion(kernel).

    mkdir -p %buildroot/etc/modprobe.d
    cat >%buildroot/etc/modprobe.d/20-kernel-%{build_flavor}-extra.conf <<EOF
# This file overrides the default from 10-unsupported-modules.conf.
# This is necessary to load kernel modules from the
# kernel-%{build_flavor}-extra package.
#
# WARNING: loading unsupported modules may compromise SLE support.
# Please read the comments in 10-unsupported-modules.conf.
allow_unsupported_modules 1
EOF
    echo "%%dir /etc/modprobe.d" >> %my_builddir/kernel-extra.files
    echo '%%config(noreplace) /etc/modprobe.d/20-kernel-%{build_flavor}-extra.conf' >> %my_builddir/kernel-extra.files
%endif
%endif
for f in %my_builddir/*-kmp-modules; do
	f2=${f%%-modules}.files
	add_dirs_to_filelist "$f" >"$f2"
done

if [ %CONFIG_MODULES = y ]; then
  install -m 644 %_sourcedir/modules.fips %{buildroot}/lib/modules/%kernelrelease-%build_flavor/modules.fips
  echo /lib/modules/%kernelrelease-%build_flavor/modules.fips >> %my_builddir/kernel-base.files
  echo /lib/modules/%kernelrelease-%build_flavor/modules.fips >> %my_builddir/kernel-main.files
fi

# Hardlink duplicate files automatically (from package fdupes): It doesn't save
# much, but it keeps rpmlint from breaking the package build. Note that we skip
# /usr/src/linux-obj intentionally, to not accidentally break timestamps there
%fdupes $RPM_BUILD_ROOT/lib

%preun -f preun.sh

%postun -f postun.sh

%pre -f pre.sh

%post -f post.sh

%files -f kernel-main.files
%defattr(-, root, root)

%package extra
Summary:        The Standard Kernel - without any SUSE patches - Unsupported kernel modules
Group:          System/Kernel
Url:            http://www.kernel.org/
Provides:       %name-extra_%_target_cpu = %version-%source_rel
Provides:       kernel-extra = %version-%source_rel
Provides:       multiversion(kernel)
Requires:       %{name}_%_target_cpu = %version-%source_rel
Requires(pre):  coreutils awk
Requires(post): modutils
Requires(post): perl-Bootloader
Requires(post): mkinitrd
%obsolete_rebuilds %name-extra
Supplements:    packageand(product(SLED):%{name}_%_target_cpu)
Supplements:    packageand(product(sle-we):%{name}_%_target_cpu)
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif

%description extra
The standard kernel - without any SUSE patches

This package contains additional modules not supported by Novell.


%source_timestamp
%preun extra -f preun-extra.sh

%postun extra -f postun-extra.sh

%pre extra -f pre-extra.sh

%post extra -f post-extra.sh

%if %split_extra

%files extra -f kernel-extra.files
%defattr(-, root, root)
%endif

%if %CONFIG_KMSG_IDS == "y"

%package man
Summary:        The collection of man pages generated by the kmsg script
Group:          System/Kernel

%description man
This package includes the man pages that have been generated from the
kmsg message documentation comments.


%source_timestamp
%files man
%defattr(-,root,root)
/usr/share/man/man9/*
%endif

%package devel
Summary:        Development files necessary for building kernel modules
Group:          Development/Sources
Provides:       %name-devel = %version-%source_rel
Provides:       multiversion(kernel)
%if ! %build_vanilla
Requires:       kernel-devel%variant = %version-%source_rel
Recommends:     make
Recommends:     gcc
Recommends:     perl
# for objtool
Requires:	libelf-devel
Supplements:    packageand(%name:kernel-devel%variant)
%else
Requires:       kernel-source-vanilla = %version-%source_rel
Supplements:    packageand(%name:kernel-source-vanilla)
%endif
%obsolete_rebuilds %name-devel
PreReq:         coreutils

%description devel
This package contains files necessary for building kernel modules (and
kernel module packages) against the %build_flavor flavor of the kernel.


%source_timestamp

%if %CONFIG_MODULES == "y"

%pre devel -f devel-pre.sh

%post devel -f devel-post.sh

%files devel -f kernel-devel.files
%defattr(-,root,root)
%dir %obj_install_dir
%dir %obj_install_dir/%cpu_arch
%dir /usr/src/linux-obj
%dir /usr/src/linux-obj/%cpu_arch
%ghost /usr/src/linux-obj/%cpu_arch_flavor
%obj_install_dir/%cpu_arch_flavor
%exclude %obj_install_dir/%cpu_arch_flavor/Symbols.list
%if %kmp_target_cpu != %cpu_arch
%obj_install_dir/%kmp_target_cpu
/usr/src/linux-obj/%kmp_target_cpu
%endif

%if %CONFIG_SUSE_KERNEL_SUPPORTED == "y"
%package livepatch
Summary:        Metapackage to pull in matching kernel-livepatch package
Group:          System/Kernel
Requires:       kernel-livepatch-%(echo %version-%source_rel | sed 'y/\./_/')-%build_flavor
Provides:	kernel-default-kgraft = %version
Provides:	kernel-xen-kgraft = %version
Provides:       multiversion(kernel)
Obsoletes:	kernel-default-kgraft < %version
Obsoletes:	kernel-xen-kgraft < %version

%description livepatch
This is a metapackage that pulls in the matching kernel-livepatch package for a
given kernel version. The advantage of the metapackage is that its name is
static, unlike the kernel-livepatch-<kernel-version>-flavor package names.

%files livepatch
# rpmlint complains about empty packages, so lets own something
%defattr(-, root, root)
%dir /lib/modules/%kernelrelease-%build_flavor
%endif

%if 0%{?klp_symbols}

%package livepatch-devel
Summary:	Kernel symbols file used during livepatch development
Group:		System/Kernel
Provides:	klp-symbols = %version

%description livepatch-devel
This package brings a file named Symbols.list, which contains a list of all
kernel symbols and its respective kernel object . This list is to be used by
the klp-convert tool, which helps livepatch developers by enabling automatic
symbol resolution.

%files livepatch-devel
%defattr(-, root, root)
%dir %obj_install_dir
%dir %obj_install_dir/%cpu_arch
%dir %obj_install_dir/%cpu_arch_flavor/
%obj_install_dir/%cpu_arch_flavor/Symbols.list

%endif

%if %CONFIG_SUSE_KERNEL_SUPPORTED == "y"
%package -n cluster-md-kmp-%build_flavor
Summary:        Clustering support for MD devices
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       cluster-md-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n cluster-md-kmp-%build_flavor
Clustering support for MD devices. This enables locking and
synchronization across multiple systems on the cluster, so all
nodes in the cluster can access the MD devices simultaneously.

%post -n cluster-md-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=cluster-md-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	rpm -ql "$nvr" | INITRD_IN_POSTTRANS=1 /bin/bash -${-/e/} "$wm2" \
	--add-kernel-modules %kernelrelease-%build_flavor
fi

%posttrans -n cluster-md-kmp-%build_flavor
%{?regenerate_initrd_posttrans}

%preun -n cluster-md-kmp-%build_flavor
nvr=cluster-md-kmp-%build_flavor-%version-%release
rpm -ql "$nvr" | grep '\.ko$' > "/var/run/rpm-$nvr-modules"

%postun -n cluster-md-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=cluster-md-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	/bin/bash -${-/e/} "$wm2" < "/var/run/rpm-$nvr-modules" \
	--remove-kernel-modules %kernelrelease-%build_flavor
fi
rm -f "/var/run/rpm-$nvr-modules"

%files -n cluster-md-kmp-%build_flavor -f cluster-md-kmp.files
%defattr(-, root, root)

%package -n dlm-kmp-%build_flavor
Summary:        DLM kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       dlm-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4

%description -n dlm-kmp-%build_flavor
DLM stands for Distributed Lock Manager, a means to synchronize access to
shared resources over the cluster.

%post -n dlm-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=dlm-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	rpm -ql "$nvr" | INITRD_IN_POSTTRANS=1 /bin/bash -${-/e/} "$wm2" \
	--add-kernel-modules %kernelrelease-%build_flavor
fi

%posttrans -n dlm-kmp-%build_flavor
%{?regenerate_initrd_posttrans}

%preun -n dlm-kmp-%build_flavor
nvr=dlm-kmp-%build_flavor-%version-%release
rpm -ql "$nvr" | grep '\.ko$' > "/var/run/rpm-$nvr-modules"

%postun -n dlm-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=dlm-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	/bin/bash -${-/e/} "$wm2" < "/var/run/rpm-$nvr-modules" \
	--remove-kernel-modules %kernelrelease-%build_flavor
fi
rm -f "/var/run/rpm-$nvr-modules"

%files -n dlm-kmp-%build_flavor -f dlm-kmp.files
%defattr(-, root, root)

%package -n gfs2-kmp-%build_flavor
Summary:        GFS2 kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       gfs2-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n gfs2-kmp-%build_flavor
GFS2 is Global Filesystem, a shared device filesystem.

%post -n gfs2-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=gfs2-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	rpm -ql "$nvr" | INITRD_IN_POSTTRANS=1 /bin/bash -${-/e/} "$wm2" \
	--add-kernel-modules %kernelrelease-%build_flavor
fi

%posttrans -n gfs2-kmp-%build_flavor
%{?regenerate_initrd_posttrans}

%preun -n gfs2-kmp-%build_flavor
nvr=gfs2-kmp-%build_flavor-%version-%release
rpm -ql "$nvr" | grep '\.ko$' > "/var/run/rpm-$nvr-modules"

%postun -n gfs2-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=gfs2-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	/bin/bash -${-/e/} "$wm2" < "/var/run/rpm-$nvr-modules" \
	--remove-kernel-modules %kernelrelease-%build_flavor
fi
rm -f "/var/run/rpm-$nvr-modules"

%files -n gfs2-kmp-%build_flavor -f gfs2-kmp.files
%defattr(-, root, root)

%package -n kselftests-kmp-%build_flavor
Summary:        Kernel sefltests
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       kselftests-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4

%description -n kselftests-kmp-%build_flavor
This package contains kernel modules which are part of the upstream kernel
selftest effort. kselftest is the name of the upstream kernel target to build
and run all selftests. You can also run each test individually from the
respective upstream tools/testing/selftests/ directory, this package is
intended to be used using individial upstream selftest scripts given only
select supported selftest drivers are enabled.

It should always be possible to always run the latest linux-next version of the
selftest scripts and tests against any older kernel selftest driver.  Certain
tests facilities may be backported onto older kernels to enable further
testing.

Selftests also provide for a vehicle or proof of concept issues to be
reproduced, verified and corrected.

Selftest drivers are intended to be supported only in testing and QA
environments, they are not intended to be run on production systems.

%post -n kselftests-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=kselftests-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	rpm -ql "$nvr" | INITRD_IN_POSTTRANS=1 /bin/bash -${-/e/} "$wm2" \
	--add-kernel-modules %kernelrelease-%build_flavor
fi

%posttrans -n kselftests-kmp-%build_flavor
%{?regenerate_initrd_posttrans}

%preun -n kselftests-kmp-%build_flavor
nvr=kselftests-kmp-%build_flavor-%version-%release
rpm -ql "$nvr" | grep '\.ko$' > "/var/run/rpm-$nvr-modules"

%postun -n kselftests-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=kselftests-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	/bin/bash -${-/e/} "$wm2" < "/var/run/rpm-$nvr-modules" \
	--remove-kernel-modules %kernelrelease-%build_flavor
fi
rm -f "/var/run/rpm-$nvr-modules"

%files -n kselftests-kmp-%build_flavor -f kselftests-kmp.files
%defattr(-, root, root)

%package -n ocfs2-kmp-%build_flavor
Summary:        OCFS2 kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       ocfs2-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n ocfs2-kmp-%build_flavor
OCFS2 is the Oracle Cluster Filesystem, a filesystem for shared devices
accessible simultaneously from multiple nodes of a cluster.

%post -n ocfs2-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=ocfs2-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	rpm -ql "$nvr" | INITRD_IN_POSTTRANS=1 /bin/bash -${-/e/} "$wm2" \
	--add-kernel-modules %kernelrelease-%build_flavor
fi

%posttrans -n ocfs2-kmp-%build_flavor
%{?regenerate_initrd_posttrans}

%preun -n ocfs2-kmp-%build_flavor
nvr=ocfs2-kmp-%build_flavor-%version-%release
rpm -ql "$nvr" | grep '\.ko$' > "/var/run/rpm-$nvr-modules"

%postun -n ocfs2-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=ocfs2-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	/bin/bash -${-/e/} "$wm2" < "/var/run/rpm-$nvr-modules" \
	--remove-kernel-modules %kernelrelease-%build_flavor
fi
rm -f "/var/run/rpm-$nvr-modules"

%files -n ocfs2-kmp-%build_flavor -f ocfs2-kmp.files
%defattr(-, root, root)

%endif # %CONFIG_SUSE_KERNEL_SUPPORTED
%endif # %CONFIG_MODULES

%changelog
* Wed Mar 27 2019 jslaby@suse.cz
- Linux 5.0.5 (bnc#1012628).
- ALSA: hda - Enforces runtime_resume after S3 and S4 for each
  codec (bnc#1012628).
- ALSA: hda - Record the current power state before suspend/resume
  calls (bnc#1012628).
- locking/lockdep: Add debug_locks check in __lock_downgrade()
  (bnc#1012628).
- x86/unwind: Add hardcoded ORC entry for NULL (bnc#1012628).
- x86/unwind: Handle NULL pointer calls better in frame unwinder
  (bnc#1012628).
- loop: access lo_backing_file only when the loop device is
  Lo_bound (bnc#1012628).
- netfilter: ebtables: remove BUGPRINT messages (bnc#1012628).
- aio: simplify - and fix - fget/fput for io_submit()
  (bnc#1012628).
- f2fs: fix to avoid deadlock of atomic file operations
  (bnc#1012628).
- RDMA/cma: Rollback source IP address if failing to acquire
  device (bnc#1012628).
- drm/vkms: Fix flush_work() without INIT_WORK() (bnc#1012628).
- Bluetooth: hci_ldisc: Postpone HCI_UART_PROTO_READY bit set
  in hci_uart_set_proto() (bnc#1012628).
- Bluetooth: hci_ldisc: Initialize hci_dev before open()
  (bnc#1012628).
- Bluetooth: Fix decrementing reference count twice in releasing
  socket (bnc#1012628).
- Bluetooth: hci_uart: Check if socket buffer is ERR_PTR in
  h4_recv_buf() (bnc#1012628).
- media: v4l2-ctrls.c/uvc: zero v4l2_event (bnc#1012628).
- ext4: brelse all indirect buffer in ext4_ind_remove_space()
  (bnc#1012628).
- ext4: fix data corruption caused by unaligned direct AIO
  (bnc#1012628).
- ext4: fix NULL pointer dereference while journal is aborted
  (bnc#1012628).
- ALSA: ac97: Fix of-node refcount unbalance (bnc#1012628).
- ALSA: hda - Don't trigger jackpoll_work in azx_resume
  (bnc#1012628).
- SMB3: Fix SMB3.1.1 guest mounts to Samba (bnc#1012628).
- clocksource/drivers/riscv: Fix clocksource mask (bnc#1012628).
- irqchip/gic-v3-its: Fix comparison logic in lpi_range_cmp
  (bnc#1012628).
- objtool: Move objtool_file struct off the stack (bnc#1012628).
- perf probe: Fix getting the kernel map (bnc#1012628).
- cifs: allow guest mounts to work for smb3.11 (bnc#1012628).
- futex: Ensure that futex address is aligned in
  handle_futex_death() (bnc#1012628).
- scsi: ibmvscsi: Fix empty event pool access during host removal
  (bnc#1012628).
- scsi: ibmvscsi: Protect ibmvscsi_head from concurrent
  modificaiton (bnc#1012628).
- scsi: qla2xxx: Fix FC-AL connection target discovery
  (bnc#1012628).
- scsi: core: Avoid that a kernel warning appears during system
  resume (bnc#1012628).
- net/mlx5: Fix DCT creation bad flow (bnc#1012628).
- powerpc/security: Fix spectre_v2 reporting (bnc#1012628).
- powerpc/vdso64: Fix CLOCK_MONOTONIC inconsistencies across Y2038
  (bnc#1012628).
- MIPS: Fix kernel crash for R6 in jump label branch function
  (bnc#1012628).
- MIPS: Ensure ELF appended dtb is relocated (bnc#1012628).
- mips: loongson64: lemote-2f: Add IRQF_NO_SUSPEND to "cascade"
  irqaction (bnc#1012628).
- udf: Fix crash on IO error during truncate (bnc#1012628).
- libceph: wait for latest osdmap in ceph_monc_blacklist_add()
  (bnc#1012628).
- iommu/iova: Fix tracking of recently failed iova address
  (bnc#1012628).
- iommu/amd: fix sg->dma_address for sg->offset bigger than
  PAGE_SIZE (bnc#1012628).
- drm/vmwgfx: Return 0 when gmrid::get_node runs out of ID's
  (bnc#1012628).
- drm/vmwgfx: Don't double-free the mode stored in par->set_mode
  (bnc#1012628).
- drm/amdgpu: fix invalid use of change_bit (bnc#1012628).
- mmc: renesas_sdhi: limit block count to 16 bit for old revisions
  (bnc#1012628).
- mmc: mxcmmc: "Revert mmc: mxcmmc: handle highmem pages"
  (bnc#1012628).
- mmc: alcor: fix DMA reads (bnc#1012628).
- mmc: pxamci: fix enum type confusion (bnc#1012628).
- ALSA: firewire-motu: use 'version' field of unit directory to
  identify model (bnc#1012628).
- ALSA: hda - add Lenovo IdeaCentre B550 to the
  power_save_blacklist (bnc#1012628).
- commit 0fb0b14
* Mon Mar 25 2019 jeffm@suse.com
- btrfs: honor path->skip_locking in backref code (bsc#1099312).
- commit 76ff396
* Sun Mar 24 2019 jslaby@suse.cz
- Linux 5.0.4 (bnc#1012628).
- SUNRPC: Respect RPC call timeouts when retrying transmission
  (bnc#1012628).
- SUNRPC: Fix up RPC back channel transmission (bnc#1012628).
- SUNRPC: Prevent thundering herd when the socket is not connected
  (bnc#1012628).
- s390/setup: fix boot crash for machine without EDAT-1
  (bnc#1012628).
- net: dsa: lantiq_gswip: fix OF child-node lookups (bnc#1012628).
- net: dsa: lantiq_gswip: fix use-after-free on failed probe
  (bnc#1012628).
- KVM: nVMX: Check a single byte for VMCS "launched" in nested
  early checks (bnc#1012628).
- KVM: nVMX: Ignore limit checks on VMX instructions using flat
  segments (bnc#1012628).
- KVM: nVMX: Apply addr size mask to effective address for VMX
  instructions (bnc#1012628).
- KVM: nVMX: Sign extend displacements of VMX instr's mem operands
  (bnc#1012628).
- KVM: x86/mmu: Do not cache MMIO accesses while memslots are
  in flux (bnc#1012628).
- KVM: x86/mmu: Detect MMIO generation wrap in any address space
  (bnc#1012628).
- KVM: VMX: Zero out *all* general purpose registers after VM-Exit
  (bnc#1012628).
- KVM: VMX: Compare only a single byte for VMCS' "launched"
  in vCPU-run (bnc#1012628).
- KVM: Call kvm_arch_memslots_updated() before updating memslots
  (bnc#1012628).
- drm/amd/display: don't call dm_pp_ function from an fpu block
  (bnc#1012628).
- drm/amd/powerplay: correct power reading on fiji (bnc#1012628).
- drm/radeon/evergreen_cs: fix missing break in switch statement
  (bnc#1012628).
- drm/fb-helper: generic: Fix drm_fbdev_client_restore()
  (bnc#1012628).
- media: imx: csi: Stop upstream before disabling IDMA channel
  (bnc#1012628).
- media: imx: csi: Disable CSI immediately after last EOF
  (bnc#1012628).
- media: imx-csi: Input connections to CSI should be optional
  (bnc#1012628).
- media: vimc: Add vimc-streamer for stream control (bnc#1012628).
- media: uvcvideo: Avoid NULL pointer dereference at the end of
  streaming (bnc#1012628).
- media: sun6i: Fix CSI regmap's max_register (bnc#1012628).
- media: lgdt330x: fix lock status reporting (bnc#1012628).
- media: imx: prpencvf: Stop upstream before disabling IDMA
  channel (bnc#1012628).
- rcu: Do RCU GP kthread self-wakeup from softirq and interrupt
  (bnc#1012628).
- tpm: Unify the send callback behaviour (bnc#1012628).
- tpm/tpm_crb: Avoid unaligned reads in crb_recv() (bnc#1012628).
- x86/ftrace: Fix warning and considate ftrace_jmp_replace()
  and ftrace_call_replace() (bnc#1012628).
- x86/kvmclock: set offset for kvm unstable clock (bnc#1012628).
- md: Fix failed allocation of md_register_thread (bnc#1012628).
- perf intel-pt: Fix divide by zero when TSC is not available
  (bnc#1012628).
- perf/x86/intel/uncore: Fix client IMC events return huge result
  (bnc#1012628).
- perf intel-pt: Fix overlap calculation for padding
  (bnc#1012628).
- perf auxtrace: Define auxtrace record alignment (bnc#1012628).
- perf tools: Fix split_kallsyms_for_kcore() for trampoline
  symbols (bnc#1012628).
- perf intel-pt: Fix CYC timestamp calculation after OVF
  (bnc#1012628).
- x86/unwind/orc: Fix ORC unwind table alignment (bnc#1012628).
- vt: perform safe console erase in the right order (bnc#1012628).
- stable-kernel-rules.rst: add link to networking patch queue
  (bnc#1012628).
- bcache: use (REQ_META|REQ_PRIO) to indicate bio for metadata
  (bnc#1012628).
- bcache: treat stale && dirty keys as bad keys (bnc#1012628).
- bcache: never writeback a discard operation (bnc#1012628).
- PM / OPP: Update performance state when freq == old_freq
  (bnc#1012628).
- PM / wakeup: Rework wakeup source timer cancellation
  (bnc#1012628).
- svcrpc: fix UDP on servers with lots of threads (bnc#1012628).
- NFSv4.1: Reinitialise sequence results before retransmitting
  a request (bnc#1012628).
- nfsd: fix wrong check in write_v4_end_grace() (bnc#1012628).
- nfsd: fix memory corruption caused by readdir (bnc#1012628).
- nfsd: fix performance-limiting session calculation
  (bnc#1012628).
- NFS: Don't recoalesce on error in nfs_pageio_complete_mirror()
  (bnc#1012628).
- NFS: Fix an I/O request leakage in nfs_do_recoalesce
  (bnc#1012628).
- NFS: Fix I/O request leakages (bnc#1012628).
- cpuidle: governor: Add new governors to cpuidle_governors again
  (bnc#1012628).
- cpcap-charger: generate events for userspace (bnc#1012628).
- mfd: sm501: Fix potential NULL pointer dereference
  (bnc#1012628).
- media: cx25840: mark pad sig_types to fix cx231xx init
  (bnc#1012628).
- dm integrity: limit the rate of error messages (bnc#1012628).
- dm: fix to_sector() for 32bit (bnc#1012628).
- ipmi_si: fix use-after-free of resource->name (bnc#1012628).
- ipmi_si: Fix crash when using hard-coded device (bnc#1012628).
- Revert "KVM/MMU: Flush tlb directly in the kvm_zap_gfn_range()"
  (bnc#1012628).
- arm64: KVM: Fix architecturally invalid reset value for
  FPEXC32_EL2 (bnc#1012628).
- arm64: debug: Ensure debug handlers check triggering exception
  level (bnc#1012628).
- arm64: debug: Don't propagate UNKNOWN FAR into si_code for
  debug signals (bnc#1012628).
- arm64: Fix HCR.TGE status for NMI contexts (bnc#1012628).
- ARM: s3c24xx: Fix boolean expressions in osiris_dvs_notify
  (bnc#1012628).
- powerpc/traps: Fix the message printed when stack overflows
  (bnc#1012628).
- powerpc/traps: fix recoverability of machine check handling
  on book3s/32 (bnc#1012628).
- powerpc/smp: Fix NMI IPI xmon timeout (bnc#1012628).
- powerpc/smp: Fix NMI IPI timeout (bnc#1012628).
- powerpc/hugetlb: Don't do runtime allocation of 16G pages in
  LPAR configuration (bnc#1012628).
- powerpc/ptrace: Simplify vr_get/set() to avoid GCC warning
  (bnc#1012628).
- powerpc: Fix 32-bit KVM-PR lockup and host crash with MacOS
  guest (bnc#1012628).
- powerpc/64s/hash: Fix assert_slb_presence() use of the
  slbfee. instruction (bnc#1012628).
- powerpc/powernv: Don't reprogram SLW image on every KVM guest
  entry/exit (bnc#1012628).
- powerpc/kvm: Save and restore host AMR/IAMR/UAMOR (bnc#1012628).
- powerpc/83xx: Also save/restore SPRG4-7 during suspend
  (bnc#1012628).
- powerpc/powernv: Make opal log only readable by root
  (bnc#1012628).
- powerpc/wii: properly disable use of BATs when requested
  (bnc#1012628).
- powerpc/32: Clear on-stack exception marker upon exception
  return (bnc#1012628).
- security/selinux: fix SECURITY_LSM_NATIVE_LABELS on reused
  superblock (bnc#1012628).
- selinux: add the missing walk_size + len check in
  selinux_sctp_bind_connect (bnc#1012628).
- jbd2: fix compile warning when using JBUFFER_TRACE
  (bnc#1012628).
- jbd2: clear dirty flag when revoking a buffer from an older
  transaction (bnc#1012628).
- serial: 8250_pci: Have ACCES cards that use the four
  port Pericom PI7C9X7954 chip use the pci_pericom_setup()
  (bnc#1012628).
- serial: 8250_pci: Fix number of ports for ACCES serial cards
  (bnc#1012628).
- serial: 8250_of: assume reg-shift of 2 for mrvl,mmp-uart
  (bnc#1012628).
- serial: uartps: Fix stuck ISR if RX disabled with non-empty FIFO
  (bnc#1012628).
- dmaengine: usb-dmac: Make DMAC system sleep callbacks explicit
  (bnc#1012628).
- usb: typec: tps6598x: handle block writes separately with
  plain-I2C adapters (bnc#1012628).
- usb: chipidea: tegra: Fix missed ci_hdrc_remove_device()
  (bnc#1012628).
- clk: ingenic: Fix doc of ingenic_cgu_div_info (bnc#1012628).
- clk: ingenic: Fix round_rate misbehaving with non-integer
  dividers (bnc#1012628).
- clk: samsung: exynos5: Fix kfree() of const memory on setting
  driver_override (bnc#1012628).
- clk: samsung: exynos5: Fix possible NULL pointer exception on
  platform_device_alloc() failure (bnc#1012628).
- clk: clk-twl6040: Fix imprecise external abort for pdmclk
  (bnc#1012628).
- clk: uniphier: Fix update register for CPU-gear (bnc#1012628).
- ext2: Fix underflow in ext2_max_size() (bnc#1012628).
- cxl: Wrap iterations over afu slices inside 'afu_list_lock'
  (bnc#1012628).
- IB/rdmavt: Fix concurrency panics in QP post_send and modify
  to error (bnc#1012628).
- IB/rdmavt: Fix loopback send with invalidate ordering
  (bnc#1012628).
- IB/hfi1: Close race condition on user context disable and close
  (bnc#1012628).
- PCI: pci-bridge-emul: Extend pci_bridge_emul_init() with flags
  (bnc#1012628).
- PCI: pci-bridge-emul: Create per-bridge copy of register
  behavior (bnc#1012628).
- PCI: pciehp: Disable Data Link Layer State Changed event on
  suspend (bnc#1012628).
- PCI: dwc: skip MSI init if MSIs have been explicitly disabled
  (bnc#1012628).
- PCI: qcom: Don't deassert reset GPIO during probe (bnc#1012628).
- PCI/DPC: Fix print AER status in DPC event handling
  (bnc#1012628).
- PCI/ASPM: Use LTR if already enabled by platform (bnc#1012628).
- swiotlb: Add is_swiotlb_active() function (bnc#1012628).
- swiotlb: Introduce swiotlb_max_mapping_size() (bnc#1012628).
- dma: Introduce dma_max_mapping_size() (bnc#1012628).
- ext4: fix crash during online resizing (bnc#1012628).
- ext4: add mask of ext4 flags to swap (bnc#1012628).
- ext4: update quota information while swapping boot loader inode
  (bnc#1012628).
- gpio: pca953x: Fix dereference of irq data in shutdown
  (bnc#1012628).
- media: i2c: ov5640: Fix post-reset delay (bnc#1012628).
- i2c: tegra: update maximum transfer size (bnc#1012628).
- i2c: tegra: fix maximum transfer size (bnc#1012628).
- parport_pc: fix find_superio io compare code, should use equal
  test (bnc#1012628).
- intel_th: Don't reference unassigned outputs (bnc#1012628).
- device property: Fix the length used in PROPERTY_ENTRY_STRING()
  (bnc#1012628).
- nvmem: core: don't check the return value of notifier chain call
  (bnc#1012628).
- kernel/sysctl.c: add missing range check in
  do_proc_dointvec_minmax_conv (bnc#1012628).
- mm/memory.c: do_fault: avoid usage of stale vm_area_struct
  (bnc#1012628).
- mm/vmalloc: fix size check for remap_vmalloc_range_partial()
  (bnc#1012628).
- mm: hwpoison: fix thp split handing in
  soft_offline_in_use_page() (bnc#1012628).
- ext4: cleanup pagecache before swap i_data (bnc#1012628).
- ext4: fix check of inode in swap_inode_boot_loader
  (bnc#1012628).
- cpufreq: pxa2xx: remove incorrect __init annotation
  (bnc#1012628).
- cpufreq: tegra124: add missing of_node_put() (bnc#1012628).
- cpufreq: kryo: Release OPP tables on module removal
  (bnc#1012628).
- x86/kprobes: Prohibit probing on optprobe template code
  (bnc#1012628).
- irqchip/brcmstb-l2: Use _irqsave locking variants in
  non-interrupt code (bnc#1012628).
- irqchip/gic-v3-its: Avoid parsing _indirect_ twice for Device
  table (bnc#1012628).
- libertas_tf: don't set URB_ZERO_PACKET on IN USB transfer
  (bnc#1012628).
- soc: qcom: rpmh: Avoid accessing freed memory from batch API
  (bnc#1012628).
- Btrfs: fix deadlock between clone/dedupe and rename
  (bnc#1012628).
- Btrfs: fix corruption reading shared and compressed extents
  after hole punching (bnc#1012628).
- btrfs: init csum_list before possible free (bnc#1012628).
- btrfs: ensure that a DUP or RAID1 block group has exactly two
  stripes (bnc#1012628).
- btrfs: drop the lock on error in btrfs_dev_replace_cancel
  (bnc#1012628).
- btrfs: scrub: fix circular locking dependency warning
  (bnc#1012628).
- Btrfs: setup a nofs context for memory allocation at
  __btrfs_set_acl (bnc#1012628).
- Btrfs: setup a nofs context for memory allocation at
  btrfs_create_tree() (bnc#1012628).
- m68k: Add -ffreestanding to CFLAGS (bnc#1012628).
- ovl: Do not lose security.capability xattr over metadata file
  copy-up (bnc#1012628).
- ovl: During copy up, first copy up data and then xattrs
  (bnc#1012628).
- splice: don't merge into linked buffers (bnc#1012628).
- fs/devpts: always delete dcache dentry-s in dput()
  (bnc#1012628).
- scsi: qla2xxx: Use complete switch scan for RSCN events
  (bnc#1012628).
- scsi: qla2xxx: Avoid PCI IRQ affinity mapping when multiqueue
  is not supported (bnc#1012628).
- scsi: qla2xxx: Fix LUN discovery if loop id is not assigned
  yet by firmware (bnc#1012628).
- scsi: target/iscsi: Avoid iscsit_release_commands_from_conn()
  deadlock (bnc#1012628).
- scsi: sd: Optimal I/O size should be a multiple of physical
  block size (bnc#1012628).
- scsi: aacraid: Fix performance issue on logical drives
  (bnc#1012628).
- scsi: virtio_scsi: don't send sc payload with tmfs
  (bnc#1012628).
- s390/virtio: handle find on invalid queue gracefully
  (bnc#1012628).
- s390/setup: fix early warning messages (bnc#1012628).
- s390: vfio_ap: link the vfio_ap devices to the vfio_ap bus
  subsystem (bnc#1012628).
- clocksource/drivers/arch_timer: Workaround for Allwinner A64
  timer instability (bnc#1012628).
- Update config files.
  Set SUN50I_ERRATUM_UNKNOWN1=y to stay aligned with the master branch.
- clocksource/drivers/exynos_mct: Clear timer interrupt when
  shutdown (bnc#1012628).
- clocksource/drivers/exynos_mct: Move one-shot check from tick
  clear to ISR (bnc#1012628).
- mt76: fix corrupted software generated tx CCMP PN (bnc#1012628).
- regulator: s2mpa01: Fix step values for some LDOs (bnc#1012628).
- regulator: max77620: Initialize values for DT properties
  (bnc#1012628).
- regulator: s2mps11: Fix steps for buck7, buck8 and LDO35
  (bnc#1012628).
- spi: spi-gpio: fix SPI_CS_HIGH capability (bnc#1012628).
- spi: omap2-mcspi: Fix DMA and FIFO event trigger size mismatch
  (bnc#1012628).
- spi: pxa2xx: Setup maximum supported DMA transfer length
  (bnc#1012628).
- spi: ti-qspi: Fix mmap read when more than one CS in use
  (bnc#1012628).
- mmc:fix a bug when max_discard is 0 (bnc#1012628).
- mmc: renesas_sdhi: Fix card initialization failure in high
  speed mode (bnc#1012628).
- mmc: sdhci-esdhc-imx: fix HS400 timing issue (bnc#1012628).
- ACPI / device_sysfs: Avoid OF modalias creation for removed
  device (bnc#1012628).
- xen: fix dom0 boot on huge systems (bnc#1012628).
- vmw_balloon: release lock on error in vmballoon_reset()
  (bnc#1012628).
- tracing/perf: Use strndup_user() instead of buggy open-coded
  version (bnc#1012628).
- tracing: Do not free iter->trace in fail path of
  tracing_open_pipe() (bnc#1012628).
- tracing: Use strncpy instead of memcpy for string keys in hist
  triggers (bnc#1012628).
- smb3: make default i/o size for smb3 mounts larger
  (bnc#1012628).
- CIFS: Fix read after write for files with read caching
  (bnc#1012628).
- CIFS: Do not skip SMB2 message IDs on send failures
  (bnc#1012628).
- CIFS: Do not reset lease state to NONE on lease break
  (bnc#1012628).
- CIFS: Fix leaking locked VFS cache pages in writeback retry
  (bnc#1012628).
- crypto: arm64/aes-ccm - fix bugs in non-NEON fallback routine
  (bnc#1012628).
- crypto: arm64/aes-ccm - fix logical bug in AAD MAC handling
  (bnc#1012628).
- crypto: x86/morus - fix handling chunked inputs and MAY_SLEEP
  (bnc#1012628).
- crypto: x86/aesni-gcm - fix crash on empty plaintext
  (bnc#1012628).
- crypto: x86/aegis - fix handling chunked inputs and MAY_SLEEP
  (bnc#1012628).
- crypto: testmgr - skip crc32c context test for ahash algorithms
  (bnc#1012628).
- crypto: skcipher - set CRYPTO_TFM_NEED_KEY if ->setkey() fails
  (bnc#1012628).
- crypto: pcbc - remove bogus memcpy()s with src == dest
  (bnc#1012628).
- crypto: morus - fix handling chunked inputs (bnc#1012628).
- crypto: hash - set CRYPTO_TFM_NEED_KEY if ->setkey() fails
  (bnc#1012628).
- crypto: arm64/crct10dif - revert to C code for short inputs
  (bnc#1012628).
- crypto: arm64/aes-neonbs - fix returning final keystream block
  (bnc#1012628).
- crypto: arm/crct10dif - revert to C code for short inputs
  (bnc#1012628).
- crypto: aegis - fix handling chunked inputs (bnc#1012628).
- crypto: aead - set CRYPTO_TFM_NEED_KEY if ->setkey() fails
  (bnc#1012628).
- fix cgroup_do_mount() handling of failure exits (bnc#1012628).
- libnvdimm: Fix altmap reservation size calculation
  (bnc#1012628).
- libnvdimm/pmem: Honor force_raw for legacy pmem regions
  (bnc#1012628).
- libnvdimm, pfn: Fix over-trim in trim_pfn_device()
  (bnc#1012628).
- libnvdimm/label: Clear 'updating' flag after label-set update
  (bnc#1012628).
- nfit/ars: Attempt short-ARS even in the no_init_ars case
  (bnc#1012628).
- nfit/ars: Attempt a short-ARS whenever the ARS state is idle
  at boot (bnc#1012628).
- acpi/nfit: Fix bus command validation (bnc#1012628).
- nfit: acpi_nfit_ctl(): Check out_obj->type in the right place
  (bnc#1012628).
- nfit: Fix nfit_intel_shutdown_status() command submission
  (bnc#1012628).
- dax: Flush partial PMDs correctly (bnc#1012628).
- crypto: rockchip - update new iv to device in multiple
  operations (bnc#1012628).
- crypto: rockchip - fix scatterlist nents error (bnc#1012628).
- crypto: ahash - fix another early termination in hash walk
  (bnc#1012628).
- crypto: ofb - fix handling partial blocks and make thread-safe
  (bnc#1012628).
- crypto: cfb - remove bogus memcpy() with src == dest
  (bnc#1012628).
- crypto: cfb - add missing 'chunksize' property (bnc#1012628).
- crypto: ccree - don't copy zero size ciphertext (bnc#1012628).
- crypto: ccree - unmap buffer before copying IV (bnc#1012628).
- crypto: ccree - fix free of unallocated mlli buffer
  (bnc#1012628).
- crypto: caam - fix DMA mapping of stack memory (bnc#1012628).
- crypto: caam - fixed handling of sg list (bnc#1012628).
- crypto: ccree - fix missing break in switch statement
  (bnc#1012628).
- crypto: caam - fix hash context DMA unmap size (bnc#1012628).
- stm class: Fix an endless loop in channel allocation
  (bnc#1012628).
- stm class: Prevent division by zero (bnc#1012628).
- mei: bus: move hw module get/put to probe/release (bnc#1012628).
- mei: hbm: clean the feature flags on link reset (bnc#1012628).
- iio: adc: exynos-adc: Use proper number of channels for
  Exynos4x12 (bnc#1012628).
- iio: adc: exynos-adc: Fix NULL pointer exception on unbind
  (bnc#1012628).
- ASoC: codecs: pcm186x: Fix energysense SLEEP bit (bnc#1012628).
- ASoC: codecs: pcm186x: fix wrong usage of DECLARE_TLV_DB_SCALE()
  (bnc#1012628).
- ASoC: fsl_esai: fix register setting issue in RIGHT_J mode
  (bnc#1012628).
- 9p/net: fix memory leak in p9_client_create (bnc#1012628).
- 9p: use inode->i_lock to protect i_size_write() under 32-bit
  (bnc#1012628).
- commit c52890c
* Fri Mar 22 2019 msuchanek@suse.de
- Do not provide kernel-default-srchash from kernel-default-base.
- commit d6c71ce
* Wed Mar 20 2019 msuchanek@suse.de
- rpm/kernel-subpackage-build: handle arm kernel zImage.
- commit 81a63c3
* Wed Mar 20 2019 jslaby@suse.cz
- config: disable IMA_ARCH_POLICY for now
  When IMA_ARCH_POLICY was enabled during the 5.0-rc* stage, IMA causes
  kdump load to fail:
  kexec_file_load failed: Permission denied
  ima: impossible to appraise a kernel image without a file descriptor; try using kexec_file_load syscall.
  We have to fix kexec tooling before enabling IMA for everyone.
  BTW IMA_APPRAISE_BOOTPARAM was disabled by IMA_ARCH_POLICY=y. So
  restore the original state (and functionality).
- commit 3fe0cfc
* Wed Mar 20 2019 tiwai@suse.de
- rpm/kernel-source.changes.old: Really drop old changelogs (bsc#1098995)
- commit 9e463cf
* Tue Mar 19 2019 msuchanek@suse.de
- config: disable BPFILTER_UMH on arm (bsc#1127188).
- commit a705565
* Tue Mar 19 2019 jslaby@suse.cz
- Linux 5.0.3 (bnc#1012628).
- drm: Block fb changes for async plane updates (bnc#1012628).
- It's wrong to add len to sector_nr in raid10 reshape twice
  (bnc#1012628).
- perf/x86/intel: Make dev_attr_allow_tsx_force_abort static
  (bnc#1012628).
- perf/x86/intel: Fix memory corruption (bnc#1012628).
- ALSA: hda/realtek: Enable headset MIC of Acer TravelMate
  X514-51T with ALC255 (bnc#1012628).
- ALSA: hda/realtek - Reduce click noise on Dell Precision 5820
  headphone (bnc#1012628).
- ALSA: hda/realtek: Enable audio jacks of ASUS UX362FA with
  ALC294 (bnc#1012628).
- ALSA: hda - add more quirks for HP Z2 G4 and HP Z240
  (bnc#1012628).
- ALSA: hda: Extend i915 component bind timeout (bnc#1012628).
- ALSA: firewire-motu: fix construction of PCM frame for capture
  direction (bnc#1012628).
- ALSA: bebob: use more identical mod_alias for Saffire Pro 10
  I/O against Liquid Saffire 56 (bnc#1012628).
- perf/x86: Fixup typo in stub functions (bnc#1012628).
- f2fs: wait on atomic writes to count F2FS_CP_WB_DATA
  (bnc#1012628).
- net: sched: flower: insert new filter to idr after setting
  its mask (bnc#1012628).
- vsock/virtio: fix kernel panic from
  virtio_transport_reset_no_sock (bnc#1012628).
- net: hns3: fix to stop multiple HNS reset due to the AER changes
  (bnc#1012628).
- net: dsa: mv88e6xxx: Set correct interface mode for CPU/DSA
  ports (bnc#1012628).
- net/mlx4_core: Fix qp mtt size calculation (bnc#1012628).
- net/mlx4_core: Fix locking in SRIOV mode when switching between
  events and polling (bnc#1012628).
- net/mlx4_core: Fix reset flow when in command polling mode
  (bnc#1012628).
- vxlan: test dev->flags & IFF_UP before calling
  gro_cells_receive() (bnc#1012628).
- vxlan: Fix GRO cells race condition between receive and link
  delete (bnc#1012628).
- tcp: handle inet_csk_reqsk_queue_add() failures (bnc#1012628).
- tcp: Don't access TCP_SKB_CB before initializing it
  (bnc#1012628).
- tcp: do not report TCP_CM_INQ of 0 for closed connections
  (bnc#1012628).
- sctp: remove sched init from sctp_stream_init (bnc#1012628).
- rxrpc: Fix client call queueing, waiting for channel
  (bnc#1012628).
- route: set the deleted fnhe fnhe_daddr to 0 in ip_del_fnhe to
  fix a race (bnc#1012628).
- ravb: Decrease TxFIFO depth of Q3 and Q2 to one (bnc#1012628).
- pptp: dst_release sk_dst_cache in pptp_sock_destruct
  (bnc#1012628).
- net/x25: reset state in x25_connect() (bnc#1012628).
- net/x25: fix use-after-free in x25_device_event() (bnc#1012628).
- net: sit: fix UBSAN Undefined behaviour in check_6rd
  (bnc#1012628).
- net/hsr: fix possible crash in add_timer() (bnc#1012628).
- net: hsr: fix memory leak in hsr_dev_finalize() (bnc#1012628).
- net: hns3: add dma_rmb() for rx description (bnc#1012628).
- lan743x: Fix TX Stall Issue (bnc#1012628).
- lan743x: Fix RX Kernel Panic (bnc#1012628).
- l2tp: fix infoleak in l2tp_ip6_recvmsg() (bnc#1012628).
- ipv4/route: fail early when inet dev is missing (bnc#1012628).
- gro_cells: make sure device is up in gro_cells_receive()
  (bnc#1012628).
- fou, fou6: avoid uninit-value in gue_err() and gue6_err()
  (bnc#1012628).
- connector: fix unsafe usage of ->real_parent (bnc#1012628).
- commit 843d1cc
* Tue Mar 19 2019 yousaf.kaukab@suse.com
- config: armv6hl: Update to v5.0.2
- commit a2d3030
* Tue Mar 19 2019 yousaf.kaukab@suse.com
- config: armv7hl: Update to v5.0.2
- commit 70aaed6
* Mon Mar 18 2019 msuchanek@suse.de
- Trim build dependencies of sample subpackage spec file (FATE#326579,
  jsc#SLE-4117, jsc#SLE-3853, bsc#1128910).
- commit 2eae420
* Mon Mar 18 2019 jslaby@suse.cz
- cifs: Fix NULL pointer dereference of devname (bnc#1129519).
- commit 018878b
* Sun Mar 17 2019 mkubecek@suse.cz
- config: enable RANDOM_TRUST_CPU
  The outcome from mailing list discussion when this config option
  appeared was that it makes more sense to enable it by default and let
  those who do not trust their CPU override it on command line; but then
  I forgot to actually change the value.
- commit 138b5df
* Fri Mar 15 2019 tiwai@suse.de
- Update config files: disable CONFIG_FRAMEBUFFER_CONSOLE_DEFERRED_TAKEOVER (bsc#1127552)
  The deferred fbcon takeover makes little sense with the current openSUSE
  boot setup, and it's harmful (more glitches, etc).  Disable it for now.
- commit 14fa903
* Fri Mar 15 2019 msuchanek@suse.de
- Remove the previous subpackage infrastructure.
  This partially reverts commit 9b3ca32c11854156b2f950ff5e26131377d8445e
  ("Add kernel-subpackage-build.spec (FATE#326579).")
- commit a5ee24e
* Fri Mar 15 2019 msuchanek@suse.de
- Add sample kernel-default-base spec file (FATE#326579, jsc#SLE-4117,
  jsc#SLE-3853, bsc#1128910).
- commit 35c4a52
* Thu Mar 14 2019 msuchanek@suse.de
- Install extra rpm scripts for kernel subpackaging (FATE#326579,
  jsc#SLE-4117, jsc#SLE-3853, bsc#1128910).
- commit ad7c227
* Thu Mar 14 2019 jslaby@suse.cz
- Linux 5.0.2 (bnc#1012628).
- perf/x86/intel: Implement support for TSX Force Abort
  (bnc#1012628).
- x86: Add TSX Force Abort CPUID/MSR (bnc#1012628).
- perf/x86/intel: Generalize dynamic constraint creation
  (bnc#1012628).
- perf/x86/intel: Make cpuc allocations consistent (bnc#1012628).
- ath9k: Avoid OF no-EEPROM quirks without qca,no-eeprom
  (bnc#1012628).
- scripts/gdb: replace flags (MS_xyz -> SB_xyz) (bnc#1012628).
- staging: erofs: compressed_pages should not be accessed again
  after freed (bnc#1012628).
- staging: erofs: keep corrupted fs from crashing kernel in
  erofs_namei() (bnc#1012628).
- gfs2: Fix missed wakeups in find_insert_glock (bnc#1012628).
- bpf: Stop the psock parser before canceling its work
  (bnc#1012628).
- Revert "PCI/PME: Implement runtime PM callbacks" (bnc#1012628).
- media: Revert "media: rc: some events are dropped by userspace"
  (bnc#1012628).
- drm: disable uncached DMA optimization for ARM and arm64
  (bnc#1012628).
- ARM: dts: exynos: Fix max voltage for buck8 regulator on Odroid
  XU3/XU4 (bnc#1012628).
- ARM: dts: exynos: Add minimal clkout parameters to Exynos3250
  PMU (bnc#1012628).
- ARM: dts: exynos: Fix pinctrl definition for eMMC RTSN line
  on Odroid X2/U3 (bnc#1012628).
- arm64: dts: hikey: Revert "Enable HS200 mode on eMMC"
  (bnc#1012628).
- arm64: dts: hikey: Give wifi some time after power-on
  (bnc#1012628).
- arm64: dts: zcu100-revC: Give wifi some time after power-on
  (bnc#1012628).
- x86/PCI: Fixup RTIT_BAR of Intel Denverton Trace Hub
  (bnc#1012628).
- scsi: aacraid: Fix missing break in switch statement
  (bnc#1012628).
- iscsi_ibft: Fix missing break in switch statement (bnc#1012628).
- Input: elan_i2c - add id for touchpad found in Lenovo s21e-20
  (bnc#1012628).
- Input: wacom_serial4 - add support for Wacom ArtPad II tablet
  (bnc#1012628).
- media: uvcvideo: Fix 'type' check leading to overflow
  (bnc#1012628).
- commit 815c1bc
* Mon Mar 11 2019 mkubecek@suse.cz
- Update patches.suse/0001-media-usb-pwc-Don-t-use-coherent-DMA-buffers-for-ISO.patch
  upstream reference.
- commit ff7c8cd
* Sun Mar 10 2019 jslaby@suse.cz
- Linux 5.0.1 (bnc#1012628).
- exec: Fix mem leak in kernel_read_file (bnc#1012628).
- Bluetooth: Fix locking in bt_accept_enqueue() for BH context
  (bnc#1012628).
- Bluetooth: btrtl: Restore old logic to assume firmware is
  already loaded (bnc#1012628).
- selftests: firmware: fix verify_reqs() return value
  (bnc#1012628).
- Revert "selftests: firmware: remove use of non-standard diff
  - Z option" (bnc#1012628).
- Revert "selftests: firmware: add
  CONFIG_FW_LOADER_USER_HELPER_FALLBACK to config" (bnc#1012628).
- USB: serial: cp210x: fix GPIO in autosuspend (bnc#1012628).
- gnss: sirf: fix premature wakeup interrupt enable (bnc#1012628).
- xtensa: fix get_wchan (bnc#1012628).
- aio: Fix locking in aio_poll() (bnc#1012628).
- MIPS: irq: Allocate accurate order pages for irq stack
  (bnc#1012628).
- alpha: wire up io_pgetevents system call (bnc#1012628).
- applicom: Fix potential Spectre v1 vulnerabilities
  (bnc#1012628).
- usb: xhci: Fix for Enabling USB ROLE SWITCH QUIRK on
  INTEL_SUNRISEPOINT_LP_XHCI (bnc#1012628).
- xhci: tegra: Prevent error pointer dereference (bnc#1012628).
- tracing: Fix event filters and triggers to handle negative
  numbers (bnc#1012628).
- x86/boot/compressed/64: Do not read legacy ROM on EFI system
  (bnc#1012628).
- x86/CPU/AMD: Set the CPB bit unconditionally on F17h
  (bnc#1012628).
- tipc: fix RDM/DGRAM connect() regression (bnc#1012628).
- team: Free BPF filter when unregistering netdev (bnc#1012628).
- sky2: Disable MSI on Dell Inspiron 1545 and Gateway P-79
  (bnc#1012628).
- sctp: call iov_iter_revert() after sending ABORT (bnc#1012628).
- qmi_wwan: Add support for Quectel EG12/EM12 (bnc#1012628).
- net-sysfs: Fix mem leak in netdev_register_kobject
  (bnc#1012628).
- net: sched: put back q.qlen into a single location
  (bnc#1012628).
- net: mscc: Enable all ports in QSGMII (bnc#1012628).
- net: dsa: mv8e6xxx: fix number of internal PHYs for 88E6x90
  family (bnc#1012628).
- net: dsa: mv88e6xxx: handle unknown duplex modes gracefully
  in mv88e6xxx_port_set_duplex (bnc#1012628).
- net: dsa: mv88e6xxx: add call to mv88e6xxx_ports_cmode_init
  to probe for new DSA framework (bnc#1012628).
- ip6mr: Do not call __IP6_INC_STATS() from preemptible context
  (bnc#1012628).
- staging: android: ashmem: Avoid range_alloc() allocation with
  ashmem_mutex held (bnc#1012628).
- staging: android: ashmem: Don't call fallocate() with
  ashmem_mutex held (bnc#1012628).
- staging: android: ion: fix sys heap pool's gfp_flags
  (bnc#1012628).
- staging: wilc1000: fix to set correct value for 'vif_num'
  (bnc#1012628).
- staging: comedi: ni_660x: fix missing break in switch statement
  (bnc#1012628).
- staging: erofs: fix illegal address access under memory pressure
  (bnc#1012628).
- staging: erofs: fix race of initializing xattrs of a inode at
  the same time (bnc#1012628).
- staging: erofs: fix memleak of inode's shared xattr array
  (bnc#1012628).
- staging: erofs: fix fast symlink w/o xattr when fs xattr is on
  (bnc#1012628).
- driver core: Postpone DMA tear-down until after devres release
  (bnc#1012628).
- USB: serial: ftdi_sio: add ID for Hjelmslund Electronics USB485
  (bnc#1012628).
- USB: serial: cp210x: add ID for Ingenico 3070 (bnc#1012628).
- USB: serial: option: add Telit ME910 ECM composition
  (bnc#1012628).
- binder: create node flag to request sender's security context
  (bnc#1012628).
- staging: erofs: fix mis-acted TAIL merging behavior
  (bnc#1012628).
- cpufreq: Use struct kobj_attribute instead of struct global_attr
  (bnc#1012628).
- commit 47a2a02
* Thu Mar  7 2019 msuchanek@suse.de
- KMPs: provide and conflict a kernel version specific KMP name
  (bsc#1127155, bsc#1109137).
- commit 5568093
* Wed Mar  6 2019 msuchanek@suse.de
- Revert "Drop multiversion(kernel) from the KMP template (fate#323189)"
  (bsc#1109137).
  This reverts commit 71504d805c1340f68715ad41958e5ef35da2c351.
- commit adade9f
* Tue Mar  5 2019 mkubecek@suse.cz
- config: disable BPFILTER_UMH on non-x86 architectures (bsc#1127188)
  CONFIG_BPFILTER_UMH depends on ability to compile and link a userspace
  binary so that it currently doesn't work in our kbuild check setups using
  a cross compiler. Disable the option on architectures where cross compiler
  is used (i.e. all except x86_64 and i386).
- commit cfb8371
* Mon Mar  4 2019 msuchanek@suse.de
- KMPs: obsolete older KMPs of the same flavour (bsc#1127155, bsc#1109137).
- commit 821419f
* Mon Mar  4 2019 mkubecek@suse.cz
- Update to 5.0 final
- Refresh configs
- commit 8f71df2
* Wed Feb 27 2019 jslaby@suse.cz
- Linux 4.20.13 (bnc#1012628).
- net: phylink: avoid resolving link state too early
  (bnc#1012628).
- pinctrl: max77620: Use define directive for
  max77620_pinconf_param values (bnc#1012628).
- netfilter: ipt_CLUSTERIP: fix sleep-in-atomic bug in
  clusterip_config_entry_put() (bnc#1012628).
- netfilter: nfnetlink_osf: add missing fmatch check
  (bnc#1012628).
- netfilter: ipv6: Don't preserve original oif for loopback
  address (bnc#1012628).
- netfilter: nft_compat: use-after-free when deleting targets
  (bnc#1012628).
- netfilter: nf_tables: fix flush after rule deletion in the
  same batch (bnc#1012628).
- Revert "bridge: do not add port to router list when receives
  query with source 0.0.0.0" (bnc#1012628).
- staging: erofs: unzip_vle_lz4.c,utils.c: rectify BUG_ONs
  (bnc#1012628).
- staging: erofs: unzip_{pagevec.h,vle.c}: rectify BUG_ONs
  (bnc#1012628).
- staging: erofs: {dir,inode,super}.c: rectify BUG_ONs
  (bnc#1012628).
- staging: erofs: add a full barrier in erofs_workgroup_unfreeze
  (bnc#1012628).
- staging: erofs: fix `erofs_workgroup_{try_to_freeze, unfreeze}'
  (bnc#1012628).
- staging: erofs: atomic_cond_read_relaxed on ref-locked workgroup
  (bnc#1012628).
- staging: erofs: remove the redundant d_rehash() for the root
  dentry (bnc#1012628).
- net: avoid false positives in untrusted gso validation
  (bnc#1012628).
- net: validate untrusted gso packets without csum offload
  (bnc#1012628).
- ASoC: soc-core: fix init platform memory handling (bnc#1012628).
- s390: vsie: Use effective CRYCBD.31 to check CRYCBD validity
  (bnc#1012628).
- kvm: x86: Return LA57 feature based on hardware capability
  (bnc#1012628).
- x86/kvm/mmu: fix switch between root and guest MMUs
  (bnc#1012628).
- KVM: MMU: record maximum physical address width in
  kvm_mmu_extended_role (bnc#1012628).
- mac80211: allocate tailroom for forwarded mesh packets
  (bnc#1012628).
- mac80211: Change default tx_sk_pacing_shift to 7 (bnc#1012628).
- drm/amd/display: Fix MST reboot/poweroff sequence (bnc#1012628).
- drm/amdgpu: disable bulk moves for now (bnc#1012628).
- drm/i915/fbdev: Actually configure untiled displays
  (bnc#1012628).
- gpu: drm: radeon: Set DPM_FLAG_NEVER_SKIP when enabling
  PM-runtime (bnc#1012628).
- drm/amdgpu: Set DPM_FLAG_NEVER_SKIP when enabling PM-runtime
  (bnc#1012628).
- cpufreq: scmi: Fix use-after-free in scmi_cpufreq_exit()
  (bnc#1012628).
- ARC: define ARCH_SLAB_MINALIGN = 8 (bnc#1012628).
- ARC: U-boot: check arguments paranoidly (bnc#1012628).
- ARCv2: Enable unaligned access in early ASM code (bnc#1012628).
- parisc: Fix ptrace syscall number modification (bnc#1012628).
- clk: at91: fix at91sam9x5 peripheral clock number (bnc#1012628).
- clk: at91: fix masterck name (bnc#1012628).
- KEYS: always initialize keyring_index_key::desc_len
  (bnc#1012628).
- KEYS: user: Align the payload buffer (bnc#1012628).
- RDMA/srp: Rework SCSI device reset handling (bnc#1012628).
- scsi: sd_zbc: Fix sd_zbc_report_zones() buffer allocation
  (bnc#1012628).
- net/mlx5e: XDP, fix redirect resources availability check
  (bnc#1012628).
- net/mlx5e: FPGA, fix Innova IPsec TX offload data path
  performance (bnc#1012628).
- net_sched: fix two more memory leaks in cls_tcindex
  (bnc#1012628).
- net_sched: fix a memory leak in cls_tcindex (bnc#1012628).
- net_sched: fix a race condition in tcindex_destroy()
  (bnc#1012628).
- sit: check if IPv6 enabled before calling
  ip6_err_gen_icmpv6_unreach() (bnc#1012628).
- geneve: should not call rt6_lookup() when ipv6 was disabled
  (bnc#1012628).
- net: socket: make bond ioctls go through compat_ifreq_ioctl()
  (bnc#1012628).
- net: socket: fix SIOCGIFNAME in compat (bnc#1012628).
- Revert "kill dev_ifsioc()" (bnc#1012628).
- Revert "socket: fix struct ifreq size in compat ioctl"
  (bnc#1012628).
- net: dsa: Fix NPD checking for br_vlan_enabled() (bnc#1012628).
- team: avoid complex list operations in team_nl_cmd_options_set()
  (bnc#1012628).
- sctp: set stream ext to NULL after freeing it in
  sctp_stream_outq_migrate (bnc#1012628).
- sctp: call gso_reset_checksum when computing checksum in
  sctp_gso_segment (bnc#1012628).
- net: sfp: do not probe SFP module before we're attached
  (bnc#1012628).
- net/packet: fix 4gb buffer limit due to overflow check
  (bnc#1012628).
- net/mlx5e: Don't overwrite pedit action when multiple pedit used
  (bnc#1012628).
- net/mlx4_en: Force CHECKSUM_NONE for short ethernet frames
  (bnc#1012628).
- net: ena: fix race between link up and device initalization
  (bnc#1012628).
- ipv6: propagate genlmsg_reply return code (bnc#1012628).
- inet_diag: fix reporting cgroup classid and fallback to priority
  (bnc#1012628).
- batman-adv: fix uninit-value in batadv_interface_tx()
  (bnc#1012628).
- isdn: avm: Fix string plus integer warning from Clang
  (bnc#1012628).
- net/mlx5e: Fix wrong (zero) TX drop counter indication for
  representor (bnc#1012628).
- bpf: pull in pkt_sched.h header for tooling to fix bpftool build
  (bnc#1012628).
- selftests: forwarding: Add a test case for externally learned
  FDB entries (bnc#1012628).
- mlxsw: spectrum_switchdev: Do not treat static FDB entries as
  sticky (bnc#1012628).
- net: bridge: Mark FDB entries that were added by user as such
  (bnc#1012628).
- mlxsw: pci: Return error on PCI reset timeout (bnc#1012628).
- dpaa_eth: NETIF_F_LLTX requires to do our own update of
  trans_start (bnc#1012628).
- bpf: fix SO_MAX_PACING_RATE to support TCP internal pacing
  (bnc#1012628).
- bpf: bpf_setsockopt: reset sock dst on SO_MARK changes
  (bnc#1012628).
- leds: lp5523: fix a missing check of return value of lp55xx_read
  (bnc#1012628).
- hwmon: (tmp421) Correct the misspelling of the tmp442 compatible
  attribute in OF device ID table (bnc#1012628).
- atm: he: fix sign-extension overflow on large shift
  (bnc#1012628).
- selftests/bpf: retry tests that expect build-id (bnc#1012628).
- bpf: zero out build_id for BPF_STACK_BUILD_ID_IP (bnc#1012628).
- bpf: don't assume build-id length is always 20 bytes
  (bnc#1012628).
- afs: Fix race in async call refcounting (bnc#1012628).
- afs: Provide a function to get a ref on a call (bnc#1012628).
- afs: Fix key refcounting in file locking code (bnc#1012628).
- afs: Don't set vnode->cb_s_break in afs_validate()
  (bnc#1012628).
- selftests: tc-testing: fix parsing of ife type (bnc#1012628).
- selftests: tc-testing: fix tunnel_key failure if dst_port is
  unspecified (bnc#1012628).
- selftests: tc-testing: drop test on missing tunnel key id
  (bnc#1012628).
- net: phy: micrel: set soft_reset callback to genphy_soft_reset
  for KSZ9031 (bnc#1012628).
- ACPI: EC: Look for ECDT EC after calling acpi_load_tables()
  (bnc#1012628).
- pvcalls-front: fix potential null dereference (bnc#1012628).
- drm/sun4i: backend: add missing of_node_puts (bnc#1012628).
- SUNRPC: Ensure we respect the RPCSEC_GSS sequence number limit
  (bnc#1012628).
- SUNRPC: Ensure rq_bytes_sent is reset before request
  transmission (bnc#1012628).
- samples/bpf: workaround clang asm goto compilation errors
  (bnc#1012628).
- selftests/bpf: install with_tunnels.sh for
  test_flow_dissector.sh (bnc#1012628).
- xsk: Check if a queue exists during umem setup (bnc#1012628).
- vhost/scsi: Use copy_to_iter() to send control queue response
  (bnc#1012628).
- vhost: return EINVAL if iovecs size does not match the message
  size (bnc#1012628).
- drm/amd/display: fix PME notification not working in RV desktop
  (bnc#1012628).
- drm/amdkfd: Don't assign dGPUs to APU topology devices
  (bnc#1012628).
- drm/meson: add missing of_node_put (bnc#1012628).
- always clear the X2APIC_ENABLE bit for PV guest (bnc#1012628).
- netfilter: nft_flow_offload: fix checking method of conntrack
  helper (bnc#1012628).
- scsi: cxgb4i: add wait_for_completion() (bnc#1012628).
- scsi: qla1280: set 64bit coherent mask (bnc#1012628).
- scsi: ufs: Fix geometry descriptor size (bnc#1012628).
- scsi: qedi: Add ep_state for login completion on un-reachable
  targets (bnc#1012628).
- scsi: ufs: Fix system suspend status (bnc#1012628).
- scsi: tcmu: avoid cmd/qfull timers updated whenever a new cmd
  comes (bnc#1012628).
- isdn: i4l: isdn_tty: Fix some concurrency double-free bugs
  (bnc#1012628).
- net: stmmac: Prevent RX starvation in stmmac_napi_poll()
  (bnc#1012628).
- net: stmmac: Fix the logic of checking if RX Watchdog must be
  enabled (bnc#1012628).
- net: stmmac: Check if CBS is supported before configuring
  (bnc#1012628).
- net: stmmac: dwxgmac2: Only clear interrupts that are active
  (bnc#1012628).
- net: stmmac: Fix PCI module removal leak (bnc#1012628).
- acpi/nfit: Fix race accessing memdev in nfit_get_smbios_id()
  (bnc#1012628).
- powerpc/8xx: fix setting of pagetable for Abatron BDI debug tool
  (bnc#1012628).
- RDMA/mthca: Clear QP objects during their allocation
  (bnc#1012628).
- netfilter: nft_flow_offload: fix interaction with vrf slave
  device (bnc#1012628).
- afs: Set correct lock type for the yfs CreateFile (bnc#1012628).
- bpf: fix panic in stack_map_get_build_id() on i386 and arm32
  (bnc#1012628).
- selftests: bpf: install files tcp_(server|client)*.py
  (bnc#1012628).
- pvcalls-front: Avoid get_free_pages(GFP_KERNEL) under spinlock
  (bnc#1012628).
- bpf: correctly set initial window on active Fast Open sender
  (bnc#1012628).
- netfilter: nft_flow_offload: Fix reverse route lookup
  (bnc#1012628).
- MIPS: jazz: fix 64bit build (bnc#1012628).
- include/linux/compiler*.h: fix OPTIMIZER_HIDE_VAR (bnc#1012628).
- scsi: isci: initialize shost fully before calling
  scsi_add_host() (bnc#1012628).
- scsi: qla4xxx: check return code of
  qla4xxx_copy_from_fwddb_param (bnc#1012628).
- netfilter: nf_tables: fix leaking object reference count
  (bnc#1012628).
- selftests: forwarding: Add a test for VLAN deletion
  (bnc#1012628).
- mlxsw: spectrum: Add VXLAN dependency for spectrum
  (bnc#1012628).
- mlxsw: spectrum_acl: Add cleanup after C-TCAM update error
  condition (bnc#1012628).
- xprtrdma: Double free in rpcrdma_sendctxs_create()
  (bnc#1012628).
- MIPS: ath79: Enable OF serial ports in the default config
  (bnc#1012628).
- net/mlx4: Get rid of page operation after dma_alloc_coherent
  (bnc#1012628).
- watchdog: mt7621_wdt/rt2880_wdt: Fix compilation problem
  (bnc#1012628).
- hwmon: (nct6775) Enable IO mapping for NCT6797D and NCT6798D
  (bnc#1012628).
- hwmon: (nct6775) Fix chip ID for NCT6798D (bnc#1012628).
- selftests/bpf: Test [::] -> [::1] rewrite in sys_sendmsg in
  test_sock_addr (bnc#1012628).
- bpf: Fix [::] -> [::1] rewrite in sys_sendmsg (bnc#1012628).
- selftests: net: fix/improve ip_defrag selftest (bnc#1012628).
- net: hns: Fix use after free identified by SLUB debug
  (bnc#1012628).
- qed: Fix qed_ll2_post_rx_buffer_notify_fw() by adding a write
  memory barrier (bnc#1012628).
- qed: Fix qed_chain_set_prod() for PBL chains with non power
  of 2 page count (bnc#1012628).
- soc/fsl/qe: fix err handling of ucc_of_parse_tdm (bnc#1012628).
- xen/pvcalls: remove set but not used variable 'intf'
  (bnc#1012628).
- mfd: mc13xxx: Fix a missing check of a register-read failure
  (bnc#1012628).
- mfd: tps65218: Use devm_regmap_add_irq_chip and clean up error
  path in probe() (bnc#1012628).
- mfd: cros_ec_dev: Add missing mfd_remove_devices() call in
  remove (bnc#1012628).
- mfd: axp20x: Add supported cells for AXP803 (bnc#1012628).
- mfd: axp20x: Re-align MFD cell entries (bnc#1012628).
- mfd: axp20x: Add AC power supply cell for AXP813 (bnc#1012628).
- mfd: wm5110: Add missing ASRC rate register (bnc#1012628).
- mfd: qcom_rpm: write fw_version to CTRL_REG (bnc#1012628).
- mfd: at91-usart: Add platform dependency (bnc#1012628).
- mfd: bd9571mwv: Add volatile register to make DVFS work
  (bnc#1012628).
- mfd: ab8500-core: Return zero in get_register_interruptible()
  (bnc#1012628).
- mfd: mt6397: Do not call irq_domain_remove if PMIC unsupported
  (bnc#1012628).
- mfd: db8500-prcmu: Fix some section annotations (bnc#1012628).
- mfd: twl-core: Fix section annotations on {,un}protect_pm_master
  (bnc#1012628).
- pvcalls-back: set -ENOTCONN in pvcalls_conn_back_read
  (bnc#1012628).
- pvcalls-front: properly allocate sk (bnc#1012628).
- pvcalls-front: don't try to free unallocated rings
  (bnc#1012628).
- pvcalls-front: read all data before closing the connection
  (bnc#1012628).
- mfd: ti_am335x_tscadc: Use PLATFORM_DEVID_AUTO while registering
  mfd cells (bnc#1012628).
- backlight: pwm_bl: Fix devicetree parsing with auto-generated
  brightness tables (bnc#1012628).
- KEYS: allow reaching the keys quotas exactly (bnc#1012628).
- ALSA: hda/realtek: Disable PC beep in passthrough on alc285
  (bnc#1012628).
- ALSA: hda/realtek - Headset microphone and internal speaker
  support for System76 oryp5 (bnc#1012628).
- proc, oom: do not report alien mms when setting oom_score_adj
  (bnc#1012628).
- numa: change get_mempolicy() to use nr_node_ids instead of
  MAX_NUMNODES (bnc#1012628).
- ceph: avoid repeatedly adding inode to mdsc->snap_flush_list
  (bnc#1012628).
- libceph: handle an empty authorize reply (bnc#1012628).
- pinctrl: qcom: qcs404: Correct SDC tile (bnc#1012628).
- mac80211: Free mpath object when rhashtable insertion fails
  (bnc#1012628).
- mac80211: Use linked list instead of rhashtable walk for mesh
  tables (bnc#1012628).
- mac80211: Restore vif beacon interval if start ap fails
  (bnc#1012628).
- gpio: pxa: avoid attempting to set pin direction via pinctrl
  on MMP2 (bnc#1012628).
- gpio: MT7621: use a per instance irq_chip structure
  (bnc#1012628).
- mt76x0u: fix suspend/resume (bnc#1012628).
- MIPS: eBPF: Always return sign extended 32b values
  (bnc#1012628).
- tracing: Fix number of entries in trace header (bnc#1012628).
- kprobe: Do not use uaccess functions to access kernel memory
  that can fault (bnc#1012628).
- ARM: 8834/1: Fix: kprobes: optimized kprobes illegal instruction
  (bnc#1012628).
- commit fb7c4a5
* Wed Feb 27 2019 msuchanek@suse.de
- BPF: UMH: do not detect if compiler can link userspace program
  (boo#1127188).
- commit 66e5d0a
* Mon Feb 25 2019 mkubecek@suse.cz
- Update to 5.0-rc8
- Eliminated 1 patch
- commit 4ddf057
* Sat Feb 23 2019 jslaby@suse.cz
- Linux 4.20.12 (bnc#1012628).
- dsa: mv88e6xxx: Ensure all pending interrupts are handled
  prior to exit (bnc#1012628).
- net: fix IPv6 prefix route residue (bnc#1012628).
- net: ipv4: use a dedicated counter for icmp_v4 redirect packets
  (bnc#1012628).
- vsock: cope with memory allocation failure at socket creation
  time (bnc#1012628).
- vxlan: test dev->flags & IFF_UP before calling netif_rx()
  (bnc#1012628).
- mlxsw: __mlxsw_sp_port_headroom_set(): Fix a use of local
  variable (bnc#1012628).
- net: Fix for_each_netdev_feature on Big endian (bnc#1012628).
- net: ip6_gre: initialize erspan_ver just for erspan tunnels
  (bnc#1012628).
- net: phy: xgmiitorgmii: Support generic PHY status read
  (bnc#1012628).
- net: stmmac: Fix a race in EEE enable callback (bnc#1012628).
- net: stmmac: handle endianness in dwmac4_get_timestamp
  (bnc#1012628).
- sky2: Increase D3 delay again (bnc#1012628).
- vhost: correctly check the return value of translate_desc()
  in log_used() (bnc#1012628).
- net: Add header for usage of fls64() (bnc#1012628).
- tcp: clear icsk_backoff in tcp_write_queue_purge()
  (bnc#1012628).
- tcp: tcp_v4_err() should be more careful (bnc#1012628).
- net: netcp: Fix ethss driver probe issue (bnc#1012628).
- net: Do not allocate page fragments that are not skb aligned
  (bnc#1012628).
- af_packet: fix raw sockets over 6in4 tunnel (bnc#1012628).
- arm64, mm, efi: Account for GICv3 LPI tables in static memblock
  reserve table (bnc#1012628).
- efi/arm: Revert "Defer persistent reservations until after
  paging_init()" (bnc#1012628).
- PCI: Fix __initdata issue with "pci=disable_acs_redir" parameter
  (bnc#1012628).
- scsi: target/core: Use kmem_cache_free() instead of kfree()
  (bnc#1012628).
- mmc: meson-gx: fix interrupt name (bnc#1012628).
- hwmon: (lm80) Fix missing unlock on error in set_fan_div()
  (bnc#1012628).
- netfilter: nf_nat_snmp_basic: add missing length checks in
  ASN.1 cbs (bnc#1012628).
- net/x25: do not hold the cpu too long in x25_new_lci()
  (bnc#1012628).
- mISDN: fix a race in dev_expire_timer() (bnc#1012628).
- ax25: fix possible use-after-free (bnc#1012628).
- commit b35c1fc
* Fri Feb 22 2019 mkubecek@suse.cz
- net: crypto set sk to NULL when af_alg_release (CVE-2019-8912
  bsc#1125907).
- commit e1b5b1f
* Fri Feb 22 2019 mkubecek@suse.cz
- net: crypto set sk to NULL when af_alg_release (CVE-2019-8912
  bsc#1125907).
- commit 3aed52e
* Fri Feb 22 2019 mkubecek@suse.cz
- config: enable PREEMPT_VOLUNTARY (bsc#1125004)
  Switch to PREEMPT_VOLUNTARY everywhere except s390x/zfcpdump.
  [js] switch also armv7hl. armv6hl seems to have PREEMPT=n.
- config: enable PREEMPT_VOLUNTARY (bsc#1125004)
  Switch to PREEMPT_VOLUNTARY everywhere except s390x/zfcpdump.
- commit 5cf91fd
* Wed Feb 20 2019 jslaby@suse.cz
- Linux 4.20.11 (bnc#1012628).
- dt-bindings: eeprom: at24: add "atmel,24c2048" compatible string
  (bnc#1012628).
- eeprom: at24: add support for 24c2048 (bnc#1012628).
- blk-mq: fix a hung issue when fsync (bnc#1012628).
- drm/amdgpu/sriov:Correct pfvf exchange logic (bnc#1012628).
- ACPI: NUMA: Use correct type for printing addresses on i386-PAE
  (bnc#1012628).
- perf stat: Fix endless wait for child process (bnc#1012628).
- perf report: Fix wrong iteration count in --branch-history
  (bnc#1012628).
- perf test shell: Use a fallback to get the pathname in
  vfs_getname (bnc#1012628).
- soc: renesas: r8a774c0-sysc: Fix initialization order of
  3DG-{A,B} (bnc#1012628).
- tools uapi: fix RISC-V 64-bit support (bnc#1012628).
- riscv: fix trace_sys_exit hook (bnc#1012628).
- cpufreq: check if policy is inactive early in __cpufreq_get()
  (bnc#1012628).
- csky: fixup relocation error with 807 & 860 (bnc#1012628).
- csky: fixup CACHEV1 store instruction fast retire (bnc#1012628).
- irqchip/csky: fixup handle_irq_perbit break irq (bnc#1012628).
- drm/amd/powerplay: avoid possible buffer overflow (bnc#1012628).
- drm/bridge: tc358767: add bus flags (bnc#1012628).
- drm/bridge: tc358767: add defines for DP1_SRCCTRL & PHY_2LANE
  (bnc#1012628).
- drm/bridge: tc358767: fix single lane configuration
  (bnc#1012628).
- drm/bridge: tc358767: fix initial DP0/1_SRCCTRL value
  (bnc#1012628).
- drm/bridge: tc358767: reject modes which require too much BW
  (bnc#1012628).
- drm/bridge: tc358767: fix output H/V syncs (bnc#1012628).
- nvme-pci: use the same attributes when freeing
  host_mem_desc_bufs (bnc#1012628).
- nvme-pci: fix out of bounds access in nvme_cqe_pending
  (bnc#1012628).
- nvme-multipath: zero out ANA log buffer (bnc#1012628).
- nvme: pad fake subsys NQN vid and ssvid with zeros
  (bnc#1012628).
- nvme: introduce NVME_QUIRK_IGNORE_DEV_SUBNQN (bnc#1012628).
- drm/amdgpu: fix CPDMA hang in PRT mode for VEGA20 (bnc#1012628).
- drm/amdgpu: set WRITE_BURST_LENGTH to 64B to workaround SDMA1
  hang (bnc#1012628).
- drm/amdgpu: disable system memory page tables for now
  (bnc#1012628).
- ARM: dts: da850-evm: Correct the audio codec regulators
  (bnc#1012628).
- ARM: dts: da850-evm: Correct the sound card name (bnc#1012628).
- ARM: dts: da850-lcdk: Correct the audio codec regulators
  (bnc#1012628).
- ARM: dts: da850-lcdk: Correct the sound card name (bnc#1012628).
- ARM: dts: kirkwood: Fix polarity of GPIO fan lines
  (bnc#1012628).
- csky: fixup compile error with CPU 810 (bnc#1012628).
- gpio: pl061: handle failed allocations (bnc#1012628).
- drm/nouveau: Don't disable polling in fallback mode
  (bnc#1012628).
- drm/nouveau/falcon: avoid touching registers if engine is off
  (bnc#1012628).
- cifs: Limit memory used by lock request calls to a page
  (bnc#1012628).
- CIFS: Fix credits calculation for cancelled requests
  (bnc#1012628).
- CIFS: Move credit processing to mid callbacks for SMB3
  (bnc#1012628).
- CIFS: Fix error paths in writeback code (bnc#1012628).
- kvm: sev: Fail KVM_SEV_INIT if already initialized
  (bnc#1012628).
- CIFS: Fix credit calculations in compound mid callback
  (bnc#1012628).
- CIFS: Do not assume one credit for async responses
  (bnc#1012628).
- CIFS: Fix mounts if the client is low on credits (bnc#1012628).
- gpio: mxc: move gpio noirq suspend/resume to syscore phase
  (bnc#1012628).
- Revert "Input: elan_i2c - add ACPI ID for touchpad in ASUS
  Aspire F5-573G" (bnc#1012628).
- Input: elan_i2c - add ACPI ID for touchpad in Lenovo V330-15ISK
  (bnc#1012628).
- arm64: dts: rockchip: enable usb-host regulators at boot on
  rk3328-rock64 (bnc#1012628).
- ARM: OMAP5+: Fix inverted nirq pin interrupts with irq_set_type
  (bnc#1012628).
- perf/core: Fix impossible ring-buffer sizes warning
  (bnc#1012628).
- perf/x86: Add check_period PMU callback (bnc#1012628).
- ALSA: hda - Add quirk for HP EliteBook 840 G5 (bnc#1012628).
- ALSA: usb-audio: Fix implicit fb endpoint setup by quirk
  (bnc#1012628).
- ALSA: pcm: Revert capture stream behavior change in blocking
  mode (bnc#1012628).
- ASoC: hdmi-codec: fix oops on re-probe (bnc#1012628).
- tools uapi: fix Alpha support (bnc#1012628).
- riscv: Add pte bit to distinguish swap from invalid
  (bnc#1012628).
- x86/kvm/nVMX: read from MSR_IA32_VMX_PROCBASED_CTLS2 only when
  it is available (bnc#1012628).
- kvm: vmx: Fix entry number check for add_atomic_switch_msr()
  (bnc#1012628).
- mmc: sunxi: Disable HS-DDR mode for H5 eMMC controller by
  default (bnc#1012628).
- mmc: sunxi: Filter out unsupported modes declared in the device
  tree (bnc#1012628).
- mmc: block: handle complete_work on separate workqueue
  (bnc#1012628).
- Input: bma150 - register input device after setting private data
  (bnc#1012628).
- Input: elantech - enable 3rd button support on Fujitsu CELSIUS
  H780 (bnc#1012628).
- Revert "nfsd4: return default lease period" (bnc#1012628).
- Revert "mm: don't reclaim inodes with many attached pages"
  (bnc#1012628).
- Revert "mm: slowly shrink slabs with a relatively small number
  of objects" (bnc#1012628).
- mm: proc: smaps_rollup: fix pss_locked calculation
  (bnc#1012628).
- alpha: fix page fault handling for r16-r18 targets
  (bnc#1012628).
- alpha: Fix Eiger NR_IRQS to 128 (bnc#1012628).
- s390/suspend: fix stack setup in swsusp_arch_suspend
  (bnc#1012628).
- s390/zcrypt: fix specification exception on z196 during ap probe
  (bnc#1012628).
- tracing: probeevent: Correctly update remaining space in
  dynamic area (bnc#1012628).
- x86/platform/UV: Use efi_runtime_lock to serialise BIOS calls
  (bnc#1012628).
- powerpc/64s: Fix possible corruption on big endian due to
  pgd/pud_present() (bnc#1012628).
- scsi: sd: fix entropy gathering for most rotational disks
  (bnc#1012628).
- crypto: ccree - fix resume race condition on init (bnc#1012628).
- md/raid1: don't clear bitmap bits on interrupted recovery
  (bnc#1012628).
- x86/a.out: Clear the dump structure initially (bnc#1012628).
- sunrpc: fix 4 more call sites that were using stack memory
  with a scatterlist (bnc#1012628).
- dm crypt: don't overallocate the integrity tag space
  (bnc#1012628).
- dm thin: fix bug where bio that overwrites thin block ignores
  FUA (bnc#1012628).
- drm: Use array_size() when creating lease (bnc#1012628).
- drm/vkms: Fix license inconsistent (bnc#1012628).
- drm/sched: Always trace the dependencies we wait on, to fix
  a race (bnc#1012628).
- drm/i915: Block fbdev HPD processing during suspend
  (bnc#1012628).
- drm/i915: Prevent a race during I915_GEM_MMAP ioctl with WC set
  (bnc#1012628).
- commit eba2b68
* Tue Feb 19 2019 mbenes@suse.cz
- rpm/klp-symbols: Remove the second column in Symbols.list
  Symbols.list file contains also a symbol type next to its name.
  klp-convert cannot handle it well and it is superfluous anyway.
- commit 62a0a00
* Tue Feb 19 2019 jslaby@suse.cz
- signal: Restore the stop PTRACE_EVENT_EXIT (strace
  threads-execve regression).
- Delete
  patches.suse/revert-signal-Always-notice-exiting-tasks.patch.
- commit 8c9f09c
* Tue Feb 19 2019 jslaby@suse.cz
- Revert "signal: Always notice exiting tasks" (strace
  threads-execve regression).
- commit 08d0345
* Mon Feb 18 2019 mkubecek@suse.cz
- Update to 5.0-rc7
- commit b094e66
* Fri Feb 15 2019 jslaby@suse.cz
- Revert "exec: load_script: don't blindly truncate shebang
  string" (bnc#1012628).
- Linux 4.20.10 (bnc#1012628).
- Delete
  patches.suse/Revert-exec-load_script-don-t-blindly-truncate-sheba.patch.
- commit 4c06520
* Fri Feb 15 2019 jslaby@suse.cz
- Linux 4.20.9 (bnc#1012628).
- batman-adv: Force mac header to start of data on xmit
  (bnc#1012628).
- batman-adv: Avoid WARN on net_device without parent in netns
  (bnc#1012628).
- xfrm: refine validation of template and selector families
  (bnc#1012628).
- libceph: avoid KEEPALIVE_PENDING races in ceph_con_keepalive()
  (bnc#1012628).
- Revert "ext4: use ext4_write_inode() when fsyncing w/o a
  journal" (bnc#1012628).
- drm/i915: Try to sanitize bogus DPLL state left over by broken
  SNB BIOSen (bnc#1012628).
- xfrm: Make set-mark default behavior backward compatible
  (bnc#1012628).
- drm/vmwgfx: Return error code from vmw_execbuf_copy_fence_user
  (bnc#1012628).
- drm/vmwgfx: Fix an uninitialized fence handle value
  (bnc#1012628).
- drm/vmwgfx: Fix setting of dma masks (bnc#1012628).
- drm/i915: always return something on DDI clock selection
  (bnc#1012628).
- drm/amd/powerplay: Fix missing break in switch (bnc#1012628).
- drm/rockchip: rgb: update SPDX license identifier (bnc#1012628).
- drm/modes: Prevent division by zero htotal (bnc#1012628).
- mac80211: ensure that mgmt tx skbs have tailroom for encryption
  (bnc#1012628).
- mic: vop: Fix use-after-free on remove (bnc#1012628).
- powerpc/radix: Fix kernel crash with mremap() (bnc#1012628).
- powerpc/papr_scm: Use the correct bind address (bnc#1012628).
- firmware: arm_scmi: provide the mandatory device release
  callback (bnc#1012628).
- ARM: dts: da850: fix interrupt numbers for clocksource
  (bnc#1012628).
- ARM: tango: Improve ARCH_MULTIPLATFORM compatibility
  (bnc#1012628).
- ARM: iop32x/n2100: fix PCI IRQ mapping (bnc#1012628).
- MIPS: VDSO: Include $(ccflags-vdso) in o32,n32 .lds builds
  (bnc#1012628).
- mips: loongson64: remove unreachable(), fix loongson_poweroff()
  (bnc#1012628).
- MIPS: VDSO: Use same -m%%-float cflag as the kernel proper
  (bnc#1012628).
- MIPS: OCTEON: don't set octeon_dma_bar_type if PCI is disabled
  (bnc#1012628).
- MIPS: Use lower case for addresses in nexys4ddr.dts
  (bnc#1012628).
- mips: cm: reprime error cause (bnc#1012628).
- tracing: uprobes: Fix typo in pr_fmt string (bnc#1012628).
- tracing/uprobes: Fix output for multiple string arguments
  (bnc#1012628).
- pinctrl: cherryview: fix Strago DMI workaround (bnc#1012628).
- pinctrl: sunxi: Correct number of IRQ banks on H6 main pin
  controller (bnc#1012628).
- svcrdma: Remove max_sge check at connect time (bnc#1012628).
- debugfs: fix debugfs_rename parameter checking (bnc#1012628).
- samples: mei: use /dev/mei0 instead of /dev/mei (bnc#1012628).
- mei: me: add ice lake point device id (bnc#1012628).
- cfg80211: call disconnect_wk when AP stops (bnc#1012628).
- misc: vexpress: Off by one in vexpress_syscfg_exec()
  (bnc#1012628).
- signal: Better detection of synchronous signals (bnc#1012628).
- signal: Always notice exiting tasks (bnc#1012628).
- signal: Always attempt to allocate siginfo for SIGSTOP
  (bnc#1012628).
- iio: ti-ads8688: Update buffer allocation for timestamps
  (bnc#1012628).
- iio: chemical: atlas-ph-sensor: correct IIO_TEMP values to
  millicelsius (bnc#1012628).
- iio: adc: axp288: Fix TS-pin handling (bnc#1012628).
- tools: iio: iio_generic_buffer: make num_loops signed
  (bnc#1012628).
- libata: Add NOLPM quirk for SAMSUNG MZ7TE512HMHP-000L1 SSD
  (bnc#1012628).
- mtd: rawnand: gpmi: fix MX28 bus master lockup problem
  (bnc#1012628).
- mtd: spinand: Fix the error/cleanup path in spinand_init()
  (bnc#1012628).
- mtd: spinand: Handle the case where PROGRAM LOAD does not
  reset the cache (bnc#1012628).
- mtd: Make sure mtd->erasesize is valid even if the partition
  is of size 0 (bnc#1012628).
- commit 54de81d
* Fri Feb 15 2019 jslaby@suse.cz
- Revert "exec: load_script: don't blindly truncate shebang
  string" (shebang regression).
- commit c99a06a
* Wed Feb 13 2019 jslaby@suse.cz
- Update config files.
  Fix armv6 build, set USB_ROLE_SWITCH=m.
- commit cc8092a
* Tue Feb 12 2019 jslaby@suse.cz
- Linux 4.20.8 (bnc#1012628).
- ath9k: dynack: check da->enabled first in sampling routines
  (bnc#1012628).
- ath9k: dynack: make ewma estimation faster (bnc#1012628).
- nfsd: Fix error return values for nfsd4_clone_file_range()
  (bnc#1012628).
- cacheinfo: Keep the old value if of_property_read_u32 fails
  (bnc#1012628).
- serial: sh-sci: Do not free irqs that have already been freed
  (bnc#1012628).
- serial: 8250_pci: Make PCI class test non fatal (bnc#1012628).
- serial: fix race between flush_to_ldisc and tty_open
  (bnc#1012628).
- perf tests evsel-tp-sched: Fix bitwise operator (bnc#1012628).
- perf/core: Don't WARN() for impossible ring-buffer sizes
  (bnc#1012628).
- x86/MCE: Initialize mce.bank in the case of a fatal error in
  mce_no_way_out() (bnc#1012628).
- perf/x86/intel: Delay memory deallocation until
  x86_pmu_dead_cpu() (bnc#1012628).
- perf/x86/intel/uncore: Add Node ID mask (bnc#1012628).
- cpu/hotplug: Fix "SMT disabled by BIOS" detection for KVM
  (bnc#1012628).
- KVM: nVMX: unconditionally cancel preemption timer in
  free_nested (CVE-2019-7221) (bnc#1012628).
- kvm: fix kvm_ioctl_create_device() reference counting
  (CVE-2019-6974) (bnc#1012628).
- KVM: x86: work around leak of uninitialized stack contents
  (CVE-2019-7222) (bnc#1012628).
- scsi: aic94xx: fix module loading (bnc#1012628).
- scsi: cxlflash: Prevent deadlock when adapter probe fails
  (bnc#1012628).
- scsi: sd_zbc: Fix zone information messages (bnc#1012628).
- staging: speakup: fix tty-operation NULL derefs (bnc#1012628).
- usb: gadget: musb: fix short isoc packets with inventra dma
  (bnc#1012628).
- usb: gadget: udc: net2272: Fix bitwise and boolean operations
  (bnc#1012628).
- usb: dwc3: gadget: Handle 0 xfer length for OUT EP
  (bnc#1012628).
- usb: phy: am335x: fix race condition in _probe (bnc#1012628).
- arm64: dts: allwinner: a64: Fix USB OTG regulator (bnc#1012628).
- irqchip/gic-v3-its: Plug allocation race for devices sharing
  a DevID (bnc#1012628).
- futex: Handle early deadlock return correctly (bnc#1012628).
- dmaengine: imx-dma: fix wrong callback invoke (bnc#1012628).
- dmaengine: bcm2835: Fix abort of transactions (bnc#1012628).
- dmaengine: bcm2835: Fix interrupt race on RT (bnc#1012628).
- HID: debug: fix the ring buffer implementation (bnc#1012628).
- cuse: fix ioctl (bnc#1012628).
- fuse: handle zero sized retrieve correctly (bnc#1012628).
- fuse: decrement NR_WRITEBACK_TEMP on the right page
  (bnc#1012628).
- fuse: call pipe_buf_release() under pipe lock (bnc#1012628).
- ALSA: hda/realtek - Headset microphone support for System76
  darp5 (bnc#1012628).
- ALSA: hda/realtek - Use a common helper for hp pin reference
  (bnc#1012628).
- ALSA: hda/realtek - Fix lose hp_pins for disable auto mute
  (bnc#1012628).
- ALSA: hda - Serialize codec registrations (bnc#1012628).
- ALSA: usb-audio: Add support for new T+A USB DAC (bnc#1012628).
- ALSA: compress: Fix stop handling on compressed capture streams
  (bnc#1012628).
- xfs: eof trim writeback mapping as soon as it is cached
  (bnc#1012628).
- net/mlx5e: Force CHECKSUM_UNNECESSARY for short ethernet frames
  (bnc#1012628).
- net/mlx5e: Use the inner headers to determine tc/pedit offload
  limitation on decap flows (bnc#1012628).
- net: dsa: b53: Fix for failure when irq is not defined in dt
  (bnc#1012628).
- net: cls_flower: Remove filter from mask before freeing it
  (bnc#1012628).
- bnxt_en: Disable interrupts when allocating CP rings or NQs
  (bnc#1012628).
- virtio_net: Account for tx bytes and packets on sending
  xdp_frames (bnc#1012628).
- skge: potential memory corruption in skge_get_regs()
  (bnc#1012628).
- sctp: walk the list of asoc safely (bnc#1012628).
- sctp: check and update stream->out_curr when allocating
  stream_out (bnc#1012628).
- rxrpc: bad unlock balance in rxrpc_recvmsg (bnc#1012628).
- Revert "net: phy: marvell: avoid pause mode on SGMII-to-Copper
  for 88e151x" (bnc#1012628).
- rds: fix refcount bug in rds_sock_addref (bnc#1012628).
- net: systemport: Fix WoL with password after deep sleep
  (bnc#1012628).
- net: dsa: slave: Don't propagate flag changes on down slave
  interfaces (bnc#1012628).
- net: dsa: mv88e6xxx: Fix counting of ATU violations
  (bnc#1012628).
- net: dsa: Fix NULL checking in dsa_slave_set_eee()
  (bnc#1012628).
- net: dsa: Fix lockdep false positive splat (bnc#1012628).
- net: dp83640: expire old TX-skb (bnc#1012628).
- lib/test_rhashtable: Make test_insert_dup() allocate its hash
  table dynamically (bnc#1012628).
- enic: fix checksum validation for IPv6 (bnc#1012628).
- dccp: fool proof ccid_hc_[rt]x_parse_options() (bnc#1012628).
- thermal: hwmon: inline helpers when CONFIG_THERMAL_HWMON is
  not set (bnc#1012628).
- xprtrdma: Don't wake pending tasks until disconnect is done
  (bnc#1012628).
- scripts/gdb: fix lx-version string output (bnc#1012628).
- kernel/kcov.c: mark write_comp_data() as notrace (bnc#1012628).
- exec: load_script: don't blindly truncate shebang string
  (bnc#1012628).
- fs/epoll: drop ovflist branch prediction (bnc#1012628).
- kernel/hung_task.c: force console verbose before panic
  (bnc#1012628).
- proc/sysctl: fix return error for proc_doulongvec_minmax()
  (bnc#1012628).
- kernel/hung_task.c: break RCU locks based on jiffies
  (bnc#1012628).
- arm64/sve: ptrace: Fix SVE_PT_REGS_OFFSET definition
  (bnc#1012628).
- HID: lenovo: Add checks to fix of_led_classdev_register
  (bnc#1012628).
- thermal: generic-adc: Fix adc to temp interpolation
  (bnc#1012628).
- block/swim3: Fix regression on PowerBook G3 (bnc#1012628).
- PCI: imx: Enable MSI from downstream components (bnc#1012628).
- thermal: tsens: qcom: do not create duplicate regmap debugfs
  entries (bnc#1012628).
- kdb: Don't back trace on a cpu that didn't round up
  (bnc#1012628).
- thermal: bcm2835: enable hwmon explicitly (bnc#1012628).
- block/swim3: Fix -EBUSY error when re-opening device after
  unmount (bnc#1012628).
- fsl/fman: Use GFP_ATOMIC in {memac,tgec}_add_hash_mac_address()
  (bnc#1012628).
- gdrom: fix a memory leak bug (bnc#1012628).
- isdn: hisax: hfc_pci: Fix a possible concurrency use-after-free
  bug in HFCPCI_l1hw() (bnc#1012628).
- zram: fix lockdep warning of free block handling (bnc#1012628).
- mm/page_alloc.c: don't call kasan_free_pages() at deferred
  mem init (bnc#1012628).
- ocfs2: improve ocfs2 Makefile (bnc#1012628).
- ocfs2: don't clear bh uptodate for block read (bnc#1012628).
- arch/sh/boards/mach-kfr2r09/setup.c: fix struct mtd_oob_ops
  build warning (bnc#1012628).
- scripts/decode_stacktrace: only strip base path when a prefix
  of the path (bnc#1012628).
- perf python: Do not force closing original perf descriptor in
  evlist.get_pollfd() (bnc#1012628).
- cgroup: fix parsing empty mount option string (bnc#1012628).
- f2fs: fix sbi->extent_list corruption issue (bnc#1012628).
- niu: fix missing checks of niu_pci_eeprom_read (bnc#1012628).
- um: Avoid marking pages with "changed protection" (bnc#1012628).
- f2fs: fix use-after-free issue when accessing sbi->stat_info
  (bnc#1012628).
- cifs: check ntwrk_buf_start for NULL before dereferencing it
  (bnc#1012628).
- MIPS: ralink: Select CONFIG_CPU_MIPSR2_IRQ_VI on MT7620/8
  (bnc#1012628).
- crypto: ux500 - Use proper enum in hash_set_dma_transfer
  (bnc#1012628).
- crypto: ux500 - Use proper enum in cryp_set_dma_transfer
  (bnc#1012628).
- seq_buf: Make seq_buf_puts() null-terminate the buffer
  (bnc#1012628).
- hwmon: (lm80) fix a missing check of bus read in lm80 probe
  (bnc#1012628).
- hwmon: (lm80) fix a missing check of the status of SMBus read
  (bnc#1012628).
- perf build: Don't unconditionally link the libbfd feature test
  to -liberty and -lz (bnc#1012628).
- NFS: nfs_compare_mount_options always compare auth flavors
  (bnc#1012628).
- kvm: Change offset in kvm_write_guest_offset_cached to unsigned
  (bnc#1012628).
- selftests: kvm: report failed stage when exit reason is
  unexpected (bnc#1012628).
- powerpc/fadump: Do not allow hot-remove memory from fadump
  reserved area (bnc#1012628).
- KVM: x86: svm: report MSR_IA32_MCG_EXT_CTL as unsupported
  (bnc#1012628).
- pinctrl: meson: meson8b: fix the GPIO function for the GPIOAO
  pins (bnc#1012628).
- pinctrl: meson: meson8: fix the GPIO function for the GPIOAO
  pins (bnc#1012628).
- bpf: sk_msg, fix socket data_ready events (bnc#1012628).
- powerpc/mm: Fix reporting of kernel execute faults on the 8xx
  (bnc#1012628).
- bpf: sk_msg, zap ingress queue on psock down (bnc#1012628).
- fbdev: fbcon: Fix unregister crash when more than one
  framebuffer (bnc#1012628).
- ACPI/APEI: Clear GHES block_status before panic() (bnc#1012628).
- igb: Fix an issue that PME is not enabled during runtime suspend
  (bnc#1012628).
- ice: Do not enable NAPI on q_vectors that have no rings
  (bnc#1012628).
- i40e: define proper net_device::neigh_priv_len (bnc#1012628).
- fbdev: fbmem: behave better with small rotated displays and
  many CPUs (bnc#1012628).
- md: fix raid10 hang issue caused by barrier (bnc#1012628).
- video: clps711x-fb: release disp device node in probe()
  (bnc#1012628).
- drm/amd/display: validate extended dongle caps (bnc#1012628).
- ath10k: fix tx_stats memory leak (bnc#1012628).
- ath10k: fix kernel panic due to use after free (bnc#1012628).
- drbd: Avoid Clang warning about pointless switch statment
  (bnc#1012628).
- drbd: skip spurious timeout (ping-timeo) when failing promote
  (bnc#1012628).
- drbd: disconnect, if the wrong UUIDs are attached on a connected
  peer (bnc#1012628).
- drbd: narrow rcu_read_lock in drbd_sync_handshake (bnc#1012628).
- mlx5: update timecounter at least twice per counter overflow
  (bnc#1012628).
- powerpc/powernv/ioda: Allocate indirect TCE levels of cached
  userspace addresses on demand (bnc#1012628).
- iwlwifi: mvm: fix setting HE ppe FW config (bnc#1012628).
- powerpc/perf: Fix thresholding counter data for unknown type
  (bnc#1012628).
- net: hns3: don't restore rules when flow director is disabled
  (bnc#1012628).
- net: hns3: fix the descriptor index when get rss type
  (bnc#1012628).
- net: hns3: add max vector number check for pf (bnc#1012628).
- cw1200: Fix concurrency use-after-free bugs in cw1200_hw_scan()
  (bnc#1012628).
- scsi: smartpqi: increase fw status register read timeout
  (bnc#1012628).
- scsi: smartpqi: correct volume status (bnc#1012628).
- scsi: smartpqi: correct host serial num for ssa (bnc#1012628).
- mlxsw: spectrum: Properly cleanup LAG uppers when removing
  port from LAG (bnc#1012628).
- xfrm6_tunnel: Fix spi check in __xfrm6_tunnel_alloc_spi
  (bnc#1012628).
- mac80211: fix radiotap vendor presence bitmap handling
  (bnc#1012628).
- powerpc/uaccess: fix warning/error with access_ok()
  (bnc#1012628).
- drm/amd/display: fix YCbCr420 blank color (bnc#1012628).
- Bluetooth: hci_bcm: Handle deferred probing for the clock supply
  (bnc#1012628).
- drm/amd/display: Wait edp HPD to high in detect_sink
  (bnc#1012628).
- drm/amd/display: Add retry to read ddc_clock pin (bnc#1012628).
- net: hns3: fix incomplete uninitialization of IRQ in the
  hns3_nic_uninit_vector_data() (bnc#1012628).
- net: hns3: fix error handling int the hns3_get_vector_ring_chain
  (bnc#1012628).
- percpu: convert spin_lock_irq to spin_lock_irqsave
  (bnc#1012628).
- perf tools: Cast off_t to s64 to avoid warning on bionic libc
  (bnc#1012628).
- perf header: Fix up argument to ctime() (bnc#1012628).
- usb: musb: dsps: fix runtime pm for peripheral mode
  (bnc#1012628).
- usb: musb: dsps: fix otg state machine (bnc#1012628).
- arm64: KVM: Skip MMIO insn after emulation (bnc#1012628).
- livepatch: check kzalloc return values (bnc#1012628).
- mac80211: Properly handle SKB with radiotap only (bnc#1012628).
- pinctrl: rza1: Handle devm_kasprintf() failure cases
  (bnc#1012628).
- tools/power/x86/intel_pstate_tracer: Fix non root execution
  for post processing a trace file (bnc#1012628).
- bnxt_en: Disable MSIX before re-reserving NQs/CMPL rings
  (bnc#1012628).
- i2c: sh_mobile: Add support for r8a774c0 (RZ/G2E) (bnc#1012628).
- perf probe: Fix unchecked usage of strncpy() (bnc#1012628).
- btrfs: use tagged writepage to mitigate livelock of snapshot
  (bnc#1012628).
- perf header: Fix unchecked usage of strncpy() (bnc#1012628).
- perf dso: Fix unchecked usage of strncpy() (bnc#1012628).
- perf test: Fix perf_event_attr test failure (bnc#1012628).
- perf stat: Fix CSV mode column output for non-cgroup events
  (bnc#1012628).
- tty: serial: samsung: Properly set flags in autoCTS mode
  (bnc#1012628).
- serial: sh-sci: Resume PIO in sci_rx_interrupt() on DMA failure
  (bnc#1012628).
- serial: sh-sci: Fix locking in sci_submit_rx() (bnc#1012628).
- btrfs: harden agaist duplicate fsid on scanned devices
  (bnc#1012628).
- usb: renesas_usbhs: add support for RZ/G2E (bnc#1012628).
- mmc: jz4740: Get CD/WP GPIOs from descriptors (bnc#1012628).
- mmc: sdhci-xenon: Fix timeout checks (bnc#1012628).
- mmc: sdhci-omap: Fix timeout checks (bnc#1012628).
- mmc: sdhci-of-esdhc: Fix timeout checks (bnc#1012628).
- memstick: Prevent memstick host from getting runtime suspended
  during card detection (bnc#1012628).
- mmc: meson-mx-sdio: check devm_kasprintf for failure
  (bnc#1012628).
- mmc: bcm2835: reset host on timeout (bnc#1012628).
- mmc: bcm2835: Recover from MMC_SEND_EXT_CSD (bnc#1012628).
- KVM: PPC: Book3S: Only report KVM_CAP_SPAPR_TCE_VFIO on powernv
  machines (bnc#1012628).
- tools: bpftool: fix -Wmissing declaration warnings
  (bnc#1012628).
- ipv6: Fix handling of LLA with VRF and sockets bound to VRF
  (bnc#1012628).
- f2fs: fix to reorder set_page_dirty and wait_on_page_writeback
  (bnc#1012628).
- clk: qcom: Leave mmss noc on for 8998 (bnc#1012628).
- fix dma-buf/udmabuf selftest (bnc#1012628).
- ASoC: fsl: Fix SND_SOC_EUKREA_TLV320 build error on i.MX8M
  (bnc#1012628).
- ARM: pxa: avoid section mismatch warning (bnc#1012628).
- selftests/bpf: use __bpf_constant_htons in test_prog.c
  (bnc#1012628).
- switchtec: Fix SWITCHTEC_IOCTL_EVENT_IDX_ALL flags overwrite
  (bnc#1012628).
- udf: Fix BUG on corrupted inode (bnc#1012628).
- mlxsw: spectrum_acl: Limit priority value (bnc#1012628).
- phy: sun4i-usb: add support for missing USB PHY index
  (bnc#1012628).
- lightnvm: Fix uninitialized return value in nvm_get_chunk_meta()
  (bnc#1012628).
- i2c-axxia: check for error conditions first (bnc#1012628).
- lightnvm: pblk: add lock protection to list operations
  (bnc#1012628).
- lightnvm: pblk: fix resubmission of overwritten write err lbas
  (bnc#1012628).
- drm/msm: dpu: Only check flush register against pending flushes
  (bnc#1012628).
- drm/msm/dsi: fix dsi clock names in DSI 10nm PLL driver
  (bnc#1012628).
- tee: optee: avoid possible double list_del() (bnc#1012628).
- OPP: Use opp_table->regulators to verify no regulator case
  (bnc#1012628).
- cpuidle: big.LITTLE: fix refcount leak (bnc#1012628).
- platform/x86: mlx-platform: Fix tachometer registers
  (bnc#1012628).
- clk: imx6sl: ensure MMDC CH0 handshake is bypassed
  (bnc#1012628).
- sata_rcar: fix deferred probing (bnc#1012628).
- iommu/arm-smmu-v3: Use explicit mb() when moving cons pointer
  (bnc#1012628).
- iommu/arm-smmu: Add support for qcom,smmu-v2 variant
  (bnc#1012628).
- iommu/arm-smmu-v3: Avoid memory corruption from Hisilicon MSI
  payloads (bnc#1012628).
- usb: dwc3: gadget: Disable CSP for stream OUT ep (bnc#1012628).
- ARM: dts: imx51-zii-rdu1: Do not specify "power-gpio" for hpa1
  (bnc#1012628).
- watchdog: renesas_wdt: don't set divider while watchdog is
  running (bnc#1012628).
- ARM: dts: Fix up the D-Link DIR-685 MTD partition info
  (bnc#1012628).
- arm64: dts: meson: Fix IRQ trigger type for macirq
  (bnc#1012628).
- media: coda: fix H.264 deblocking filter controls (bnc#1012628).
- mips: bpf: fix encoding bug for mm_srlv32_op (bnc#1012628).
- ARM: dts: Fix OMAP4430 SDP Ethernet startup (bnc#1012628).
- ARM: OMAP1: ams-delta: Fix audio permanently muted
  (bnc#1012628).
- media: v4l2-device: Link subdevices to their parent devices
  if available (bnc#1012628).
- iommu/amd: Fix amd_iommu=force_isolation (bnc#1012628).
- pinctrl: sx150x: handle failure case of devm_kstrdup
  (bnc#1012628).
- gpio: mt7621: pass mediatek_gpio_bank_probe() failure up the
  stack (bnc#1012628).
- gpio: mt7621: report failure of devm_kasprintf() (bnc#1012628).
- usb: dwc3: trace: add missing break statement to make compiler
  happy (bnc#1012628).
- IB/hfi1: Unreserve a reserved request when it is completed
  (bnc#1012628).
- kobject: return error code if writing /sys/.../uevent fails
  (bnc#1012628).
- driver core: Move async_synchronize_full call (bnc#1012628).
- arm64: dts: rockchip: fix rk3399-rockpro64 regulator gpios
  (bnc#1012628).
- tipc: fix node keep alive interval calculation (bnc#1012628).
- drm/amdgpu/powerplay: fix clock stretcher limits on polaris (v2)
  (bnc#1012628).
- pinctrl: nuvoton: check for devm_kasprintf() failure
  (bnc#1012628).
- mac80211: fix deauth TX when we disconnect (bnc#1012628).
- media: imx274: select REGMAP_I2C (bnc#1012628).
- clk: sunxi-ng: a33: Set CLK_SET_RATE_PARENT for all audio
  module clocks (bnc#1012628).
- usb: mtu3: fix the issue about SetFeature(U1/U2_Enable)
  (bnc#1012628).
- timekeeping: Use proper seqcount initializer (bnc#1012628).
- usb: hub: delay hub autosuspend if USB3 port is still link
  training (bnc#1012628).
- usb: dwc2: Disable power down feature on Samsung SoCs
  (bnc#1012628).
- dmaengine: sprd: Support DMA link-list cyclic callback
  (bnc#1012628).
- usb: dwc3: Correct the logic for checking TRB full in
  __dwc3_prepare_one_trb() (bnc#1012628).
- xtensa: xtfpga.dtsi: fix dtc warnings about SPI (bnc#1012628).
- smack: fix access permissions for keyring (bnc#1012628).
- platform/x86: Fix config space access for intel_atomisp2_pm
  (bnc#1012628).
- media: DaVinci-VPBE: fix error handling in vpbe_initialize()
  (bnc#1012628).
- media: i2c: TDA1997x: select CONFIG_HDMI (bnc#1012628).
- x86/fpu: Add might_fault() to user_insn() (bnc#1012628).
- spi: fix spi-at91-usart.c build errors when PINCTRL is not set
  (bnc#1012628).
- ARM: dts: aspeed: add missing memory unit-address (bnc#1012628).
- ARM: dts: mmp2: fix TWSI2 (bnc#1012628).
- drm/v3d: Fix prime imports of buffers from other drivers
  (bnc#1012628).
- arm64: ftrace: don't adjust the LR value (bnc#1012628).
- mt76x0: dfs: fix IBI_R11 configuration on non-radar channels
  (bnc#1012628).
- s390/zcrypt: improve special ap message cmd handling
  (bnc#1012628).
- firmware/efi: Add NULL pointer checks in efivars API functions
  (bnc#1012628).
- thermal: Fix locking in cooling device sysfs update cur_state
  (bnc#1012628).
- Thermal: do not clear passive state during system sleep
  (bnc#1012628).
- arm64: io: Ensure value passed to __iormb() is held in a 64-bit
  register (bnc#1012628).
- perf: arm_spe: handle devm_kasprintf() failure (bnc#1012628).
- drm: Clear state->acquire_ctx before leaving
  drm_atomic_helper_commit_duplicated_state() (bnc#1012628).
- nfsd4: fix crash on writing v4_end_grace before nfsd startup
  (bnc#1012628).
- soc: bcm: brcmstb: Don't leak device tree node reference
  (bnc#1012628).
- sunvdc: Do not spin in an infinite loop when vio_ldc_send()
  returns EAGAIN (bnc#1012628).
- net: aquantia: return 'err' if set MPI_DEINIT state fails
  (bnc#1012628).
- arm64: io: Ensure calls to delay routines are ordered against
  prior readX() (bnc#1012628).
- i2c: sh_mobile: add support for r8a77990 (R-Car E3)
  (bnc#1012628).
- f2fs: fix wrong return value of f2fs_acl_create (bnc#1012628).
- f2fs: fix race between write_checkpoint and write_begin
  (bnc#1012628).
- f2fs: move dir data flush to write checkpoint process
  (bnc#1012628).
- f2fs: avoid GC causing encrypted file corrupted (bnc#1012628).
- staging: pi433: fix potential null dereference (bnc#1012628).
- ACPI: SPCR: Consider baud rate 0 as preconfigured state
  (bnc#1012628).
- media: adv*/tc358743/ths8200: fill in min
  width/height/pixelclock (bnc#1012628).
- iio: accel: kxcjk1013: Add KIOX010A ACPI Hardware-ID
  (bnc#1012628).
- iio: adc: meson-saradc: fix internal clock names (bnc#1012628).
- iio: adc: meson-saradc: check for devm_kasprintf failure
  (bnc#1012628).
- powerpc/32: Add .data..Lubsan_data*/.data..Lubsan_type*
  sections explicitly (bnc#1012628).
- dmaengine: xilinx_dma: Remove __aligned attribute on
  zynqmp_dma_desc_ll (bnc#1012628).
- ptp: Fix pass zero to ERR_PTR() in ptp_clock_register
  (bnc#1012628).
- clk: meson: meson8b: mark the CPU clock as CLK_IS_CRITICAL
  (bnc#1012628).
- clk: meson: meson8b: fix the width of the cpu_scale_div clock
  (bnc#1012628).
- clk: meson: meson8b: do not use cpu_div3 for cpu_scale_out_sel
  (bnc#1012628).
- drm: rcar-du: Fix external clock error checks (bnc#1012628).
- RDMA/core: Sync unregistration with netlink commands
  (bnc#1012628).
- media: vivid: fill in media_device bus_info (bnc#1012628).
- staging: erofs: fix race when the managed cache is enabled
  (bnc#1012628).
- staging: erofs: fix the definition of DBG_BUGON (bnc#1012628).
- media: mtk-vcodec: Release device nodes in
  mtk_vcodec_init_enc_pm() (bnc#1012628).
- media: video-i2c: avoid accessing released memory area when
  removing driver (bnc#1012628).
- media: rc: ensure close() is called on rc_unregister_device
  (bnc#1012628).
- soc/tegra: Don't leak device tree node reference (bnc#1012628).
- scsi: cxgb4i: fix thermal configuration dependencies
  (bnc#1012628).
- perf tools: Add Hygon Dhyana support (bnc#1012628).
- modpost: validate symbol names also in find_elf_symbol
  (bnc#1012628).
- net/mlx5: EQ, Use the right place to store/read IRQ affinity
  hint (bnc#1012628).
- bpf: libbpf: retry map creation without the name (bnc#1012628).
- drm/amd/display: calculate stream->phy_pix_clk before clock
  mapping (bnc#1012628).
- drm/amd/display: fix gamma not being applied correctly
  (bnc#1012628).
- ARM: OMAP2+: hwmod: Fix some section annotations (bnc#1012628).
- drm/rockchip: fix for mailbox read size (bnc#1012628).
- usbnet: smsc95xx: fix rx packet alignment (bnc#1012628).
- staging: iio: ad7780: update voltage on read (bnc#1012628).
- scsi: hisi_sas: change the time of SAS SSP connection
  (bnc#1012628).
- i40e: prevent overlapping tx_timeout recover (bnc#1012628).
- i40e: suppress bogus error message (bnc#1012628).
- platform/chrome: don't report EC_MKBP_EVENT_SENSOR_FIFO as
  wakeup (bnc#1012628).
- vbox: fix link error with 'gcc -Og' (bnc#1012628).
- fpga: altera-cvp: fix 'bad IO access' on x86_64 (bnc#1012628).
- Tools: hv: kvp: Fix a warning of buffer overflow with gcc 8.0.1
  (bnc#1012628).
- fpga: altera-cvp: Fix registration for CvP incapable devices
  (bnc#1012628).
- staging:iio:ad2s90: Make probe handle spi_setup failure
  (bnc#1012628).
- iwlwifi: fw: do not set sgi bits for HE connection
  (bnc#1012628).
- dpaa2-ptp: defer probe when portal allocation failed
  (bnc#1012628).
- MIPS: Boston: Disable EG20T prefetch (bnc#1012628).
- ptp: check gettime64 return code in PTP_SYS_OFFSET ioctl
  (bnc#1012628).
- serial: fsl_lpuart: clear parity enable bit when disable parity
  (bnc#1012628).
- drm/vc4: ->x_scaling[1] should never be set to VC4_SCALING_NONE
  (bnc#1012628).
- crypto: aes_ti - disable interrupts while accessing S-box
  (bnc#1012628).
- s390/qeth: utilize virtual MAC for Layer2 OSD devices
  (bnc#1012628).
- bpftool: Improve handling of ENOENT on map dumps (bnc#1012628).
- powerpc/pseries: add of_node_put() in dlpar_detach_node()
  (bnc#1012628).
- x86/PCI: Fix Broadcom CNB20LE unintended sign extension (redux)
  (bnc#1012628).
- dlm: Don't swamp the CPU with callbacks queued during recovery
  (bnc#1012628).
- clk: boston: fix possible memory leak in clk_boston_setup()
  (bnc#1012628).
- ARM: 8808/1: kexec:offline panic_smp_self_stop CPU
  (bnc#1012628).
- scsi: lpfc: Fix LOGO/PLOGI handling when triggerd by ABTS
  Timeout event (bnc#1012628).
- scsi: mpt3sas: Call sas_remove_host before removing the target
  devices (bnc#1012628).
- scsi: lpfc: Correct LCB RJT handling (bnc#1012628).
- ath9k: dynack: use authentication messages for 'late' ack
  (bnc#1012628).
- ath10k: assign 'n_cipher_suites' for WCN3990 (bnc#1012628).
- wil6210: fix memory leak in wil_find_tx_bcast_2 (bnc#1012628).
- wil6210: fix reset flow for Talyn-mb (bnc#1012628).
- nds32: Fix gcc 8.0 compiler option incompatible (bnc#1012628).
- drm/amd/display: Fix potential nullptr error (bnc#1012628).
- gpu: ipu-v3: image-convert: Prevent race between run and
  unprepare (bnc#1012628).
- genirq/affinity: Spread IRQs to all available NUMA nodes
  (bnc#1012628).
- ath10k: fixup extended per sta tx statistics (bnc#1012628).
- drm/sun4i: Initialize registers in tcon-top driver
  (bnc#1012628).
- gpiolib: Fix possible use after free on label (bnc#1012628).
- ASoC: Intel: mrfld: fix uninitialized variable access
  (bnc#1012628).
- clk: sunxi-ng: h6: Set video PLLs limits (bnc#1012628).
- pinctrl: bcm2835: Use raw spinlock for RT compatibility
  (bnc#1012628).
- drm/vgem: Fix vgem_init to get drm device available
  (bnc#1012628).
- staging: iio: adc: ad7280a: handle error from __ad7280_read32()
  (bnc#1012628).
- drm/v3d: Fix a use-after-free race accessing the scheduler's
  fences (bnc#1012628).
- drm/bufs: Fix Spectre v1 vulnerability (bnc#1012628).
- commit 02864b1
* Mon Feb 11 2019 mkubecek@suse.cz
- Update to 5.0-rc6
- commit eb4b248
* Fri Feb  8 2019 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Build livepatch support in SUSE release
  projects (bsc#1124167).
- commit 7519080
* Thu Feb  7 2019 jslaby@suse.cz
- Linux 4.20.7 (bnc#1012628).
- drm/msm/gpu: fix building without debugfs (bnc#1012628).
- ipv6: sr: clear IP6CB(skb) on SRH ip4ip6 encapsulation
  (bnc#1012628).
- ipvlan, l3mdev: fix broken l3s mode wrt local routes
  (bnc#1012628).
- l2tp: copy 4 more bytes to linear part if necessary
  (bnc#1012628).
- l2tp: fix reading optional fields of L2TPv3 (bnc#1012628).
- net: ip_gre: always reports o_key to userspace (bnc#1012628).
- net: ip_gre: use erspan key field for tunnel lookup
  (bnc#1012628).
- net/ipv6: don't return positive numbers when nothing was dumped
  (bnc#1012628).
- net/mlx4_core: Add masking for a few queries on HCA caps
  (bnc#1012628).
- netrom: switch to sock timer API (bnc#1012628).
- net/rose: fix NULL ax25_cb kernel panic (bnc#1012628).
- net: set default network namespace in init_dummy_netdev()
  (bnc#1012628).
- ravb: expand rx descriptor data to accommodate hw checksum
  (bnc#1012628).
- sctp: improve the events for sctp stream reset (bnc#1012628).
- tun: move the call to tun_set_real_num_queues (bnc#1012628).
- ucc_geth: Reset BQL queue when stopping device (bnc#1012628).
- vhost: fix OOB in get_rx_bufs() (bnc#1012628).
- net: ip6_gre: always reports o_key to userspace (bnc#1012628).
- sctp: improve the events for sctp stream adding (bnc#1012628).
- net/mlx5e: Allow MAC invalidation while spoofchk is ON
  (bnc#1012628).
- ip6mr: Fix notifiers call on mroute_clean_tables()
  (bnc#1012628).
- Revert "net/mlx5e: E-Switch, Initialize eswitch only if eswitch
  manager" (bnc#1012628).
- sctp: set chunk transport correctly when it's a new asoc
  (bnc#1012628).
- sctp: set flow sport from saddr only when it's 0 (bnc#1012628).
- net: tls: Fix deadlock in free_resources tx (bnc#1012628).
- net: tls: Save iv in tls_rec for async crypto requests
  (bnc#1012628).
- virtio_net: Don't enable NAPI when interface is down
  (bnc#1012628).
- virtio_net: Don't call free_old_xmit_skbs for xdp_frames
  (bnc#1012628).
- virtio_net: Fix not restoring real_num_rx_queues (bnc#1012628).
- virtio_net: Fix out of bounds access of sq (bnc#1012628).
- virtio_net: Don't process redirected XDP frames when XDP is
  disabled (bnc#1012628).
- virtio_net: Use xdp_return_frame to free xdp_frames on
  destroying vqs (bnc#1012628).
- virtio_net: Differentiate sk_buff and xdp_frame on freeing
  (bnc#1012628).
- ipv6: Consider sk_bound_dev_if when binding a socket to an
  address (bnc#1012628).
- CIFS: Do not count -ENODATA as failure for query directory
  (bnc#1012628).
- CIFS: Fix possible oops and memory leaks in async IO
  (bnc#1012628).
- CIFS: Fix trace command logging for SMB2 reads and writes
  (bnc#1012628).
- CIFS: fix use-after-free of the lease keys (bnc#1012628).
- CIFS: Do not consider -ENODATA as stat failure for reads
  (bnc#1012628).
- fs/dcache: Fix incorrect nr_dentry_unused accounting in
  shrink_dcache_sb() (bnc#1012628).
- iommu/vt-d: Fix memory leak in intel_iommu_put_resv_regions()
  (bnc#1012628).
- selftests/seccomp: Enhance per-arch ptrace syscall skip tests
  (bnc#1012628).
- NFS: Fix up return value on fatal errors in
  nfs_page_async_flush() (bnc#1012628).
- ARM: cns3xxx: Fix writing to wrong PCI config registers after
  alignment (bnc#1012628).
- arm64: kaslr: ensure randomized quantities are clean also when
  kaslr is off (bnc#1012628).
- arm64: Do not issue IPIs for user executable ptes (bnc#1012628).
- arm64: hyp-stub: Forbid kprobing of the hyp-stub (bnc#1012628).
- arm64: hibernate: Clean the __hyp_text to PoC after resume
  (bnc#1012628).
- gpio: altera-a10sr: Set proper output level for direction_output
  (bnc#1012628).
- gpiolib: fix line event timestamps for nested irqs
  (bnc#1012628).
- gpio: pcf857x: Fix interrupts on multiple instances
  (bnc#1012628).
- gpio: sprd: Fix the incorrect data register (bnc#1012628).
- gpio: sprd: Fix incorrect irq type setting for the async EIC
  (bnc#1012628).
- gfs2: Revert "Fix loop in gfs2_rbm_find" (bnc#1012628).
- mmc: bcm2835: Fix DMA channel leak on probe error (bnc#1012628).
- mmc: mediatek: fix incorrect register setting of
  hs400_cmd_int_delay (bnc#1012628).
- ALSA: usb-audio: Add Opus #3 to quirks for native DSD support
  (bnc#1012628).
- ALSA: hda/realtek - Fixed hp_pin no value (bnc#1012628).
- ALSA: pcm: Fix tight loop of OSS capture stream (bnc#1012628).
- IB/uverbs: Fix OOPs upon device disassociation (bnc#1012628).
- IB/uverbs: Fix OOPs in uverbs_user_mmap_disassociate
  (bnc#1012628).
- IB/hfi1: Remove overly conservative VM_EXEC flag check
  (bnc#1012628).
- IB/hfi1: Add limit test for RC/UC send via loopback
  (bnc#1012628).
- platform/x86: asus-nb-wmi: Map 0x35 to KEY_SCREENLOCK
  (bnc#1012628).
- platform/x86: asus-nb-wmi: Drop mapping of 0x33 and 0x34 scan
  codes (bnc#1012628).
- Btrfs: fix deadlock when allocating tree block during leaf/node
  split (bnc#1012628).
- btrfs: On error always free subvol_name in btrfs_mount
  (bnc#1012628).
- kernel/exit.c: release ptraced tasks before zap_pid_ns_processes
  (bnc#1012628).
- mm/hugetlb.c: teach follow_hugetlb_page() to handle FOLL_NOWAIT
  (bnc#1012628).
- oom, oom_reaper: do not enqueue same task twice (bnc#1012628).
- mm,memory_hotplug: fix scan_movable_pages() for gigantic
  hugepages (bnc#1012628).
- mm, oom: fix use-after-free in oom_kill_process (bnc#1012628).
- mm: hwpoison: use do_send_sig_info() instead of force_sig()
  (bnc#1012628).
- mm: migrate: don't rely on __PageMovable() of newpage after
  unlocking it (bnc#1012628).
- of: overlay: add tests to validate kfrees from overlay removal
  (bnc#1012628).
- of: overlay: add missing of_node_get() in __of_attach_node_sysfs
  (bnc#1012628).
- of: overlay: use prop add changeset entry for property in new
  nodes (bnc#1012628).
- of: overlay: do not duplicate properties from overlay for new
  nodes (bnc#1012628).
- md/raid5: fix 'out of memory' during raid cache recovery
  (bnc#1012628).
- cifs: Always resolve hostname before reconnecting (bnc#1012628).
- Refresh
  patches.suse/btrfs-8447-serialize-subvolume-mounts-with-potentially-mi.patch.
- commit 730812f
* Sun Feb  3 2019 mkubecek@suse.cz
- Update to 5.0-rc5
- Config changes:
  - x86:
  - X86_RESCTRL renamed to X86_CPU_RESCTRL
- commit a42dcc6
* Thu Jan 31 2019 jslaby@suse.cz
- Linux 4.20.6 (bnc#1012628).
- amd-xgbe: Fix mdio access for non-zero ports and clause 45 PHYs
  (bnc#1012628).
- net: bridge: Fix ethernet header pointer before check skb
  forwardable (bnc#1012628).
- net: Fix usage of pskb_trim_rcsum (bnc#1012628).
- net: phy: marvell: Errata for mv88e6390 internal PHYs
  (bnc#1012628).
- net: phy: mdio_bus: add missing device_del() in
  mdiobus_register() error handling (bnc#1012628).
- net: phy: phy driver features are mandatory (bnc#1012628).
- net/sched: act_tunnel_key: fix memory leak in case of action
  replace (bnc#1012628).
- net_sched: refetch skb protocol for each filter (bnc#1012628).
- openvswitch: Avoid OOB read when parsing flow nlattrs
  (bnc#1012628).
- vhost: log dirty page correctly (bnc#1012628).
- mlxsw: pci: Increase PCI SW reset timeout (bnc#1012628).
- net: ipv4: Fix memory leak in network namespace dismantle
  (bnc#1012628).
- mlxsw: spectrum_fid: Update dummy FID index (bnc#1012628).
- mlxsw: pci: Ring CQ's doorbell before RDQ's (bnc#1012628).
- net/sched: cls_flower: allocate mask dynamically in fl_change()
  (bnc#1012628).
- udp: with udp_segment release on error path (bnc#1012628).
- ip6_gre: fix tunnel list corruption for x-netns (bnc#1012628).
- erspan: build the header with the right proto according to
  erspan_ver (bnc#1012628).
- net: phy: marvell: Fix deadlock from wrong locking
  (bnc#1012628).
- ip6_gre: update version related info when changing link
  (bnc#1012628).
- tcp: allow MSG_ZEROCOPY transmission also in CLOSE_WAIT state
  (bnc#1012628).
- ARM: fix the cockup in the previous patch (bnc#1012628).
- SUNRPC: Address Kerberos performance/behavior regression
  (bnc#1012628).
- mei: me: mark LBG devices as having dma support (bnc#1012628).
- mei: me: add denverton innovation engine device IDs
  (bnc#1012628).
- USB: leds: fix regression in usbport led trigger (bnc#1012628).
- USB: EHCI: ehci-mv: add MODULE_DEVICE_TABLE (bnc#1012628).
- USB: serial: ftdi_sio: fix GPIO not working in autosuspend
  (bnc#1012628).
- USB: serial: simple: add Motorola Tetra TPG2200 device id
  (bnc#1012628).
- USB: serial: pl2303: add new PID to support PL2303TB
  (bnc#1012628).
- ceph: clear inode pointer when snap realm gets dropped by its
  inode (bnc#1012628).
- ASoC: atom: fix a missing check of snd_pcm_lib_malloc_pages
  (bnc#1012628).
- ASoC: rt5514-spi: Fix potential NULL pointer dereference
  (bnc#1012628).
- ASoC: tlv320aic32x4: Kernel OOPS while entering DAPM standby
  mode (bnc#1012628).
- clk: zynqmp: Fix memory allocation in zynqmp_clk_setup
  (bnc#1012628).
- clk: socfpga: stratix10: fix rate calculation for pll clocks
  (bnc#1012628).
- clk: socfpga: stratix10: fix naming convention for the
  fixed-clocks (bnc#1012628).
- inotify: Fix fd refcount leak in inotify_add_watch()
  (bnc#1012628).
- ALSA: hda/realtek - Fix typo for ALC225 model (bnc#1012628).
- ALSA: hda - Add mute LED support for HP ProBook 470 G5
  (bnc#1012628).
- ARCv2: lib: memeset: fix doing prefetchw outside of buffer
  (bnc#1012628).
- ARC: adjust memblock_reserve of kernel memory (bnc#1012628).
- ARC: perf: map generic branches to correct hardware condition
  (bnc#1012628).
- s390/vdso: correct vdso mapping for compat tasks (bnc#1012628).
- s390/mm: always force a load of the primary ASCE on context
  switch (bnc#1012628).
- s390/early: improve machine detection (bnc#1012628).
- s390/smp: fix CPU hotplug deadlock with CPU rescan
  (bnc#1012628).
- s390/smp: Fix calling smp_call_ipl_cpu() from ipl CPU
  (bnc#1012628).
- misc: ibmvsm: Fix potential NULL pointer dereference
  (bnc#1012628).
- char/mwave: fix potential Spectre v1 vulnerability
  (bnc#1012628).
- mmc: sdhci-iproc: handle mmc_of_parse() errors during probe
  (bnc#1012628).
- mmc: dw_mmc-bluefield: : Fix the license information
  (bnc#1012628).
- mmc: meson-gx: Free irq in release() callback (bnc#1012628).
- staging: rtl8188eu: Add device code for D-Link DWA-121 rev B1
  (bnc#1012628).
- tty: Handle problem if line discipline does not have receive_buf
  (bnc#1012628).
- uart: Fix crash in uart_write and uart_put_char (bnc#1012628).
- tty/n_hdlc: fix __might_sleep warning (bnc#1012628).
- hv_balloon: avoid touching uninitialized struct page during
  tail onlining (bnc#1012628).
- Drivers: hv: vmbus: Check for ring when getting debug info
  (bnc#1012628).
- vgacon: unconfuse vc_origin when using soft scrollback
  (bnc#1012628).
- CIFS: Fix possible hang during async MTU reads and writes
  (bnc#1012628).
- CIFS: Fix credits calculations for reads with errors
  (bnc#1012628).
- CIFS: Fix credit calculation for encrypted reads with errors
  (bnc#1012628).
- CIFS: Do not reconnect TCP session in add_credits()
  (bnc#1012628).
- smb3: add credits we receive from oplock/break PDUs
  (bnc#1012628).
- Input: xpad - add support for SteelSeries Stratus Duo
  (bnc#1012628).
- Input: input_event - provide override for sparc64 (bnc#1012628).
- Input: uinput - fix undefined behavior in
  uinput_validate_absinfo() (bnc#1012628).
- acpi/nfit: Block function zero DSMs (bnc#1012628).
- acpi/nfit: Fix command-supported detection (bnc#1012628).
- scsi: ufs: Use explicit access size in ufshcd_dump_regs
  (bnc#1012628).
- dm thin: fix passdown_double_checking_shared_status()
  (bnc#1012628).
- dm crypt: fix parsing of extended IV arguments (bnc#1012628).
- drm/amdgpu: Add APTX quirk for Lenovo laptop (bnc#1012628).
- EDAC, altera: Fix S10 persistent register offset (bnc#1012628).
- KVM: x86: Fix single-step debugging (bnc#1012628).
- KVM: x86: Fix PV IPIs for 32-bit KVM host (bnc#1012628).
- KVM: x86: WARN_ONCE if sending a PV IPI returns a fatal error
  (bnc#1012628).
- kvm: x86/vmx: Use kzalloc for cached_vmcs12 (bnc#1012628).
- x86/pkeys: Properly copy pkey state at fork() (bnc#1012628).
- x86/selftests/pkeys: Fork() to check for state being preserved
  (bnc#1012628).
- x86/kaslr: Fix incorrect i8254 outb() parameters (bnc#1012628).
- x86/entry/64/compat: Fix stack switching for XEN PV
  (bnc#1012628).
- posix-cpu-timers: Unbreak timer rearming (bnc#1012628).
- net: sun: cassini: Cleanup license conflict (bnc#1012628).
- irqchip/gic-v3-its: Align PCI Multi-MSI allocation on their size
  (bnc#1012628).
- can: dev: __can_get_echo_skb(): fix bogous check for
  non-existing skb by removing it (bnc#1012628).
- can: bcm: check timer values before ktime conversion
  (bnc#1012628).
- can: flexcan: fix NULL pointer exception during bringup
  (bnc#1012628).
- vt: make vt_console_print() compatible with the unicode screen
  buffer (bnc#1012628).
- vt: always call notifier with the console lock held
  (bnc#1012628).
- vt: invoke notifier on screen size change (bnc#1012628).
- drm/meson: Fix atomic mode switching regression (bnc#1012628).
- bpf: move {prev_,}insn_idx into verifier env (bnc#1012628).
- bpf: move tmp variable into ax register in interpreter
  (bnc#1012628).
- nvmet-rdma: Add unlikely for response allocated check
  (bnc#1012628).
- nvmet-rdma: fix null dereference under heavy load (bnc#1012628).
- bpf: enable access to ax register also from verifier rewrite
  (bnc#1012628).
- bpf: restrict map value pointer arithmetic for unprivileged
  (bnc#1012628).
- bpf: restrict stack pointer arithmetic for unprivileged
  (bnc#1012628).
- bpf: restrict unknown scalars of mixed signed bounds for
  unprivileged (bnc#1012628).
- bpf: fix check_map_access smin_value test when pointer contains
  offset (bnc#1012628).
- bpf: prevent out of bounds speculation on pointer arithmetic
  (bnc#1012628).
- bpf: fix sanitation of alu op with pointer / scalar type from
  different paths (bnc#1012628).
- bpf: fix inner map masking to prevent oob under speculation
  (bnc#1012628).
- Drivers: hv: vmbus: Remove the useless API
  vmbus_get_outgoing_channel() (bnc#1012628).
- vmbus: fix subchannel removal (bnc#1012628).
- Revert "mm, memory_hotplug: initialize struct pages for the
  full memory section" (bnc#1012628).
- usb: dwc3: gadget: Clear req->needs_extra_trb flag on cleanup
  (bnc#1012628).
- mt76x0: do not overwrite other MT_BBP(AGC, 8) fields
  (bnc#1012628).
- mt76x0: use band parameter for LC calibration (bnc#1012628).
- mt76x02: run calibration after scanning (bnc#1012628).
- mt76x02: assure we update gain after scan (bnc#1012628).
- mt76x0: do not perform MCU calibration for MT7630 (bnc#1012628).
- mt76x0: antenna select corrections (bnc#1012628).
- mt76x0: phy: unify calibration between mt76x0u and mt76x0e
  (bnc#1012628).
- ide: fix a typo in the settings proc file name (bnc#1012628).
- Input: input_event - fix the CONFIG_SPARC64 mixup (bnc#1012628).
- Refresh
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- commit 463cfd2
* Wed Jan 30 2019 mwilck@suse.com
- rpm/kernel-binary.spec.in: fix initrd permissions (bsc#1123697)
  dracut has been using permissions 0600 for the initrd for a long
  time. On SLE15 or higher, that leads to a permission mismatch
  reported by "rpm -V". Set the permissions correctly for our
  ghost file.
- commit 9e5e2a5
* Wed Jan 30 2019 mwilck@suse.com
- config files: set CONFIG_SCSI_MQ_DEFAULT=y (bsc#1122182)
  Kernel 4.20 and newer use blk_mq for device mapper exclusively.
  Thus stacking device mapper on SCSI devices fails unless we
  use blk_mq for SCSI devices as well.
- commit 0a5bbbc
* Mon Jan 28 2019 tiwai@suse.de
- doc/README.SUSE: Correct description for building a kernel (bsc#1123348)
  The obsoleted make cloneconfig is corrected.  Also the order of make
  scripts and make prepare are corrected as well.
- commit 17a2073
* Mon Jan 28 2019 tiwai@suse.de
- rpm/release-projects: Add SUSE:Maintenance:* for MU kernels (bsc#1123317)
- commit c784b79
* Mon Jan 28 2019 mkubecek@suse.cz
- Update to 5.0-rc4
- commit 8e6abff
* Sat Jan 26 2019 jslaby@suse.cz
- Linux 4.20.5 (bnc#1012628).
- ipmi:ssif: Fix handling of multi-part return messages
  (bnc#1012628).
- ipmi: Prevent use-after-free in deliver_response (bnc#1012628).
- ipmi: msghandler: Fix potential Spectre v1 vulnerabilities
  (bnc#1012628).
- ipmi: Don't initialize anything in the core until something
  uses it (bnc#1012628).
- ipmi: fix use-after-free of user->release_barrier.rda
  (bnc#1012628).
- Bluetooth: Fix unnecessary error message for HCI request
  completion (bnc#1012628).
- drm/amd/display: Fix disabled cursor on top screen edge
  (bnc#1012628).
- mm/memblock.c: skip kmemleak for kasan_init() (bnc#1012628).
- mm, proc: be more verbose about unstable VMA flags in
  /proc/<pid>/smaps (bnc#1012628).
- userfaultfd: clear flag if remap event not enabled
  (bnc#1012628).
- mm/swap: use nr_node_ids for avail_lists in swap_info_struct
  (bnc#1012628).
- mm/page-writeback.c: don't break integrity writeback on
  - >writepage() error (bnc#1012628).
- ocfs2: fix panic due to unrecovered local alloc (bnc#1012628).
- iomap: don't search past page end in iomap_is_partially_uptodate
  (bnc#1012628).
- scsi: megaraid: fix out-of-bound array accesses (bnc#1012628).
- KVM: PPC: Book3S HV: Apply combination of host and l1 pte rc
  for nested guest (bnc#1012628).
- KVM: PPC: Book3S HV: Align gfn to L1 page size when inserting
  nest-rmap entry (bnc#1012628).
- scsi: smartpqi: call pqi_free_interrupts() in pqi_shutdown()
  (bnc#1012628).
- ath10k: fix peer stats null pointer dereference (bnc#1012628).
- scsi: smartpqi: correct lun reset issues (bnc#1012628).
- scsi: mpt3sas: fix memory ordering on 64bit writes
  (bnc#1012628).
- IB/usnic: Fix potential deadlock (bnc#1012628).
- sysfs: Disable lockdep for driver bind/unbind files
  (bnc#1012628).
- ALSA: bebob: fix model-id of unit for Apogee Ensemble
  (bnc#1012628).
- Bluetooth: btusb: Add support for Intel bluetooth device
  8087:0029 (bnc#1012628).
- dm: Check for device sector overflow if CONFIG_LBDAF is not set
  (bnc#1012628).
- clocksource/drivers/integrator-ap: Add missing of_node_put()
  (bnc#1012628).
- quota: Lock s_umount in exclusive mode for Q_XQUOTA{ON,OFF}
  quotactls (bnc#1012628).
- perf tools: Add missing open_memstream() prototype for systems
  lacking it (bnc#1012628).
- perf tools: Add missing sigqueue() prototype for systems
  lacking it (bnc#1012628).
- perf cs-etm: Correct packets swapping in cs_etm__flush()
  (bnc#1012628).
- dm snapshot: Fix excessive memory usage and workqueue stalls
  (bnc#1012628).
- tools lib subcmd: Don't add the kernel sources to the include
  path (bnc#1012628).
- perf stat: Avoid segfaults caused by negated options
  (bnc#1012628).
- dm kcopyd: Fix bug causing workqueue stalls (bnc#1012628).
- dm crypt: use u64 instead of sector_t to store iv_offset
  (bnc#1012628).
- x86/topology: Use total_cpus for max logical packages
  calculation (bnc#1012628).
- netfilter: ipt_CLUSTERIP: fix deadlock in netns exit routine
  (bnc#1012628).
- netfilter: ipt_CLUSTERIP: remove wrong WARN_ON_ONCE in netns
  exit routine (bnc#1012628).
- netfilter: ipt_CLUSTERIP: check MAC address when duplicate
  config is set (bnc#1012628).
- perf vendor events intel: Fix Load_Miss_Real_Latency on SKL/SKX
  (bnc#1012628).
- perf parse-events: Fix unchecked usage of strncpy()
  (bnc#1012628).
- perf svghelper: Fix unchecked usage of strncpy() (bnc#1012628).
- perf tests ARM: Disable breakpoint tests 32-bit (bnc#1012628).
- perf intel-pt: Fix error with config term "pt=0" (bnc#1012628).
- tools lib traceevent: Fix compile warnings in
  tools/lib/traceevent/event-parse.c (bnc#1012628).
- tty/serial: do not free trasnmit buffer page under port lock
  (bnc#1012628).
- btrfs: improve error handling of btrfs_add_link (bnc#1012628).
- btrfs: fix use-after-free due to race between replace start
  and cancel (bnc#1012628).
- btrfs: alloc_chunk: fix more DUP stripe size handling
  (bnc#1012628).
- btrfs: volumes: Make sure there is no overlap of dev extents
  at mount time (bnc#1012628).
- mmc: atmel-mci: do not assume idle after atmci_request_end
  (bnc#1012628).
- kconfig: fix memory leak when EOF is encountered in quotation
  (bnc#1012628).
- kconfig: fix file name and line number of
  warn_ignored_character() (bnc#1012628).
- x86/resctrl: Fix rdt_find_domain() return value and checks
  (bnc#1012628).
- usb: dwc2: Fix disable all EP's on disconnect (bnc#1012628).
- bpf: relax verifier restriction on BPF_MOV | BPF_ALU
  (bnc#1012628).
- arm64: Fix minor issues with the dcache_by_line_op macro
  (bnc#1012628).
- clk: imx6q: reset exclusive gates on init (bnc#1012628).
- arm64: kasan: Increase stack size for KASAN_EXTRA (bnc#1012628).
- selftests: do not macro-expand failed assertion expressions
  (bnc#1012628).
- scsi: target/core: Make sure that target_wait_for_sess_cmds()
  waits long enough (bnc#1012628).
- scsi: target: use consistent left-aligned ASCII INQUIRY data
  (bnc#1012628).
- net: call sk_dst_reset when set SO_DONTROUTE (bnc#1012628).
- staging: erofs: fix use-after-free of on-stack
  `z_erofs_vle_unzip_io' (bnc#1012628).
- media: venus: core: Set dma maximum segment size (bnc#1012628).
- coresight: tmc: Fix bad register address for CLAIM
  (bnc#1012628).
- ASoC: use dma_ops of parent device for acp_audio_dma
  (bnc#1012628).
- media: firewire: Fix app_info parameter type in
  avc_ca{,_app}_info (bnc#1012628).
- arm64: relocatable: fix inconsistencies in linker script and
  options (bnc#1012628).
- powerpc/pseries/cpuidle: Fix preempt warning (bnc#1012628).
- powerpc/xmon: Fix invocation inside lock region (bnc#1012628).
- media: uvcvideo: Refactor teardown of uvc on USB disconnect
  (bnc#1012628).
- pstore/ram: Do not treat empty buffers as valid (bnc#1012628).
- clk: imx: make mux parent strings const (bnc#1012628).
- kbuild: let fixdep directly write to .*.cmd files (bnc#1012628).
- jffs2: Fix use of uninitialized delayed_work, lockdep breakage
  (bnc#1012628).
- efi/libstub: Disable some warnings for x86{,_64} (bnc#1012628).
- rxe: IB_WR_REG_MR does not capture MR's iova field
  (bnc#1012628).
- drm/amdgpu: Reorder uvd ring init before uvd resume
  (bnc#1012628).
- net: ethernet: ave: Set initial wol state to disabled
  (bnc#1012628).
- scsi: qedi: Check for session online before getting iSCSI TLV
  data (bnc#1012628).
- ASoC: pcm3168a: Don't disable pcm3168a when CONFIG_PM defined
  (bnc#1012628).
- arm64: Use a raw spinlock in __install_bp_hardening_cb()
  (bnc#1012628).
- selinux: always allow mounting submounts (bnc#1012628).
- fpga: altera-cvp: fix probing for multiple FPGAs on the bus
  (bnc#1012628).
- usb: gadget: udc: renesas_usb3: add a safety connection way
  for forced_b_device (bnc#1012628).
- samples: bpf: fix: error handling regarding kprobe_events
  (bnc#1012628).
- clk: meson: meson8b: fix incorrect divider mapping in
  cpu_scale_table (bnc#1012628).
- clk: meson: meson8b: add support for more M/N values in sys_pll
  (bnc#1012628).
- drm/atomic-helper: Complete fake_commit->flip_done potentially
  earlier (bnc#1012628).
- MIPS: Loongson: Add Loongson-3A R2.1 basic support
  (bnc#1012628).
- arm64: perf: set suppress_bind_attrs flag to true (bnc#1012628).
- drm/scheduler: Fix bad job be re-processed in TDR (bnc#1012628).
- crypto: ecc - regularize scalar for scalar multiplication
  (bnc#1012628).
- MIPS: SiByte: Enable swiotlb for SWARM, LittleSur and BigSur
  (bnc#1012628).
- x86/mce: Fix -Wmissing-prototypes warnings (bnc#1012628).
- ALSA: oxfw: add support for APOGEE duet FireWire (bnc#1012628).
- bpf: Allow narrow loads with offset > 0 (bnc#1012628).
- serial: set suppress_bind_attrs flag only if builtin
  (bnc#1012628).
- writeback: don't decrement wb->refcnt if !wb->bdi (bnc#1012628).
- of: overlay: add missing of_node_put() after add new node to
  changeset (bnc#1012628).
- selftests/bpf: enable (uncomment) all tests in test_libbpf.sh
  (bnc#1012628).
- usb: typec: tcpm: Do not disconnect link for self powered
  devices (bnc#1012628).
- e1000e: allow non-monotonic SYSTIM readings (bnc#1012628).
- platform/x86: asus-wmi: Tell the EC the OS will handle the
  display off hotkey (bnc#1012628).
- ixgbe: allow IPsec Tx offload in VEPA mode (bnc#1012628).
- qtnfmac: fix error handling in control path (bnc#1012628).
- drm/amdkfd: fix interrupt spin lock (bnc#1012628).
- drm/amd/display: Guard against null stream_state in
  set_crc_source (bnc#1012628).
- ASoC: wm97xx: fix uninitialized regmap pointer problem
  (bnc#1012628).
- gpio: pl061: Move irq_chip definition inside struct pl061
  (bnc#1012628).
- netfilter: ipset: Allow matching on destination MAC address
  for mac and ipmac sets (bnc#1012628).
- net: clear skb->tstamp in bridge forwarding path (bnc#1012628).
- openvswitch: Fix IPv6 later frags parsing (bnc#1012628).
- octeontx2-af: Fix a resource leak in an error handling path in
  'cgx_probe()' (bnc#1012628).
- netlink: fixup regression in RTM_GETADDR (bnc#1012628).
- ipv6: Fix dump of specific table with strict checking
  (bnc#1012628).
- ipv6: Take rcu_read_lock in __inet6_bind for mapped addresses
  (bnc#1012628).
- r8169: Add support for new Realtek Ethernet (bnc#1012628).
- qmi_wwan: add MTU default to qmap network interface
  (bnc#1012628).
- net, skbuff: do not prefer skb allocation fails early
  (bnc#1012628).
- net: dsa: mv88x6xxx: mv88e6390 errata (bnc#1012628).
- mlxsw: spectrum_switchdev: Set PVID correctly during VLAN
  deletion (bnc#1012628).
- mlxsw: spectrum: Disable lag port TX before removing it
  (bnc#1012628).
- ipv6: Consider sk_bound_dev_if when binding a socket to a v4
  mapped address (bnc#1012628).
- commit 34ae151
* Thu Jan 24 2019 msuchanek@suse.de
- rpm/kernel-*.spec.in: replace update srchash dependencies (FATE#325312).
  Due to some limitations version cannot be matched so move the hash into
  the provide name.
- commit 219bcec
* Wed Jan 23 2019 jslaby@suse.cz
- Linux 4.20.4 (bnc#1012628).
- tty/ldsem: Wake up readers after timed out down_write()
  (bnc#1012628).
- tty: Hold tty_ldisc_lock() during tty_reopen() (bnc#1012628).
- tty: Simplify tty->count math in tty_reopen() (bnc#1012628).
- tty: Don't hold ldisc lock in tty_reopen() if ldisc present
  (bnc#1012628).
- can: gw: ensure DLC boundaries after CAN frame modification
  (bnc#1012628).
- netfilter: nf_conncount: replace CONNCOUNT_LOCK_SLOTS with
  CONNCOUNT_SLOTS (bnc#1012628).
- netfilter: nf_conncount: don't skip eviction when age is
  negative (bnc#1012628).
- netfilter: nf_conncount: split gc in two phases (bnc#1012628).
- netfilter: nf_conncount: restart search when nodes have been
  erased (bnc#1012628).
- netfilter: nf_conncount: merge lookup and add functions
  (bnc#1012628).
- netfilter: nf_conncount: move all list iterations under spinlock
  (bnc#1012628).
- netfilter: nf_conncount: speculative garbage collection on
  empty lists (bnc#1012628).
- netfilter: nf_conncount: fix argument order to find_next_bit
  (bnc#1012628).
- mmc: sdhci-msm: Disable CDR function on TX (bnc#1012628).
- arm64/kvm: consistently handle host HCR_EL2 flags (bnc#1012628).
- arm64: Don't trap host pointer auth use to EL2 (bnc#1012628).
- ipv6: fix kernel-infoleak in ipv6_local_error() (bnc#1012628).
- net: bridge: fix a bug on using a neighbour cache entry without
  checking its state (bnc#1012628).
- packet: Do not leak dev refcounts on error exit (bnc#1012628).
- tcp: change txhash on SYN-data timeout (bnc#1012628).
- tun: publish tfile after it's fully initialized (bnc#1012628).
- net: phy: add missing phy driver features (bnc#1012628).
- net: phy: Add missing features to PHY drivers (bnc#1012628).
- net: phy: meson-gxl: Use the genphy_soft_reset callback
  (bnc#1012628).
- lan743x: Remove phy_read from link status change function
  (bnc#1012628).
- IN_BADCLASS: fix macro to actually work (bnc#1012628).
- r8169: load Realtek PHY driver module before r8169
  (bnc#1012628).
- bonding: update nest level on unlink (bnc#1012628).
- ip: on queued skb use skb_header_pointer instead of
  pskb_may_pull (bnc#1012628).
- r8169: don't try to read counters if chip is in a PCI power-save
  state (bnc#1012628).
- smc: move unhash as early as possible in smc_release()
  (bnc#1012628).
- crypto: sm3 - fix undefined shift by >= width of value
  (bnc#1012628).
- crypto: caam - fix zero-length buffer DMA mapping (bnc#1012628).
- crypto: authencesn - Avoid twice completion call in decrypt path
  (bnc#1012628).
- crypto: ccree - convert to use crypto_authenc_extractkeys()
  (bnc#1012628).
- crypto: bcm - convert to use crypto_authenc_extractkeys()
  (bnc#1012628).
- crypto: authenc - fix parsing key with misaligned rta_len
  (bnc#1012628).
- crypto: talitos - reorder code in talitos_edesc_alloc()
  (bnc#1012628).
- crypto: talitos - fix ablkcipher for CONFIG_VMAP_STACK
  (bnc#1012628).
- xen: Fix x86 sched_clock() interface for xen (bnc#1012628).
- Revert "btrfs: balance dirty metadata pages in
  btrfs_finish_ordered_io" (bnc#1012628).
- btrfs: wait on ordered extents on abort cleanup (bnc#1012628).
- Yama: Check for pid death before checking ancestry
  (bnc#1012628).
- scsi: core: Synchronize request queue PM status only on
  successful resume (bnc#1012628).
- scsi: sd: Fix cache_type_store() (bnc#1012628).
- virtio: don't allocate vqs when names[i] = NULL (bnc#1012628).
- virtio-balloon: tweak config_changed implementation
  (bnc#1012628).
- mips: fix n32 compat_ipc_parse_version (bnc#1012628).
- MIPS: BCM47XX: Setup struct device for the SoC (bnc#1012628).
- MIPS: lantiq: Fix IPI interrupt handling (bnc#1012628).
- MIPS: OCTEON: fix kexec support (bnc#1012628).
- drm/i915/gvt: Fix mmap range check (bnc#1012628).
- drm/rockchip: add missing of_node_put (bnc#1012628).
- OF: properties: add missing of_node_put (bnc#1012628).
- mfd: tps6586x: Handle interrupts on suspend (bnc#1012628).
- media: v4l: ioctl: Validate num_planes for debug messages
  (bnc#1012628).
- media: vim2m: only cancel work if it is for right context
  (bnc#1012628).
- RDMA/nldev: Don't expose unsafe global rkey to regular user
  (bnc#1012628).
- RDMA/vmw_pvrdma: Return the correct opcode when creating WR
  (bnc#1012628).
- kbuild: Disable LD_DEAD_CODE_DATA_ELIMINATION with ftrace &
  GCC <= 4.7 (bnc#1012628).
- kbuild: fix single target build for external module
  (bnc#1012628).
- kbuild: mark prepare0 as PHONY to fix external module build
  (bnc#1012628).
- net: dsa: realtek-smi: fix OF child-node lookup (bnc#1012628).
- pstore/ram: Avoid allocation and leak of platform data
  (bnc#1012628).
- SUNRPC: Fix TCP receive code on archs with flush_dcache_page()
  (bnc#1012628).
- powerpc/tm: Limit TM code inside PPC_TRANSACTIONAL_MEM
  (bnc#1012628).
- arm64: kaslr: ensure randomized quantities are clean to the PoC
  (bnc#1012628).
- arm64: dts: marvell: armada-ap806: reserve PSCI area
  (bnc#1012628).
- fbdev: offb: Fix OF node name handling (bnc#1012628).
- Disable MSI also when pcie-octeon.pcie_disable on (bnc#1012628).
- fix int_sqrt64() for very large numbers (bnc#1012628).
- omap2fb: Fix stack memory disclosure (bnc#1012628).
- media: vivid: fix error handling of kthread_run (bnc#1012628).
- media: vivid: set min width/height to a value > 0 (bnc#1012628).
- bpf: in __bpf_redirect_no_mac pull mac only if present
  (bnc#1012628).
- ipv6: make icmp6_send() robust against null skb->dev
  (bnc#1012628).
- LSM: Check for NULL cred-security on free (bnc#1012628).
- media: vb2: vb2_mmap: move lock up (bnc#1012628).
- sunrpc: handle ENOMEM in rpcb_getport_async (bnc#1012628).
- netfilter: ebtables: account ebt_table_info to kmemcg
  (bnc#1012628).
- block: use rcu_work instead of call_rcu to avoid sleep in
  softirq (bnc#1012628).
- drm/vkms: Fix plane duplicate_state (bnc#1012628).
- gpu/drm: Fix lock held when returning to user space
  (bnc#1012628).
- selinux: fix GPF on invalid policy (bnc#1012628).
- blockdev: Fix livelocks on loop device (bnc#1012628).
- sctp: allocate sctp_sockaddr_entry with kzalloc (bnc#1012628).
- tipc: fix uninit-value in in tipc_conn_rcv_sub (bnc#1012628).
- tipc: fix uninit-value in tipc_nl_compat_link_reset_stats
  (bnc#1012628).
- tipc: fix uninit-value in tipc_nl_compat_bearer_enable
  (bnc#1012628).
- tipc: fix uninit-value in tipc_nl_compat_link_set (bnc#1012628).
- tipc: fix uninit-value in tipc_nl_compat_name_table_dump
  (bnc#1012628).
- tipc: fix uninit-value in tipc_nl_compat_doit (bnc#1012628).
- block/loop: Don't grab "struct file" for vfs_getattr() operation
  (bnc#1012628).
- block/loop: Use global lock for ioctl() operation (bnc#1012628).
- loop: Fold __loop_release into loop_release (bnc#1012628).
- loop: Get rid of loop_index_mutex (bnc#1012628).
- loop: Push lo_ctl_mutex down into individual ioctls
  (bnc#1012628).
- loop: Split setting of lo_state from loop_clr_fd (bnc#1012628).
- loop: Push loop_ctl_mutex down into loop_clr_fd() (bnc#1012628).
- loop: Push loop_ctl_mutex down to loop_get_status()
  (bnc#1012628).
- loop: Push loop_ctl_mutex down to loop_set_status()
  (bnc#1012628).
- loop: Push loop_ctl_mutex down to loop_set_fd() (bnc#1012628).
- loop: Push loop_ctl_mutex down to loop_change_fd()
  (bnc#1012628).
- loop: Move special partition reread handling in loop_clr_fd()
  (bnc#1012628).
- loop: Move loop_reread_partitions() out of loop_ctl_mutex
  (bnc#1012628).
- loop: Fix deadlock when calling blkdev_reread_part()
  (bnc#1012628).
- loop: Avoid circular locking dependency between loop_ctl_mutex
  and bd_mutex (bnc#1012628).
- loop: Get rid of 'nested' acquisition of loop_ctl_mutex
  (bnc#1012628).
- loop: Fix double mutex_unlock(&loop_ctl_mutex) in
  loop_control_ioctl() (bnc#1012628).
- loop: drop caches if offset or block_size are changed
  (bnc#1012628).
- drm/fb-helper: Ignore the value of fb_var_screeninfo.pixclock
  (bnc#1012628).
- media: vb2: be sure to unlock mutex on errors (bnc#1012628).
- nbd: Use set_blocksize() to set device blocksize (bnc#1012628).
- Refresh
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch.
- commit b458db8
* Tue Jan 22 2019 oneukum@suse.com
- media: usb: pwc: Don't use coherent DMA buffers for ISO transfer
  (bsc#1054610).
- commit 59d243a
* Mon Jan 21 2019 mkubecek@suse.cz
- Update to 5.0-rc3
- Config changes:
  - ARM64:
  - HSA_AMD=y
- commit 05bf5c0
* Fri Jan 18 2019 jslaby@suse.cz
- Linux 4.20.3 (bnc#1012628).
- Btrfs: use nofs context when initializing security xattrs to
  avoid deadlock (bnc#1012628).
- Btrfs: fix deadlock when enabling quotas due to concurrent
  snapshot creation (bnc#1012628).
- Btrfs: fix access to available allocation bits when starting
  balance (bnc#1012628).
- sunrpc: use-after-free in svc_process_common() (bnc#1012628).
- mm: page_mapped: don't assume compound page is huge or THP
  (bnc#1012628).
- ext4: fix special inode number checks in __ext4_iget()
  (bnc#1012628).
- ext4: track writeback errors using the generic tracking
  infrastructure (bnc#1012628).
- ext4: use ext4_write_inode() when fsyncing w/o a journal
  (bnc#1012628).
- ext4: avoid kernel warning when writing the superblock to a
  dead device (bnc#1012628).
- ext4: fix a potential fiemap/page fault deadlock w/ inline_data
  (bnc#1012628).
- ext4: make sure enough credits are reserved for dioread_nolock
  writes (bnc#1012628).
- rbd: don't return 0 on unmap if RBD_DEV_FLAG_REMOVING is set
  (bnc#1012628).
- drm/amdgpu: Don't fail resume process if resuming atomic state
  fails (bnc#1012628).
- drm/amdgpu: Don't ignore rc from
  drm_dp_mst_topology_mgr_resume() (bnc#1012628).
- drm/i915: Unwind failure on pinning the gen7 ppgtt
  (bnc#1012628).
- drm/fb-helper: Partially bring back workaround for bugs of
  SDL 1.2 (bnc#1012628).
- drm/amd/display: Fix MST dp_blank REG_WAIT timeout
  (bnc#1012628).
- PCI: dwc: Move interrupt acking into the proper callback
  (bnc#1012628).
- PCI: dwc: Take lock when ACKing an interrupt (bnc#1012628).
- PCI: dwc: Use interrupt masking instead of disabling
  (bnc#1012628).
- drm/amdgpu: Add new VegaM pci id (bnc#1012628).
- vfio/type1: Fix unmap overflow off-by-one (bnc#1012628).
- mtd: rawnand: qcom: fix memory corruption that causes panic
  (bnc#1012628).
- i2c: dev: prevent adapter retries and timeout being set as
  minus value (bnc#1012628).
- ACPI/IORT: Fix rc_dma_get_range() (bnc#1012628).
- ACPI / PMIC: xpower: Fix TS-pin current-source handling
  (bnc#1012628).
- ACPI: power: Skip duplicate power resource references in _PRx
  (bnc#1012628).
- mm, memcg: fix reclaim deadlock with writeback (bnc#1012628).
- mm/usercopy.c: no check page span for stack objects
  (bnc#1012628).
- slab: alien caches must not be initialized if the allocation
  of the alien cache failed (bnc#1012628).
- fork, memcg: fix cached_stacks case (bnc#1012628).
- USB: Add USB_QUIRK_DELAY_CTRL_MSG quirk for Corsair K70 RGB
  (bnc#1012628).
- USB: storage: add quirk for SMI SM3350 (bnc#1012628).
- USB: storage: don't insert sane sense for SPC3+ when bad sense
  specified (bnc#1012628).
- usb: cdc-acm: send ZLP for Telit 3G Intel based modems
  (bnc#1012628).
- ARM: davinci: da830-evm: fix label names in GPIO lookup entries
  (bnc#1012628).
- ARM: davinci: dm644x-evm: fix label names in GPIO lookup entries
  (bnc#1012628).
- ARM: davinci: omapl138-hawk: fix label names in GPIO lookup
  entries (bnc#1012628).
- ARM: davinci: da850-evm: fix label names in GPIO lookup entries
  (bnc#1012628).
- ARM: davinci: dm355-evm: fix label names in GPIO lookup entries
  (bnc#1012628).
- cifs: check kzalloc return (bnc#1012628).
- cifs: Fix potential OOB access of lock element array
  (bnc#1012628).
- CIFS: Fix credit computation for compounded requests
  (bnc#1012628).
- CIFS: Do not hide EINTR after sending network packets
  (bnc#1012628).
- CIFS: Do not set credits to 1 if the server didn't grant
  anything (bnc#1012628).
- CIFS: Fix adjustment of credits for MTU requests (bnc#1012628).
- ALSA: hda/realtek - Disable headset Mic VREF for headset mode
  of ALC225 (bnc#1012628).
- ALSA: hda/realtek - Add unplug function into unplug state of
  Headset Mode for ALC225 (bnc#1012628).
- ALSA: hda/realtek - Support Dell headset mode for New AIO
  platform (bnc#1012628).
- x86, modpost: Replace last remnants of RETPOLINE with
  CONFIG_RETPOLINE (bnc#1012628).
- cpufreq: scmi: Fix frequency invariance in slow path
  (bnc#1012628).
- cpufreq: scpi/scmi: Fix freeing of dynamic OPPs (bnc#1012628).
- staging: rtl8188eu: Fix module loading from tasklet for WEP
  encryption (bnc#1012628).
- staging: rtl8188eu: Fix module loading from tasklet for CCMP
  encryption (bnc#1012628).
- usbcore: Select only first configuration for non-UAC3 compliant
  devices (bnc#1012628).
- Btrfs: fix deadlock when using free space tree due to block
  group creation (bnc#1012628).
- powerpc/tm: Unset MSR[TS] if not recheckpointing (bnc#1012628).
- commit 4b478de
* Mon Jan 14 2019 mkubecek@suse.cz
- Update to 5.0-rc2
- Config changes:
  - x86:
  - RESCTRL renamed to X86_RESCTRL
- commit 879eb5c
* Sun Jan 13 2019 jslaby@suse.cz
- Linux 4.20.2 (bnc#1012628).
- drm/rockchip: psr: do not dereference encoder before it is
  null checked (bnc#1012628).
- drm/vc4: Set ->is_yuv to false when num_planes == 1
  (bnc#1012628).
- drm/nouveau/drm/nouveau: Check rc from
  drm_dp_mst_topology_mgr_resume() (bnc#1012628).
- lib: fix build failure in CONFIG_DEBUG_VIRTUAL test
  (bnc#1012628).
- of: __of_detach_node() - remove node from phandle cache
  (bnc#1012628).
- of: of_node_get()/of_node_put() nodes held in phandle cache
  (bnc#1012628).
- power: supply: olpc_battery: correct the temperature units
  (bnc#1012628).
- intel_th: msu: Fix an off-by-one in attribute store
  (bnc#1012628).
- genwqe: Fix size check (bnc#1012628).
- selftests: Fix test errors related to lib.mk khdr target
  (bnc#1012628).
- powerpc/4xx/ocm: Fix compilation error due to PAGE_KERNEL usage
  (bnc#1012628).
- drivers/perf: hisi: Fixup one DDRC PMU register offset
  (bnc#1012628).
- video: fbdev: pxafb: Fix "WARNING: invalid free of devm_
  allocated data" (bnc#1012628).
- ceph: don't update importing cap's mseq when handing cap export
  (bnc#1012628).
- sched/fair: Fix infinite loop in update_blocked_averages()
  by reverting a9e7f6544b9c (bnc#1012628).
- iommu/vt-d: Handle domain agaw being less than iommu agaw
  (bnc#1012628).
- RDMA/iwcm: Don't copy past the end of dev_name() string
  (bnc#1012628).
- RDMA/srpt: Fix a use-after-free in the channel release code
  (bnc#1012628).
- stm class: Fix a module refcount leak in policy creation error
  path (bnc#1012628).
- rxe: fix error completion wr_id and qp_num (bnc#1012628).
- 9p/net: put a lower bound on msize (bnc#1012628).
- iio: dac: ad5686: fix bit shift read register (bnc#1012628).
- iio: adc: qcom-spmi-adc5: Initialize prescale properly
  (bnc#1012628).
- powerpc/tm: Set MSR[TS] just prior to recheckpoint
  (bnc#1012628).
- Revert "powerpc/tm: Unset MSR[TS] if not recheckpointing"
  (bnc#1012628).
- nfsd4: zero-length WRITE should succeed (bnc#1012628).
- xprtrdma: Yet another double DMA-unmap (bnc#1012628).
- lockd: Show pid of lockd for remote locks (bnc#1012628).
- PCI / PM: Allow runtime PM without callback functions
  (bnc#1012628).
- selinux: policydb - fix byte order and alignment issues
  (bnc#1012628).
- b43: Fix error in cordic routine (bnc#1012628).
- gfs2: Fix loop in gfs2_rbm_find (bnc#1012628).
- gfs2: Get rid of potential double-freeing in gfs2_create_inode
  (bnc#1012628).
- dlm: memory leaks on error path in dlm_user_request()
  (bnc#1012628).
- dlm: lost put_lkb on error path in receive_convert() and
  receive_unlock() (bnc#1012628).
- dlm: possible memory leak on error path in create_lkb()
  (bnc#1012628).
- dlm: fixed memory leaks after failed ls_remove_names allocation
  (bnc#1012628).
- dm: do not allow readahead to limit IO size (bnc#1012628).
- block: mq-deadline: Fix write completion handling (bnc#1012628).
- block: deactivate blk_stat timer in wbt_disable_default()
  (bnc#1012628).
- Fix failure path in alloc_pid() (bnc#1012628).
- driver core: Add missing dev->bus->need_parent_lock checks
  (bnc#1012628).
- srcu: Lock srcu_data structure in srcu_gp_start() (bnc#1012628).
- ALSA: usb-audio: Always check descriptor sizes in parser code
  (bnc#1012628).
- ALSA: usb-audio: Fix an out-of-bound read in
  create_composite_quirks (bnc#1012628).
- ALSA: usb-audio: Check mixer unit descriptors more strictly
  (bnc#1012628).
- ALSA: usb-audio: Avoid access before bLength check in
  build_audio_procunit() (bnc#1012628).
- ALSA: cs46xx: Potential NULL dereference in probe (bnc#1012628).
- media: cx23885: only reset DMA on problematic CPUs
  (bnc#1012628).
- mm, swap: fix swapoff with KSM pages (bnc#1012628).
- mm, hmm: mark hmm_devmem_{add, add_resource} EXPORT_SYMBOL_GPL
  (bnc#1012628).
- mm, hmm: replace hmm_devmem_pages_create() with
  devm_memremap_pages() (bnc#1012628).
- mm, hmm: use devm semantics for hmm_devmem_{add, remove}
  (bnc#1012628).
- mm, devm_memremap_pages: add MEMORY_DEVICE_PRIVATE support
  (bnc#1012628).
- sunrpc: use SVC_NET() in svcauth_gss_* functions (bnc#1012628).
- sunrpc: fix cache_head leak due to queued request (bnc#1012628).
- memcg, oom: notify on oom killer invocation from the charge path
  (bnc#1012628).
- mm, devm_memremap_pages: fix shutdown handling (bnc#1012628).
- mm, devm_memremap_pages: kill mapping "System RAM" support
  (bnc#1012628).
- mm, devm_memremap_pages: mark devm_memremap_pages()
  EXPORT_SYMBOL_GPL (bnc#1012628).
- hwpoison, memory_hotplug: allow hwpoisoned pages to be offlined
  (bnc#1012628).
- zram: fix double free backing device (bnc#1012628).
- fork: record start_time late (bnc#1012628).
- scsi: lpfc: do not set queue->page_count to 0 if
  pc_sli4_params.wqpcnt is invalid (bnc#1012628).
- scsi: zfcp: fix posting too many status read buffers leading
  to adapter shutdown (bnc#1012628).
- commit 036c5c2
* Fri Jan 11 2019 afaerber@suse.de
- config: arm64: Update to 5.0-rc1
- commit 88c2434
* Wed Jan  9 2019 jslaby@suse.cz
- Linux 4.20.1 (bnc#1012628).
- panic: avoid deadlocks in re-entrant console drivers
  (bnc#1012628).
- iwlwifi: add new cards for 9560, 9462, 9461 and killer series
  (bnc#1012628).
- media: ov5640: Fix set format regression (bnc#1012628).
- bnx2x: Fix NULL pointer dereference in bnx2x_del_all_vlans()
  on some hw (bnc#1012628).
- tap: call skb_probe_transport_header after setting skb->dev
  (bnc#1012628).
- ax25: fix a use-after-free in ax25_fillin_cb() (bnc#1012628).
- ibmveth: fix DMA unmap error in ibmveth_xmit_start error path
  (bnc#1012628).
- ieee802154: lowpan_header_create check must check daddr
  (bnc#1012628).
- ip: validate header length on virtual device xmit (bnc#1012628).
- net/hamradio/6pack: use mod_timer() to rearm timers
  (bnc#1012628).
- isdn: fix kernel-infoleak in capi_unlocked_ioctl (bnc#1012628).
- netrom: fix locking in nr_find_socket() (bnc#1012628).
- net/wan: fix a double free in x25_asy_open_tty() (bnc#1012628).
- ptr_ring: wrap back ->producer in __ptr_ring_swap_queue()
  (bnc#1012628).
- sock: Make sock->sk_stamp thread-safe (bnc#1012628).
- tipc: fix a double free in tipc_enable_bearer() (bnc#1012628).
- IB/hfi1: Incorrect sizing of sge for PIO will OOPs
  (bnc#1012628).
- ALSA: rme9652: Fix potential Spectre v1 vulnerability
  (bnc#1012628).
- ALSA: emu10k1: Fix potential Spectre v1 vulnerabilities
  (bnc#1012628).
- ALSA: pcm: Fix potential Spectre v1 vulnerability (bnc#1012628).
- ALSA: emux: Fix potential Spectre v1 vulnerabilities
  (bnc#1012628).
- powerpc/fsl: Fix spectre_v2 mitigations reporting (bnc#1012628).
- mtd: atmel-quadspi: disallow building on ebsa110 (bnc#1012628).
- mtd: rawnand: marvell: prevent timeouts on a loaded machine
  (bnc#1012628).
- mtd: rawnand: Fix JEDEC detection (bnc#1012628).
- mtd: rawnand: omap2: Pass the parent of pdev to
  dma_request_chan() (bnc#1012628).
- ALSA: hda: add mute LED support for HP EliteBook 840 G4
  (bnc#1012628).
- ALSA: hda/realtek: Enable audio jacks of ASUS UX391UA with
  ALC294 (bnc#1012628).
- ALSA: fireface: fix for state to fetch PCM frames (bnc#1012628).
- ALSA: firewire-lib: fix wrong handling payload_length as
  payload_quadlet (bnc#1012628).
- ALSA: firewire-lib: fix wrong assignment for
  'out_packet_without_header' tracepoint (bnc#1012628).
- ALSA: firewire-lib: use the same print format for
  'without_header' tracepoints (bnc#1012628).
- ALSA: hda/realtek: Enable the headset mic auto detection for
  ASUS laptops (bnc#1012628).
- ALSA: hda/tegra: clear pending irq handlers (bnc#1012628).
- usb: dwc2: host: use hrtimer for NAK retries (bnc#1012628).
- USB: serial: pl2303: add ids for Hewlett-Packard HP POS pole
  displays (bnc#1012628).
- USB: serial: option: add Fibocom NL678 series (bnc#1012628).
- usb: r8a66597: Fix a possible concurrency use-after-free bug
  in r8a66597_endpoint_disable() (bnc#1012628).
- usb: dwc2: disable power_down on Amlogic devices (bnc#1012628).
- Revert "usb: dwc3: pci: Use devm functions to get the phy GPIOs"
  (bnc#1012628).
- usb: roles: Add a description for the class to Kconfig
  (bnc#1012628).
- media: dvb-usb-v2: Fix incorrect use of transfer_flags
  URB_FREE_BUFFER (bnc#1012628).
- i915: fix missing user_access_end() in page fault exception case
  (bnc#1012628).
- staging: wilc1000: fix missing read_write setting when reading
  data (bnc#1012628).
- staging: bcm2835-audio: double free in init error path
  (bnc#1012628).
- ASoC: intel: cht_bsw_max98090_ti: Add pmc_plt_clk_0 quirk for
  Chromebook Clapper (bnc#1012628).
- ASoC: intel: cht_bsw_max98090_ti: Add pmc_plt_clk_0 quirk for
  Chromebook Gnawty (bnc#1012628).
- s390/pci: fix sleeping in atomic during hotplug (bnc#1012628).
- Input: atmel_mxt_ts - don't try to free unallocated kernel
  memory (bnc#1012628).
- Input: elan_i2c - add ACPI ID for touchpad in ASUS Aspire
  F5-573G (bnc#1012628).
- x86/speculation/l1tf: Drop the swap storage limit restriction
  when l1tf=off (bnc#1012628).
- x86/mm: Drop usage of __flush_tlb_all() in
  kernel_physical_mapping_init() (bnc#1012628).
- KVM: x86: Use jmp to invoke kvm_spurious_fault() from .fixup
  (bnc#1012628).
- arm64: KVM: Make VHE Stage-2 TLB invalidation operations
  non-interruptible (bnc#1012628).
- KVM: PPC: Book3S HV: Fix race between kvm_unmap_hva_range and
  MMU mode switch (bnc#1012628).
- KVM: nVMX: Free the VMREAD/VMWRITE bitmaps if alloc_kvm_area()
  fails (bnc#1012628).
- platform-msi: Free descriptors in platform_msi_domain_free()
  (bnc#1012628).
- drm/v3d: Skip debugfs dumping GCA on platforms without GCA
  (bnc#1012628).
- DRM: UDL: get rid of useless vblank initialization
  (bnc#1012628).
- clocksource/drivers/arc_timer: Utilize generic sched_clock
  (bnc#1012628).
- perf machine: Record if a arch has a single user/kernel address
  space (bnc#1012628).
- perf thread: Add fallback functions for cases where cpumode
  is insufficient (bnc#1012628).
- perf tools: Use fallback for sample_addr_correlates_sym()
  cases (bnc#1012628).
- perf script: Use fallbacks for branch stacks (bnc#1012628).
- perf pmu: Suppress potential format-truncation warning
  (bnc#1012628).
- perf env: Also consider env->arch == NULL as local operation
  (bnc#1012628).
- ocxl: Fix endiannes bug in ocxl_link_update_pe() (bnc#1012628).
- ocxl: Fix endiannes bug in read_afu_name() (bnc#1012628).
- ext4: add ext4_sb_bread() to disambiguate ENOMEM cases
  (bnc#1012628).
- ext4: fix possible use after free in ext4_quota_enable
  (bnc#1012628).
- ext4: missing unlock/put_page() in
  ext4_try_to_write_inline_data() (bnc#1012628).
- ext4: fix EXT4_IOC_GROUP_ADD ioctl (bnc#1012628).
- ext4: include terminating u32 in size of xattr entries when
  expanding inodes (bnc#1012628).
- ext4: avoid declaring fs inconsistent due to invalid file
  handles (bnc#1012628).
- ext4: force inode writes when nfsd calls commit_metadata()
  (bnc#1012628).
- ext4: check for shutdown and r/o file system in
  ext4_write_inode() (bnc#1012628).
- spi: bcm2835: Fix race on DMA termination (bnc#1012628).
- spi: bcm2835: Fix book-keeping of DMA termination (bnc#1012628).
- spi: bcm2835: Avoid finishing transfer prematurely in IRQ mode
  (bnc#1012628).
- clk: rockchip: fix typo in rk3188 spdif_frac parent
  (bnc#1012628).
- clk: sunxi-ng: Use u64 for calculation of NM rate (bnc#1012628).
- crypto: cavium/nitrox - fix a DMA pool free failure
  (bnc#1012628).
- crypto: chcr - small packet Tx stalls the queue (bnc#1012628).
- crypto: testmgr - add AES-CFB tests (bnc#1012628).
- crypto: cfb - fix decryption (bnc#1012628).
- cgroup: fix CSS_TASK_ITER_PROCS (bnc#1012628).
- binder: fix use-after-free due to ksys_close() during fdget()
  (bnc#1012628).
- cdc-acm: fix abnormal DATA RX issue for Mediatek Preloader
  (bnc#1012628).
- btrfs: dev-replace: go back to suspended state if target device
  is missing (bnc#1012628).
- btrfs: dev-replace: go back to suspend state if another EXCL_OP
  is running (bnc#1012628).
- Btrfs: fix deadlock with memory reclaim during scrub
  (bnc#1012628).
- btrfs: skip file_extent generation check for free_space_inode
  in run_delalloc_nocow (bnc#1012628).
- Btrfs: fix fsync of files with multiple hard links in new
  directories (bnc#1012628).
- btrfs: run delayed items before dropping the snapshot
  (bnc#1012628).
- Btrfs: send, fix race with transaction commits that create
  snapshots (bnc#1012628).
- brcmfmac: fix roamoff=1 modparam (bnc#1012628).
- brcmfmac: Fix out of bounds memory access during fw load
  (bnc#1012628).
- KEYS: fix parsing invalid pkey info string (bnc#1012628).
- powerpc/tm: Unset MSR[TS] if not recheckpointing (bnc#1012628).
- f2fs: read page index before freeing (bnc#1012628).
- f2fs: fix to update new block address correctly for OPU
  (bnc#1012628).
- f2fs: fix missing unlock(sbi->gc_mutex) (bnc#1012628).
- f2fs: fix validation of the block count in
  sanity_check_raw_super (bnc#1012628).
- f2fs: sanity check of xattr entry size (bnc#1012628).
- serial: uartps: Fix interrupt mask issue to handle the RX
  interrupts properly (bnc#1012628).
- media: cec: keep track of outstanding transmits (bnc#1012628).
- media: cec-pin: fix broken tx_ignore_nack_until_eom error
  injection (bnc#1012628).
- media: rc: cec devices do not have a lirc chardev (bnc#1012628).
- media: imx274: fix stack corruption in imx274_read_reg
  (bnc#1012628).
- media: vivid: free bitmap_cap when updating std/timings/etc
  (bnc#1012628).
- media: vim2m: use cancel_delayed_work_sync instead of
  flush_schedule_work (bnc#1012628).
- media: vb2: check memory model for VIDIOC_CREATE_BUFS
  (bnc#1012628).
- media: v4l2-tpg: array index could become negative
  (bnc#1012628).
- media: v4l2-fwnode: Fix setting V4L2_MBUS_DATA_ACTIVE_HIGH/LOW
  flag (bnc#1012628).
- tools lib traceevent: Fix processing of dereferenced args in
  bprintk events (bnc#1012628).
- MIPS: math-emu: Write-protect delay slot emulation pages
  (bnc#1012628).
- MIPS: c-r4k: Add r4k_blast_scache_node for Loongson-3
  (bnc#1012628).
- MIPS: Ensure pmd_present() returns false after
  pmd_mknotpresent() (bnc#1012628).
- MIPS: Align kernel load address to 64KB (bnc#1012628).
- MIPS: Expand MIPS32 ASIDs to 64 bits (bnc#1012628).
- MIPS: OCTEON: mark RGMII interface disabled on OCTEON III
  (bnc#1012628).
- MIPS: Fix a R10000_LLSC_WAR logic in atomic.h (bnc#1012628).
- CIFS: Fix error mapping for SMB2_LOCK command which caused
  OFD lock problem (bnc#1012628).
- smb3: fix large reads on encrypted connections (bnc#1012628).
- CIFS: return correct errors when pinning memory failed for
  direct I/O (bnc#1012628).
- CIFS: use the correct length when pinning memory for direct
  I/O for write (bnc#1012628).
- arm64: KVM: Avoid setting the upper 32 bits of VTCR_EL2 to 1
  (bnc#1012628).
- arm/arm64: KVM: vgic: Force VM halt when changing the active
  state of GICv3 PPIs/SGIs (bnc#1012628).
- ARM: dts: exynos: Specify I2S assigned clocks in proper node
  (bnc#1012628).
- rtc: m41t80: Correct alarm month range with RTC reads
  (bnc#1012628).
- KVM: arm/arm64: vgic: Do not cond_resched_lock() with IRQs
  disabled (bnc#1012628).
- KVM: arm/arm64: vgic: Cap SPIs to the VM-defined maximum
  (bnc#1012628).
- KVM: arm/arm64: vgic-v2: Set active_source to 0 when restoring
  state (bnc#1012628).
- KVM: arm/arm64: Fix VMID alloc race by reverting to lock-less
  (bnc#1012628).
- KVM: arm/arm64: vgic: Fix off-by-one bug in vgic_get_irq()
  (bnc#1012628).
- iommu/arm-smmu-v3: Fix big-endian CMD_SYNC writes (bnc#1012628).
- arm64: compat: Avoid sending SIGILL for unallocated syscall
  numbers (bnc#1012628).
- arm64: compat: Don't pull syscall number from regs in
  arm_compat_syscall (bnc#1012628).
- parisc: Remap hugepage-aligned pages in set_kernel_text_rw()
  (bnc#1012628).
- tpm: tpm_try_transmit() refactor error flow (bnc#1012628).
- tpm: tpm_i2c_nuvoton: use correct command duration for TPM 2.x
  (bnc#1012628).
- spi: bcm2835: Unbreak the build of esoteric configs
  (bnc#1012628).
- MIPS: Only include mmzone.h when CONFIG_NEED_MULTIPLE_NODES=y
  (bnc#1012628).
- commit 5978cc8
* Tue Jan  8 2019 jslaby@suse.cz
- packet: validate address length if non-zero (nmap EINVAL
  failure).
- commit 34f009a
* Mon Jan  7 2019 mkubecek@suse.cz
- config: restore accidentally lost BPFILTER_UMH (ppc64, ppc64le, s390x)
- commit a56baa9
* Mon Jan  7 2019 mkubecek@suse.cz
- vfio_pci: Add local source directory as include.
- commit ea6d6e3
* Mon Jan  7 2019 mkubecek@suse.cz
- Update to 5.0-rc1
- Eliminated 1 patch
- ARM configs need update
- Config changes:
  - PM:
  - ENERGY_MODEL=y
  - Networking:
  - CAN_FLEXCAN=m
  - USB_NET_AQC111=m
  - QTNFMAC_PCIE=m
  - VIRT_WIFI=m
  - PCI:
  - PCI_MESON=n
  - SCSI:
  - SCSI_UFS_CDNS_PLATFORM=m
  - NVME:
  - NVME_TCP=m
  - NVME_TARGET_TCP=m
  - Graphics:
  - DRM_PANEL_OLIMEX_LCD_OLINUXINO=n
  - DRM_PANEL_SAMSUNG_S6D16D0=n
  - DRM_PANEL_TRULY_NT35597_WQXGA=n
  - TINYDRM_HX8357D=n
  - Sound:
  - SND_SOC_AMD_ACP3x=n
  - SND_SOC_INTEL_KBL_RT5660_MACH=m
  - SND_SOC_XILINX_I2S=n
  - SND_SOC_AK4118=n
  - Multimedia:
  - VIDEO_ASPEED=m
  - VIDEO_SECO_CEC=m
  - VIDEO_SECO_RC=y
  - I3C:
  - I3C=m
  - CDNS_I3C_MASTER=m
  - DW_I3C_MASTER=m
  - IIO:
  - AD7124=n
  - AD7949=n
  - TI_DAC7311=n
  - VCNL4035=n
  - SENSORS_RM3100_I2C=n
  - SENSORS_RM3100_SPI=n
  - MCP41010=m
  - PHY:
  - PHY_CADENCE_SIERRA=m
  - PHY_FSL_IMX8MQ_USB=m
  - misc drivers:
  - MTD_PHYSMAP_GPIO_ADDR=y
  - SPI_MXIC=n
  - MISC_ALCOR_PCI=m
  - RC_XBOX_DVD=m
  - PINCTRL_OCELOT=n
  - GPIO_CADENCE=m
  - SENSORS_OCC_P8_I2C=m
  - TQMX86_WDT=m
  - MMC_ALCOR=m
  - MMC_SDHCI_AM654=m
  - LEDS_TRIGGER_AUDIO=m
  - SERIO_OLPC_APSP=m
  - Security:
  - INTEGRITY_PLATFORM_KEYRING=y
  - IMA_ARCH_POLICY=y
  - Crypto:
  - CRYPTO_ADIANTUM=m
  - CRYPTO_STREEBOG=m
  - CRYPTO_STATS=n
  - Library:
  - RAID6_PQ_BENCHMARK=y (preserve current behaviour)
  - Testing:
  - TEST_OBJAGG=n
  - x86:
  - RESCTRL=y
  - HUAWEI_WMI=m
  - i386:
  - PVH=y
  - MTD_PHYSMAP_OF=m
  - ppc*:
  - PVPANIC=m
  - FB_LOGO_CENTER=n
  - FSI_OCC=m
  - DEBUG_VIRTUAL=n
  - SENSORS_OCC_P9_SBE=m
  - s390x:
  - PCCARD=n
  - RAPIDIO
  - other RapidIO options copy other architectures
  - DMADEVICES related options copy other architectures
  - */debug:
  - CRYPTO_STATS=y
  - TTY_PRINTK_LEVEL=6
- commit 6a4ceaa
* Mon Dec 24 2018 mkubecek@suse.cz
- Update to 4.20 final
- Eliminated 1 patch
- Refresh configs
- commit ba5c149
* Sat Dec 22 2018 jslaby@suse.cz
- Linux 4.19.12 (bnc#1012628).
- Btrfs: fix missing delayed iputs on unmount (bnc#1012628).
- nvmet-rdma: fix response use after free (bnc#1012628).
- nvme: validate controller state before rescheduling keep alive
  (bnc#1012628).
- i2c: uniphier-f: fix violation of tLOW requirement for Fast-mode
  (bnc#1012628).
- i2c: uniphier: fix violation of tLOW requirement for Fast-mode
  (bnc#1012628).
- i2c: scmi: Fix probe error on devices with an empty SMB0001
  ACPI device node (bnc#1012628).
- i2c: axxia: properly handle master timeout (bnc#1012628).
- mlxsw: spectrum_switchdev: Fix VLAN device deletion via ioctl
  (bnc#1012628).
- vhost/vsock: fix reset orphans race with close timeout
  (bnc#1012628).
- cifs: In Kconfig CONFIG_CIFS_POSIX needs depends on legacy
  (insecure cifs) (bnc#1012628).
- drm/ast: Fix connector leak during driver unload (bnc#1012628).
- acpi/nfit: Fix user-initiated ARS to be "ARS-long" rather than
  "ARS-short" (bnc#1012628).
- tools/testing/nvdimm: Align test resources to 128M
  (bnc#1012628).
- drm/amdgpu/vcn: Update vcn.cur_state during suspend
  (bnc#1012628).
- net: mvpp2: fix phylink handling of invalid PHY modes
  (bnc#1012628).
- net: mvpp2: fix detection of 10G SFP modules (bnc#1012628).
- thermal: armada: fix legacy validity test sense (bnc#1012628).
- ethernet: fman: fix wrong of_node_put() in probe function
  (bnc#1012628).
- ARM: 8816/1: dma-mapping: fix potential uninitialized return
  (bnc#1012628).
- ARM: 8815/1: V7M: align v7m_dma_inv_range() with v7 counterpart
  (bnc#1012628).
- ARM: 8814/1: mm: improve/fix ARM v7_dma_inv_range() unaligned
  address handling (bnc#1012628).
- bpf: check pending signals while verifying programs
  (bnc#1012628).
- net/mlx4_en: Fix build break when CONFIG_INET is off
  (bnc#1012628).
- mv88e6060: disable hardware level MAC learning (bnc#1012628).
- macvlan: return correct error value (bnc#1012628).
- libata: whitelist all SAMSUNG MZ7KM* solid-state disks
  (bnc#1012628).
- Input: omap-keypad - fix keyboard debounce configuration
  (bnc#1012628).
- Input: synaptics - enable SMBus for HP 15-ay000 (bnc#1012628).
- clk: mmp: Off by one in mmp_clk_add() (bnc#1012628).
- clk: mvebu: Off by one bugs in cp110_of_clk_get() (bnc#1012628).
- drm/amd/powerplay: issue pre-display settings for display
  change event (bnc#1012628).
- drm/msm: Fix error return checking (bnc#1012628).
- drm/msm: dpu: Fix "WARNING: invalid free of devm_ allocated
  data" (bnc#1012628).
- drm/msm: dpu: Don't set legacy plane->crtc pointer
  (bnc#1012628).
- drm/msm/hdmi: Enable HPD after HDMI IRQ is set up (bnc#1012628).
- ide: pmac: add of_node_put() (bnc#1012628).
- drivers/tty: add missing of_node_put() (bnc#1012628).
- drivers/sbus/char: add of_node_put() (bnc#1012628).
- sbus: char: add of_node_put() (bnc#1012628).
- SUNRPC: Fix a potential race in xprt_connect() (bnc#1012628).
- nfs: don't dirty kernel pages read by direct-io (bnc#1012628).
- liquidio: read sc->iq_no before release sc (bnc#1012628).
- bpf: Fix verifier log string check for bad alignment
  (bnc#1012628).
- bonding: fix 802.3ad state sent to partner when unbinding slave
  (bnc#1012628).
- net: aquantia: fix rx checksum offload bits (bnc#1012628).
- net: stmmac: Move debugfs init/exit to ->probe()/->remove()
  (bnc#1012628).
- ARC: io.h: Implement reads{x}()/writes{x}() (bnc#1012628).
- drm/amdgpu: wait for IB test on first device open (bnc#1012628).
- drm/ttm: fix LRU handling in ttm_buffer_object_transfer
  (bnc#1012628).
- drm/msm: Grab a vblank reference when waiting for commit_done
  (bnc#1012628).
- drm/msm/dsi: configure VCO rate for 10nm PLL driver
  (bnc#1012628).
- drm/msm: fix handling of cmdstream offset (bnc#1012628).
- drm/msm/gpu: Fix a couple memory leaks in debugfs (bnc#1012628).
- drm/msm: Fix task dump in gpu recovery (bnc#1012628).
- x86/earlyprintk/efi: Fix infinite loop on some screen widths
  (bnc#1012628).
- drm/amd/display: Fix 6x4K displays light-up on Vega20 (v2)
  (bnc#1012628).
- net: ethernet: ave: Replace NET_IP_ALIGN with AVE_FRAME_HEADROOM
  (bnc#1012628).
- tools/bpf: add addition type tests to test_btf (bnc#1012628).
- tools/bpf: fix two test_btf unit test cases (bnc#1012628).
- scsi: vmw_pscsi: Rearrange code to avoid multiple calls to
  free_irq during unload (bnc#1012628).
- scsi: libiscsi: Fix NULL pointer dereference in
  iscsi_eh_session_reset (bnc#1012628).
- i2c: rcar: check bus state before reinitializing (bnc#1012628).
- Input: hyper-v - fix wakeup from suspend-to-idle (bnc#1012628).
- mac80211_hwsim: fix module init error paths for netlink
  (bnc#1012628).
- IB/hfi1: Remove race conditions in user_sdma send path
  (bnc#1012628).
- locking/qspinlock, x86: Provide liveness guarantee
  (bnc#1012628).
- locking/qspinlock: Re-order code (bnc#1012628).
- commit c634493
* Fri Dec 21 2018 mkubecek@suse.cz
- rtlwifi: Fix leak of skb when processing C2H_BT_INFO
  (bsc#1116448).
- commit 9d82d20
* Thu Dec 20 2018 msuchanek@suse.de
- mm: add mm_pxd_folded checks to pgtable_bytes accounting
  functions (s390/mm: fix mis-accounting of pgtable_bytes).
- mm: introduce mm_[p4d|pud|pmd]_folded (s390/mm: fix
  mis-accounting of pgtable_bytes).
- mm: make the __PAGETABLE_PxD_FOLDED defines non-empty (s390/mm:
  fix mis-accounting of pgtable_bytes).
- commit c005ee0
* Thu Dec 20 2018 jslaby@suse.cz
- Linux 4.19.11 (bnc#1012628).
- sched/pelt: Fix warning and clean up IRQ PELT config
  (bnc#1012628).
- scsi: raid_attrs: fix unused variable warning (bnc#1012628).
- staging: olpc_dcon: add a missing dependency (bnc#1012628).
- slimbus: ngd: mark PM functions as __maybe_unused (bnc#1012628).
- i2c: aspeed: fix build warning (bnc#1012628).
- ARM: dts: qcom-apq8064-arrow-sd-600eval fix graph_endpoint
  warning (bnc#1012628).
- drm/msm: fix address space warning (bnc#1012628).
- pinctrl: sunxi: a83t: Fix IRQ offset typo for PH11
  (bnc#1012628).
- aio: fix spectre gadget in lookup_ioctx (bnc#1012628).
- scripts/spdxcheck.py: always open files in binary mode
  (bnc#1012628).
- fs/iomap.c: get/put the page in iomap_page_create/release()
  (bnc#1012628).
- userfaultfd: check VM_MAYWRITE was set after verifying the
  uffd is registered (bnc#1012628).
- arm64: dma-mapping: Fix FORCE_CONTIGUOUS buffer clearing
  (bnc#1012628).
- block/bio: Do not zero user pages (bnc#1012628).
- ovl: fix decode of dir file handle with multi lower layers
  (bnc#1012628).
- ovl: fix missing override creds in link of a metacopy upper
  (bnc#1012628).
- MMC: OMAP: fix broken MMC on OMAP15XX/OMAP5910/OMAP310
  (bnc#1012628).
- mmc: core: use mrq->sbc when sending CMD23 for RPMB
  (bnc#1012628).
- mmc: sdhci-omap: Fix DCRC error handling during tuning
  (bnc#1012628).
- mmc: sdhci: fix the timeout check window for clock and reset
  (bnc#1012628).
- fuse: continue to send FUSE_RELEASEDIR when FUSE_OPEN returns
  ENOSYS (bnc#1012628).
- ARM: mmp/mmp2: fix cpu_is_mmp2() on mmp2-dt (bnc#1012628).
- ARM: dts: bcm2837: Fix polarity of wifi reset GPIOs
  (bnc#1012628).
- dm thin: send event about thin-pool state change _after_
  making it (bnc#1012628).
- dm cache metadata: verify cache has blocks in
  blocks_are_clean_separate_dirty() (bnc#1012628).
- dm: call blk_queue_split() to impose device limits on bios
  (bnc#1012628).
- tracing: Fix memory leak in create_filter() (bnc#1012628).
- tracing: Fix memory leak in set_trigger_filter() (bnc#1012628).
- tracing: Fix memory leak of instance function hash filters
  (bnc#1012628).
- media: vb2: don't call __vb2_queue_cancel if vb2_start_streaming
  failed (bnc#1012628).
- powerpc/msi: Fix NULL pointer access in teardown code
  (bnc#1012628).
- powerpc: Look for "stdout-path" when setting up legacy consoles
  (bnc#1012628).
- drm/nouveau/kms: Fix memory leak in nv50_mstm_del()
  (bnc#1012628).
- drm/nouveau/kms/nv50-: also flush fb writes when rewinding
  push buffer (bnc#1012628).
- Revert "drm/rockchip: Allow driver to be shutdown on
  reboot/kexec" (bnc#1012628).
- drm/i915/gvt: Fix tiled memory decoding bug on BDW
  (bnc#1012628).
- drm/i915/execlists: Apply a full mb before execution for
  Braswell (bnc#1012628).
- drm/amdgpu/powerplay: Apply avfs cks-off voltages on VI
  (bnc#1012628).
- drm/amdkfd: add new vega10 pci ids (bnc#1012628).
- drm/amdgpu: add some additional vega10 pci ids (bnc#1012628).
- drm/amdgpu: update smu firmware images for VI variants (v2)
  (bnc#1012628).
- drm/amdgpu: update SMC firmware image for polaris10 variants
  (bnc#1012628).
- dm zoned: Fix target BIO completion handling (bnc#1012628).
- commit 096f733
* Mon Dec 17 2018 jslaby@suse.cz
- Linux 4.19.10 (bnc#1012628).
- tcp: lack of available data can also cause TSO defer
  (bnc#1012628).
- bpf: fix off-by-one error in adjust_subprog_starts
  (bnc#1012628).
- IB/hfi1: Fix an out-of-bounds access in get_hw_stats
  (bnc#1012628).
- ALSA: hda/realtek - Fix the mute LED regresion on Lenovo X1
  Carbon (bnc#1012628).
- ALSA: hda/realtek: Enable audio jacks of ASUS UX433FN/UX333FA
  with ALC294 (bnc#1012628).
- ALSA: hda/realtek: Enable audio jacks of ASUS UX533FD with
  ALC294 (bnc#1012628).
- ALSA: hda/realtek: ALC294 mic and headset-mode fixups for ASUS
  X542UN (bnc#1012628).
- ALSA: hda/realtek - Fixed headphone issue for ALC700
  (bnc#1012628).
- ALSA: fireface: fix reference to wrong register for clock
  configuration (bnc#1012628).
- dax: Check page->mapping isn't NULL (bnc#1012628).
- flexfiles: enforce per-mirror stateid only for v4 DSes
  (bnc#1012628).
- ocfs2: fix potential use after free (bnc#1012628).
- initramfs: clean old path before creating a hardlink
  (bnc#1012628).
- kernel/kcov.c: mark funcs in __sanitizer_cov_trace_pc() as
  notrace (bnc#1012628).
- proc: fixup map_files test on arm (bnc#1012628).
- debugobjects: avoid recursive calls with kmemleak (bnc#1012628).
- hfsplus: do not free node before using (bnc#1012628).
- hfs: do not free node before using (bnc#1012628).
- mm/page_alloc.c: fix calculation of pgdat->nr_zones
  (bnc#1012628).
- ocfs2: fix deadlock caused by ocfs2_defrag_extent()
  (bnc#1012628).
- ACPI/IORT: Fix iort_get_platform_device_domain() uninitialized
  pointer value (bnc#1012628).
- nvme-rdma: fix double freeing of async event data (bnc#1012628).
- nvme: flush namespace scanning work just before removing
  namespaces (bnc#1012628).
- nvme: warn when finding multi-port subsystems without
  multipathing enabled (bnc#1012628).
- fscache, cachefiles: remove redundant variable 'cache'
  (bnc#1012628).
- cachefiles: Explicitly cast enumerated type in put_object
  (bnc#1012628).
- fscache: fix race between enablement and dropping of object
  (bnc#1012628).
- afs: Fix validation/callback interaction (bnc#1012628).
- pstore/ram: Correctly calculate usable PRZ bytes (bnc#1012628).
- pvcalls-front: fixes incorrect error handling (bnc#1012628).
- Revert "xen/balloon: Mark unallocated host memory as UNUSABLE"
  (bnc#1012628).
- xen: xlate_mmu: add missing header to fix 'W=1' warning
  (bnc#1012628).
- drm/ast: fixed reading monitor EDID not stable issue
  (bnc#1012628).
- drm/amdgpu: Add delay after enable RLC ucode (bnc#1012628).
- net: hisilicon: remove unexpected free_netdev (bnc#1012628).
- ixgbe: recognize 1000BaseLX SFP modules as 1Gbps (bnc#1012628).
- igb: fix uninitialized variables (bnc#1012628).
- cachefiles: Fix page leak in cachefiles_read_backing_file
  while vmscan is active (bnc#1012628).
- fscache: Fix race in fscache_op_complete() due to split
  atomic_sub & read (bnc#1012628).
- cachefiles: Fix an assertion failure when trying to update a
  failed object (bnc#1012628).
- ALSA: usb-audio: Add vendor and product name for Dell WD19 Dock
  (bnc#1012628).
- netfilter: nf_tables: deactivate expressions in rule replecement
  routine (bnc#1012628).
- usb: gadget: u_ether: fix unsafe list iteration (bnc#1012628).
- net: thunderx: fix NULL pointer dereference in nic_remove
  (bnc#1012628).
- x86/kvm/vmx: fix old-style function declaration (bnc#1012628).
- KVM: x86: fix empty-body warnings (bnc#1012628).
- KVM: VMX: Update shared MSRs to be saved/restored on
  MSR_EFER.LMA changes (bnc#1012628).
- netfilter: nf_conncount: remove wrong condition check routine
  (bnc#1012628).
- netfilter: nat: fix double register in masquerade modules
  (bnc#1012628).
- netfilter: add missing error handling code for register
  functions (bnc#1012628).
- IB/mlx5: Fix page fault handling for MW (bnc#1012628).
- netfilter: ipv6: Preserve link scope traffic original oif
  (bnc#1012628).
- drm/meson: add support for 1080p25 mode (bnc#1012628).
- thunderbolt: Prevent root port runtime suspend during NVM
  upgrade (bnc#1012628).
- USB: omap_udc: fix rejection of out transfers when DMA is used
  (bnc#1012628).
- USB: omap_udc: fix USB gadget functionality on Palm Tungsten E
  (bnc#1012628).
- USB: omap_udc: fix omap_udc_start() on 15xx machines
  (bnc#1012628).
- USB: omap_udc: fix crashes on probe error and module removal
  (bnc#1012628).
- USB: omap_udc: use devm_request_irq() (bnc#1012628).
- ipvs: call ip_vs_dst_notifier earlier than ipv6_dev_notf
  (bnc#1012628).
- fsi: master-ast-cf: select GENERIC_ALLOCATOR (bnc#1012628).
- bpf: fix check of allowed specifiers in bpf_trace_printk
  (bnc#1012628).
- RDMA/hns: Bugfix pbl configuration for rereg mr (bnc#1012628).
- exportfs: do not read dentry after free (bnc#1012628).
- ASoC: omap-dmic: Add pm_qos handling to avoid overruns with
  CPU_IDLE (bnc#1012628).
- ASoC: omap-mcpdm: Add pm_qos handling to avoid under/overruns
  with CPU_IDLE (bnc#1012628).
- ASoC: omap-mcbsp: Fix latency value calculation for pm_qos
  (bnc#1012628).
- tools: bpftool: fix potential NULL pointer dereference in
  do_load (bnc#1012628).
- RDMA/rdmavt: Fix rvt_create_ah function signature (bnc#1012628).
- RDMA/bnxt_re: Avoid accessing the device structure after it
  is freed (bnc#1012628).
- RDMA/bnxt_re: Fix system hang when registration with L2 driver
  fails (bnc#1012628).
- RDMA/core: Add GIDs while changing MAC addr only for registered
  ndev (bnc#1012628).
- RDMA/mlx5: Fix fence type for IB_WR_LOCAL_INV WR (bnc#1012628).
- Btrfs: send, fix infinite loop due to directory rename
  dependencies (bnc#1012628).
- ARM: dts: at91: sama5d2: use the divided clock for SMC
  (bnc#1012628).
- phy: qcom-qusb2: Fix HSTX_TRIM tuning with fused value for
  SDM845 (bnc#1012628).
- phy: qcom-qusb2: Use HSTX_TRIM fused value as is (bnc#1012628).
- objtool: Fix segfault in .cold detection with
  - ffunction-sections (bnc#1012628).
- objtool: Fix double-free in .cold detection error path
  (bnc#1012628).
- ASoC: acpi: fix: continue searching when machine is ignored
  (bnc#1012628).
- PCI: imx6: Fix link training status detection in link up check
  (bnc#1012628).
- perf tools: Restore proper cwd on return from mnt namespace
  (bnc#1012628).
- hwmon: (w83795) temp4_type has writable permission
  (bnc#1012628).
- netfilter: xt_hashlimit: fix a possible memory leak in
  htable_create() (bnc#1012628).
- aio: fix failure to put the file pointer (bnc#1012628).
- bpf: allocate local storage buffers using GFP_ATOMIC
  (bnc#1012628).
- hwmon: (mlxreg-fan) Fix macros for tacho fault reading
  (bnc#1012628).
- spi: omap2-mcspi: Add missing suspend and resume calls
  (bnc#1012628).
- ASoC: dapm: Recalculate audio map forcely when card instantiated
  (bnc#1012628).
- ASoC: omap-abe-twl6040: Fix missing audio card caused by
  deferred probing (bnc#1012628).
- hwmon: (ina2xx) Fix current value calculation (bnc#1012628).
- s390/cpum_cf: Reject request for sampling in event
  initialization (bnc#1012628).
- ASoC: qcom: Set dai_link id to each dai_link (bnc#1012628).
- ASoC: Intel: Power down links before turning off display audio
  power (bnc#1012628).
- ASoC: wm_adsp: Fix dma-unsafe read of scratch registers
  (bnc#1012628).
- ASoC: rockchip: add missing slave_config setting for I2S
  (bnc#1012628).
- hwmon: (raspberrypi) Fix initial notify (bnc#1012628).
- hwmon (ina2xx) Fix NULL id pointer in probe() (bnc#1012628).
- s390/cio: Fix cleanup when unsupported IDA format is used
  (bnc#1012628).
- s390/cio: Fix cleanup of pfn_array alloc failure (bnc#1012628).
- netfilter: nf_tables: fix use-after-free when deleting compat
  expressions (bnc#1012628).
- netfilter: xt_RATEEST: remove netns exit routine (bnc#1012628).
- perf tools: Fix crash on synthesizing the unit (bnc#1012628).
- selftests: add script to stress-test nft packet path vs. control
  plane (bnc#1012628).
- netfilter: nf_tables: don't skip inactive chains during update
  (bnc#1012628).
- netfilter: nf_conncount: fix unexpected permanent node of list
  (bnc#1012628).
- netfilter: nf_conncount: fix list_del corruption in conn_free
  (bnc#1012628).
- netfilter: nf_conncount: use spin_lock_bh instead of spin_lock
  (bnc#1012628).
- sysv: return 'err' instead of 0 in __sysv_write_inode
  (bnc#1012628).
- arm64: dts: sdm845-mtp: Reserve reserved gpios (bnc#1012628).
- ASoC: sun8i-codec: fix crash on module removal (bnc#1012628).
- tools: bpftool: prevent infinite loop in get_fdinfo()
  (bnc#1012628).
- ARM: OMAP1: ams-delta: Fix possible use of uninitialized field
  (bnc#1012628).
- ARM: dts: am3517-som: Fix WL127x Wifi interrupt (bnc#1012628).
- ARM: dts: logicpd-somlv: Fix interrupt on mmc3_dat1
  (bnc#1012628).
- ARM: dts: LogicPD Torpedo: Fix mmc3_dat1 interrupt
  (bnc#1012628).
- ARM: dts: am3517: Fix pinmuxing for CD on MMC1 (bnc#1012628).
- staging: rtl8723bs: Fix the return value in case of error in
  'rtw_wx_read32()' (bnc#1012628).
- ASoC: qdsp6: q6afe-dai: Fix the dai widgets (bnc#1012628).
- ASoC: qdsp6: q6afe: Fix wrong MI2S SD line mask (bnc#1012628).
- ASoC: rsnd: fixup clock start checker (bnc#1012628).
- ARM: OMAP2+: prm44xx: Fix section annotation on
  omap44xx_prm_enable_io_wakeup (bnc#1012628).
- net: fix XPS static_key accounting (bnc#1012628).
- net: restore call to netdev_queue_numa_node_write when resetting
  XPS (bnc#1012628).
- sctp: update frag_point when stream_interleave is set
  (bnc#1012628).
- net: phy: sfp: correct store of detected link modes
  (bnc#1012628).
- virtio-net: keep vnet header zeroed after processing XDP
  (bnc#1012628).
- tun: forbid iface creation with rtnl ops (bnc#1012628).
- tcp: fix NULL ref in tail loss probe (bnc#1012628).
- tcp: Do not underestimate rwnd_limited (bnc#1012628).
- sctp: kfree_rcu asoc (bnc#1012628).
- rtnetlink: ndo_dflt_fdb_dump() only work for ARPHRD_ETHER
  devices (bnc#1012628).
- Revert "net/ibm/emac: wrong bit is used for STA control"
  (bnc#1012628).
- net: use skb_list_del_init() to remove from RX sublists
  (bnc#1012628).
- net: Prevent invalid access to skb->prev in __qdisc_drop_all
  (bnc#1012628).
- net: phy: don't allow __set_phy_supported to add unsupported
  modes (bnc#1012628).
- net/mlx4_en: Change min MTU size to ETH_MIN_MTU (bnc#1012628).
- net/mlx4_core: Correctly set PFC param if global pause is
  turned off (bnc#1012628).
- net: 8139cp: fix a BUG triggered by changing mtu with network
  traffic (bnc#1012628).
- ipv6: sr: properly initialize flowi6 prior passing to
  ip6_route_output (bnc#1012628).
- neighbour: Avoid writing before skb->head in neigh_hh_output()
  (bnc#1012628).
- ipv6: Check available headroom in ip6_xmit() even without
  options (bnc#1012628).
- ipv4: ipv6: netfilter: Adjust the frag mem limit when truesize
  changes (bnc#1012628).
- commit 9284d89
* Mon Dec 17 2018 mkubecek@suse.cz
- Update to 4.20-rc7
- Config changes:
  - ARM:
  - MEDIA_CONTROLLER_REQUEST_API=y
- commit 4731528
* Thu Dec 13 2018 jslaby@suse.cz
- Linux 4.19.9 (bnc#1012628).
- media: vicodec: lower minimum height to 360 (bnc#1012628).
- media: cec: check for non-OK/NACK conditions while claiming a LA
  (bnc#1012628).
- media: omap3isp: Unregister media device as first (bnc#1012628).
- media: ipu3-cio2: Unregister device nodes first, then release
  resources (bnc#1012628).
- iommu/vt-d: Fix NULL pointer dereference in prq_event_thread()
  (bnc#1012628).
- brcmutil: really fix decoding channel info for 160 MHz bandwidth
  (bnc#1012628).
- mt76: fix building without CONFIG_LEDS_CLASS (bnc#1012628).
- iommu/ipmmu-vmsa: Fix crash on early domain free (bnc#1012628).
- scsi: ufs: Fix hynix ufs bug with quirk on hi36xx SoC
  (bnc#1012628).
- can: ucan: remove set but not used variable 'udev'
  (bnc#1012628).
- can: rcar_can: Fix erroneous registration (bnc#1012628).
- test_firmware: fix error return getting clobbered (bnc#1012628).
- HID: input: Ignore battery reported by Symbol DS4308
  (bnc#1012628).
- batman-adv: Use explicit tvlv padding for ELP packets
  (bnc#1012628).
- batman-adv: Expand merged fragment buffer for full packet
  (bnc#1012628).
- amd/iommu: Fix Guest Virtual APIC Log Tail Address Register
  (bnc#1012628).
- bnx2x: Assign unique DMAE channel number for FW DMAE
  transactions (bnc#1012628).
- qed: Fix PTT leak in qed_drain() (bnc#1012628).
- qed: Fix overriding offload_tc by protocols without APP TLV
  (bnc#1012628).
- qed: Fix rdma_info structure allocation (bnc#1012628).
- qed: Fix reading wrong value in loop condition (bnc#1012628).
- usb: dwc2: pci: Fix an error code in probe (bnc#1012628).
- Revert "usb: gadget: ffs: Fix BUG when userland exits with
  submitted AIO transfers" (bnc#1012628).
- s390/ism: clear dmbe_mask bit before SMC IRQ handling
  (bnc#1012628).
- nvme-fc: resolve io failures during connect (bnc#1012628).
- bnxt_en: Fix filling time in bnxt_fill_coredump_record()
  (bnc#1012628).
- drm/amdgpu: Add amdgpu "max bpc" connector property (v2)
  (bnc#1012628).
- drm/amd/display: Support amdgpu "max bpc" connector property
  (v2) (bnc#1012628).
- net/mlx4_core: Zero out lkey field in SW2HW_MPT fw command
  (bnc#1012628).
- net/mlx4_core: Fix uninitialized variable compilation warning
  (bnc#1012628).
- net/mlx4: Fix UBSAN warning of signed integer overflow
  (bnc#1012628).
- drivers/net/ethernet/qlogic/qed/qed_rdma.h: fix typo
  (bnc#1012628).
- gpio: pxa: fix legacy non pinctrl aware builds again
  (bnc#1012628).
- gpio: mockup: fix indicated direction (bnc#1012628).
- tc-testing: tdc.py: ignore errors when decoding stdout/stderr
  (bnc#1012628).
- tc-testing: tdc.py: Guard against lack of returncode in executed
  command (bnc#1012628).
- mtd: rawnand: qcom: Namespace prefix some commands
  (bnc#1012628).
- cpufreq: ti-cpufreq: Only register platform_device when
  supported (bnc#1012628).
- Revert "HID: uhid: use strlcpy() instead of strncpy()"
  (bnc#1012628).
- HID: multitouch: Add pointstick support for Cirque Touchpad
  (bnc#1012628).
- mtd: spi-nor: Fix Cadence QSPI page fault kernel panic
  (bnc#1012628).
- net: ena: fix crash during failed resume from hibernation
  (bnc#1012628).
- NFSv4: Fix a NFSv4 state manager deadlock (bnc#1012628).
- qed: Fix bitmap_weight() check (bnc#1012628).
- qed: Fix QM getters to always return a valid pq (bnc#1012628).
- net/ibmnvic: Fix deadlock problem in reset (bnc#1012628).
- riscv: fix warning in arch/riscv/include/asm/module.h
  (bnc#1012628).
- net: faraday: ftmac100: remove netif_running(netdev) check
  before disabling interrupts (bnc#1012628).
- iommu/vt-d: Use memunmap to free memremap (bnc#1012628).
- NFSv4.2 copy do not allocate memory under the lock
  (bnc#1012628).
- flexfiles: use per-mirror specified stateid for IO
  (bnc#1012628).
- ibmvnic: Fix RX queue buffer cleanup (bnc#1012628).
- ibmvnic: Update driver queues after change in ring size support
  (bnc#1012628).
- team: no need to do team_notify_peers or team_mcast_rejoin
  when disabling port (bnc#1012628).
- net: amd: add missing of_node_put() (bnc#1012628).
- usb: quirk: add no-LPM quirk on SanDisk Ultra Flair device
  (bnc#1012628).
- usb: appledisplay: Add 27" Apple Cinema Display (bnc#1012628).
- USB: check usb_get_extra_descriptor for proper size
  (bnc#1012628).
- USB: serial: console: fix reported terminal settings
  (bnc#1012628).
- ALSA: usb-audio: Add SMSL D1 to quirks for native DSD support
  (bnc#1012628).
- ALSA: hda: Add support for AMD Stoney Ridge (bnc#1012628).
- ALSA: pcm: Fix starvation on down_write_nonblock()
  (bnc#1012628).
- ALSA: pcm: Call snd_pcm_unlink() conditionally at closing
  (bnc#1012628).
- ALSA: pcm: Fix interval evaluation with openmin/max
  (bnc#1012628).
- ALSA: hda/realtek - Fix speaker output regression on Thinkpad
  T570 (bnc#1012628).
- ALSA: hda/realtek: ALC286 mic and headset-mode fixups for Acer
  Aspire U27-880 (bnc#1012628).
- ALSA: hda/realtek - Add support for Acer Aspire C24-860 headset
  mic (bnc#1012628).
- ALSA: hda/realtek: Fix mic issue on Acer AIO Veriton Z4660G
  (bnc#1012628).
- ALSA: hda/realtek: Fix mic issue on Acer AIO Veriton
  Z4860G/Z6860G (bnc#1012628).
- media: gspca: fix frame overflow error (bnc#1012628).
- media: vicodec: fix memchr() kernel oops (bnc#1012628).
- Revert "mfd: cros_ec: Use devm_kzalloc for private data"
  (bnc#1012628).
- parisc: Enable -ffunction-sections for modules on 32-bit kernel
  (bnc#1012628).
- virtio/s390: avoid race on vcdev->config (bnc#1012628).
- virtio/s390: fix race in ccw_io_helper() (bnc#1012628).
- vhost/vsock: fix use-after-free in network stack callers
  (bnc#1012628).
- arm64: hibernate: Avoid sending cross-calling with interrupts
  disabled (bnc#1012628).
- SUNRPC: Fix leak of krb5p encode pages (bnc#1012628).
- dmaengine: dw: Fix FIFO size for Intel Merrifield (bnc#1012628).
- Revert "dmaengine: imx-sdma: Use GFP_NOWAIT for dma allocations"
  (bnc#1012628).
- Revert "dmaengine: imx-sdma: alloclate bd memory from dma pool"
  (bnc#1012628).
- dmaengine: imx-sdma: implement channel termination via worker
  (bnc#1012628).
- dmaengine: imx-sdma: use GFP_NOWAIT for dma descriptor
  allocations (bnc#1012628).
- dmaengine: cppi41: delete channel from pending list when stop
  channel (bnc#1012628).
- ARM: 8806/1: kprobes: Fix false positive with FORTIFY_SOURCE
  (bnc#1012628).
- xhci: workaround CSS timeout on AMD SNPS 3.0 xHC (bnc#1012628).
- xhci: Prevent U1/U2 link pm states if exit latency is too long
  (bnc#1012628).
- arm64: dts: rockchip: remove vdd_log from rock960 to fix a
  stability issues (bnc#1012628).
- Revert "x86/e820: put !E820_TYPE_RAM regions into
  memblock.reserved" (bnc#1012628).
- cifs: Fix separator when building path from dentry
  (bnc#1012628).
- staging: rtl8712: Fix possible buffer overrun (bnc#1012628).
- Revert commit ef9209b642f "staging: rtl8723bs: Fix indenting
  errors and an off-by-one mistake in core/rtw_mlme_ext.c"
  (bnc#1012628).
- crypto: do not free algorithm before using (bnc#1012628).
- drm/amdgpu: update mc firmware image for polaris12 variants
  (bnc#1012628).
- drm/lease: Send a distinct uevent (bnc#1012628).
- drm/msm: Move fence put to where failure occurs (bnc#1012628).
- drm/amdgpu/gmc8: update MC firmware for polaris (bnc#1012628).
- drm/amdgpu/gmc8: always load MC firmware in the driver
  (bnc#1012628).
- drm/i915: Downgrade Gen9 Plane WM latency error (bnc#1012628).
- kprobes/x86: Fix instruction patching corruption when copying
  more than one RIP-relative instruction (bnc#1012628).
- x86/efi: Allocate e820 buffer before calling
  efi_exit_boot_service (bnc#1012628).
- Drivers: hv: vmbus: Offload the handling of channels to two
  workqueues (bnc#1012628).
- tty: serial: 8250_mtk: always resume the device in probe
  (bnc#1012628).
- tty: do not set TTY_IO_ERROR flag if console port (bnc#1012628).
- gnss: sirf: fix activation retry handling (bnc#1012628).
- kgdboc: fix KASAN global-out-of-bounds bug in
  param_set_kgdboc_var() (bnc#1012628).
- libnvdimm, pfn: Pad pfn namespaces relative to other regions
  (bnc#1012628).
- cfg80211: Fix busy loop regression in ieee80211_ie_split_ric()
  (bnc#1012628).
- mac80211_hwsim: Timer should be initialized before device
  registered (bnc#1012628).
- mac80211: fix GFP_KERNEL under tasklet context (bnc#1012628).
- mac80211: Clear beacon_int in ieee80211_do_stop (bnc#1012628).
- mac80211: ignore tx status for PS stations in
  ieee80211_tx_status_ext (bnc#1012628).
- mac80211: fix reordering of buffered broadcast packets
  (bnc#1012628).
- mac80211: ignore NullFunc frames in the duplicate detection
  (bnc#1012628).
- HID: quirks: fix RetroUSB.com devices (bnc#1012628).
- Update config files.
- commit 2f28da6
* Mon Dec 10 2018 afaerber@suse.de
- config: arm: Enable EFI support (boo#1104833)
- commit 7050650
* Mon Dec 10 2018 afaerber@suse.de
- config: armv7hl: Update to 4.20-rc5
- commit f01387b
* Mon Dec 10 2018 jslaby@suse.cz
- Delete
  patches.suse/blk-mq-fix-corruption-with-direct-issue.patch.
  It is in 4.20-rc6 as ffe81d45322c but was partially reverted by
  c616cbee97ae, so this patch still applies cleanly, but is unwanted.
  Drop it.
- commit 7670339
* Mon Dec 10 2018 jslaby@suse.cz
- Refresh
  patches.rpmify/x86-build-Fix-compiler-support-check-for-CONFIG_RETP.patch.
  Update upstream status.
- commit ceaabb8
* Mon Dec 10 2018 mkubecek@suse.cz
- Update to 4.20-rc6
- Eliminated 1 patch
- Refresh configs
- commit 93f10c3
* Sun Dec  9 2018 jslaby@suse.cz
- Linux 4.19.8 (bnc#1012628).
- blk-mq: punt failed direct issue to dispatch list (bnc#1012628).
- tipc: use destination length for copy string (bnc#1012628).
- arc: [devboards] Add support of NFSv3 ACL (bnc#1012628).
- ARC: change defconfig defaults to ARCv2 (bnc#1012628).
- btrfs: tree-checker: Don't check max block group size as
  current max chunk size limit is unreliable (bnc#1012628).
- Input: elan_i2c - add support for ELAN0621 touchpad
  (bnc#1012628).
- Input: elan_i2c - add ACPI ID for Lenovo IdeaPad 330-15ARR
  (bnc#1012628).
- Input: elan_i2c - add ELAN0620 to the ACPI table (bnc#1012628).
- Input: cros_ec_keyb - fix button/switch capability reports
  (bnc#1012628).
- Input: matrix_keypad - check for errors from of_get_named_gpio()
  (bnc#1012628).
- Input: synaptics - add PNP ID for ThinkPad P50 to SMBus
  (bnc#1012628).
- Input: xpad - quirk all PDP Xbox One gamepads (bnc#1012628).
- scsi: lpfc: fix block guard enablement on SLI3 adapters
  (bnc#1012628).
- i40e: Fix deletion of MAC filters (bnc#1012628).
- selinux: add support for RTM_NEWCHAIN, RTM_DELCHAIN, and
  RTM_GETCHAIN (bnc#1012628).
- svm: Add mutex_lock to protect apic_access_page_done on AMD
  systems (bnc#1012628).
- kgdboc: Fix warning with module build (bnc#1012628).
- kgdboc: Fix restrict error (bnc#1012628).
- userfaultfd: shmem: UFFDIO_COPY: set the page dirty if VM_WRITE
  is not set (bnc#1012628).
- userfaultfd: shmem: add i_size checks (bnc#1012628).
- userfaultfd: shmem: allocate anonymous memory for MAP_PRIVATE
  shmem (bnc#1012628).
- userfaultfd: use ENOENT instead of EFAULT if the atomic copy
  user fails (bnc#1012628).
- drm/meson: Fix OOB memory accesses in meson_viu_set_osd_lut()
  (bnc#1012628).
- drm/meson: Enable fast_io in meson_dw_hdmi_regmap_config
  (bnc#1012628).
- drm/meson: Fixes for drm_crtc_vblank_on/off support
  (bnc#1012628).
- drm: set is_master to 0 upon drm_new_set_master() failure
  (bnc#1012628).
- drm/amd/dm: Don't forget to attach MST encoders (bnc#1012628).
- drm/ast: Fix incorrect free on ioregs (bnc#1012628).
- tracing/fgraph: Fix set_graph_function from showing interrupts
  (bnc#1012628).
- IB/mlx5: Avoid load failure due to unknown link width
  (bnc#1012628).
- mips: fix mips_get_syscall_arg o32 check (bnc#1012628).
- MIPS: ralink: Fix mt7620 nd_sd pinmux (bnc#1012628).
- tracepoint: Use __idx instead of idx in DO_TRACE macro to make
  it unique (bnc#1012628).
- sched, trace: Fix prev_state output in sched_switch tracepoint
  (bnc#1012628).
- arm64: ftrace: Fix to enable syscall events on arm64
  (bnc#1012628).
- mtd: nand: Fix memory allocation in nanddev_bbt_init()
  (bnc#1012628).
- uprobes: Fix handle_swbp() vs. unregister() + register()
  race once more (bnc#1012628).
- iser: set sector for ambiguous mr status errors (bnc#1012628).
- unifdef: use memcpy instead of strncpy (bnc#1012628).
- test_hexdump: use memcpy instead of strncpy (bnc#1012628).
- blk-mq: fix corruption with direct issue (bnc#1012628).
- Delete
  patches.suse/blk-mq-fix-corruption-with-direct-issue.patch.
- commit 9cae63f
* Sat Dec  8 2018 msuchanek@suse.de
- Include modules.fips in kernel-binary as well as kernel-binary-base
  (FATE#323247).
- commit e42315d
* Fri Dec  7 2018 jslaby@suse.cz
- x86/build: Fix compiler support check for CONFIG_RETPOLINE
  (KMP build).
- commit fb5fd39
* Wed Dec  5 2018 mkubecek@suse.cz
- blk-mq: fix corruption with direct issue (bko#201685).
- commit 8970eff
* Wed Dec  5 2018 jslaby@suse.cz
- Linux 4.19.7 (bnc#1012628).
- mm/huge_memory: rename freeze_page() to unmap_page()
  (bnc#1012628).
- mm/huge_memory: splitting set mapping+index before unfreeze
  (bnc#1012628).
- mm/huge_memory: fix lockdep complaint on 32-bit i_size_read()
  (bnc#1012628).
- mm/khugepaged: collapse_shmem() stop if punched or truncated
  (bnc#1012628).
- mm/khugepaged: fix crashes due to misaccounted holes
  (bnc#1012628).
- mm/khugepaged: collapse_shmem() remember to clear holes
  (bnc#1012628).
- mm/khugepaged: minor reorderings in collapse_shmem()
  (bnc#1012628).
- mm/khugepaged: collapse_shmem() without freezing new_page
  (bnc#1012628).
- mm/khugepaged: collapse_shmem() do not crash on Compound
  (bnc#1012628).
- lan743x: Enable driver to work with LAN7431 (bnc#1012628).
- lan743x: fix return value for lan743x_tx_napi_poll
  (bnc#1012628).
- net: don't keep lonely packets forever in the gro hash
  (bnc#1012628).
- net: gemini: Fix copy/paste error (bnc#1012628).
- net: thunderx: set tso_hdrs pointer to NULL in
  nicvf_free_snd_queue (bnc#1012628).
- packet: copy user buffers before orphan or clone (bnc#1012628).
- rapidio/rionet: do not free skb before reading its length
  (bnc#1012628).
- s390/qeth: fix length check in SNMP processing (bnc#1012628).
- usbnet: ipheth: fix potential recvmsg bug and recvmsg bug 2
  (bnc#1012628).
- net: thunderx: set xdp_prog to NULL if bpf_prog_add fails
  (bnc#1012628).
- net: skb_scrub_packet(): Scrub offload_fwd_mark (bnc#1012628).
- virtio-net: disable guest csum during XDP set (bnc#1012628).
- virtio-net: fail XDP set if guest csum is negotiated
  (bnc#1012628).
- net/dim: Update DIM start sample after each DIM iteration
  (bnc#1012628).
- tcp: defer SACK compression after DupThresh (bnc#1012628).
- net: phy: add workaround for issue where PHY driver doesn't
  bind to the device (bnc#1012628).
- tipc: fix lockdep warning during node delete (bnc#1012628).
- x86/speculation: Enable cross-hyperthread spectre v2 STIBP
  mitigation (bnc#1012628).
- x86/speculation: Apply IBPB more strictly to avoid cross-process
  data leak (bnc#1012628).
- x86/speculation: Propagate information about RSB filling
  mitigation to sysfs (bnc#1012628).
- x86/speculation: Add RETPOLINE_AMD support to the inline asm
  CALL_NOSPEC variant (bnc#1012628).
- x86/retpoline: Make CONFIG_RETPOLINE depend on compiler support
  (bnc#1012628).
- x86/retpoline: Remove minimal retpoline support (bnc#1012628).
- x86/speculation: Update the TIF_SSBD comment (bnc#1012628).
- x86/speculation: Clean up spectre_v2_parse_cmdline()
  (bnc#1012628).
- x86/speculation: Remove unnecessary ret variable in
  cpu_show_common() (bnc#1012628).
- x86/speculation: Move STIPB/IBPB string conditionals out of
  cpu_show_common() (bnc#1012628).
- x86/speculation: Disable STIBP when enhanced IBRS is in use
  (bnc#1012628).
- x86/speculation: Rename SSBD update functions (bnc#1012628).
- x86/speculation: Reorganize speculation control MSRs update
  (bnc#1012628).
- sched/smt: Make sched_smt_present track topology (bnc#1012628).
- x86/Kconfig: Select SCHED_SMT if SMP enabled (bnc#1012628).
- sched/smt: Expose sched_smt_present static key (bnc#1012628).
- x86/speculation: Rework SMT state change (bnc#1012628).
- x86/l1tf: Show actual SMT state (bnc#1012628).
- x86/speculation: Reorder the spec_v2 code (bnc#1012628).
- x86/speculation: Mark string arrays const correctly
  (bnc#1012628).
- x86/speculataion: Mark command line parser data __initdata
  (bnc#1012628).
- x86/speculation: Unify conditional spectre v2 print functions
  (bnc#1012628).
- x86/speculation: Add command line control for indirect branch
  speculation (bnc#1012628).
- x86/speculation: Prepare for per task indirect branch
  speculation control (bnc#1012628).
- x86/process: Consolidate and simplify switch_to_xtra() code
  (bnc#1012628).
- x86/speculation: Avoid __switch_to_xtra() calls (bnc#1012628).
- x86/speculation: Prepare for conditional IBPB in switch_mm()
  (bnc#1012628).
- ptrace: Remove unused ptrace_may_access_sched() and MODE_IBRS
  (bnc#1012628).
- x86/speculation: Split out TIF update (bnc#1012628).
- x86/speculation: Prevent stale SPEC_CTRL msr content
  (bnc#1012628).
- x86/speculation: Prepare arch_smt_update() for PRCTL mode
  (bnc#1012628).
- x86/speculation: Add prctl() control for indirect branch
  speculation (bnc#1012628).
- x86/speculation: Enable prctl mode for spectre_v2_user
  (bnc#1012628).
- x86/speculation: Add seccomp Spectre v2 user space protection
  mode (bnc#1012628).
- x86/speculation: Provide IBPB always command line options
  (bnc#1012628).
- userfaultfd: shmem/hugetlbfs: only allow to register VM_MAYWRITE
  vmas (bnc#1012628).
- kvm: mmu: Fix race in emulated page table writes (bnc#1012628).
- kvm: svm: Ensure an IBPB on all affected CPUs when freeing a
  vmcb (bnc#1012628).
- KVM: nVMX/nSVM: Fix bug which sets vcpu->arch.tsc_offset to
  L1 tsc_offset (bnc#1012628).
- KVM: x86: Fix kernel info-leak in KVM_HC_CLOCK_PAIRING hypercall
  (bnc#1012628).
- KVM: LAPIC: Fix pv ipis use-before-initialization (bnc#1012628).
- KVM: X86: Fix scan ioapic use-before-initialization
  (bnc#1012628).
- KVM: VMX: re-add ple_gap module parameter (bnc#1012628).
- xtensa: enable coprocessors that are being flushed
  (bnc#1012628).
- xtensa: fix coprocessor context offset definitions
  (bnc#1012628).
- xtensa: fix coprocessor part of ptrace_{get,set}xregs
  (bnc#1012628).
- udf: Allow mounting volumes with incorrect identification
  strings (bnc#1012628).
- btrfs: Always try all copies when reading extent buffers
  (bnc#1012628).
- Btrfs: ensure path name is null terminated at
  btrfs_control_ioctl (bnc#1012628).
- Btrfs: fix rare chances for data loss when doing a fast fsync
  (bnc#1012628).
- Btrfs: fix race between enabling quotas and subvolume creation
  (bnc#1012628).
- btrfs: relocation: set trans to be NULL after ending transaction
  (bnc#1012628).
- PCI: layerscape: Fix wrong invocation of outbound window
  disable accessor (bnc#1012628).
- PCI: dwc: Fix MSI-X EP framework address calculation bug
  (bnc#1012628).
- PCI: Fix incorrect value returned from pcie_get_speed_cap()
  (bnc#1012628).
- arm64: dts: rockchip: Fix PCIe reset polarity for
  rk3399-puma-haikou (bnc#1012628).
- x86/MCE/AMD: Fix the thresholding machinery initialization order
  (bnc#1012628).
- x86/fpu: Disable bottom halves while loading FPU registers
  (bnc#1012628).
- perf/x86/intel: Move branch tracing setup to the Intel-specific
  source file (bnc#1012628).
- perf/x86/intel: Add generic branch tracing check to
  intel_pmu_has_bts() (bnc#1012628).
- perf/x86/intel: Disallow precise_ip on BTS events (bnc#1012628).
- fs: fix lost error code in dio_complete (bnc#1012628).
- ALSA: wss: Fix invalid snd_free_pages() at error path
  (bnc#1012628).
- ALSA: ac97: Fix incorrect bit shift at AC97-SPSA control write
  (bnc#1012628).
- ALSA: control: Fix race between adding and removing a user
  element (bnc#1012628).
- ALSA: sparc: Fix invalid snd_free_pages() at error path
  (bnc#1012628).
- ALSA: hda: Add ASRock N68C-S UCC the power_save blacklist
  (bnc#1012628).
- ALSA: hda/realtek - Support ALC300 (bnc#1012628).
- ALSA: hda/realtek - fix headset mic detection for MSI MS-B171
  (bnc#1012628).
- ALSA: hda/realtek - fix the pop noise on headphone for lenovo
  laptops (bnc#1012628).
- ALSA: hda/realtek - Add auto-mute quirk for HP Spectre x360
  laptop (bnc#1012628).
- function_graph: Create function_graph_enter() to consolidate
  architecture code (bnc#1012628).
- ARM: function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- microblaze: function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- x86/function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- nds32: function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- powerpc/function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- sh/function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- sparc/function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- parisc: function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- riscv/function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- s390/function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- arm64: function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- MIPS: function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- function_graph: Make ftrace_push_return_trace() static
  (bnc#1012628).
- function_graph: Use new curr_ret_depth to manage depth instead
  of curr_ret_stack (bnc#1012628).
- function_graph: Have profiler use curr_ret_stack and not depth
  (bnc#1012628).
- function_graph: Move return callback before update of
  curr_ret_stack (bnc#1012628).
- function_graph: Reverse the order of pushing the ret_stack
  and the callback (bnc#1012628).
- binder: fix race that allows malicious free of live buffer
  (bnc#1012628).
- ext2: initialize opts.s_mount_opt as zero before using it
  (bnc#1012628).
- ext2: fix potential use after free (bnc#1012628).
- ASoC: intel: cht_bsw_max98090_ti: Add quirk for boards using
  pmc_plt_clk_0 (bnc#1012628).
- ASoC: pcm186x: Fix device reset-registers trigger value
  (bnc#1012628).
- ARM: dts: rockchip: Remove @0 from the veyron memory node
  (bnc#1012628).
- dmaengine: at_hdmac: fix memory leak in at_dma_xlate()
  (bnc#1012628).
- dmaengine: at_hdmac: fix module unloading (bnc#1012628).
- staging: most: use format specifier "%%s" in snprintf
  (bnc#1012628).
- staging: vchiq_arm: fix compat VCHIQ_IOC_AWAIT_COMPLETION
  (bnc#1012628).
- staging: mt7621-dma: fix potentially dereferencing uninitialized
  'tx_desc' (bnc#1012628).
- staging: mt7621-pinctrl: fix uninitialized variable ngroups
  (bnc#1012628).
- staging: rtl8723bs: Fix incorrect sense of ether_addr_equal
  (bnc#1012628).
- staging: rtl8723bs: Add missing return for
  cfg80211_rtw_get_station (bnc#1012628).
- USB: usb-storage: Add new IDs to ums-realtek (bnc#1012628).
- usb: core: quirks: add RESET_RESUME quirk for Cherry G230
  Stream series (bnc#1012628).
- Revert "usb: dwc3: gadget: skip Set/Clear Halt when invalid"
  (bnc#1012628).
- iio/hid-sensors: Fix IIO_CHAN_INFO_RAW returning wrong values
  for signed numbers (bnc#1012628).
- iio:st_magn: Fix enable device after trigger (bnc#1012628).
- lib/test_kmod.c: fix rmmod double free (bnc#1012628).
- mm: cleancache: fix corruption on missed inode invalidation
  (bnc#1012628).
- mm: use swp_offset as key in shmem_replace_page() (bnc#1012628).
- Drivers: hv: vmbus: check the creation_status in
  vmbus_establish_gpadl() (bnc#1012628).
- misc: mic/scif: fix copy-paste error in
  scif_create_remote_lookup (bnc#1012628).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Refresh
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- commit 745e582
* Wed Dec  5 2018 jslaby@suse.cz
- blk-mq: fix corruption with direct issue (ext4 corruption).
- commit 34177d9
* Tue Dec  4 2018 jroedel@suse.de
- blacklist.conf: Blacklist MAINTAINERS file
- commit c4b3c90
* Mon Dec  3 2018 tiwai@suse.de
- ALSA: usb-audio: Fix UAF decrement if card has no live
  interfaces in card.c (CVE-2018-19824,bsc#1118152).
- commit 8ad46ce
* Mon Dec  3 2018 afaerber@suse.de
- config: armv6hl: Update to 4.20-rc5
- commit c85b385
* Mon Dec  3 2018 guillaume.gardet@free.fr
- config: armv7hl: Build some options as modules (boo#1104833)
  Enable HISI_THERMAL=m while at it.
  (cherry picked from commit c9b9dd67316b831b4cddb2fb439c96767d6cee14)
- config: armv7hl: Build some options as modules (boo#1104833)
  Enable HISI_THERMAL=m while at it.
- commit f931328
* Mon Dec  3 2018 guillaume.gardet@free.fr
- config: arm: Update to 4.19.5
- commit f7aa38e
* Mon Dec  3 2018 mkubecek@suse.cz
- Update to 4.20-rc5
- Config changes:
  - General:
  - PSI_DEFAULT_DISABLED=y
  - Sound:
  - SND_SOC_INTEL_SKYLAKE_HDAUDIO_CODEC=y
  - ARM:
  - ARM64_ERRATUM_1286807=y
- commit 2ccaf30
* Sun Dec  2 2018 jslaby@suse.cz
- Linux 4.19.6 (bnc#1012628).
- HID: steam: remove input device when a hid client is running
  (bnc#1012628).
- efi/libstub: arm: support building with clang (bnc#1012628).
- usb: core: Fix hub port connection events lost (bnc#1012628).
- usb: dwc3: gadget: fix ISOC TRB type on unaligned transfers
  (bnc#1012628).
- usb: dwc3: gadget: Properly check last unaligned/zero chain TRB
  (bnc#1012628).
- usb: dwc3: core: Clean up ULPI device (bnc#1012628).
- usb: dwc3: Fix NULL pointer exception in dwc3_pci_remove()
  (bnc#1012628).
- xhci: Fix leaking USB3 shared_hcd at xhci removal (bnc#1012628).
- xhci: handle port status events for removed USB3 hcd
  (bnc#1012628).
- xhci: Add check for invalid byte size error when UAS devices
  are connected (bnc#1012628).
- usb: xhci: fix uninitialized completion when USB3 port got
  wrong status (bnc#1012628).
- usb: xhci: fix timeout for transition from RExit to U0
  (bnc#1012628).
- xhci: Add quirk to workaround the errata seen on Cavium
  Thunder-X2 Soc (bnc#1012628).
- usb: xhci: Prevent bus suspend if a port connect change or
  polling state is detected (bnc#1012628).
- ALSA: oss: Use kvzalloc() for local buffer allocations
  (bnc#1012628).
- MAINTAINERS: Add Sasha as a stable branch maintainer
  (bnc#1012628).
- Documentation/security-bugs: Clarify treatment of embargoed
  information (bnc#1012628).
- Documentation/security-bugs: Postpone fix publication in
  exceptional cases (bnc#1012628).
- mmc: sdhci-pci: Try "cd" for card-detect lookup before using
  NULL (bnc#1012628).
- mmc: sdhci-pci: Workaround GLK firmware failing to restore
  the tuning value (bnc#1012628).
- gpio: don't free unallocated ida on gpiochip_add_data_with_key()
  error path (bnc#1012628).
- iwlwifi: fix wrong WGDS_WIFI_DATA_SIZE (bnc#1012628).
- iwlwifi: mvm: support sta_statistics() even on older firmware
  (bnc#1012628).
- iwlwifi: mvm: fix regulatory domain update when the firmware
  starts (bnc#1012628).
- iwlwifi: mvm: don't use SAR Geo if basic SAR is not used
  (bnc#1012628).
- brcmfmac: fix reporting support for 160 MHz channels
  (bnc#1012628).
- opp: ti-opp-supply: Dynamically update u_volt_min (bnc#1012628).
- opp: ti-opp-supply: Correct the supply in
  _get_optimal_vdd_voltage call (bnc#1012628).
- tools/power/cpupower: fix compilation with STATIC=true
  (bnc#1012628).
- v9fs_dir_readdir: fix double-free on p9stat_read error
  (bnc#1012628).
- selinux: Add __GFP_NOWARN to allocation at str_read()
  (bnc#1012628).
- Input: synaptics - avoid using uninitialized variable when
  probing (bnc#1012628).
- bfs: add sanity check at bfs_fill_super() (bnc#1012628).
- sctp: clear the transport of some out_chunk_list chunks in
  sctp_assoc_rm_peer (bnc#1012628).
- gfs2: Don't leave s_fs_info pointing to freed memory in init_sbd
  (bnc#1012628).
- llc: do not use sk_eat_skb() (bnc#1012628).
- mm: don't warn about large allocations for slab (bnc#1012628).
- mm/memory.c: recheck page table entry with page table lock held
  (bnc#1012628).
- tcp: do not release socket ownership in tcp_close()
  (bnc#1012628).
- drm/fb-helper: Blacklist writeback when adding connectors to
  fbdev (bnc#1012628).
- drm/vc4: Set ->legacy_cursor_update to false when doing
  non-async updates (bnc#1012628).
- drm/amdgpu: Fix oops when pp_funcs->switch_power_profile is
  unset (bnc#1012628).
- drm/i915: Disable LP3 watermarks on all SNB machines
  (bnc#1012628).
- drm/ast: change resolution may cause screen blurred
  (bnc#1012628).
- drm/ast: fixed cursor may disappear sometimes (bnc#1012628).
- drm/ast: Remove existing framebuffers before loading driver
  (bnc#1012628).
- can: flexcan: Unlock the MB unconditionally (bnc#1012628).
- can: dev: can_get_echo_skb(): factor out non sending code to
  __can_get_echo_skb() (bnc#1012628).
- can: dev: __can_get_echo_skb(): replace struct can_frame by
  canfd_frame to access frame length (bnc#1012628).
- can: dev: __can_get_echo_skb(): Don't crash the kernel if
  can_priv::echo_skb is accessed out of bounds (bnc#1012628).
- can: dev: __can_get_echo_skb(): print error message, if trying
  to echo non existing skb (bnc#1012628).
- can: rx-offload: introduce can_rx_offload_get_echo_skb()
  and can_rx_offload_queue_sorted() functions (bnc#1012628).
- can: rx-offload: rename can_rx_offload_irq_queue_err_skb()
  to can_rx_offload_queue_tail() (bnc#1012628).
- can: flexcan: use can_rx_offload_queue_sorted() for
  flexcan_irq_bus_*() (bnc#1012628).
- can: flexcan: handle tx-complete CAN frames via rx-offload
  infrastructure (bnc#1012628).
- can: raw: check for CAN FD capable netdev in raw_sendmsg()
  (bnc#1012628).
- can: hi311x: Use level-triggered interrupt (bnc#1012628).
- can: flexcan: Always use last mailbox for TX (bnc#1012628).
- can: flexcan: remove not needed struct flexcan_priv::tx_mb
  and struct flexcan_priv::tx_mb_idx (bnc#1012628).
- ACPICA: AML interpreter: add region addresses in global list
  during initialization (bnc#1012628).
- IB/hfi1: Eliminate races in the SDMA send error path
  (bnc#1012628).
- fsnotify: generalize handling of extra event flags
  (bnc#1012628).
- fanotify: fix handling of events on child sub-directory
  (bnc#1012628).
- pinctrl: meson: fix pinconf bias disable (bnc#1012628).
- pinctrl: meson: fix gxbb ao pull register bits (bnc#1012628).
- pinctrl: meson: fix gxl ao pull register bits (bnc#1012628).
- pinctrl: meson: fix meson8 ao pull register bits (bnc#1012628).
- pinctrl: meson: fix meson8b ao pull register bits (bnc#1012628).
- tools/testing/nvdimm: Fix the array size for dimm devices
  (bnc#1012628).
- scsi: lpfc: fix remoteport access (bnc#1012628).
- scsi: hisi_sas: Remove set but not used variable 'dq_list'
  (bnc#1012628).
- KVM: PPC: Move and undef TRACE_INCLUDE_PATH/FILE (bnc#1012628).
- cpufreq: imx6q: add return value check for voltage scale
  (bnc#1012628).
- rtc: cmos: Do not export alarm rtc_ops when we do not support
  alarms (bnc#1012628).
- rtc: pcf2127: fix a kmemleak caused in pcf2127_i2c_gather_write
  (bnc#1012628).
- crypto: simd - correctly take reqsize of wrapped skcipher into
  account (bnc#1012628).
- floppy: fix race condition in __floppy_read_block_0()
  (bnc#1012628).
- powerpc/io: Fix the IO workarounds code to work with Radix
  (bnc#1012628).
- sched/fair: Fix cpu_util_wake() for 'execl' type workloads
  (bnc#1012628).
- perf/x86/intel/uncore: Add more IMC PCI IDs for KabyLake and
  CoffeeLake CPUs (bnc#1012628).
- block: copy ioprio in __bio_clone_fast() and bounce
  (bnc#1012628).
- SUNRPC: Fix a bogus get/put in generic_key_to_expire()
  (bnc#1012628).
- riscv: add missing vdso_install target (bnc#1012628).
- RISC-V: Silence some module warnings on 32-bit (bnc#1012628).
- drm/amdgpu: fix bug with IH ring setup (bnc#1012628).
- kdb: Use strscpy with destination buffer size (bnc#1012628).
- NFSv4: Fix an Oops during delegation callbacks (bnc#1012628).
- powerpc/numa: Suppress "VPHN is not supported" messages
  (bnc#1012628).
- efi/arm: Revert deferred unmap of early memmap mapping
  (bnc#1012628).
- z3fold: fix possible reclaim races (bnc#1012628).
- mm, memory_hotplug: check zone_movable in has_unmovable_pages
  (bnc#1012628).
- tmpfs: make lseek(SEEK_DATA/SEK_HOLE) return ENXIO with a
  negative offset (bnc#1012628).
- mm, page_alloc: check for max order in hot path (bnc#1012628).
- dax: Avoid losing wakeup in dax_lock_mapping_entry
  (bnc#1012628).
- include/linux/pfn_t.h: force '~' to be parsed as an unary
  operator (bnc#1012628).
- tty: wipe buffer (bnc#1012628).
- tty: wipe buffer if not echoing data (bnc#1012628).
- gfs2: Fix iomap buffer head reference counting bug
  (bnc#1012628).
- rcu: Make need_resched() respond to urgent RCU-QS needs
  (bnc#1012628).
- media: ov5640: Re-work MIPI startup sequence (bnc#1012628).
- media: ov5640: Fix timings setup code (bnc#1012628).
- media: ov5640: fix exposure regression (bnc#1012628).
- media: ov5640: fix auto gain & exposure when changing mode
  (bnc#1012628).
- media: ov5640: fix wrong binning value in exposure calculation
  (bnc#1012628).
- media: ov5640: fix auto controls values when switching to
  manual mode (bnc#1012628).
- commit e8181d1
* Tue Nov 27 2018 jslaby@suse.cz
- Linux 4.19.5 (bnc#1012628).
- drm/i915: Replace some PAGE_SIZE with I915_GTT_PAGE_SIZE
  (bnc#1012628).
- cifs: don't dereference smb_file_target before null check
  (bnc#1012628).
- cifs: fix return value for cifs_listxattr (bnc#1012628).
- arm64: kprobe: make page to RO mode when allocate it
  (bnc#1012628).
- block: brd: associate with queue until adding disk
  (bnc#1012628).
- net: hns3: bugfix for rtnl_lock's range in the hclgevf_reset()
  (bnc#1012628).
- net: hns3: bugfix for rtnl_lock's range in the hclge_reset()
  (bnc#1012628).
- net: hns3: bugfix for handling mailbox while the command queue
  reinitialized (bnc#1012628).
- net: hns3: bugfix for the initialization of command queue's
  spin lock (bnc#1012628).
- ixgbe: fix MAC anti-spoofing filter after VFLR (bnc#1012628).
- reiserfs: propagate errors from fill_with_dentries() properly
  (bnc#1012628).
- hfs: prevent btree data loss on root split (bnc#1012628).
- hfsplus: prevent btree data loss on root split (bnc#1012628).
- perf unwind: Take pgoff into account when reporting elf to
  libdwfl (bnc#1012628).
- um: Give start_idle_thread() a return code (bnc#1012628).
- drm/edid: Add 6 bpc quirk for BOE panel (bnc#1012628).
- afs: Handle EIO from delivery function (bnc#1012628).
- platform/x86: intel_telemetry: report debugfs failure
  (bnc#1012628).
- clk: fixed-rate: fix of_node_get-put imbalance (bnc#1012628).
- perf symbols: Set PLT entry/header sizes properly on Sparc
  (bnc#1012628).
- fs/exofs: fix potential memory leak in mount option parsing
  (bnc#1012628).
- clk: samsung: exynos5420: Enable PERIS clocks for suspend
  (bnc#1012628).
- apparmor: Fix uninitialized value in aa_split_fqname
  (bnc#1012628).
- x86/earlyprintk: Add a force option for pciserial device
  (bnc#1012628).
- platform/x86: acerhdf: Add BIOS entry for Gateway LT31 v1.3307
  (bnc#1012628).
- clk: meson-axg: pcie: drop the mpll3 clock parent (bnc#1012628).
- arm64: percpu: Initialize ret in the default case (bnc#1012628).
- clk: meson: clk-pll: drop CLK_GET_RATE_NOCACHE where unnecessary
  (bnc#1012628).
- clk: renesas: r9a06g032: Fix UART34567 clock rate (bnc#1012628).
- clk: ti: fix OF child-node lookup (bnc#1012628).
- serial: sh-sci: Fix receive on SCIFA/SCIFB variants with DMA
  (bnc#1012628).
- netfilter: ipv6: fix oops when defragmenting locally generated
  fragments (bnc#1012628).
- s390/decompressor: add missing FORCE to build targets
  (bnc#1012628).
- s390/vdso: add missing FORCE to build targets (bnc#1012628).
- HID: i2c-hid: Add a small delay after sleep command for Raydium
  touchpanel (bnc#1012628).
- Revert "HID: add NOGET quirk for Eaton Ellipse MAX UPS"
  (bnc#1012628).
- HID: alps: allow incoming reports when only the trackstick is
  opened (bnc#1012628).
- Revert "netfilter: nft_numgen: add map lookups for numgen
  random operations" (bnc#1012628).
- netfilter: ipset: list:set: Decrease refcount synchronously
  on deletion and replace (bnc#1012628).
- netfilter: ipset: actually allow allowable CIDR 0 in
  hash:net,port,net (bnc#1012628).
- netfilter: ipset: fix ip_set_list allocation failure
  (bnc#1012628).
- s390/mm: fix mis-accounting of pgtable_bytes (bnc#1012628).
- s390/mm: Fix ERROR: "__node_distance" undefined! (bnc#1012628).
- bpf: fix bpf_prog_get_info_by_fd to return 0 func_lens for
  unpriv (bnc#1012628).
- netfilter: ipset: Correct rcu_dereference() call in
  ip_set_put_comment() (bnc#1012628).
- netfilter: xt_IDLETIMER: add sysfs filename checking routine
  (bnc#1012628).
- netfilter: ipset: Fix calling ip_set() macro at dumping
  (bnc#1012628).
- netfilter: nft_compat: ebtables 'nat' table is normal chain type
  (bnc#1012628).
- s390/qeth: fix HiperSockets sniffer (bnc#1012628).
- s390/qeth: unregister netdevice only when registered
  (bnc#1012628).
- net: hns3: Fix for out-of-bounds access when setting pfc back
  pressure (bnc#1012628).
- hwmon: (ibmpowernv) Remove bogus __init annotations
  (bnc#1012628).
- ARM: dts: imx6sll: fix typo for fsl,imx6sll-i2c node
  (bnc#1012628).
- ARM: dts: fsl: Fix improperly quoted stdout-path values
  (bnc#1012628).
- Revert "drm/exynos/decon5433: implement frame counter"
  (bnc#1012628).
- arm64: dts: renesas: r8a7795: add missing dma-names on hscif2
  (bnc#1012628).
- arm64: dts: renesas: condor: switch from EtherAVB to GEther
  (bnc#1012628).
- xen/grant-table: Fix incorrect gnttab_dma_free_pages() pr_debug
  message (bnc#1012628).
- clk: fixed-factor: fix of_node_get-put imbalance (bnc#1012628).
- mtd: nand: Fix nanddev_pos_next_page() kernel-doc header
  (bnc#1012628).
- lib/raid6: Fix arm64 test build (bnc#1012628).
- drm/amd/display: Stop leaking planes (bnc#1012628).
- block: Clear kernel memory before copying to user (bnc#1012628).
- drm/amd/display: Drop reusing drm connector for MST
  (bnc#1012628).
- drm/amd/amdgpu/dm: Fix dm_dp_create_fake_mst_encoder()
  (bnc#1012628).
- s390/perf: Change CPUM_CF return code in event init function
  (bnc#1012628).
- ceph: quota: fix null pointer dereference in quota check
  (bnc#1012628).
- of/device: Really only set bus DMA mask when appropriate
  (bnc#1012628).
- nvme: make sure ns head inherits underlying device limits
  (bnc#1012628).
- i2c: omap: Enable for ARCH_K3 (bnc#1012628).
- i2c: qcom-geni: Fix runtime PM mismatch with child devices
  (bnc#1012628).
- sched/core: Take the hotplug lock in sched_init_smp()
  (bnc#1012628).
- perf tools: Fix undefined symbol scnprintf in libperf-jvmti.so
  (bnc#1012628).
- perf tools: Do not zero sample_id_all for group members
  (bnc#1012628).
- ice: Fix dead device link issue with flow control (bnc#1012628).
- ice: Fix the bytecount sent to netdev_tx_sent_queue
  (bnc#1012628).
- ice: Change req_speeds to be u16 (bnc#1012628).
- i40e: restore NETIF_F_GSO_IPXIP[46] to netdev features
  (bnc#1012628).
- qed: Fix memory/entry leak in qed_init_sp_request()
  (bnc#1012628).
- qed: Fix blocking/unlimited SPQ entries leak (bnc#1012628).
- qed: Fix SPQ entries not returned to pool in error flows
  (bnc#1012628).
- qed: Fix potential memory corruption (bnc#1012628).
- net: stmmac: Fix RX packet size > 8191 (bnc#1012628).
- net: aquantia: fix potential IOMMU fault after driver unbind
  (bnc#1012628).
- net: aquantia: fixed enable unicast on 32 macvlan (bnc#1012628).
- net: aquantia: invalid checksumm offload implementation
  (bnc#1012628).
- kbuild: deb-pkg: fix too low build version number (bnc#1012628).
- Revert "scripts/setlocalversion: git: Make -dirty check more
  robust" (bnc#1012628).
- SUNRPC: drop pointless static qualifier in
  xdr_get_next_encode_buffer() (bnc#1012628).
- x86/mm: Move LDT remap out of KASLR region on 5-level paging
  (bnc#1012628).
- x86/ldt: Unmap PTEs for the slot before freeing LDT pages
  (bnc#1012628).
- x86/ldt: Remove unused variable in map_ldt_struct()
  (bnc#1012628).
- media: v4l: event: Add subscription to list before calling
  "add" operation (bnc#1012628).
- MIPS: OCTEON: cavium_octeon_defconfig: re-enable OCTEON USB
  driver (bnc#1012628).
- RISC-V: Fix raw_copy_{to,from}_user() (bnc#1012628).
- uio: Fix an Oops on load (bnc#1012628).
- ALSA: hda/realtek - Add quirk entry for HP Pavilion 15
  (bnc#1012628).
- ALSA: hda/ca0132 - Call pci_iounmap() instead of iounmap()
  (bnc#1012628).
- can: kvaser_usb: Fix accessing freed memory in
  kvaser_usb_start_xmit() (bnc#1012628).
- can: kvaser_usb: Fix potential uninitialized variable use
  (bnc#1012628).
- usb: cdc-acm: add entry for Hiro (Conexant) modem (bnc#1012628).
- USB: quirks: Add no-lpm quirk for Raydium touchscreens
  (bnc#1012628).
- USB: Wait for extra delay time after USB_PORT_FEAT_RESET for
  quirky hub (bnc#1012628).
- usb: quirks: Add delay-init quirk for Corsair K70 LUX RGB
  (bnc#1012628).
- misc: atmel-ssc: Fix section annotation on
  atmel_ssc_get_driver_data (bnc#1012628).
- USB: misc: appledisplay: add 20" Apple Cinema Display
  (bnc#1012628).
- gnss: serial: fix synchronous write timeout (bnc#1012628).
- gnss: sirf: fix synchronous write timeout (bnc#1012628).
- mtd: rawnand: atmel: fix OF child-node lookup (bnc#1012628).
- drivers/misc/sgi-gru: fix Spectre v1 vulnerability
  (bnc#1012628).
- ACPI / platform: Add SMB0001 HID to forbidden_id_list
  (bnc#1012628).
- HID: uhid: forbid UHID_CREATE under KERNEL_DS or elevated
  privileges (bnc#1012628).
- HID: Add quirk for Primax PIXART OEM mice (bnc#1012628).
- HID: Add quirk for Microsoft PIXART OEM mouse (bnc#1012628).
- libceph: fall back to sendmsg for slab pages (bnc#1012628).
- mt76x0: run vco calibration for each channel configuration
  (bnc#1012628).
- commit 6210279
* Tue Nov 27 2018 tiwai@suse.de
- media: dvb-pll: don't re-validate tuner frequencies
  (bsc#1116374).
- commit 3debe43
* Mon Nov 26 2018 mkubecek@suse.cz
- Update to 4.20-rc4
- Config changes:
  - Networking:
  - MT76_LEDS=y (split from MT76_CORE)
- commit 1ac69b7
* Fri Nov 23 2018 msuchanek@suse.de
- Build ppc64le for POWER8+ (FATE#325617).
- commit f6da51b
* Fri Nov 23 2018 jslaby@suse.cz
- Linux 4.19.4 (bnc#1012628).
- flow_dissector: do not dissect l4 ports for fragments
  (bnc#1012628).
- ibmvnic: fix accelerated VLAN handling (bnc#1012628).
- ip_tunnel: don't force DF when MTU is locked (bnc#1012628).
- ipv6: fix a dst leak when removing its exception (bnc#1012628).
- ipv6: Fix PMTU updates for UDP/raw sockets in presence of VRF
  (bnc#1012628).
- net: bcmgenet: protect stop from timeout (bnc#1012628).
- net-gro: reset skb->pkt_type in napi_reuse_skb() (bnc#1012628).
- sctp: not allow to set asoc prsctp_enable by sockopt
  (bnc#1012628).
- tcp: Fix SOF_TIMESTAMPING_RX_HARDWARE to use the latest
  timestamp during TCP coalescing (bnc#1012628).
- tg3: Add PHY reset for 5717/5719/5720 in change ring and flow
  control paths (bnc#1012628).
- tipc: don't assume linear buffer when reading ancillary data
  (bnc#1012628).
- tipc: fix lockdep warning when reinitilaizing sockets
  (bnc#1012628).
- tuntap: fix multiqueue rx (bnc#1012628).
- net: systemport: Protect stop from timeout (bnc#1012628).
- net/sched: act_pedit: fix memory leak when IDR allocation fails
  (bnc#1012628).
- net: sched: cls_flower: validate nested enc_opts_policy to
  avoid warning (bnc#1012628).
- tipc: fix link re-establish failure (bnc#1012628).
- net/mlx5e: Don't match on vlan non-existence if ethertype is
  wildcarded (bnc#1012628).
- net/mlx5e: Claim TC hw offloads support only under a proper
  build config (bnc#1012628).
- net/mlx5e: Adjust to max number of channles when re-attaching
  (bnc#1012628).
- net/mlx5e: RX, verify received packet size in Linear Striding RQ
  (bnc#1012628).
- Revert "sctp: remove sctp_transport_pmtu_check" (bnc#1012628).
- net/mlx5e: Always use the match level enum when parsing TC
  rule match (bnc#1012628).
- net/mlx5e: Fix selftest for small MTUs (bnc#1012628).
- net/mlx5e: Removed unnecessary warnings in FEC caps query
  (bnc#1012628).
- inet: frags: better deal with smp races (bnc#1012628).
- l2tp: fix a sock refcnt leak in l2tp_tunnel_register
  (bnc#1012628).
- net/mlx5: IPSec, Fix the SA context hash key (bnc#1012628).
- net/mlx5e: IPoIB, Reset QP after channels are closed
  (bnc#1012628).
- net: dsa: mv88e6xxx: Fix clearing of stats counters
  (bnc#1012628).
- net: phy: realtek: fix RTL8201F sysfs name (bnc#1012628).
- sctp: define SCTP_SS_DEFAULT for Stream schedulers
  (bnc#1012628).
- net: qualcomm: rmnet: Fix incorrect assignment of real_dev
  (bnc#1012628).
- net: dsa: microchip: initialize mutex before use (bnc#1012628).
- sctp: fix strchange_flags name for Stream Change Event
  (bnc#1012628).
- net: phy: mdio-gpio: Fix working over slow can_sleep GPIOs
  (bnc#1012628).
- sctp: not increase stream's incnt before sending addstrm_in
  request (bnc#1012628).
- mlxsw: spectrum: Fix IP2ME CPU policer configuration
  (bnc#1012628).
- net: smsc95xx: Fix MTU range (bnc#1012628).
- rxrpc: Fix lockup due to no error backoff after ack transmit
  error (bnc#1012628).
- usbnet: smsc95xx: disable carrier check while suspending
  (bnc#1012628).
- Revert "x86/speculation: Enable cross-hyperthread spectre v2
  STIBP mitigation" (bnc#1012628).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- commit 2f38375
* Fri Nov 23 2018 msuchanek@suse.de
- Revert "Remove Cell/PS3 support from ppc64 kernel (boo#1114846)"
  This reverts commit fd6aaf7f98693355e7dcc5e4e1926fb1664d803b.
  Fixed upstream in 43c6494fa149 ("powerpc/io: Fix the IO workarounds code
  to work with Radix")
- commit 4f86993
* Thu Nov 22 2018 tiwai@suse.de
- media: dvb-pll: fix tuner frequency ranges (bsc#1116374).
- commit edac906
* Wed Nov 21 2018 jslaby@suse.cz
- Linux 4.19.3 (bnc#1012628).
- powerpc/traps: restore recoverability of machine_check
  interrupts (bnc#1012628).
- powerpc/64/module: REL32 relocation range check (bnc#1012628).
- powerpc/mm: Fix page table dump to work on Radix (bnc#1012628).
- powerpc/mm: fix always true/false warning in slice.c
  (bnc#1012628).
- drm/amd/display: fix bug of accessing invalid memory
  (bnc#1012628).
- Input: wm97xx-ts - fix exit path (bnc#1012628).
- powerpc/Makefile: Fix PPC_BOOK3S_64 ASFLAGS (bnc#1012628).
- powerpc/eeh: Fix possible null deref in eeh_dump_dev_log()
  (bnc#1012628).
- tty: check name length in tty_find_polling_driver()
  (bnc#1012628).
- tracing/kprobes: Check the probe on unloaded module correctly
  (bnc#1012628).
- drm/nouveau/secboot/acr: fix memory leak (bnc#1012628).
- drm/amdgpu/powerplay: fix missing break in switch statements
  (bnc#1012628).
- ARM: imx_v6_v7_defconfig: Select CONFIG_TMPFS_POSIX_ACL
  (bnc#1012628).
- powerpc/nohash: fix undefined behaviour when testing page size
  support (bnc#1012628).
- drm/msm/gpu: fix parameters in function
  msm_gpu_crashstate_capture (bnc#1012628).
- drm/msm/disp/dpu: Use proper define for drm_encoder_init()
  'encoder_type' (bnc#1012628).
- drm/msm: dpu: Allow planes to extend past active display
  (bnc#1012628).
- powerpc/mm: Don't report hugepage tables as memory leaks when
  using kmemleak (bnc#1012628).
- drm/omap: fix memory barrier bug in DMM driver (bnc#1012628).
- drm/amd/display: Raise dispclk value for dce120 by 15%%
  (bnc#1012628).
- drm/amd/display: fix gamma not being applied (bnc#1012628).
- drm/hisilicon: hibmc: Do not carry error code in HiBMC
  framebuffer pointer (bnc#1012628).
- media: pci: cx23885: handle adding to list failure
  (bnc#1012628).
- media: coda: don't overwrite h.264 profile_idc on decoder
  instance (bnc#1012628).
- MIPS: kexec: Mark CPU offline before disabling local IRQ
  (bnc#1012628).
- powerpc/boot: Ensure _zimage_start is a weak symbol
  (bnc#1012628).
- powerpc/memtrace: Remove memory in chunks (bnc#1012628).
- MIPS/PCI: Call pcie_bus_configure_settings() to set MPS/MRRS
  (bnc#1012628).
- staging: erofs: fix a missing endian conversion (bnc#1012628).
- serial: 8250_of: Fix for lack of interrupt support
  (bnc#1012628).
- sc16is7xx: Fix for multi-channel stall (bnc#1012628).
- media: tvp5150: fix width alignment during set_selection()
  (bnc#1012628).
- powerpc/selftests: Wait all threads to join (bnc#1012628).
- staging:iio:ad7606: fix voltage scales (bnc#1012628).
- drm: rcar-du: Update Gen3 output limitations (bnc#1012628).
- drm/amdgpu: Fix SDMA TO after GPU reset v3 (bnc#1012628).
- staging: most: video: fix registration of an empty comp
  core_component (bnc#1012628).
- 9p locks: fix glock.client_id leak in do_lock (bnc#1012628).
- udf: Prevent write-unsupported filesystem to be remounted
  read-write (bnc#1012628).
- ARM: dts: imx6ull: keep IMX6UL_ prefix for signals on both
  i.MX6UL and i.MX6ULL (bnc#1012628).
- media: ov5640: fix mode change regression (bnc#1012628).
- 9p: clear dangling pointers in p9stat_free (bnc#1012628).
- drm/amdgpu: fix integer overflow test in amdgpu_bo_list_create()
  (bnc#1012628).
- media: ov5640: fix restore of last mode set (bnc#1012628).
- ovl: fix error handling in ovl_verify_set_fh() (bnc#1012628).
- ovl: fix recursive oi->lock in ovl_link() (bnc#1012628).
- ovl: check whiteout in ovl_create_over_whiteout() (bnc#1012628).
- ovl: automatically enable redirect_dir on metacopy=on
  (bnc#1012628).
- serial: sh-sci: Fix could not remove dev_attr_rx_fifo_timeout
  (bnc#1012628).
- scsi: qla2xxx: Fix incorrect port speed being set for FC
  adapters (bnc#1012628).
- scsi: qla2xxx: Fix process response queue for ISP26XX and above
  (bnc#1012628).
- scsi: qla2xxx: Remove stale debug trace message from tcm_qla2xxx
  (bnc#1012628).
- scsi: qla2xxx: Fix early srb free on abort (bnc#1012628).
- scsi: qla2xxx: shutdown chip if reset fail (bnc#1012628).
- scsi: qla2xxx: Reject bsg request if chip is down (bnc#1012628).
- scsi: qla2xxx: Fix re-using LoopID when handle is in use
  (bnc#1012628).
- scsi: qla2xxx: Fix for double free of SRB structure
  (bnc#1012628).
- scsi: qla2xxx: Fix NVMe session hang on unload (bnc#1012628).
- scsi: qla2xxx: Fix NVMe Target discovery (bnc#1012628).
- scsi: qla2xxx: Fix duplicate switch database entries
  (bnc#1012628).
- scsi: qla2xxx: Fix driver hang when FC-NVMe LUNs are configured
  (bnc#1012628).
- vfs: fix FIGETBSZ ioctl on an overlayfs file (bnc#1012628).
- fuse: Fix use-after-free in fuse_dev_do_read() (bnc#1012628).
- fuse: Fix use-after-free in fuse_dev_do_write() (bnc#1012628).
- fuse: fix blocked_waitq wakeup (bnc#1012628).
- fuse: set FR_SENT while locked (bnc#1012628).
- drm/msm: fix OF child-node lookup (bnc#1012628).
- arm64: dts: stratix10: Support Ethernet Jumbo frame
  (bnc#1012628).
- arm64: dts: stratix10: fix multicast filtering (bnc#1012628).
- clk: meson-gxbb: set fclk_div3 as CLK_IS_CRITICAL (bnc#1012628).
- clk: meson: axg: mark fdiv2 and fdiv3 as critical (bnc#1012628).
- zram: close udev startup race condition as default groups
  (bnc#1012628).
- MIPS: Loongson-3: Fix CPU UART irq delivery problem
  (bnc#1012628).
- MIPS: Loongson-3: Fix BRIDGE irq delivery problem (bnc#1012628).
- xtensa: add NOTES section to the linker script (bnc#1012628).
- xtensa: make sure bFLT stack is 16 byte aligned (bnc#1012628).
- xtensa: fix boot parameters address translation (bnc#1012628).
- um: Drop own definition of PTRACE_SYSEMU/_SINGLESTEP
  (bnc#1012628).
- clk: s2mps11: Fix matching when built as module and DT node
  contains compatible (bnc#1012628).
- clk: at91: Fix division by zero in PLL recalc_rate()
  (bnc#1012628).
- clk: sunxi-ng: h6: fix bus clocks' divider position
  (bnc#1012628).
- clk: rockchip: fix wrong mmc sample phase shift for rk3328
  (bnc#1012628).
- clk: rockchip: Fix static checker warning in
  rockchip_ddrclk_get_parent call (bnc#1012628).
- libceph: bump CEPH_MSG_MAX_DATA_LEN (bnc#1012628).
- Revert "ceph: fix dentry leak in splice_dentry()" (bnc#1012628).
- thermal: core: Fix use-after-free in
  thermal_cooling_device_destroy_sysfs (bnc#1012628).
- mach64: fix display corruption on big endian machines
  (bnc#1012628).
- mach64: fix image corruption due to reading accelerator
  registers (bnc#1012628).
- acpi/nfit, x86/mce: Handle only uncorrectable machine checks
  (bnc#1012628).
- acpi/nfit, x86/mce: Validate a MCE's address before using it
  (bnc#1012628).
- acpi, nfit: Fix ARS overflow continuation (bnc#1012628).
- reset: hisilicon: fix potential NULL pointer dereference
  (bnc#1012628).
- crypto: hisilicon - Fix NULL dereference for same dst and src
  (bnc#1012628).
- crypto: hisilicon - Fix reference after free of memories on
  error path (bnc#1012628).
- vhost/scsi: truncate T10 PI iov_iter to prot_bytes
  (bnc#1012628).
- scsi: qla2xxx: Initialize port speed to avoid setting lower
  speed (bnc#1012628).
- SCSI: fix queue cleanup race before queue initialization is done
  (bnc#1012628).
- Revert "powerpc/8xx: Use L1 entry APG to handle _PAGE_ACCESSED
  for CONFIG_SWAP" (bnc#1012628).
- soc: ti: QMSS: Fix usage of irq_set_affinity_hint (bnc#1012628).
- ocfs2: fix a misuse a of brelse after failing
  ocfs2_check_dir_entry (bnc#1012628).
- ocfs2: free up write context when direct IO failed
  (bnc#1012628).
- mm: thp: relax __GFP_THISNODE for MADV_HUGEPAGE mappings
  (bnc#1012628).
- memory_hotplug: cond_resched in __remove_pages (bnc#1012628).
- netfilter: conntrack: fix calculation of next bucket number
  in early_drop (bnc#1012628).
- ARM: 8809/1: proc-v7: fix Thumb annotation of
  cpu_v7_hvc_switch_mm (bnc#1012628).
- bonding/802.3ad: fix link_failure_count tracking (bnc#1012628).
- mtd: spi-nor: cadence-quadspi: Return error code in
  cqspi_direct_read_execute() (bnc#1012628).
- mtd: nand: Fix nanddev_neraseblocks() (bnc#1012628).
- mtd: docg3: don't set conflicting BCH_CONST_PARAMS option
  (bnc#1012628).
- hwmon: (core) Fix double-free in __hwmon_device_register()
  (bnc#1012628).
- perf cs-etm: Correct CPU mode for samples (bnc#1012628).
- perf stat: Handle different PMU names with common prefix
  (bnc#1012628).
- perf callchain: Honour the ordering of
  PERF_CONTEXT_{USER,KERNEL,etc} (bnc#1012628).
- perf intel-pt/bts: Calculate cpumode for synthesized samples
  (bnc#1012628).
- perf intel-pt: Insert callchain context into synthesized
  callchains (bnc#1012628).
- of, numa: Validate some distance map rules (bnc#1012628).
- x86/cpu/vmware: Do not trace vmware_sched_clock() (bnc#1012628).
- x86/hyper-v: Enable PIT shutdown quirk (bnc#1012628).
- termios, tty/tty_baudrate.c: fix buffer overrun (bnc#1012628).
- arch/alpha, termios: implement BOTHER, IBSHIFT and termios2
  (bnc#1012628).
- watchdog/core: Add missing prototypes for weak functions
  (bnc#1012628).
- btrfs: fix pinned underflow after transaction aborted
  (bnc#1012628).
- Btrfs: fix missing data checksums after a ranged fsync (msync)
  (bnc#1012628).
- Btrfs: fix cur_offset in the error case for nocow (bnc#1012628).
- Btrfs: fix infinite loop on inode eviction after deduplication
  of eof block (bnc#1012628).
- Btrfs: fix data corruption due to cloning of eof block
  (bnc#1012628).
- btrfs: tree-checker: Fix misleading group system information
  (bnc#1012628).
- clockevents/drivers/i8253: Add support for PIT shutdown quirk
  (bnc#1012628).
- ext4: add missing brelse() update_backups()'s error path
  (bnc#1012628).
- ext4: add missing brelse() in set_flexbg_block_bitmap()'s
  error path (bnc#1012628).
- ext4: add missing brelse() add_new_gdb_meta_bg()'s error path
  (bnc#1012628).
- ext4: avoid potential extra brelse in
  setup_new_flex_group_blocks() (bnc#1012628).
- ext4: missing !bh check in ext4_xattr_inode_write()
  (bnc#1012628).
- ext4: fix possible inode leak in the retry loop of
  ext4_resize_fs() (bnc#1012628).
- ext4: avoid buffer leak on shutdown in ext4_mark_iloc_dirty()
  (bnc#1012628).
- ext4: avoid buffer leak in ext4_orphan_add() after prior errors
  (bnc#1012628).
- ext4: fix missing cleanup if ext4_alloc_flex_bg_array() fails
  while resizing (bnc#1012628).
- ext4: avoid possible double brelse() in add_new_gdb() on error
  path (bnc#1012628).
- ext4: fix possible leak of sbi->s_group_desc_leak in error path
  (bnc#1012628).
- ext4: fix possible leak of s_journal_flag_rwsem in error path
  (bnc#1012628).
- ext4: fix buffer leak in ext4_xattr_get_block() on error path
  (bnc#1012628).
- ext4: release bs.bh before re-using in ext4_xattr_block_find()
  (bnc#1012628).
- ext4: fix buffer leak in ext4_xattr_move_to_block() on error
  path (bnc#1012628).
- ext4: fix buffer leak in ext4_expand_extra_isize_ea() on error
  path (bnc#1012628).
- ext4: fix buffer leak in __ext4_read_dirblock() on error path
  (bnc#1012628).
- mount: Retest MNT_LOCKED in do_umount (bnc#1012628).
- mount: Don't allow copying MNT_UNBINDABLE|MNT_LOCKED mounts
  (bnc#1012628).
- mount: Prevent MNT_DETACH from disconnecting locked mounts
  (bnc#1012628).
- mnt: fix __detach_mounts infinite loop (bnc#1012628).
- uapi: fix linux/kfd_ioctl.h userspace compilation errors
  (bnc#1012628).
- ARM: cpuidle: Don't register the driver when back-end init
  returns -ENXIO (bnc#1012628).
- kdb: use correct pointer when 'btc' calls 'btt' (bnc#1012628).
- kdb: print real address of pointers instead of hashed addresses
  (bnc#1012628).
- sunrpc: correct the computation for page_ptr when truncating
  (bnc#1012628).
- NFSv4: Don't exit the state manager without clearing
  NFS4CLNT_MANAGER_RUNNING (bnc#1012628).
- nfsd: COPY and CLONE operations require the saved filehandle
  to be set (bnc#1012628).
- rtc: hctosys: Add missing range error reporting (bnc#1012628).
- fuse: fix use-after-free in fuse_direct_IO() (bnc#1012628).
- fuse: fix leaked notify reply (bnc#1012628).
- fuse: fix possibly missed wake-up after abort (bnc#1012628).
- selinux: check length properly in SCTP bind hook (bnc#1012628).
- gfs2: Put bitmap buffers in put_super (bnc#1012628).
- gfs2: Fix metadata read-ahead during truncate (2) (bnc#1012628).
- libata: blacklist SAMSUNG MZ7TD256HAFV-000L9 SSD (bnc#1012628).
- crypto: user - fix leaking uninitialized memory to userspace
  (bnc#1012628).
- lib/ubsan.c: don't mark __ubsan_handle_builtin_unreachable as
  noreturn (bnc#1012628).
- hugetlbfs: fix kernel BUG at
  fs/hugetlbfs/inode.c:444! (bnc#1012628).
- mm/swapfile.c: use kvzalloc for swap_info_struct allocation
  (bnc#1012628).
- efi/arm/libstub: Pack FDT after populating it (bnc#1012628).
- mm: don't reclaim inodes with many attached pages (bnc#1012628).
- scripts/spdxcheck.py: make python3 compliant (bnc#1012628).
- drm/rockchip: Allow driver to be shutdown on reboot/kexec
  (bnc#1012628).
- drm/amdgpu: Fix typo in amdgpu_vmid_mgr_init (bnc#1012628).
- drm/amdgpu: add missing CHIP_HAINAN in
  amdgpu_ucode_get_load_type (bnc#1012628).
- drm/amdgpu: Suppress keypresses from ACPI_VIDEO events
  (bnc#1012628).
- drm/nouveau: Check backlight IDs are >= 0, not > 0
  (bnc#1012628).
- drm/nouveau: Fix nv50_mstc->best_encoder() (bnc#1012628).
- drm/amd/powerplay: Enable/Disable NBPSTATE on On/OFF of UVD
  (bnc#1012628).
- drm/etnaviv: fix bogus fence complete check in timeout handler
  (bnc#1012628).
- drm/dp_mst: Check if primary mstb is null (bnc#1012628).
- drm: panel-orientation-quirks: Add quirk for Acer One 10 (S1003)
  (bnc#1012628).
- drm/i915/dp: Link train Fallback on eDP only if fallback link
  BW can fit panel's native mode (bnc#1012628).
- drm/i915: Use the correct crtc when sanitizing plane mapping
  (bnc#1012628).
- drm/i915: Restore vblank interrupts earlier (bnc#1012628).
- drm/i915: Don't unset intel_connector->mst_port (bnc#1012628).
- drm/i915: Skip vcpi allocation for MSTB ports that are gone
  (bnc#1012628).
- drm/i915: Large page offsets for pread/pwrite (bnc#1012628).
- drm/i915/dp: Fix link retraining comment in
  intel_dp_long_pulse() (bnc#1012628).
- drm/i915/dp: Restrict link retrain workaround to external
  monitors (bnc#1012628).
- drm/i915/icl: Fix the macros for DFLEXDPMLE register bits
  (bnc#1012628).
- drm/i915/hdmi: Add HDMI 2.0 audio clock recovery N values
  (bnc#1012628).
- drm/i915: Mark up GTT sizes as u64 (bnc#1012628).
- drm/i915: Fix error handling for the NV12 fb dimensions check
  (bnc#1012628).
- drm/i915: Fix ilk+ watermarks when disabling pipes
  (bnc#1012628).
- drm/i915: Compare user's 64b GTT offset even on 32b
  (bnc#1012628).
- drm/i915: Don't oops during modeset shutdown after lpe audio
  deinit (bnc#1012628).
- drm/i915: Mark pin flags as u64 (bnc#1012628).
- drm/i915/ringbuffer: Delay after EMIT_INVALIDATE for gen4/gen5
  (bnc#1012628).
- drm/i915/execlists: Force write serialisation into context
  image vs execution (bnc#1012628).
- drm/i915: Fix possible race in intel_dp_add_mst_connector()
  (bnc#1012628).
- drm/i915: Fix NULL deref when re-enabling HPD IRQs on systems
  with MST (bnc#1012628).
- drm/i915: Fix hpd handling for pins with two encoders
  (bnc#1012628).
- CONFIG_XEN_PV breaks xen_create_contiguous_region on ARM
  (bnc#1012628).
- Revert "ACPICA: AML interpreter: add region addresses in global
  list during initialization" (bnc#1012628).
- commit fc4ca8a
* Tue Nov 20 2018 rgoldwyn@suse.com
- apparmor: fix unnecessary creation of net-compat (bsc#1116724).
- commit f5cf767
* Mon Nov 19 2018 tiwai@suse.de
- drm/amdgpu: Add missing firmware entry for HAINAN (bsc#1116239).
- commit 21d18c9
* Mon Nov 19 2018 mkubecek@suse.cz
- Update to 4.20-rc3
- Refresh configs
- commit 81d20d2
* Tue Nov 13 2018 jslaby@suse.cz
- Linux 4.19.2 (bnc#1012628).
- bpf: fix partial copy of map_ptr when dst is scalar
  (bnc#1012628).
- MIPS: VDSO: Reduce VDSO_RANDOMIZE_SIZE to 64MB for 64bit
  (bnc#1012628).
- gpio: mxs: Get rid of external API call (bnc#1012628).
- mtd: rawnand: marvell: fix the IRQ handler complete() condition
  (bnc#1012628).
- mtd: maps: gpio-addr-flash: Fix ioremapped size (bnc#1012628).
- mtd: spi-nor: fsl-quadspi: fix read error for flash size larger
  than 16MB (bnc#1012628).
- mtd: spi-nor: intel-spi: Add support for Intel Ice Lake SPI
  serial flash (bnc#1012628).
- mtd: spi-nor: fsl-quadspi: Don't let -EINVAL on the bus
  (bnc#1012628).
- spi: spi-mem: Adjust op len based on message/transfer size
  limitations (bnc#1012628).
- spi: bcm-qspi: switch back to reading flash using smaller chunks
  (bnc#1012628).
- spi: bcm-qspi: fix calculation of address length (bnc#1012628).
- bcache: trace missed reading by cache_missed (bnc#1012628).
- bcache: fix ioctl in flash device (bnc#1012628).
- bcache: correct dirty data statistics (bnc#1012628).
- bcache: fix miss key refill->end in writeback (bnc#1012628).
- hwmon: (pmbus) Fix page count auto-detection (bnc#1012628).
- jffs2: free jffs2_sb_info through jffs2_kill_sb() (bnc#1012628).
- block: setup bounce bio_sets properly (bnc#1012628).
- block: make sure discard bio is aligned with logical block size
  (bnc#1012628).
- block: make sure writesame bio is aligned with logical block
  size (bnc#1012628).
- cpufreq: conservative: Take limits changes into account properly
  (bnc#1012628).
- dma-mapping: fix panic caused by passing empty cma command
  line argument (bnc#1012628).
- pcmcia: Implement CLKRUN protocol disabling for Ricoh bridges
  (bnc#1012628).
- ACPI / OSL: Use 'jiffies' as the time bassis for
  acpi_os_get_timer() (bnc#1012628).
- ACPICA: AML interpreter: add region addresses in global list
  during initialization (bnc#1012628).
- ACPICA: AML Parser: fix parse loop to correctly skip erroneous
  extended opcodes (bnc#1012628).
- acpi, nfit: Fix Address Range Scrub completion tracking
  (bnc#1012628).
- kprobes/x86: Use preempt_enable() in optimized_callback()
  (bnc#1012628).
- ipmi: Fix timer race with module unload (bnc#1012628).
- mailbox: PCC: handle parse error (bnc#1012628).
- parisc: Fix address in HPMC IVA (bnc#1012628).
- parisc: Fix map_pages() to not overwrite existing pte entries
  (bnc#1012628).
- parisc: Fix exported address of os_hpmc handler (bnc#1012628).
- ALSA: hda - Add quirk for ASUS G751 laptop (bnc#1012628).
- ALSA: hda - Fix headphone pin config for ASUS G751
  (bnc#1012628).
- ALSA: hda/realtek - Fix the problem of the front MIC on the
  Lenovo M715 (bnc#1012628).
- ALSA: hda - Add mic quirk for the Lenovo G50-30 (17aa:3905)
  (bnc#1012628).
- ALSA: hda: Add 2 more models to the power_save blacklist
  (bnc#1012628).
- ALSA: ca0106: Disable IZD on SB0570 DAC to fix audio pops
  (bnc#1012628).
- ALSA: hda - Fix incorrect clearance of thinkpad_acpi hooks
  (bnc#1012628).
- x86/speculation: Enable cross-hyperthread spectre v2 STIBP
  mitigation (bnc#1012628).
- x86/xen: Fix boot loader version reported for PVH guests
  (bnc#1012628).
- x86/corruption-check: Fix panic in memory_corruption_check()
  when boot option without value is provided (bnc#1012628).
- x86/kvm/nVMX: allow bare VMXON state migration (bnc#1012628).
- x86/mm/pat: Disable preemption around __flush_tlb_all()
  (bnc#1012628).
- x86/numa_emulation: Fix uniform-split numa emulation
  (bnc#1012628).
- ARM: dts: exynos: Disable pull control for MAX8997 interrupts
  on Origen (bnc#1012628).
- net: socionext: Reset tx queue in ndo_stop (bnc#1012628).
- net: loopback: clear skb->tstamp before netif_rx()
  (bnc#1012628).
- locking/lockdep: Fix debug_locks off performance problem
  (bnc#1012628).
- netfilter: xt_nat: fix DNAT target for shifted portmap ranges
  (bnc#1012628).
- ataflop: fix error handling during setup (bnc#1012628).
- swim: fix cleanup on setup error (bnc#1012628).
- arm64: cpufeature: ctr: Fix cpu capability check for late CPUs
  (bnc#1012628).
- hv_netvsc: fix vf serial matching with pci slot info
  (bnc#1012628).
- nfp: devlink port split support for 1x100G CXP NIC
  (bnc#1012628).
- tun: Consistently configure generic netdev params via rtnetlink
  (bnc#1012628).
- s390/sthyi: Fix machine name validity indication (bnc#1012628).
- hwmon: (pwm-fan) Set fan speed to 0 on suspend (bnc#1012628).
- lightnvm: pblk: fix race on sysfs line state (bnc#1012628).
- lightnvm: pblk: fix two sleep-in-atomic-context bugs
  (bnc#1012628).
- lightnvm: pblk: fix race condition on metadata I/O
  (bnc#1012628).
- spi: spi-ep93xx: Use dma_data_direction for
  ep93xx_spi_dma_{finish,prepare} (bnc#1012628).
- perf tools: Free temporary 'sys' string in read_event_files()
  (bnc#1012628).
- perf tools: Cleanup trace-event-info 'tdata' leak (bnc#1012628).
- perf tools: Free 'printk' string in parse_ftrace_printk()
  (bnc#1012628).
- perf strbuf: Match va_{add,copy} with va_end (bnc#1012628).
- cpupower: Fix coredump on VMWare (bnc#1012628).
- bcache: Populate writeback_rate_minimum attribute (bnc#1012628).
- mmc: sdhci-pci-o2micro: Add quirk for O2 Micro dev 0x8620 rev
  0x01 (bnc#1012628).
- sdhci: acpi: add free_slot callback (bnc#1012628).
- mtd: rawnand: denali: set SPARE_AREA_SKIP_BYTES register to
  8 if unset (bnc#1012628).
- iwlwifi: pcie: avoid empty free RB queue (bnc#1012628).
- iwlwifi: mvm: clear HW_RESTART_REQUESTED when stopping the
  interface (bnc#1012628).
- iwlwifi: mvm: check for n_profiles validity in EWRD ACPI
  (bnc#1012628).
- x86/olpc: Indicate that legacy PC XO-1 platform should not
  register RTC (bnc#1012628).
- wlcore: Fix BUG with clear completion on timeout (bnc#1012628).
- ACPI/PPTT: Handle architecturally unknown cache types
  (bnc#1012628).
- ACPI / PM: LPIT: Register sysfs attributes based on FADT
  (bnc#1012628).
- ACPI / processor: Fix the return value of
  acpi_processor_ids_walk() (bnc#1012628).
- cpufreq: dt: Try freeing static OPPs only if we have added them
  (bnc#1012628).
- x86/intel_rdt: Show missing resctrl mount options (bnc#1012628).
- mtd: rawnand: atmel: Fix potential NULL pointer dereference
  (bnc#1012628).
- nvme: call nvme_complete_rq when nvmf_check_ready fails for
  mpath I/O (bnc#1012628).
- ath10k: fix tx status flag setting for management frames
  (bnc#1012628).
- signal: Introduce COMPAT_SIGMINSTKSZ for use in
  compat_sys_sigaltstack (bnc#1012628).
- ice: fix changing of ring descriptor size (ethtool -G)
  (bnc#1012628).
- ice: update fw version check logic (bnc#1012628).
- net: hns3: Fix for packet buffer setting bug (bnc#1012628).
- Bluetooth: btbcm: Add entry for BCM4335C0 UART bluetooth
  (bnc#1012628).
- Bluetooth: hci_qca: Remove hdev dereference in qca_close()
  (bnc#1012628).
- efi/x86: Call efi_parse_options() from efi_main() (bnc#1012628).
- x86: boot: Fix EFI stub alignment (bnc#1012628).
- net: hns3: Add nic state check before calling
  netif_tx_wake_queue (bnc#1012628).
- net: hns3: Fix ets validate issue (bnc#1012628).
- pinctrl: sunxi: fix 'pctrl->functions' allocation in
  sunxi_pinctrl_build_state (bnc#1012628).
- pinctrl: qcom: spmi-mpp: Fix err handling of pmic_mpp_set_mux
  (bnc#1012628).
- brcmfmac: fix for proper support of 160MHz bandwidth
  (bnc#1012628).
- net: hns3: Check hdev state when getting link status
  (bnc#1012628).
- net: hns3: Set STATE_DOWN bit of hdev state when stopping net
  (bnc#1012628).
- net: phy: phylink: ensure the carrier is off when starting
  phylink (bnc#1012628).
- block, bfq: correctly charge and reset entity service in all
  cases (bnc#1012628).
- arm64: entry: Allow handling of undefined instructions from EL1
  (bnc#1012628).
- kprobes: Return error if we fail to reuse kprobe instead of
  BUG_ON() (bnc#1012628).
- spi: gpio: No MISO does not imply no RX (bnc#1012628).
- ACPI / LPSS: Add alternative ACPI HIDs for Cherry Trail DMA
  controllers (bnc#1012628).
- pinctrl: qcom: spmi-mpp: Fix drive strength setting
  (bnc#1012628).
- bpf/verifier: fix verifier instability (bnc#1012628).
- failover: Add missing check to validate 'slave_dev' in
  net_failover_slave_unregister (bnc#1012628).
- perf tests: Fix record+probe_libc_inet_pton.sh without ping's
  debuginfo (bnc#1012628).
- pinctrl: spmi-mpp: Fix pmic_mpp_config_get() to be compliant
  (bnc#1012628).
- pinctrl: ssbi-gpio: Fix pm8xxx_pin_config_get() to be compliant
  (bnc#1012628).
- net: hns3: Preserve vlan 0 in hardware table (bnc#1012628).
- net: hns3: Fix ping exited problem when doing lp selftest
  (bnc#1012628).
- net: hns3: Fix for vf vlan delete failed problem (bnc#1012628).
- net: dsa: mv88e6xxx: Fix writing to a PHY page (bnc#1012628).
- mt76x2u: run device cleanup routine if resume fails
  (bnc#1012628).
- rsi: fix memory alignment issue in ARM32 platforms
  (bnc#1012628).
- libertas_tf: prevent underflow in process_cmdrequest()
  (bnc#1012628).
- iwlwifi: mvm: fix BAR seq ctrl reporting (bnc#1012628).
- gpio: brcmstb: allow 0 width GPIO banks (bnc#1012628).
- ixgbe: disallow IPsec Tx offload when in SR-IOV mode
  (bnc#1012628).
- ixgbevf: VF2VF TCP RSS (bnc#1012628).
- wil6210: fix RX buffers release and unmap (bnc#1012628).
- ath10k: schedule hardware restart if WMI command times out
  (bnc#1012628).
- libata: Apply NOLPM quirk for SAMSUNG MZ7TD256HAFV-000L9
  (bnc#1012628).
- thermal: rcar_thermal: Prevent doing work after unbind
  (bnc#1012628).
- thermal: da9062/61: Prevent hardware access during system
  suspend (bnc#1012628).
- cifs: fix a credits leak for compund commands (bnc#1012628).
- cgroup, netclassid: add a preemption point to write_classid
  (bnc#1012628).
- net: stmmac: dwmac-sun8i: fix OF child-node lookup
  (bnc#1012628).
- f2fs: fix to account IO correctly for cgroup writeback
  (bnc#1012628).
- MD: Memory leak when flush bio size is zero (bnc#1012628).
- md: fix memleak for mempool (bnc#1012628).
- of: Add missing exports of node name compare functions
  (bnc#1012628).
- scsi: esp_scsi: Track residual for PIO transfers (bnc#1012628).
- scsi: ufs: Schedule clk gating work on correct queue
  (bnc#1012628).
- UAPI: ndctl: Fix g++-unsupported initialisation in headers
  (bnc#1012628).
- KVM: nVMX: Clear reserved bits of #DB exit qualification
  (bnc#1012628).
- scsi: megaraid_sas: fix a missing-check bug (bnc#1012628).
- RDMA/core: Do not expose unsupported counters (bnc#1012628).
- RDMA/cm: Respect returned status of cm_init_av_by_path
  (bnc#1012628).
- IB/ipoib: Clear IPCB before icmp_send (bnc#1012628).
- RDMA/bnxt_re: Avoid accessing nq->bar_reg_iomem in failure case
  (bnc#1012628).
- RDMA/bnxt_re: Fix recursive lock warning in debug kernel
  (bnc#1012628).
- usb: host: ohci-at91: fix request of irq for optional gpio
  (bnc#1012628).
- PCI: mediatek: Fix mtk_pcie_find_port() endpoint/port matching
  logic (bnc#1012628).
- PCI: cadence: Use AXI region 0 to signal interrupts from EP
  (bnc#1012628).
- usb: typec: tcpm: Report back negotiated PPS voltage and current
  (bnc#1012628).
- tpm: suppress transmit cmd error logs when TPM 1.2 is
  disabled/deactivated (bnc#1012628).
- f2fs: clear PageError on the read path (bnc#1012628).
- Drivers: hv: vmbus: Use cpumask_var_t for on-stack cpu mask
  (bnc#1012628).
- VMCI: Resource wildcard match fixed (bnc#1012628).
- PCI / ACPI: Enable wake automatically for power managed bridges
  (bnc#1012628).
- xprtrdma: Reset credit grant properly after a disconnect
  (bnc#1012628).
- irqchip/pdc: Setup all edge interrupts as rising edge at GIC
  (bnc#1012628).
- usb: dwc2: fix call to vbus supply exit routine, call it
  unlocked (bnc#1012628).
- usb: dwc2: fix a race with external vbus supply (bnc#1012628).
- usb: gadget: udc: atmel: handle at91sam9rl PMC (bnc#1012628).
- ext4: fix argument checking in EXT4_IOC_MOVE_EXT (bnc#1012628).
- MD: fix invalid stored role for a disk (bnc#1012628).
- PCI: cadence: Correct probe behaviour when failing to get PHY
  (bnc#1012628).
- nvmem: check the return value of nvmem_add_cells()
  (bnc#1012628).
- xhci: Avoid USB autosuspend when resuming USB2 ports
  (bnc#1012628).
- scsi: qla2xxx: Fix recursive mailbox timeout (bnc#1012628).
- f2fs: fix to recover inode's crtime during POR (bnc#1012628).
- f2fs: fix to recover inode's i_flags during POR (bnc#1012628).
- PCI/MSI: Warn and return error if driver enables MSI/MSI-X twice
  (bnc#1012628).
- coresight: etb10: Fix handling of perf mode (bnc#1012628).
- PCI: dwc: pci-dra7xx: Enable errata i870 for both EP and RC mode
  (bnc#1012628).
- crypto: caam - fix implicit casts in endianness helpers
  (bnc#1012628).
- usb: chipidea: Prevent unbalanced IRQ disable (bnc#1012628).
- Smack: ptrace capability use fixes (bnc#1012628).
- driver/dma/ioat: Call del_timer_sync() without holding prep_lock
  (bnc#1012628).
- ASoC: AMD: Fix capture unstable in beginning for some runs
  (bnc#1012628).
- firmware: coreboot: Unmap ioregion after device population
  (bnc#1012628).
- IB/ipoib: Use dev_port to expose network interface port numbers
  (bnc#1012628).
- IB/mlx5: Allow transition of DCI QP to reset (bnc#1012628).
- uio: ensure class is registered before devices (bnc#1012628).
- scsi: lpfc: Correct soft lockup when running mds diagnostics
  (bnc#1012628).
- scsi: lpfc: Correct race with abort on completion path
  (bnc#1012628).
- f2fs: avoid sleeping under spin_lock (bnc#1012628).
- f2fs: report error if quota off error during umount
  (bnc#1012628).
- signal: Always deliver the kernel's SIGKILL and SIGSTOP to a
  pid namespace init (bnc#1012628).
- f2fs: fix to flush all dirty inodes recovered in readonly fs
  (bnc#1012628).
- mfd: menelaus: Fix possible race condition and leak
  (bnc#1012628).
- dmaengine: dma-jz4780: Return error if not probed from DT
  (bnc#1012628).
- IB/rxe: fix for duplicate request processing and ack psns
  (bnc#1012628).
- ALSA: hda: Check the non-cached stream buffers more explicitly
  (bnc#1012628).
- cpupower: Fix AMD Family 0x17 msr_pstate size (bnc#1012628).
- Revert "f2fs: fix to clear PG_checked flag in set_page_dirty()"
  (bnc#1012628).
- f2fs: fix missing up_read (bnc#1012628).
- f2fs: fix to recover cold bit of inode block during POR
  (bnc#1012628).
- f2fs: fix to account IO correctly (bnc#1012628).
- OPP: Free OPP table properly on performance state irregularities
  (bnc#1012628).
- ARM: dts: exynos: Convert exynos5250.dtsi to opp-v2 bindings
  (bnc#1012628).
- ARM: dts: exynos: Mark 1 GHz CPU OPP as suspend OPP on
  Exynos5250 (bnc#1012628).
- xen-swiotlb: use actually allocated size on check physical
  continuous (bnc#1012628).
- tpm: Restore functionality to xen vtpm driver (bnc#1012628).
- xen/blkfront: avoid NULL blkfront_info dereference on device
  removal (bnc#1012628).
- xen/balloon: Support xend-based toolstack (bnc#1012628).
- xen: fix race in xen_qlock_wait() (bnc#1012628).
- xen: make xen_qlock_wait() nestable (bnc#1012628).
- xen/pvh: increase early stack size (bnc#1012628).
- xen/pvh: don't try to unplug emulated devices (bnc#1012628).
- libertas: don't set URB_ZERO_PACKET on IN USB transfer
  (bnc#1012628).
- usbip:vudc: BUG kmalloc-2048 (Not tainted): Poison overwritten
  (bnc#1012628).
- usb: typec: tcpm: Fix APDO PPS order checking to be based on
  voltage (bnc#1012628).
- usb: gadget: udc: renesas_usb3: Fix b-device mode for
  "workaround" (bnc#1012628).
- mt76: mt76x2: fix multi-interface beacon configuration
  (bnc#1012628).
- iwlwifi: mvm: check return value of rs_rate_from_ucode_rate()
  (bnc#1012628).
- net/ipv4: defensive cipso option parsing (bnc#1012628).
- dmaengine: ppc4xx: fix off-by-one build failure (bnc#1012628).
- scsi: sched/wait: Add wait_event_lock_irq_timeout for
  TASK_UNINTERRUPTIBLE usage (bnc#1012628).
- scsi: target: Fix target_wait_for_sess_cmds breakage with
  active signals (bnc#1012628).
- libnvdimm: Hold reference on parent while scheduling async init
  (bnc#1012628).
- libnvdimm, region: Fail badblocks listing for inactive regions
  (bnc#1012628).
- libnvdimm, pmem: Fix badblocks population for 'raw' namespaces
  (bnc#1012628).
- ASoC: intel: skylake: Add missing break in skl_tplg_get_token()
  (bnc#1012628).
- ASoC: sta32x: set ->component pointer in private struct
  (bnc#1012628).
- IB/mlx5: Fix MR cache initialization (bnc#1012628).
- IB/rxe: Revise the ib_wr_opcode enum (bnc#1012628).
- jbd2: fix use after free in jbd2_log_do_checkpoint()
  (bnc#1012628).
- gfs2_meta: ->mount() can get NULL dev_name (bnc#1012628).
- ext4: fix EXT4_IOC_SWAP_BOOT (bnc#1012628).
- ext4: initialize retries variable in
  ext4_da_write_inline_data_begin() (bnc#1012628).
- ext4: fix setattr project check in fssetxattr ioctl
  (bnc#1012628).
- ext4: propagate error from dquot_initialize() in
  EXT4_IOC_FSSETXATTR (bnc#1012628).
- ext4: fix use-after-free race in ext4_remount()'s error path
  (bnc#1012628).
- selinux: fix mounting of cgroup2 under older policies
  (bnc#1012628).
- HID: wacom: Work around HID descriptor bug in DTK-2451 and
  DTH-2452 (bnc#1012628).
- HID: hiddev: fix potential Spectre v1 (bnc#1012628).
- EDAC, amd64: Add Family 17h, models 10h-2fh support
  (bnc#1012628).
- EDAC, {i7core,sb,skx}_edac: Fix uncorrected error counting
  (bnc#1012628).
- EDAC, skx_edac: Fix logical channel intermediate decoding
  (bnc#1012628).
- ARM: dts: dra7: Fix up unaligned access setting for PCIe EP
  (bnc#1012628).
- PCI/ASPM: Fix link_state teardown on device removal
  (bnc#1012628).
- PCI: Add Device IDs for Intel GPU "spurious interrupt" quirk
  (bnc#1012628).
- signal/GenWQE: Fix sending of SIGKILL (bnc#1012628).
- signal: Guard against negative signal numbers in
  copy_siginfo_from_user32 (bnc#1012628).
- crypto: lrw - Fix out-of bounds access on counter overflow
  (bnc#1012628).
- crypto: tcrypt - fix ghash-generic speed test (bnc#1012628).
- crypto: aesni - don't use GFP_ATOMIC allocation if the request
  doesn't cross a page in gcm (bnc#1012628).
- crypto: morus/generic - fix for big endian systems
  (bnc#1012628).
- crypto: aegis/generic - fix for big endian systems
  (bnc#1012628).
- crypto: speck - remove Speck (bnc#1012628).
- mm: /proc/pid/smaps_rollup: fix NULL pointer deref in
  smaps_pte_range() (bnc#1012628).
- userfaultfd: disable irqs when taking the waitqueue lock
  (bnc#1012628).
- ima: fix showing large 'violations' or
  'runtime_measurements_count' (bnc#1012628).
- ima: open a new file instance if no read permissions
  (bnc#1012628).
- hugetlbfs: dirty pages as they are added to pagecache
  (bnc#1012628).
- mm/rmap: map_pte() was not handling private ZONE_DEVICE page
  properly (bnc#1012628).
- mm/hmm: fix race between hmm_mirror_unregister() and
  mmu_notifier callback (bnc#1012628).
- KVM: arm/arm64: Ensure only THP is candidate for adjustment
  (bnc#1012628).
- KVM: arm64: Fix caching of host MDCR_EL2 value (bnc#1012628).
- kbuild: fix kernel/bounds.c 'W=1' warning (bnc#1012628).
- iio: ad5064: Fix regulator handling (bnc#1012628).
- iio: adc: imx25-gcq: Fix leak of device_node in
  mx25_gcq_setup_cfgs() (bnc#1012628).
- iio: adc: at91: fix acking DRDY irq on simple conversions
  (bnc#1012628).
- iio: adc: at91: fix wrong channel number in triggered buffer
  mode (bnc#1012628).
- w1: omap-hdq: fix missing bus unregister at removal
  (bnc#1012628).
- smb3: allow stats which track session and share reconnects to
  be reset (bnc#1012628).
- smb3: do not attempt cifs operation in smb3 query info error
  path (bnc#1012628).
- smb3: on kerberos mount if server doesn't specify auth type
  use krb5 (bnc#1012628).
- printk: Fix panic caused by passing log_buf_len to command line
  (bnc#1012628).
- genirq: Fix race on spurious interrupt detection (bnc#1012628).
- tpm: fix response size validation in tpm_get_random()
  (bnc#1012628).
- NFC: nfcmrvl_uart: fix OF child-node lookup (bnc#1012628).
- NFSv4.1: Fix the r/wsize checking (bnc#1012628).
- nfs: Fix a missed page unlock after pg_doio() (bnc#1012628).
- nfsd: correctly decrement odstate refcount in error path
  (bnc#1012628).
- nfsd: Fix an Oops in free_session() (bnc#1012628).
- lockd: fix access beyond unterminated strings in prints
  (bnc#1012628).
- dm ioctl: harden copy_params()'s copy_from_user() from malicious
  users (bnc#1012628).
- dm zoned: fix metadata block ref counting (bnc#1012628).
- dm zoned: fix various dmz_get_mblock() issues (bnc#1012628).
- media: ov7670: make "xclk" clock optional (bnc#1012628).
- fsnotify: Fix busy inodes during unmount (bnc#1012628).
- powerpc64/module elfv1: Set opd addresses after module
  relocation (bnc#1012628).
- powerpc/msi: Fix compile error on mpc83xx (bnc#1012628).
- powerpc/tm: Fix HFSCR bit for no suspend case (bnc#1012628).
- powerpc/64s/hash: Do not use PPC_INVALIDATE_ERAT on CPUs before
  POWER9 (bnc#1012628).
- MIPS: OCTEON: fix out of bounds array access on CN68XX
  (bnc#1012628).
- rtc: ds1307: fix ds1339 wakealarm support (bnc#1012628).
- rtc: cmos: Fix non-ACPI undefined reference to
  `hpet_rtc_interrupt' (bnc#1012628).
- rtc: cmos: Remove the `use_acpi_alarm' module parameter for
  !ACPI (bnc#1012628).
- power: supply: twl4030-charger: fix OF sibling-node lookup
  (bnc#1012628).
- ocxl: Fix access to the AFU Descriptor Data (bnc#1012628).
- iommu/arm-smmu: Ensure that page-table updates are visible
  before TLBI (bnc#1012628).
- TC: Set DMA masks for devices (bnc#1012628).
- net: bcmgenet: fix OF child-node lookup (bnc#1012628).
- media: v4l2-tpg: fix kernel oops when enabling HFLIP and OSD
  (bnc#1012628).
- Revert "media: dvbsky: use just one mutex for serializing
  device R/W ops" (bnc#1012628).
- kgdboc: Passing ekgdboc to command line causes panic
  (bnc#1012628).
- remoteproc: qcom: q6v5: Propagate EPROBE_DEFER (bnc#1012628).
- media: cec: make cec_get_edid_spa_location() an inline function
  (bnc#1012628).
- media: cec: integrate cec_validate_phys_addr() in cec-api.c
  (bnc#1012628).
- xen: fix xen_qlock_wait() (bnc#1012628).
- xen: remove size limit of privcmd-buf mapping interface
  (bnc#1012628).
- xen-blkfront: fix kernel panic with negotiate_mq error path
  (bnc#1012628).
- media: cec: add new tx/rx status bits to detect aborts/timeouts
  (bnc#1012628).
- media: cec: fix the Signal Free Time calculation (bnc#1012628).
- media: cec: forgot to cancel delayed work (bnc#1012628).
- media: em28xx: use a default format if TRY_FMT fails
  (bnc#1012628).
- media: tvp5150: avoid going past array on v4l2_querymenu()
  (bnc#1012628).
- media: em28xx: fix input name for Terratec AV 350 (bnc#1012628).
- media: em28xx: make v4l2-compliance happier by starting sequence
  on zero (bnc#1012628).
- media: em28xx: fix handler for vidioc_s_input() (bnc#1012628).
- media: adv7604: when the EDID is cleared, unconfigure CEC as
  well (bnc#1012628).
- media: adv7842: when the EDID is cleared, unconfigure CEC as
  well (bnc#1012628).
- drm/mediatek: fix OF sibling-node lookup (bnc#1012628).
- media: media colorspaces*.rst: rename AdobeRGB to opRGB
  (bnc#1012628).
- media: replace ADOBERGB by OPRGB (bnc#1012628).
- media: hdmi.h: rename ADOBE_RGB to OPRGB and ADOBE_YCC to OPYCC
  (bnc#1012628).
- arm64: lse: remove -fcall-used-x0 flag (bnc#1012628).
- rpmsg: smd: fix memory leak on channel create (bnc#1012628).
- Cramfs: fix abad comparison when wrap-arounds occur
  (bnc#1012628).
- ARM: dts: socfpga: Fix SDRAM node address for Arria10
  (bnc#1012628).
- arm64: dts: stratix10: Correct System Manager register size
  (bnc#1012628).
- soc: qcom: rmtfs-mem: Validate that scm is available
  (bnc#1012628).
- soc/tegra: pmc: Fix child-node lookup (bnc#1012628).
- selftests/ftrace: Fix synthetic event test to delete event
  correctly (bnc#1012628).
- selftests/powerpc: Fix ptrace tm failure (bnc#1012628).
- tracing: Return -ENOENT if there is no target synthetic event
  (bnc#1012628).
- btrfs: qgroup: Avoid calling qgroup functions if qgroup is
  not enabled (bnc#1012628).
- btrfs: Handle owner mismatch gracefully when walking up tree
  (bnc#1012628).
- btrfs: locking: Add extra check in btrfs_init_new_buffer()
  to avoid deadlock (bnc#1012628).
- btrfs: fix error handling in free_log_tree (bnc#1012628).
- btrfs: fix error handling in btrfs_dev_replace_start
  (bnc#1012628).
- btrfs: Enhance btrfs_trim_fs function to handle error better
  (bnc#1012628).
- btrfs: Ensure btrfs_trim_fs can trim the whole filesystem
  (bnc#1012628).
- btrfs: iterate all devices during trim, instead of
  fs_devices::alloc_list (bnc#1012628).
- btrfs: don't attempt to trim devices that don't support it
  (bnc#1012628).
- btrfs: keep trim from interfering with transaction commits
  (bnc#1012628).
- btrfs: wait on caching when putting the bg cache (bnc#1012628).
- Btrfs: don't clean dirty pages during buffered writes
  (bnc#1012628).
- btrfs: release metadata before running delayed refs
  (bnc#1012628).
- btrfs: protect space cache inode alloc with GFP_NOFS
  (bnc#1012628).
- btrfs: reset max_extent_size on clear in a bitmap (bnc#1012628).
- btrfs: make sure we create all new block groups (bnc#1012628).
- Btrfs: fix warning when replaying log after fsync of a tmpfile
  (bnc#1012628).
- Btrfs: fix wrong dentries after fsync of file that got its
  parent replaced (bnc#1012628).
- btrfs: qgroup: Dirty all qgroups before rescan (bnc#1012628).
- Btrfs: fix null pointer dereference on compressed write path
  error (bnc#1012628).
- Btrfs: fix assertion on fsync of regular file when using
  no-holes feature (bnc#1012628).
- Btrfs: fix deadlock when writing out free space caches
  (bnc#1012628).
- btrfs: reset max_extent_size properly (bnc#1012628).
- btrfs: set max_extent_size properly (bnc#1012628).
- btrfs: don't use ctl->free_space for max_extent_size
  (bnc#1012628).
- btrfs: only free reserved extent if we didn't insert it
  (bnc#1012628).
- btrfs: fix insert_reserved error handling (bnc#1012628).
- btrfs: don't run delayed_iputs in commit (bnc#1012628).
- btrfs: move the dio_sem higher up the callchain (bnc#1012628).
- Btrfs: fix use-after-free during inode eviction (bnc#1012628).
- Btrfs: fix use-after-free when dumping free space (bnc#1012628).
- net: sched: Remove TCA_OPTIONS from policy (bnc#1012628).
- userns: also map extents in the reverse map to kernel IDs
  (bnc#1012628).
- bpf: wait for running BPF programs when updating map-in-map
  (bnc#1012628).
- vga_switcheroo: Fix missing gpu_bound call at audio client
  registration (bnc#1012628).
- MD: fix invalid stored role for a disk - try2 (bnc#1012628).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- commit 8adee6e
* Tue Nov 13 2018 msuchanek@suse.de
- Add kernel-subpackage-build.spec (FATE#326579).
  - add kernel-subpackage-build.spec.in and support scripts
  - hook it in mkspec
  - extend the mechanism that copies dependencies inside
  kernel-binary.spec.in from kernel-%%build_flavor to
  kernel-%%build_flavor-base to also handle
  kernel-subpackage-build.spec.in using BINARY DEPS marker.
  - expand %%name in kernel-%%build_flavor so the dependencies are expanded
  correctly in kernel-subpackage-build.spec.in
- commit 9b3ca32
* Mon Nov 12 2018 mkubecek@suse.cz
- Update to 4.20-rc2
- Eliminated 1 patch
- Config changes:
  - I2C:
    I2C_NVIDIA_GPU=m
  - USB:
    UCSI_CCG=m
- commit 1c08d7f
* Sun Nov 11 2018 afaerber@suse.de
- config: arm64: Update to 4.20-rc1
- commit 2d02cd8
* Sun Nov 11 2018 jslaby@suse.cz
- vt: fix broken display when running aptitude (bnc#1114836).
- commit 5bec309
* Thu Nov  8 2018 jslaby@suse.cz
- doc/README.SUSE: correct GIT url
  No more gitorious, github we use.
- commit 31864f3
* Tue Nov  6 2018 mkubecek@suse.cz
- config: reenable BPFILTER_UMH on ppc64
- commit 46cb36e
* Tue Nov  6 2018 agraf@suse.de
- Remove Cell/PS3 support from ppc64 kernel (boo#1114846)
- commit c336d64
* Mon Nov  5 2018 mkubecek@suse.cz
- scripts/mkmakefile: honor second argument.
- commit 78325a6
* Mon Nov  5 2018 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: add macros.s into kernel-*-devel
  Starting with 4.20-rc1, file arch/*/kernel/macros.s is needed to build out
  of tree modules. Add it to kernel-${flavor}-devel packages if it exists.
- commit 09d14c8
* Mon Nov  5 2018 mkubecek@suse.cz
- series.conf: delete an obsolete comment
- commit c3bd57d
* Mon Nov  5 2018 jslaby@suse.cz
- Refresh
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
  Adapt to 4.20.
- commit dcaec93
* Mon Nov  5 2018 jslaby@suse.cz
- Linux 4.19.1 (bnc#1012628).
- net: bridge: remove ipv6 zero address check in mcast queries
  (bnc#1012628).
- sparc64: Wire up compat getpeername and getsockname
  (bnc#1012628).
- sparc64: Make corrupted user stacks more debuggable
  (bnc#1012628).
- sparc64: Export __node_distance (bnc#1012628).
- sctp: check policy more carefully when getting pr status
  (bnc#1012628).
- Revert "be2net: remove desc field from be_eq_obj" (bnc#1012628).
- r8169: fix broken Wake-on-LAN from S5 (poweroff) (bnc#1012628).
- net: Properly unlink GRO packets on overflow (bnc#1012628).
- net: drop skb on failure in ip_check_defrag() (bnc#1012628).
- mlxsw: core: Fix devlink unregister flow (bnc#1012628).
- mlxsw: spectrum_switchdev: Don't ignore deletions of learned
  MACs (bnc#1012628).
- net/smc: fix smc_buf_unuse to use the lgr pointer (bnc#1012628).
- net/ipv6: Allow onlink routes to have a device mismatch if it
  is the default route (bnc#1012628).
- openvswitch: Fix push/pop ethernet validation (bnc#1012628).
- bonding: fix length of actor system (bnc#1012628).
- vhost: Fix Spectre V1 vulnerability (bnc#1012628).
- rtnetlink: Disallow FDB configuration for non-Ethernet device
  (bnc#1012628).
- Revert "net: simplify sock_poll_wait" (bnc#1012628).
- net: udp: fix handling of CHECKSUM_COMPLETE packets
  (bnc#1012628).
- net: stmmac: Fix stmmac_mdio_reset() when building stmmac as
  modules (bnc#1012628).
- net: sched: gred: pass the right attribute to
  gred_change_table_def() (bnc#1012628).
- net/mlx5e: fix csum adjustments caused by RXFCS (bnc#1012628).
- ipv6/ndisc: Preserve IPv6 control buffer if protocol error
  handlers are called (bnc#1012628).
- bridge: do not add port to router list when receives query
  with source 0.0.0.0 (bnc#1012628).
- commit 57135d7
* Mon Nov  5 2018 mkubecek@suse.cz
- Update to 4.20-rc1
- ARM configs need updating
- disabled (needs refresh):
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch
- Config changes:
  - General:
  - PSI=y
  - Networking:
  - NFT_XFRM=m
  - NET_SCH_TAPRIO=m
  - BATMAN_ADV_TRACING=n
  - NCSI_OEM_CMD_GET_MAC=y
  - EEPROM_EE1004=m
  - SCSI_UFS_BSG=y
  - SCSI_MYRB=m
  - SCSI_MYRS=m
  - IXGBE_IPSEC=y
  - IXGBEVF_IPSEC=y
  - IGC=m
  - NI_XGE_MANAGEMENT_ENET=m
  - MT76x0E=m
  - File systems:
  - EROFS_FS_IO_MAX_RETRIES=5 (default)
  - AFS_DEBUG_CURSOR=n
  - CONFIG_UBIFS_FS_AUTHENTICATION=y
  - Crypto:
  - CRYPTO_OFB=m
  - CRYPTO_STATS=n
  - ASYMMETRIC_TPM_KEY_SUBTYPE=m
  - PKCS8_PRIVATE_KEY_PARSER=m
  - TPM_KEY_PARSER=m
  - Graphics:
  - VIDEO_VICODEC=m
  - DRM_FBDEV_LEAK_PHYS_SMEM=n
  - DRM_I915_DEBUG_RUNTIME_PM=n
  - DRM_TOSHIBA_TC358764=n
  - DRM_TI_SN65DSI86=n
  - Sound:
  - SND_SOC_INTEL_KBL_DA7219_MAX98927_MACH=m
  - SND_SOC_INTEL_SKL_HDA_DSP_GENERIC_MACH=m
  - SND_SOC_MAX98088=n
  - SND_SOC_PCM3060_I2C=n
  - SND_SOC_PCM3060_SPI=n
  - SND_SOC_NAU8822=n
  - Input devices:
  - HID_BIGBEN_FF=m
  - Platform:
  - LG_LAPTOP=m
  - INTEL_ATOMISP2_PM=m
  - IIO:
  - ADXL372_SPI=n
  - ADXL372_I2C=n
  - MCP3911=n
  - QCOM_SPMI_ADC5=n
  - LTC1660=n
  - VL53L0X_I2C=m
  - Misc drivers:
  - UDMABUF=y
  - MFD_AT91_USART=n
  - LEDS_AN30259A=n
  - LEDS_TRIGGER_PATTERN=m
  - PHY_CADENCE_DP=m
  - STM_PROTO_BASIC=m
  - STM_PROTO_SYS_T=m
  - Testing:
  - TEST_XARRAY=n
  - TEST_MEMCAT_P=n
  - x86:
  - X86_CPA_STATISTICS=n (y for -debug)
  - i386:
  - MSCC_OCELOT_SWITCH_OCELOT=m
  - ppc64, ppc64le:
  - PAPR_SCM=m
  - PCI_P2PDMA=y
  - STACKPROTECTOR=y
  - STACKPROTECTOR_STRONG=n
  - BLK_DEV_PMEM=m
  - ND_BLK=m
  - BTT=y
  - NVDIMM_PFN=y
  - NVDIMM_DAX=y
  - OF_PMEM=m
  - DEV_DAX_PMEM=m
  - FAIL_FUNCTION=n
  - ENA_ETHERNET=m
  - s390:
  - VMAP_STACK=y
  - S390_AP_IOMMU=n
  - ZCRYPT_MULTIDEVNODES=y
  - KASAN=n
  - */debug:
  - INTEL_IOMMU_DEBUGFS=y
  - BPF_KPROBE_OVERRIDE=y
  - CONFIG_X86_CPA_STATISTICS=y
  - CONFIG_CRYPTO_STATS=y
- commit f29310b
* Sun Nov  4 2018 mkubecek@suse.cz
- rpm: use syncconfig instead of silentoldconfig where available
  Since mainline commit 0085b4191f3e ("kconfig: remove silentoldconfig
  target"), "make silentoldconfig" can be no longer used. Use "make
  syncconfig" instead if available.
- commit a239c6e
* Fri Nov  2 2018 mkubecek@suse.cz
- series.conf: more descriptive name for network driver section
  We have two networking sections in series.conf: one for networking core and
  one for network drivers. The latter is among other driver related sections
  but it may not be obvious that it is not intended for core networking
  patches. Change the label to "Network drivers" to make its purpose more
  apparent.
- commit 7968e32
* Fri Nov  2 2018 mkubecek@suse.cz
- config: enable SCSI_AACRAID on ppc64le and ppc64 (bsc#1114523)
- commit 5f3762b
* Tue Oct 30 2018 jslaby@suse.cz
- Refresh
  patches.suse/netfilter-bridge-define-INT_MIN-INT_MAX-in-userspace.patch.
  Update upstream status.
- commit 37417fa
* Mon Oct 29 2018 jmoreira@suse.de
- Add version information to KLP_SYMBOLS file
- commit f77f8d2
* Mon Oct 29 2018 tiwai@suse.de
- cdrom: fix improper type cast, which can leat to information
  leak (CVE-2018-18710,bsc#1113751).
- commit 6216efb
* Thu Oct 25 2018 mwilck@suse.com
- rpm/kernel-binary.spec.in: allow unsupported modules for -extra
  (bsc#1111183). SLE-15 and later only.
- commit 0d585a8
* Wed Oct 24 2018 mkubecek@suse.cz
- series.conf: move patches.suse/netfilter-bridge-define-INT_MIN-INT_MAX-in-userspace.patch to netfilter section
- commit 7656685
* Wed Oct 24 2018 jslaby@suse.cz
- netfilter: bridge: define INT_MIN & INT_MAX in userspace
  (4.19 fixes).
- commit e7213f6
* Mon Oct 22 2018 mkubecek@suse.cz
- Update to 4.19 final
- Refresh configs
- commit b4c35bb
* Sat Oct 20 2018 jslaby@suse.cz
- Linux 4.18.16 (bnc#1012628).
- ARC: build: Don't set CROSS_COMPILE in arch's Makefile
  (bnc#1012628).
- ARC: build: Get rid of toolchain check (bnc#1012628).
- mremap: properly flush TLB before releasing the page
  (bnc#1012628).
- Revert "vfs: fix freeze protection in mnt_want_write_file()
  for overlayfs" (bnc#1012628).
- x86/boot: Fix kexec booting failure in the SEV bit detection
  code (bnc#1012628).
- iommu/amd: Return devid as alias for ACPI HID devices
  (bnc#1012628).
- powerpc/numa: Use associativity if VPHN hcall is successful
  (bnc#1012628).
- powerpc/tm: Avoid possible userspace r1 corruption on reclaim
  (bnc#1012628).
- powerpc/tm: Fix userspace r13 corruption (bnc#1012628).
- pinctrl/amd: poll InterruptEnable bits in amd_gpio_irq_set_type
  (bnc#1012628).
- iommu/rockchip: Free irqs in shutdown handler (bnc#1012628).
- RISC-V: include linux/ftrace.h in asm-prototypes.h
  (bnc#1012628).
- RDMA/bnxt_re: Fix system crash during RDMA resource
  initialization (bnc#1012628).
- clocksource/drivers/fttmr010: Fix set_next_event handler
  (bnc#1012628).
- net/mlx4: Use cpumask_available for eq->affinity_mask
  (bnc#1012628).
- bpf: test_maps, only support ESTABLISHED socks (bnc#1012628).
- bpf: sockmap, fix transition through disconnect without close
  (bnc#1012628).
- bpf: sockmap only allow ESTABLISHED sock state (bnc#1012628).
- scsi: sd: don't crash the host on invalid commands
  (bnc#1012628).
- scsi: ipr: System hung while dlpar adding primary ipr adapter
  back (bnc#1012628).
- drm: mali-dp: Call drm_crtc_vblank_reset on device init
  (bnc#1012628).
- scsi: lpfc: Synchronize access to remoteport via rport
  (bnc#1012628).
- RDMA/uverbs: Fix validity check for modify QP (bnc#1012628).
- PCI: dwc: Fix scheduling while atomic issues (bnc#1012628).
- qed: Do not add VLAN 0 tag to untagged frames in multi-function
  mode (bnc#1012628).
- qed: Fix populating the invalid stag value in multi function
  mode (bnc#1012628).
- net/smc: fix sizeof to int comparison (bnc#1012628).
- net/smc: fix non-blocking connect problem (bnc#1012628).
- ravb: do not write 1 to reserved bits (bnc#1012628).
- net: emac: fix fixed-link setup for the RTL8363SB switch
  (bnc#1012628).
- selftests: pmtu: properly redirect stderr to /dev/null
  (bnc#1012628).
- Input: atakbd - fix Atari CapsLock behaviour (bnc#1012628).
- Input: atakbd - fix Atari keymap (bnc#1012628).
- intel_th: pci: Add Ice Lake PCH support (bnc#1012628).
- scsi: ibmvscsis: Ensure partition name is properly NUL
  terminated (bnc#1012628).
- scsi: ibmvscsis: Fix a stringop-overflow warning (bnc#1012628).
- clocksource/drivers/ti-32k: Add CLOCK_SOURCE_SUSPEND_NONSTOP
  flag for non-am43 SoCs (bnc#1012628).
- cxgb4: fix abort_req_rss6 struct (bnc#1012628).
- batman-adv: fix hardif_neigh refcount on queue_work() failure
  (bnc#1012628).
- batman-adv: fix backbone_gw refcount on queue_work() failure
  (bnc#1012628).
- batman-adv: Prevent duplicated tvlv handler (bnc#1012628).
- batman-adv: Prevent duplicated global TT entry (bnc#1012628).
- batman-adv: Prevent duplicated softif_vlan entry (bnc#1012628).
- batman-adv: Prevent duplicated nc_node entry (bnc#1012628).
- batman-adv: Prevent duplicated gateway_node entry (bnc#1012628).
- batman-adv: Fix segfault when writing to sysfs elp_interval
  (bnc#1012628).
- batman-adv: Fix segfault when writing to throughput_override
  (bnc#1012628).
- batman-adv: Avoid probe ELP information leak (bnc#1012628).
- spi: gpio: Fix copy-and-paste error (bnc#1012628).
- media: af9035: prevent buffer overflow on write (bnc#1012628).
- soundwire: Fix acquiring bus lock twice during master release
  (bnc#1012628).
- soundwire: Fix incorrect exit after configuring stream
  (bnc#1012628).
- soundwire: Fix duplicate stream state assignment (bnc#1012628).
- commit bd19c86
* Thu Oct 18 2018 jslaby@suse.cz
- Linux 4.18.15 (bnc#1012628).
- KVM: PPC: Book3S HV: Avoid crash from THP collapse during
  radix page fault (bnc#1012628).
- i2c: i2c-scmi: fix for i2c_smbus_write_block_data (bnc#1012628).
- mm: Preserve _PAGE_DEVMAP across mprotect() calls (bnc#1012628).
- filesystem-dax: Fix dax_layout_busy_page() livelock
  (bnc#1012628).
- mm/thp: fix call to mmu_notifier in set_pmd_migration_entry()
  v2 (bnc#1012628).
- mm/mmap.c: don't clobber partially overlapping VMA with
  MAP_FIXED_NOREPLACE (bnc#1012628).
- arm64: perf: Reject stand-alone CHAIN events for PMUv3
  (bnc#1012628).
- pinctrl: mcp23s08: fix irq and irqchip setup order
  (bnc#1012628).
- mmc: block: avoid multiblock reads for the last sector in SPI
  mode (bnc#1012628).
- drm/nouveau/drm/nouveau: Grab runtime PM ref in
  nv50_mstc_detect() (bnc#1012628).
- Input: xpad - add support for Xbox1 PDP Camo series gamepad
  (bnc#1012628).
- cgroup: Fix dom_cgrp propagation when enabling threaded mode
  (bnc#1012628).
- dm linear: fix linear_end_io conditional definition
  (bnc#1012628).
- dm linear: eliminate linear_end_io call if CONFIG_DM_ZONED
  disabled (bnc#1012628).
- dm: fix report zone remapping to account for partition offset
  (bnc#1012628).
- dm cache: destroy migration_cache if cache target registration
  failed (bnc#1012628).
- s390/cio: Fix how vfio-ccw checks pinned pages (bnc#1012628).
- perf script python: Fix export-to-sqlite.py sample columns
  (bnc#1012628).
- perf script python: Fix export-to-postgresql.py occasional
  failure (bnc#1012628).
- percpu: stop leaking bitmap metadata blocks (bnc#1012628).
- vsprintf: Fix off-by-one bug in bstr_printf() processing
  dereferenced pointers (bnc#1012628).
- mach64: detect the dot clock divider correctly on sparc
  (bnc#1012628).
- MIPS: VDSO: Always map near top of user memory (bnc#1012628).
- MIPS: Fix CONFIG_CMDLINE handling (bnc#1012628).
- afs: Fix clearance of reply (bnc#1012628).
- afs: Fix afs_server struct leak (bnc#1012628).
- mm/vmstat.c: fix outdated vmstat_text (bnc#1012628).
- mm: slowly shrink slabs with a relatively small number of
  objects (bnc#1012628).
- drm/amdkfd: Fix ATS capablity was not reported correctly on
  some APUs (bnc#1012628).
- drm/amdkfd: Change the control stack MTYPE from UC to NC on GFX9
  (bnc#1012628).
- drm/amdgpu: Fix SDMA HQD destroy error on gfx_v7 (bnc#1012628).
- x86/kvm/lapic: always disable MMIO interface in x2APIC mode
  (bnc#1012628).
- pinctrl: cannonlake: Fix gpio base for GPP-E (bnc#1012628).
- clk: x86: Stop marking clocks as CLK_IS_CRITICAL (bnc#1012628).
- clk: x86: add "ether_clk" alias for Bay Trail / Cherry Trail
  (bnc#1012628).
- PCI: hv: support reporting serial number as slot information
  (bnc#1012628).
- ARM: dts: at91: add new compatibility string for macb on sama5d3
  (bnc#1012628).
- net: macb: disable scatter-gather for macb on sama5d3
  (bnc#1012628).
- net: ethernet: ti: add missing GENERIC_ALLOCATOR dependency
  (bnc#1012628).
- hwmon: (nct6775) Use different register to get fan RPM for fan7
  (bnc#1012628).
- stmmac: fix valid numbers of unicast filter entries
  (bnc#1012628).
- hwmon: (nct6775) Fix RPM output for fan7 on NCT6796D
  (bnc#1012628).
- hwmon: (nct6775) Fix virtual temperature sources for NCT6796D
  (bnc#1012628).
- bpf: use __GFP_COMP while allocating page (bnc#1012628).
- bpf: btf: Fix end boundary calculation for type section
  (bnc#1012628).
- sound: don't call skl_init_chip() to reset intel skl soc
  (bnc#1012628).
- sound: enable interrupt after dma buffer initialization
  (bnc#1012628).
- scsi: qla2xxx: Fix an endian bug in fcpcmd_is_corrupted()
  (bnc#1012628).
- scsi: iscsi: target: Don't use stack buffer for scatterlist
  (bnc#1012628).
- KVM: PPC: Book3S HV: Don't use compound_order to determine
  host mapping size (bnc#1012628).
- mfd: omap-usb-host: Fix dts probe of children (bnc#1012628).
- Bluetooth: hci_ldisc: Free rw_semaphore on close (bnc#1012628).
- Bluetooth: Use correct tfm to generate OOB data (bnc#1012628).
- Bluetooth: SMP: Fix trying to use non-existent local OOB data
  (bnc#1012628).
- drm/pl111: Make sure of_device_id tables are NULL terminated
  (bnc#1012628).
- ASoC: AMD: Ensure reset bit is cleared before configuring
  (bnc#1012628).
- Fix cg_read_strcmp() (bnc#1012628).
- hwmon: (nct6775) Fix access to fan pulse registers
  (bnc#1012628).
- ASoC: rsnd: don't fallback to PIO mode when -EPROBE_DEFER
  (bnc#1012628).
- ASoC: rsnd: adg: care clock-frequency size (bnc#1012628).
- selftests: memory-hotplug: add required configs (bnc#1012628).
- selftests/efivarfs: add required kernel configs (bnc#1012628).
- selftests: add headers_install to lib.mk (bnc#1012628).
- ASoC: q6routing: initialize data correctly (bnc#1012628).
- ASoC: sigmadsp: safeload should not have lower byte limit
  (bnc#1012628).
- ASoC: wm8804: Add ACPI support (bnc#1012628).
- ASoC: max98373: Added 10ms sleep after amp software reset
  (bnc#1012628).
- selftests: kselftest: Remove outdated comment (bnc#1012628).
- selftests: android: move config up a level (bnc#1012628).
- ASoC: rt5514: Fix the issue of the delay volume applied again
  (bnc#1012628).
- ASoC: max98373: Added speaker FS gain cotnrol register to
  volatile (bnc#1012628).
- ASoC: dapm: Fix NULL pointer deference on CODEC to CODEC DAIs
  (bnc#1012628).
- vxlan: fill ttl inherit info (bnc#1012628).
- r8169: set RX_MULTI_EN bit in RxConfig for 8168F-family chips
  (bnc#1012628).
- r8169: fix network stalls due to missing bit TXCFG_AUTO_FIFO
  (bnc#1012628).
- qed: Fix shmem structure inconsistency between driver and the
  mfw (bnc#1012628).
- net: mscc: fix the frame extraction into the skb (bnc#1012628).
- net/ipv6: stop leaking percpu memory in fib6 info (bnc#1012628).
- net/ipv6: Remove extra call to ip6_convert_metrics for multipath
  case (bnc#1012628).
- bnxt_en: get the reduced max_irqs by the ones used by RDMA
  (bnc#1012628).
- bnxt_en: Fix enables field in HWRM_QUEUE_COS2BW_CFG request
  (bnc#1012628).
- net/mlx5: Check for SQ and not RQ state when modifying hairpin
  SQ (bnc#1012628).
- net: ipv4: don't let PMTU updates increase route MTU
  (bnc#1012628).
- bnxt_en: Fix VNIC reservations on the PF (bnc#1012628).
- rtnetlink: Fail dump if target netnsid is invalid (bnc#1012628).
- net: dsa: b53: Keep CPU port as tagged in all VLANs
  (bnc#1012628).
- inet: make sure to grab rcu_read_lock before using
  ireq->ireq_opt (bnc#1012628).
- tcp/dccp: fix lockdep issue when SYN is backlogged
  (bnc#1012628).
- sfp: fix oops with ethtool -m (bnc#1012628).
- net: phy: phylink: fix SFP interface autodetection
  (bnc#1012628).
- net-ethtool: ETHTOOL_GUFO did not and should not require
  CAP_NET_ADMIN (bnc#1012628).
- bnxt_en: don't try to offload VLAN 'modify' action
  (bnc#1012628).
- nfp: avoid soft lockups under control message storm
  (bnc#1012628).
- net: stmmac: Rework coalesce timer and fix multi-queue races
  (bnc#1012628).
- bonding: fix warning message (bnc#1012628).
- bonding: pass link-local packets to bonding master also
  (bnc#1012628).
- net/mlx5: E-Switch, Fix out of bound access when setting vport
  rate (bnc#1012628).
- net: aquantia: memory corruption on jumbo frames (bnc#1012628).
- net/mlx5e: Set vlan masks for all offloaded TC rules
  (bnc#1012628).
- net: dsa: bcm_sf2: Fix unbind ordering (bnc#1012628).
- net/packet: fix packet drop as of virtio gso (bnc#1012628).
- net: stmmac: Fixup the tail addr setting in xmit path
  (bnc#1012628).
- tun: napi flags belong to tfile (bnc#1012628).
- tun: initialize napi_mutex unconditionally (bnc#1012628).
- tun: remove unused parameters (bnc#1012628).
- net: qualcomm: rmnet: Fix incorrect allocation flag in receive
  path (bnc#1012628).
- net: qualcomm: rmnet: Fix incorrect allocation flag in transmit
  (bnc#1012628).
- net: qualcomm: rmnet: Skip processing loopback packets
  (bnc#1012628).
- udp: Unbreak modules that rely on external __skb_recv_udp()
  availability (bnc#1012628).
- tipc: fix flow control accounting for implicit connect
  (bnc#1012628).
- team: Forbid enslaving team device to itself (bnc#1012628).
- sctp: update dst pmtu with the correct daddr (bnc#1012628).
- rtnl: limit IFLA_NUM_TX_QUEUES and IFLA_NUM_RX_QUEUES to 4096
  (bnc#1012628).
- rtnetlink: fix rtnl_fdb_dump() for ndmsg header (bnc#1012628).
- commit 5a53676
* Thu Oct 18 2018 jslaby@suse.cz
- qmi_wwan: Added support for Gemalto's Cinterion ALASxx WWAN
  interface (bnc#1012628).
- qlcnic: fix Tx descriptor corruption on 82xx devices
  (bnc#1012628).
- net/usb: cancel pending work when unbinding smsc75xx
  (bnc#1012628).
- net: systemport: Fix wake-up interrupt race during resume
  (bnc#1012628).
- net: sched: cls_u32: fix hnode refcounting (bnc#1012628).
- net: sched: Add policy validation for tc attributes
  (bnc#1012628).
- net: mvpp2: fix a txq_done race condition (bnc#1012628).
- net: mvpp2: Extract the correct ethtype from the skb for tx
  csum offload (bnc#1012628).
- netlabel: check for IPV4MASK in addrinfo_get (bnc#1012628).
- net/ipv6: Display all addresses in output of /proc/net/if_inet6
  (bnc#1012628).
- net: ipv4: update fnhe_pmtu when first hop's MTU changes
  (bnc#1012628).
- net: hns: fix for unmapping problem when SMMU is on
  (bnc#1012628).
- net: dsa: bcm_sf2: Call setup during switch resume
  (bnc#1012628).
- ipv6: take rcu lock in rawv6_send_hdrinc() (bnc#1012628).
- ipv4: fix use-after-free in ip_cmsg_recv_dstaddr()
  (bnc#1012628).
- ip_tunnel: be careful when accessing the inner header
  (bnc#1012628).
- ip6_tunnel: be careful when accessing the inner header
  (bnc#1012628).
- bonding: avoid possible dead-lock (bnc#1012628).
- bnxt_en: free hwrm resources, if driver probe fails
  (bnc#1012628).
- bnxt_en: Fix TX timeout during netpoll (bnc#1012628).
- commit ee9d247
* Mon Oct 15 2018 mkubecek@suse.cz
- Update to 4.19-rc8
- commit 2e61ca8
* Sat Oct 13 2018 jslaby@suse.cz
- Linux 4.18.14 (bnc#1012628).
- ath10k: fix scan crash due to incorrect length calculation
  (bnc#1012628).
- rds: rds_ib_recv_alloc_cache() should call alloc_percpu_gfp()
  instead (bnc#1012628).
- ubifs: Check for name being NULL while mounting (bnc#1012628).
- ucma: fix a use-after-free in ucma_resolve_ip() (bnc#1012628).
- tipc: call start and done ops directly in
  __tipc_nl_compat_dumpit() (bnc#1012628).
- f2fs: fix invalid memory access (bnc#1012628).
- ARC: clone syscall to setp r25 as thread pointer (bnc#1012628).
- powerpc/lib: fix book3s/32 boot failure due to code patching
  (bnc#1012628).
- powerpc: Avoid code patching freed init sections (bnc#1012628).
- of: unittest: Disable interrupt node tests for old world MAC
  systems (bnc#1012628).
- tty: Drop tty->count on tty_reopen() failure (bnc#1012628).
- usb: cdc_acm: Do not leak URB buffers (bnc#1012628).
- USB: serial: option: add two-endpoints device-id flag
  (bnc#1012628).
- USB: serial: option: improve Quectel EP06 detection
  (bnc#1012628).
- USB: serial: simple: add Motorola Tetra MTP6550 id
  (bnc#1012628).
- usb: xhci-mtk: resume USB3 roothub first (bnc#1012628).
- xhci: Add missing CAS workaround for Intel Sunrise Point xHCI
  (bnc#1012628).
- dm cache: fix resize crash if user doesn't reload cache table
  (bnc#1012628).
- dm cache metadata: ignore hints array being too small during
  resize (bnc#1012628).
- dm mpath: fix attached_handler_name leak and dangling
  hw_handler_name pointer (bnc#1012628).
- PM / core: Clear the direct_complete flag on errors
  (bnc#1012628).
- mac80211: fix setting IEEE80211_KEY_FLAG_RX_MGMT for AP mode
  keys (bnc#1012628).
- PCI: Reprogram bridge prefetch registers on resume
  (bnc#1012628).
- x86/vdso: Fix vDSO syscall fallback asm constraint regression
  (bnc#1012628).
- x86/vdso: Only enable vDSO retpolines when enabled and supported
  (bnc#1012628).
- selftests/x86: Add clock_gettime() tests to test_vdso
  (bnc#1012628).
- x86/vdso: Fix asm constraints on vDSO syscall fallbacks
  (bnc#1012628).
- drm: fix use-after-free read in drm_mode_create_lease_ioctl()
  (bnc#1012628).
- drm/syncobj: Don't leak fences when WAIT_FOR_SUBMIT is set
  (bnc#1012628).
- drm/amdgpu: Fix vce work queue was not cancelled when suspend
  (bnc#1012628).
- mac80211: allocate TXQs for active monitor interfaces
  (bnc#1012628).
- mmc: slot-gpio: Fix debounce time to use miliseconds again
  (bnc#1012628).
- mmc: core: Fix debounce time to use microseconds (bnc#1012628).
- xen-netback: fix input validation in xenvif_set_hash_mapping()
  (bnc#1012628).
- fbdev/omapfb: fix omapfb_memory_read infoleak (bnc#1012628).
- clocksource/drivers/timer-atmel-pit: Properly handle error cases
  (bnc#1012628).
- pstore/ram: Fix failure-path memory leak in ramoops_init
  (bnc#1012628).
- blk-mq: I/O and timer unplugs are inverted in blktrace
  (bnc#1012628).
- KVM: VMX: check for existence of secondary exec controls before
  accessing (bnc#1012628).
- KVM: x86: fix L1TF's MMIO GFN calculation (bnc#1012628).
- mm/vmstat.c: skip NR_TLB_REMOTE_FLUSH* properly (bnc#1012628).
- mm, thp: fix mlocking THP page with migration enabled
  (bnc#1012628).
- mm: migration: fix migration of huge PMD shared pages
  (bnc#1012628).
- perf/core: Add sanity check to deal with pinned event failure
  (bnc#1012628).
- commit ce1c446
* Fri Oct 12 2018 tzimmermann@suse.de
- README: Clean-up trailing whitespace
- commit 06542f9
* Thu Oct 11 2018 tzimmermann@suse.de
- README: Update documentation wrt. Patch-mainline
  Common practice is to set Patch-mainline to a Linux release tag. More
  than 95%% of all patches follow this convention. The remaining 5%% have
  been fixed accordingly in SLE15.
  The README file is inconsistent wrt. to the content of Patch-mainline.
  In some places it refers to a release tag, in others it refers to a version
  number. With this cleanup, it refers to release tags everywhere.
  This change is a follow-up for commit 1d81d2699cd3.
- commit 57326f5
* Wed Oct 10 2018 jslaby@suse.cz
- Linux 4.18.13 (bnc#1012628).
- Revert "drm/amd/pp: Send khz clock values to DC for smu7/8"
  (bnc#1012628).
- dm thin metadata: fix __udivdi3 undefined on 32-bit
  (bnc#1012628).
- ixgbe: check return value of napi_complete_done() (bnc#1012628).
- HID: i2c-hid: disable runtime PM operations on hantick touchpad
  (bnc#1012628).
- ocfs2: fix locking for res->tracking and dlm->tracking_list
  (bnc#1012628).
- proc: restrict kernel stack dumps to root (bnc#1012628).
- tools: hv: fcopy: set 'error' in case an unknown operation
  was requested (bnc#1012628).
- Drivers: hv: vmbus: Use get/put_cpu() in vmbus_connect()
  (bnc#1012628).
- gpiolib: Free the last requested descriptor (bnc#1012628).
- crypto: caam/jr - fix ablkcipher_edesc pointer arithmetic
  (bnc#1012628).
- crypto: mxs-dcp - Fix wait logic on chan threads (bnc#1012628).
- crypto: chelsio - Fix memory corruption in DMA Mapped buffers
  (bnc#1012628).
- crypto: qat - Fix KASAN stack-out-of-bounds bug in adf_probe()
  (bnc#1012628).
- ALSA: hda/realtek - Cannot adjust speaker's volume on Dell
  XPS 27 7760 (bnc#1012628).
- iommu/amd: Clear memory encryption mask from physical address
  (bnc#1012628).
- smb2: fix missing files in root share directory listing
  (bnc#1012628).
- cpufreq: qcom-kryo: Fix section annotations (bnc#1012628).
- firmware: Always initialize the fw_priv list object
  (bnc#1012628).
- firmware: Fix security issue with request_firmware_into_buf()
  (bnc#1012628).
- b43: fix DMA error related regression with proprietary firmware
  (bnc#1012628).
- sysfs: Do not return POSIX ACL xattrs via listxattr
  (bnc#1012628).
- ovl: fix format of setxattr debug (bnc#1012628).
- ovl: fix memory leak on unlink of indexed file (bnc#1012628).
- ovl: fix access beyond unterminated strings (bnc#1012628).
- ovl: set I_CREATING on inode being created (bnc#1012628).
- vfs: don't evict uninitialized inode (bnc#1012628).
- new primitive: discard_new_inode() (bnc#1012628).
- x86/APM: Fix build warning when PROC_FS is not enabled
  (bnc#1012628).
- xen: fix GCC warning and remove duplicate EVTCHN_ROW/EVTCHN_COL
  usage (bnc#1012628).
- xen: avoid crash in disable_hotplug_cpu (bnc#1012628).
- xen/manage: don't complain about an empty value in control/sysrq
  node (bnc#1012628).
- asm-generic: io: Fix ioport_map() for !CONFIG_GENERIC_IOMAP &&
  CONFIG_INDIRECT_PIO (bnc#1012628).
- cifs: read overflow in is_valid_oplock_break() (bnc#1012628).
- s390/qeth: don't dump past end of unknown HW header
  (bnc#1012628).
- s390/qeth: use vzalloc for QUERY OAT buffer (bnc#1012628).
- r8169: Clear RTL_FLAG_TASK_*_PENDING when clearing
  RTL_FLAG_TASK_ENABLED (bnc#1012628).
- drm/amdgpu: fix error handling in amdgpu_cs_user_fence_chunk
  (bnc#1012628).
- arm64: jump_label.h: use asm_volatile_goto macro instead of
  "asm goto" (bnc#1012628).
- drm/amdgpu: Fix SDMA hang in prt mode v2 (bnc#1012628).
- hexagon: modify ffs() and fls() to return int (bnc#1012628).
- commit c434d5c
* Wed Oct 10 2018 jslaby@suse.cz
- arch/hexagon: fix kernel/dma.c build warning (bnc#1012628).
- commit b07518e
* Wed Oct 10 2018 jslaby@suse.cz
- netfilter: xt_hashlimit: use s->file instead of s->private
  (bnc#1012628).
- netfilter: nfnetlink_queue: Solve the NFQUEUE/conntrack clash
  for NF_REPEAT (bnc#1012628).
- dm thin metadata: try to avoid ever aborting transactions
  (bnc#1012628).
- sched/topology: Set correct NUMA topology type (bnc#1012628).
- perf/x86/intel: Add support/quirk for the MISPREDICT bit on
  Knights Landing CPUs (bnc#1012628).
- net: ena: fix missing calls to READ_ONCE (bnc#1012628).
- net: ena: fix missing lock during device destruction
  (bnc#1012628).
- net: ena: fix potential double ena_destroy_device()
  (bnc#1012628).
- net: ena: fix device destruction to gracefully free resources
  (bnc#1012628).
- net: ena: fix driver when PAGE_SIZE == 64kB (bnc#1012628).
- net: ena: fix surprise unplug NULL dereference kernel crash
  (bnc#1012628).
- fs/cifs: suppress a string overflow warning (bnc#1012628).
- r8169: set TxConfig register after TX / RX is enabled, just
  like RxConfig (bnc#1012628).
- dm raid: fix RAID leg rebuild errors (bnc#1012628).
- dm raid: fix rebuild of specific devices by updating superblock
  (bnc#1012628).
- dm raid: fix stripe adding reshape deadlock (bnc#1012628).
- drm/nouveau/disp/gm200-: enforce identity-mapped SOR assignment
  for LVDS/eDP panels (bnc#1012628).
- drm/nouveau/disp: fix DP disable race (bnc#1012628).
- drm/nouveau/TBDdevinit: don't fail when PMU/PRE_OS is missing
  from VBIOS (bnc#1012628).
- drm/nouveau/mmu: don't attempt to dereference vmm without
  valid instance pointer (bnc#1012628).
- drm/nouveau: fix oops in client init failure path (bnc#1012628).
- dm raid: fix reshape race on small devices (bnc#1012628).
- HID: i2c-hid: Don't reset device upon system resume
  (bnc#1012628).
- net/mlx5: Consider PCI domain in search for next dev
  (bnc#1012628).
- bnxt_re: Fix couple of memory leaks that could lead to IOMMU
  call traces (bnc#1012628).
- nvmet-rdma: fix possible bogus dereference under heavy load
  (bnc#1012628).
- USB: yurex: Check for truncation in yurex_read() (bnc#1012628).
- usb: host: xhci-plat: Iterate over parent nodes for finding
  quirks (bnc#1012628).
- HID: sensor-hub: Restore fixup for Lenovo ThinkPad Helix 2
  sensor hub report (bnc#1012628).
- riscv: Do not overwrite initrd_start and initrd_end
  (bnc#1012628).
- RDMA/ucma: check fd type in ucma_migrate_id() (bnc#1012628).
- iio: imu: st_lsm6dsx: take into account ts samples in wm
  configuration (bnc#1012628).
- Revert "iio: temperature: maxim_thermocouple: add MAX31856 part"
  (bnc#1012628).
- netfilter: nf_tables: release chain in flushing set
  (bnc#1012628).
- netfilter: kconfig: nat related expression depend on nftables
  core (bnc#1012628).
- perf annotate: Fix parsing aarch64 branch instructions after
  objdump update (bnc#1012628).
- perf probe powerpc: Ignore SyS symbols irrespective of
  endianness (bnc#1012628).
- perf util: Fix bad memory access in trace info (bnc#1012628).
- perf evsel: Fix potential null pointer dereference in
  perf_evsel__new_idx() (bnc#1012628).
- perf annotate: Properly interpret indirect call (bnc#1012628).
- commit 342ac1f
* Wed Oct 10 2018 jslaby@suse.cz
- scsi: qedi: Add the CRC size within iSCSI NVM image
  (bnc#1012628).
- scsi: iscsi: target: Fix conn_ops double free (bnc#1012628).
- scsi: iscsi: target: Set conn->sess to NULL when
  iscsi_login_set_conn_values fails (bnc#1012628).
- HID: hid-saitek: Add device ID for RAT 7 Contagion
  (bnc#1012628).
- usb: gadget: fotg210-udc: Fix memory leak of fotg210->ep[i]
  (bnc#1012628).
- HID: add support for Apple Magic Keyboards (bnc#1012628).
- HID: intel-ish-hid: Enable Sunrise Point-H ish driver
  (bnc#1012628).
- netfilter: xt_checksum: ignore gso skbs (bnc#1012628).
- netfilter: xt_cluster: add dependency on conntrack module
  (bnc#1012628).
- bpf: 32-bit RSH verification must truncate input before the
  ALU op (bnc#1012628).
- mm: madvise(MADV_DODUMP): allow hugetlbfs pages (bnc#1012628).
- afs: Fix cell specification to permit an empty address list
  (bnc#1012628).
- firmware: arm_scmi: fix divide by zero when sustained_perf_level
  is zero (bnc#1012628).
- ceph: avoid a use-after-free in ceph_destroy_options()
  (bnc#1012628).
- nds32: linker script: GCOV kernel may refers data in __exit
  (bnc#1012628).
- tools/vm/page-types.c: fix "defined but not used" warning
  (bnc#1012628).
- tools/vm/slabinfo.c: fix sign-compare warning (bnc#1012628).
- nds32: fix build error because of wrong semicolon (bnc#1012628).
- nds32: Fix get_user/put_user macro expand pointer problem
  (bnc#1012628).
- nds32: Fix empty call trace (bnc#1012628).
- nds32: add NULL entry to the end of_device_id array
  (bnc#1012628).
- nds32: fix logic for module (bnc#1012628).
- net/ibm/emac: wrong emac_calc_base call was used by typo
  (bnc#1012628).
- fsnotify: fix ignore mask logic in fsnotify() (bnc#1012628).
- mac80211: shorten the IBSS debug messages (bnc#1012628).
- mac80211: don't Tx a deauth frame if the AP forbade Tx
  (bnc#1012628).
- mac80211: Fix station bandwidth setting after channel switch
  (bnc#1012628).
- mac80211: fix a race between restart and CSA flows
  (bnc#1012628).
- mac80211: fix WMM TXOP calculation (bnc#1012628).
- cfg80211: fix a type issue in
  ieee80211_chandef_to_operating_class() (bnc#1012628).
- mac80211: fix an off-by-one issue in A-MSDU max_subframe
  computation (bnc#1012628).
- fs/cifs: don't translate SFM_SLASH (U+F026) to backslash
  (bnc#1012628).
- net: cadence: Fix a sleep-in-atomic-context bug in
  macb_halt_tx() (bnc#1012628).
- i2c: uniphier-f: issue STOP only for last message or I2C_M_STOP
  (bnc#1012628).
- i2c: uniphier: issue STOP only for last message or I2C_M_STOP
  (bnc#1012628).
- bpf: avoid misuse of psock when TCP_ULP_BPF collides with
  another ULP (bnc#1012628).
- bpf: Fix bpf_msg_pull_data() (bnc#1012628).
- ibmvnic: Include missing return code checks in reset function
  (bnc#1012628).
- selftests: pmtu: detect correct binary to ping ipv6 addresses
  (bnc#1012628).
- selftests: pmtu: maximum MTU for vti4 is 2^16-1-20
  (bnc#1012628).
- RAID10 BUG_ON in raise_barrier when force is true and
  conf->barrier is 0 (bnc#1012628).
- md/raid5-cache: disable reshape completely (bnc#1012628).
- Revert "blk-throttle: fix race between blkcg_bio_issue_check()
  and cgroup_rmdir()" (bnc#1012628).
- ARC: atomics: unbork atomic_fetch_##op() (bnc#1012628).
- gpio: Fix crash due to registration race (bnc#1012628).
- tools/kvm_stat: fix updates for dead guests (bnc#1012628).
- tools/kvm_stat: fix handling of invalid paths in debugfs
  provider (bnc#1012628).
- tools/kvm_stat: fix python3 issues (bnc#1012628).
- mac80211: always account for A-MSDU header changes
  (bnc#1012628).
- mac80211: do not convert to A-MSDU if frag/subframe limited
  (bnc#1012628).
- cfg80211: nl80211_update_ft_ies() to validate NL80211_ATTR_IE
  (bnc#1012628).
- tc-testing: add test-cases for numeric and invalid control
  action (bnc#1012628).
- net: mvpp2: initialize port of_node pointer (bnc#1012628).
- sh_eth: Add R7S9210 support (bnc#1012628).
- net: hns: add netif_carrier_off before change speed and duplex
  (bnc#1012628).
- net: hns: add the code for cleaning pkt in chip (bnc#1012628).
- tipc: switch to rhashtable iterator (bnc#1012628).
- bpf: fix sg shift repair start offset in bpf_msg_pull_data
  (bnc#1012628).
- bpf: fix shift upon scatterlist ring wrap-around in
  bpf_msg_pull_data (bnc#1012628).
- bpf: fix msg->data/data_end after sg shift repair in
  bpf_msg_pull_data (bnc#1012628).
- gpio: dwapb: Fix error handling in dwapb_gpio_probe()
  (bnc#1012628).
- gpiolib-acpi: Register GpioInt ACPI event handlers from a
  late_initcall (bnc#1012628).
- gpiolib: acpi: Switch to cansleep version of GPIO library call
  (bnc#1012628).
- mac80211: avoid kernel panic when building AMSDU from non-linear
  SKB (bnc#1012628).
- mac80211: mesh: fix HWMP sequence numbering to follow standard
  (bnc#1012628).
- gpio: adp5588: Fix sleep-in-atomic-context bug (bnc#1012628).
- bpf: fix several offset tests in bpf_msg_pull_data
  (bnc#1012628).
- nl80211: Pass center frequency in kHz instead of MHz
  (bnc#1012628).
- nl80211: Fix nla_put_u8 to u16 for NL80211_WMMR_TXOP
  (bnc#1012628).
- mac80211_hwsim: Fix possible Spectre-v1 for
  hwsim_world_regdom_custom (bnc#1012628).
- cfg80211: make wmm_rule part of the reg_rule structure
  (bnc#1012628).
- mac80211_hwsim: correct use of IEEE80211_VHT_CAP_RXSTBC_X
  (bnc#1012628).
- mac80211: correct use of IEEE80211_VHT_CAP_RXSTBC_X
  (bnc#1012628).
- bpf: sockmap, decrement copied count correctly in redirect
  error case (bnc#1012628).
- bpf, sockmap: fix psock refcount leak in bpf_tcp_recvmsg
  (bnc#1012628).
- bpf, sockmap: fix potential use after free in bpf_tcp_close
  (bnc#1012628).
- scsi: aacraid: fix a signedness bug (bnc#1012628).
- scsi: libata: Add missing newline at end of file (bnc#1012628).
- scsi: csiostor: fix incorrect port capabilities (bnc#1012628).
- scsi: csiostor: add a check for NULL pointer after kmalloc()
  (bnc#1012628).
- btrfs: btrfs_shrink_device should call commit transaction at
  the end (bnc#1012628).
- cfg80211: remove division by size of sizeof(struct
  ieee80211_wmm_rule) (bnc#1012628).
- KVM: PPC: Book3S HV: Don't truncate HPTE index in xlate function
  (bnc#1012628).
- Btrfs: fix unexpected failure of nocow buffered writes after
  snapshotting when low on space (bnc#1012628).
- mac80211_hwsim: require at least one channel (bnc#1012628).
- mac80211: Run TXQ teardown code before de-registering interfaces
  (bnc#1012628).
- rseq/selftests: fix parametrized test with -fpie (bnc#1012628).
- commit 37173f2
* Tue Oct  9 2018 msuchanek@suse.de
- Revert "Limit kernel-source build to architectures for which we build binaries"
  This reverts commit d6435125446d740016904abe30a60611549ae812.
- commit 48b03c4
* Mon Oct  8 2018 mkubecek@suse.cz
- Update to 4.19-rc7
- commit 63b130b
* Thu Oct  4 2018 mbrugger@suse.com
- arm64: Update config files. (bsc#1110716)
  Enable ST LPS25H pressure sensor.
- commit 9882f33
* Thu Oct  4 2018 jslaby@suse.cz
- Linux 4.18.12 (bnc#1012628).
- crypto: skcipher - Fix -Wstringop-truncation warnings
  (bnc#1012628).
- iio: adc: ina2xx: avoid kthread_stop() with stale task_struct
  (bnc#1012628).
- tsl2550: fix lux1_input error in low light (bnc#1012628).
- misc: ibmvmc: Use GFP_ATOMIC under spin lock (bnc#1012628).
- vmci: type promotion bug in qp_host_get_user_memory()
  (bnc#1012628).
- siox: don't create a thread without starting it (bnc#1012628).
- net: hns3: Fix for mailbox message truncated problem
  (bnc#1012628).
- net: hns3: Fix for mac pause not disable in pfc mode
  (bnc#1012628).
- net: hns3: Fix warning bug when doing lp selftest (bnc#1012628).
- net: hns3: Fix get_vector ops in hclgevf_main module
  (bnc#1012628).
- x86/numa_emulation: Fix emulated-to-physical node mapping
  (bnc#1012628).
- staging: rts5208: fix missing error check on call to
  rtsx_write_register (bnc#1012628).
- power: supply: axp288_charger: Fix initial
  constant_charge_current value (bnc#1012628).
- misc: sram: enable clock before registering regions
  (bnc#1012628).
- serial: sh-sci: Stop RX FIFO timer during port shutdown
  (bnc#1012628).
- uwb: hwa-rc: fix memory leak at probe (bnc#1012628).
- power: vexpress: fix corruption in notifier registration
  (bnc#1012628).
- iommu/amd: make sure TLB to be flushed before IOVA freed
  (bnc#1012628).
- Bluetooth: Add a new Realtek 8723DE ID 0bda:b009 (bnc#1012628).
- USB: serial: kobil_sct: fix modem-status error handling
  (bnc#1012628).
- 6lowpan: iphc: reset mac_header after decompress to fix panic
  (bnc#1012628).
- iommu/msm: Don't call iommu_device_{,un}link from atomic context
  (bnc#1012628).
- s390/mm: correct allocate_pgste proc_handler callback
  (bnc#1012628).
- power: remove possible deadlock when unregistering power_supply
  (bnc#1012628).
- drm/amd/display/dc/dce: Fix multiple potential integer overflows
  (bnc#1012628).
- drm/amd/display: fix use of uninitialized memory (bnc#1012628).
- md-cluster: clear another node's suspend_area after the copy
  is finished (bnc#1012628).
- cxgb4: Fix the condition to check if the card is T5
  (bnc#1012628).
- RDMA/bnxt_re: Fix a couple off by one bugs (bnc#1012628).
- RDMA/i40w: Hold read semaphore while looking after VMA
  (bnc#1012628).
- RDMA/bnxt_re: Fix a bunch of off by one bugs in qplib_fp.c
  (bnc#1012628).
- IB/core: type promotion bug in rdma_rw_init_one_mr()
  (bnc#1012628).
- media: exynos4-is: Prevent NULL pointer dereference in
  __isp_video_try_fmt() (bnc#1012628).
- IB/mlx4: Test port number before querying type (bnc#1012628).
- powerpc/kdump: Handle crashkernel memory reservation failure
  (bnc#1012628).
- media: fsl-viu: fix error handling in viu_of_probe()
  (bnc#1012628).
- vhost_net: Avoid tx vring kicks during busyloop (bnc#1012628).
- media: staging/imx: fill vb2_v4l2_buffer field entry
  (bnc#1012628).
- IB/mlx5: Fix GRE flow specification (bnc#1012628).
- include/rdma/opa_addr.h: Fix an endianness issue (bnc#1012628).
- x86/tsc: Add missing header to tsc_msr.c (bnc#1012628).
- ARM: hwmod: RTC: Don't assume lock/unlock will be called with
  irq enabled (bnc#1012628).
- x86/entry/64: Add two more instruction suffixes (bnc#1012628).
- ARM: dts: ls1021a: Add missing cooling device properties for
  CPUs (bnc#1012628).
- scsi: target/iscsi: Make iscsit_ta_authentication() respect
  the output buffer size (bnc#1012628).
- thermal: i.MX: Allow thermal probe to fail gracefully in case
  of bad calibration (bnc#1012628).
- scsi: klist: Make it safe to use klists in atomic context
  (bnc#1012628).
- scsi: ibmvscsi: Improve strings handling (bnc#1012628).
- scsi: target: Avoid that EXTENDED COPY commands trigger lock
  inversion (bnc#1012628).
- usb: wusbcore: security: cast sizeof to int for comparison
  (bnc#1012628).
- ath10k: sdio: use same endpoint id for all packets in a bundle
  (bnc#1012628).
- ath10k: sdio: set skb len for all rx packets (bnc#1012628).
- powerpc/powernv/ioda2: Reduce upper limit for DMA window size
  (bnc#1012628).
- platform/x86: asus-wireless: Fix uninitialized symbol usage
  (bnc#1012628).
- ACPI / button: increment wakeup count only when notified
  (bnc#1012628).
- s390/sysinfo: add missing #ifdef CONFIG_PROC_FS (bnc#1012628).
- s390/dasd: correct numa_node in dasd_alloc_queue (bnc#1012628).
- s390/scm_blk: correct numa_node in scm_blk_dev_setup
  (bnc#1012628).
- s390/extmem: fix gcc 8 stringop-overflow warning (bnc#1012628).
- mtd: rawnand: atmel: add module param to avoid using dma
  (bnc#1012628).
- iio: accel: adxl345: convert address field usage in
  iio_chan_spec (bnc#1012628).
- posix-timers: Make forward callback return s64 (bnc#1012628).
- posix-timers: Sanitize overrun handling (bnc#1012628).
- ALSA: snd-aoa: add of_node_put() in error path (bnc#1012628).
- selftests: forwarding: Tweak tc filters for mirror-to-gretap
  tests (bnc#1012628).
- ath10k: use locked skb_dequeue for rx completions (bnc#1012628).
- media: s3c-camif: ignore -ENOIOCTLCMD from v4l2_subdev_call
  for s_power (bnc#1012628).
- media: soc_camera: ov772x: correct setting of banding filter
  (bnc#1012628).
- media: omap3isp: zero-initialize the isp cam_xclk{a,b} initial
  data (bnc#1012628).
- media: ov772x: add checks for register read errors
  (bnc#1012628).
- staging: android: ashmem: Fix mmap size validation
  (bnc#1012628).
- media: ov772x: allow i2c controllers without
  I2C_FUNC_PROTOCOL_MANGLING (bnc#1012628).
- staging: mt7621-eth: Fix memory leak in mtk_add_mac() error path
  (bnc#1012628).
- drivers/tty: add error handling for pcmcia_loop_config
  (bnc#1012628).
- arm64: dts: renesas: salvator-common: Fix adv7482 decimal unit
  addresses (bnc#1012628).
- serial: pxa: Fix an error handling path in 'serial_pxa_probe()'
  (bnc#1012628).
- staging: mt7621-dts: Fix remaining pcie warnings (bnc#1012628).
- media: tm6000: add error handling for dvb_register_adapter
  (bnc#1012628).
- ASoC: qdsp6: qdafe: fix some off by one bugs (bnc#1012628).
- ALSA: hda: Add AZX_DCAPS_PM_RUNTIME for AMD Raven Ridge
  (bnc#1012628).
- net: phy: xgmiitorgmii: Check read_status results (bnc#1012628).
- ath10k: protect ath10k_htt_rx_ring_free with rx_ring.lock
  (bnc#1012628).
- drm/sun4i: Enable DW HDMI PHY clock (bnc#1012628).
- net: phy: xgmiitorgmii: Check phy_driver ready before accessing
  (bnc#1012628).
- drm/sun4i: Fix releasing node when enumerating enpoints
  (bnc#1012628).
- ath10k: transmit queued frames after processing rx packets
  (bnc#1012628).
- mt76x2: fix mrr idx/count estimation in
  mt76x2_mac_fill_tx_status() (bnc#1012628).
- rndis_wlan: potential buffer overflow in
  rndis_wlan_auth_indication() (bnc#1012628).
- brcmsmac: fix wrap around in conversion from constant to s16
  (bnc#1012628).
- bitfield: fix *_encode_bits() (bnc#1012628).
- wlcore: Add missing PM call for
  wlcore_cmd_wait_for_event_or_timeout() (bnc#1012628).
- drm/omap: gem: Fix mm_list locking (bnc#1012628).
- ARM: mvebu: declare asm symbols as character arrays in pmsu.c
  (bnc#1012628).
- RDMA/uverbs: Don't overwrite NULL pointer with ZERO_SIZE_PTR
  (bnc#1012628).
- Documentation/process: fix reST table border error
  (bnc#1012628).
- perf/hw_breakpoint: Split attribute parse and commit
  (bnc#1012628).
- arm: dts: mediatek: Add missing cooling device properties for
  CPUs (bnc#1012628).
- HID: hid-ntrig: add error handling for sysfs_create_group
  (bnc#1012628).
- HID: i2c-hid: Use devm to allocate i2c_hid struct (bnc#1012628).
- MIPS: boot: fix build rule of vmlinux.its.S (bnc#1012628).
- arm64: dts: renesas: Fix VSPD registers range (bnc#1012628).
- drm/v3d: Take a lock across GPU scheduler job creation and
  queuing (bnc#1012628).
- perf/x86/intel/lbr: Fix incomplete LBR call stack (bnc#1012628).
- scsi: bnx2i: add error handling for ioremap_nocache
  (bnc#1012628).
- iomap: complete partial direct I/O writes synchronously
  (bnc#1012628).
- scsi: hisi_sas: Fix the conflict between dev gone and host reset
  (bnc#1012628).
- spi: orion: fix CS GPIO handling again (bnc#1012628).
- scsi: megaraid_sas: Update controller info during resume
  (bnc#1012628).
- ASoC: Intel: bytcr_rt5640: Fix Acer Iconia 8 over-current
  detect threshold (bnc#1012628).
- ASoC: rt1305: Use ULL suffixes for 64-bit constants
  (bnc#1012628).
- ASoC: rsnd: SSI parent cares SWSP bit (bnc#1012628).
- EDAC, i7core: Fix memleaks and use-after-free on probe and
  remove (bnc#1012628).
- ASoC: dapm: Fix potential DAI widget pointer deref when linking
  DAIs (bnc#1012628).
- module: exclude SHN_UNDEF symbols from kallsyms api
  (bnc#1012628).
- gpio: Fix wrong rounding in gpio-menz127 (bnc#1012628).
- nfsd: fix corrupted reply to badly ordered compound
  (bnc#1012628).
- EDAC: Fix memleak in module init error path (bnc#1012628).
- EDAC, altera: Fix an error handling path in
  altr_s10_sdram_probe() (bnc#1012628).
- staging: pi433: fix race condition in pi433_ioctl (bnc#1012628).
- ath10k: fix incorrect size of dma_free_coherent in
  ath10k_ce_alloc_src_ring_64 (bnc#1012628).
- ath10k: snoc: use correct bus-specific pointer in RX retry
  (bnc#1012628).
- fs/lock: skip lock owner pid translation in case we are in
  init_pid_ns (bnc#1012628).
- ath10k: fix memory leak of tpc_stats (bnc#1012628).
- Input: xen-kbdfront - fix multi-touch XenStore node's locations
  (bnc#1012628).
- iio: 104-quad-8: Fix off-by-one error in register selection
  (bnc#1012628).
- drm/vc4: Add missing formats to vc4_format_mod_supported()
  (bnc#1012628).
- ARM: dts: dra7: fix DCAN node addresses (bnc#1012628).
- drm/vc4: plane: Expand the lower bits by repeating the higher
  bits (bnc#1012628).
- perf tests: Fix indexing when invoking subtests (bnc#1012628).
- gpio: tegra: Fix tegra_gpio_irq_set_type() (bnc#1012628).
- floppy: Do not copy a kernel pointer to user memory in FDGETPRM
  ioctl (bnc#1012628).
- block: fix deadline elevator drain for zoned block devices
  (bnc#1012628).
- x86/mm: Expand static page table for fixmap space (bnc#1012628).
- tty: serial: lpuart: avoid leaking struct tty_struct
  (bnc#1012628).
- serial: imx: restore handshaking irq for imx1 (bnc#1012628).
- serial: mvebu-uart: Fix reporting of effective CSIZE to
  userspace (bnc#1012628).
- serial: cpm_uart: return immediately from console poll
  (bnc#1012628).
- intel_th: Fix device removal logic (bnc#1012628).
- intel_th: Fix resource handling for ACPI glue layer
  (bnc#1012628).
- spi: tegra20-slink: explicitly enable/disable clock
  (bnc#1012628).
- spi: sh-msiof: Fix invalid SPI use during system suspend
  (bnc#1012628).
- spi: sh-msiof: Fix handling of write value for SISTR register
  (bnc#1012628).
- spi: rspi: Fix invalid SPI use during system suspend
  (bnc#1012628).
- spi: rspi: Fix interrupted DMA transfers (bnc#1012628).
- regulator: fix crash caused by null driver data (bnc#1012628).
- regulator: Fix 'do-nothing' value for regulators without
  suspend state (bnc#1012628).
- USB: fix error handling in usb_driver_claim_interface()
  (bnc#1012628).
- USB: handle NULL config in usb_find_alt_setting() (bnc#1012628).
- usb: roles: Take care of driver module reference counting
  (bnc#1012628).
- usb: core: safely deal with the dynamic quirk lists
  (bnc#1012628).
- usb: musb: dsps: do not disable CPPI41 irq in driver teardown
  (bnc#1012628).
- USB: usbdevfs: sanitize flags more (bnc#1012628).
- USB: usbdevfs: restore warning for nonsensical flags
  (bnc#1012628).
- Revert "usb: cdc-wdm: Fix a sleep-in-atomic-context bug in
  service_outstanding_interrupt()" (bnc#1012628).
- USB: remove LPM management from usb_driver_claim_interface()
  (bnc#1012628).
- uaccess: Fix is_source param for check_copy_size() in
  copy_to_iter_mcsafe() (bnc#1012628).
- ext2, dax: set ext2_dax_aops for dax files (bnc#1012628).
- filesystem-dax: Fix use of zero page (bnc#1012628).
- Input: elantech - enable middle button of touchpad on ThinkPad
  P72 (bnc#1012628).
- IB/srp: Avoid that sg_reset -d ${srp_device} triggers an
  infinite loop (bnc#1012628).
- IB/hfi1: Fix SL array bounds check (bnc#1012628).
- IB/hfi1: Invalid user input can result in crash (bnc#1012628).
- IB/hfi1: Fix context recovery when PBC has an UnsupportedVL
  (bnc#1012628).
- IB/hfi1: Fix destroy_qp hang after a link down (bnc#1012628).
- ACPI / hotplug / PCI: Don't scan for non-hotplug bridges if
  slot is not bridge (bnc#1012628).
- RDMA/uverbs: Atomically flush and mark closed the comp event
  queue (bnc#1012628).
- arm64: KVM: Tighten guest core register access from userspace
  (bnc#1012628).
- ARM: OMAP2+: Fix null hwmod for ti-sysc debug (bnc#1012628).
- ARM: OMAP2+: Fix module address for modules using mpu_rt_idx
  (bnc#1012628).
- bus: ti-sysc: Fix module register ioremap for larger offsets
  (bnc#1012628).
- qed: Wait for ready indication before rereading the shmem
  (bnc#1012628).
- qed: Wait for MCP halt and resume commands to take place
  (bnc#1012628).
- qed: Prevent a possible deadlock during driver load and unload
  (bnc#1012628).
- qed: Avoid sending mailbox commands when MFW is not responsive
  (bnc#1012628).
- thermal: of-thermal: disable passive polling when thermal zone
  is disabled (bnc#1012628).
- isofs: reject hardware sector size > 2048 bytes (bnc#1012628).
- mmc: atmel-mci: fix bad logic of sg_copy_{from,to}_buffer
  conversion (bnc#1012628).
- mmc: android-goldfish: fix bad logic of sg_copy_{from,to}_buffer
  conversion (bnc#1012628).
- bus: ti-sysc: Fix no_console_suspend handling (bnc#1012628).
- ARM: dts: omap4-droid4: fix vibrations on Droid 4 (bnc#1012628).
- bpf, sockmap: fix sock_hash_alloc and reject zero-sized keys
  (bnc#1012628).
- bpf, sockmap: fix sock hash count in alloc_sock_hash_elem
  (bnc#1012628).
- tls: possible hang when do_tcp_sendpages hits sndbuf is full
  case (bnc#1012628).
- bpf: sockmap: write_space events need to be passed to TCP
  handler (bnc#1012628).
- drm/amdgpu: fix VM clearing for the root PD (bnc#1012628).
- drm/amdgpu: fix preamble handling (bnc#1012628).
- amdgpu: fix multi-process hang issue (bnc#1012628).
- net/ncsi: Fixup .dumpit message flags and ID check in Netlink
  handler (bnc#1012628).
- tcp_bbr: add bbr_check_probe_rtt_done() helper (bnc#1012628).
- tcp_bbr: in restart from idle, see if we should exit PROBE_RTT
  (bnc#1012628).
- net: hns: fix length and page_offset overflow when
  CONFIG_ARM64_64K_PAGES (bnc#1012628).
- net: hns: fix skb->truesize underestimation (bnc#1012628).
- net: hns3: fix page_offset overflow when CONFIG_ARM64_64K_PAGES
  (bnc#1012628).
- ice: Fix multiple static analyser warnings (bnc#1012628).
- ice: Report stats for allocated queues via ethtool stats
  (bnc#1012628).
- ice: Clean control queues only when they are initialized
  (bnc#1012628).
- ice: Fix bugs in control queue processing (bnc#1012628).
- ice: Use order_base_2 to calculate higher power of 2
  (bnc#1012628).
- ice: Set VLAN flags correctly (bnc#1012628).
- tools: bpftool: return from do_event_pipe() on bad arguments
  (bnc#1012628).
- ice: Fix a few null pointer dereference issues (bnc#1012628).
- ice: Fix potential return of uninitialized value (bnc#1012628).
- e1000: check on netif_running() before calling e1000_up()
  (bnc#1012628).
- e1000: ensure to free old tx/rx rings in set_ringparam()
  (bnc#1012628).
- ixgbe: fix driver behaviour after issuing VFLR (bnc#1012628).
- i40e: Fix for Tx timeouts when interface is brought up if DCB
  is enabled (bnc#1012628).
- i40e: fix condition of WARN_ONCE for stat strings (bnc#1012628).
- crypto: chtls - fix null dereference chtls_free_uld()
  (bnc#1012628).
- crypto: cavium/nitrox - fix for command corruption in queue
  full case with backlog submissions (bnc#1012628).
- hwmon: (ina2xx) fix sysfs shunt resistor read access
  (bnc#1012628).
- hwmon: (adt7475) Make adt7475_read_word() return errors
  (bnc#1012628).
- Revert "ARM: dts: imx7d: Invert legacy PCI irq mapping"
  (bnc#1012628).
- drm/amdgpu: Enable/disable gfx PG feature in rlc safe mode
  (bnc#1012628).
- drm/amdgpu: Update power state at the end of smu hw_init
  (bnc#1012628).
- ata: ftide010: Add a quirk for SQ201 (bnc#1012628).
- nvme-fcloop: Fix dropped LS's to removed target port
  (bnc#1012628).
- ARM: dts: omap4-droid4: Fix emmc errors seen on some devices
  (bnc#1012628).
- drm/amdgpu: Need to set moved to true when evict bo
  (bnc#1012628).
- arm/arm64: smccc-1.1: Make return values unsigned long
  (bnc#1012628).
- arm/arm64: smccc-1.1: Handle function result as parameters
  (bnc#1012628).
- i2c: i801: Allow ACPI AML access I/O ports not reserved for
  SMBus (bnc#1012628).
- clk: x86: Set default parent to 48Mhz (bnc#1012628).
- x86/pti: Fix section mismatch warning/error (bnc#1012628).
- KVM: PPC: Book3S HV: Fix guest r11 corruption with POWER9 TM
  workarounds (bnc#1012628).
- powerpc: fix csum_ipv6_magic() on little endian platforms
  (bnc#1012628).
- powerpc/pkeys: Fix reading of ibm, processor-storage-keys
  property (bnc#1012628).
- powerpc/pseries: Fix unitialized timer reset on migration
  (bnc#1012628).
- arm64: KVM: Sanitize PSTATE.M when being set from userspace
  (bnc#1012628).
- media: v4l: event: Prevent freeing event subscriptions while
  accessed (bnc#1012628).
- commit a880bd8
* Tue Oct  2 2018 nborisov@suse.com
- Update config files. (boo##1109665)
- commit 76516eb
* Mon Oct  1 2018 msuchanek@suse.de
- rpm/mkspec: fix ppc64 kernel-source build.
- commit 85c9272
* Sun Sep 30 2018 mkubecek@suse.cz
- Update to 4.19-rc6
- Eliminated 2 patches
- commit 80aa112
* Sat Sep 29 2018 jslaby@suse.cz
- Linux 4.18.11 (bnc#1012628).
- spi: Fix double IDR allocation with DT aliases (bnc#1012628).
- iw_cxgb4: only allow 1 flush on user qps (bnc#1012628).
- vmw_balloon: include asm/io.h (bnc#1012628).
- sched/fair: Fix vruntime_normalized() for remote non-migration
  wakeup (bnc#1012628).
- ext4, dax: set ext4_dax_aops for dax files (bnc#1012628).
- ext4, dax: add ext4_bmap to ext4_dax_aops (bnc#1012628).
- ext4: show test_dummy_encryption mount option in /proc/mounts
  (bnc#1012628).
- ext4: don't mark mmp buffer head dirty (bnc#1012628).
- ext4: fix online resizing for bigalloc file systems with a 1k
  block size (bnc#1012628).
- ext4: fix online resize's handling of a too-small final block
  group (bnc#1012628).
- ext4: recalucate superblock checksum after updating free
  blocks/inodes (bnc#1012628).
- ext4: avoid arithemetic overflow that can trigger a BUG
  (bnc#1012628).
- ext4: avoid divide by zero fault when deleting corrupted inline
  directories (bnc#1012628).
- ext4: check to make sure the rename(2)'s destination is not
  freed (bnc#1012628).
- tty: vt_ioctl: fix potential Spectre v1 (bnc#1012628).
- drm/amdgpu: add new polaris pci id (bnc#1012628).
- drm: udl: Destroy framebuffer only if it was initialized
  (bnc#1012628).
- drm/vc4: Fix the "no scaling" case on multi-planar YUV formats
  (bnc#1012628).
- drm/nouveau/drm/nouveau: Prevent handling ACPI HPD events too
  early (bnc#1012628).
- drm/nouveau/drm/nouveau: Use pm_runtime_get_noresume() in
  connector_detect() (bnc#1012628).
- drm/nouveau/drm/nouveau: Fix deadlock with fb_helper with
  async RPM requests (bnc#1012628).
- drm/nouveau/drm/nouveau: Fix bogus drm_kms_helper_poll_enable()
  placement (bnc#1012628).
- drm/nouveau/drm/nouveau: Don't forget to cancel hpd_work on
  suspend/unload (bnc#1012628).
- drm/nouveau: Fix deadlocks in nouveau_connector_detect()
  (bnc#1012628).
- drm/nouveau: Remove duplicate poll_enable() in
  pmops_runtime_suspend() (bnc#1012628).
- drm/nouveau: Only write DP_MSTM_CTRL when needed (bnc#1012628).
- drm/nouveau: Reset MST branching unit before enabling
  (bnc#1012628).
- drm/i915/bdw: Increase IPS disable timeout to 100ms
  (bnc#1012628).
- ocfs2: fix ocfs2 read block panic (bnc#1012628).
- libata: mask swap internal and hardware tag (bnc#1012628).
- Revert "ubifs: xattr: Don't operate on deleted inodes"
  (bnc#1012628).
- scsi: target: iscsi: Use bin2hex instead of a re-implementation
  (bnc#1012628).
- scsi: target: iscsi: Use hex2bin instead of a re-implementation
  (bnc#1012628).
- Revert "uapi/linux/keyctl.h: don't use C++ reserved keyword
  as a struct member name" (bnc#1012628).
- bpf/verifier: disallow pointer subtraction (bnc#1012628).
- Revert "rpmsg: core: add support to power domains for devices"
  (bnc#1012628).
- mm: shmem.c: Correctly annotate new inodes for lockdep
  (bnc#1012628).
- mm: disable deferred struct page for 32-bit arches
  (bnc#1012628).
- fork: report pid exhaustion correctly (bnc#1012628).
- crypto: x86/aegis,morus - Do not require OSXSAVE for SSE2
  (bnc#1012628).
- ring-buffer: Allow for rescheduling when removing pages
  (bnc#1012628).
- Revert "PCI: Add ACS quirk for Intel 300 series" (bnc#1012628).
- spi: fix IDR collision on systems with both fixed and dynamic
  SPI bus numbers (bnc#1012628).
- xen/x86/vpmu: Zero struct pt_regs before calling into sample
  handling code (bnc#1012628).
- xen/netfront: don't bug in case of too many frags (bnc#1012628).
- platform/x86: alienware-wmi: Correct a memory leak
  (bnc#1012628).
- platform/x86: dell-smbios-wmi: Correct a memory leak
  (bnc#1012628).
- mtd: rawnand: denali: fix a race condition when DMA is kicked
  (bnc#1012628).
- mtd: devices: m25p80: Make sure the buffer passed in op is
  DMA-able (bnc#1012628).
- ALSA: oxfw: fix memory leak of private data (bnc#1012628).
- ALSA: oxfw: fix memory leak of discovered stream formats at
  error path (bnc#1012628).
- ALSA: oxfw: fix memory leak for model-dependent data at error
  path (bnc#1012628).
- ALSA: fireworks: fix memory leak of response buffer at error
  path (bnc#1012628).
- ALSA: firewire-tascam: fix memory leak of private data
  (bnc#1012628).
- ALSA: firewire-digi00x: fix memory leak of private data
  (bnc#1012628).
- ALSA: fireface: fix memory leak in ff400_switch_fetching_mode()
  (bnc#1012628).
- ALSA: emu10k1: fix possible info leak to userspace on
  SNDRV_EMU10K1_IOCTL_INFO (bnc#1012628).
- ALSA: bebob: use address returned by kmalloc() instead of
  kernel stack for streaming DMA mapping (bnc#1012628).
- ALSA: bebob: fix memory leak for M-Audio FW1814 and ProjectMix
  I/O at error path (bnc#1012628).
- ASoC: uapi: fix sound/skl-tplg-interface.h userspace compilation
  errors (bnc#1012628).
- ASoC: rsnd: fixup not to call clk_get/set under non-atomic
  (bnc#1012628).
- ASoC: tas6424: Save last fault register even when clear
  (bnc#1012628).
- ASoC: cs4265: fix MMTLR Data switch control (bnc#1012628).
- ASoC: wm9712: fix replace codec to component (bnc#1012628).
- NFC: Fix the number of pipes (bnc#1012628).
- NFC: Fix possible memory corruption when handling SHDLC I-Frame
  commands (bnc#1012628).
- net: rtnl_configure_link: fix dev flags changes arg to
  __dev_notify_flags (bnc#1012628).
- net: mvpp2: let phylink manage the carrier state (bnc#1012628).
- net/ipv6: do not copy dst flags on rt init (bnc#1012628).
- ipv6: use rt6_info members when dst is set in rt6_fill_node
  (bnc#1012628).
- bnxt_en: Fix VF mac address regression (bnc#1012628).
- tls: fix currently broken MSG_PEEK behavior (bnc#1012628).
- socket: fix struct ifreq size in compat ioctl (bnc#1012628).
- net: dsa: mv88e6xxx: Fix ATU Miss Violation (bnc#1012628).
- hv_netvsc: fix schedule in RCU context (bnc#1012628).
- net/sched: act_sample: fix NULL dereference in the data path
  (bnc#1012628).
- udp6: add missing checks on edumux packet processing
  (bnc#1012628).
- neighbour: confirm neigh entries when ARP packet is received
  (bnc#1012628).
- tls: clear key material from kernel memory when
  do_tls_setsockopt_conf fails (bnc#1012628).
- tls: zero the crypto information from tls_context before freeing
  (bnc#1012628).
- tls: don't copy the key out of tls12_crypto_info_aes_gcm_128
  (bnc#1012628).
- udp4: fix IP_CMSG_CHECKSUM for connected sockets (bnc#1012628).
- qmi_wwan: set DTR for modems in forced USB2 mode (bnc#1012628).
- pppoe: fix reception of frames with no mac header (bnc#1012628).
- net: hp100: fix always-true check for link up state
  (bnc#1012628).
- net/appletalk: fix minor pointer leak to userspace in
  SIOCFINDIPDDPRT (bnc#1012628).
- ipv6: fix possible use-after-free in ip6_xmit() (bnc#1012628).
- gso_segment: Reset skb->mac_len after modifying network header
  (bnc#1012628).
- commit 4a5c1c1
* Fri Sep 28 2018 lduncan@suse.com
- Added CVE numbers for two patches (bsc#1107829)
- commit e3ac2a8
* Fri Sep 28 2018 lduncan@suse.com
- scsi: target: iscsi: Use bin2hex instead of a re-implementation
  (bsc#1107829).
- scsi: target: iscsi: Use hex2bin instead of a re-implementation
  (bsc#1107829).
- commit 8791706
* Thu Sep 27 2018 msuchanek@suse.de
- rpm/mkspec: build dtbs for architectures marked -!needs_updating
- commit 2d47640
* Thu Sep 27 2018 msuchanek@suse.de
- Limit kernel-source build to architectures for which we build binaries
  (bsc#1108281).
- commit d643512
* Wed Sep 26 2018 jslaby@suse.cz
- Linux 4.18.10 (bnc#1012628).
- crypto: ccp - add timeout support in the SEV command
  (bnc#1012628).
- mei: bus: type promotion bug in mei_nfc_if_version()
  (bnc#1012628).
- clk: tegra: bpmp: Don't crash when a clock fails to register
  (bnc#1012628).
- pinctrl: qcom: spmi-gpio: Fix pmic_gpio_config_get() to be
  compliant (bnc#1012628).
- pinctrl: msm: Fix msm_config_group_get() to be compliant
  (bnc#1012628).
- blk-mq: avoid to synchronize rcu inside blk_cleanup_queue()
  (bnc#1012628).
- blk-mq: only attempt to merge bio if there is rq in sw queue
  (bnc#1012628).
- IB/mlx5: fix uaccess beyond "count" in debugfs read/write
  handlers (bnc#1012628).
- block/DAC960.c: fix defined but not used build warnings
  (bnc#1012628).
- staging: fsl-dpaa2/eth: Fix DMA mapping direction (bnc#1012628).
- dmaengine: sh: rcar-dmac: avoid to write CHCR.TE to 1 if TCR
  is set to 0 (bnc#1012628).
- drm/amd/pp: Send khz clock values to DC for smu7/8
  (bnc#1012628).
- arm64: perf: Disable PMU while processing counter overflows
  (bnc#1012628).
- drm/panel: type promotion bug in s6e8aa0_read_mtp_id()
  (bnc#1012628).
- ASoC: rt5651: Fix workqueue cancel vs irq free race on remove
  (bnc#1012628).
- selftest: timers: Tweak raw_skew to SKIP when ADJ_OFFSET/other
  clock adjustments are in progress (bnc#1012628).
- remoteproc: qcom: q6v5-pil: fix modem hang on SDM845 after
  axis2 clk unvote (bnc#1012628).
- scsi: lpfc: Fix panic if driver unloaded when port is offline
  (bnc#1012628).
- scsi: lpfc: Fix NVME Target crash in defer rcv logic
  (bnc#1012628).
- scsi: libfc: fixup 'sleeping function called from invalid
  context' (bnc#1012628).
- ALSA: pcm: Fix snd_interval_refine first/last with open min/max
  (bnc#1012628).
- selftests/android: initialize heap_type to avoid compiling
  warning (bnc#1012628).
- selftests: vDSO - fix to return KSFT_SKIP when test couldn't
  be run (bnc#1012628).
- rtc: bq4802: add error handling for devm_ioremap (bnc#1012628).
- drm/amdkfd: Fix error codes in kfd_get_process (bnc#1012628).
- drm/amdkfd: Fix kernel queue 64 bit doorbell offset calculation
  (bnc#1012628).
- input: rohm_bu21023: switch to i2c_lock_bus(...,
  I2C_LOCK_SEGMENT) (bnc#1012628).
- mfd: 88pm860x-i2c: switch to i2c_lock_bus(..., I2C_LOCK_SEGMENT)
  (bnc#1012628).
- rcutorture: Use monotonic timestamp for stall detection
  (bnc#1012628).
- net: mvpp2: make sure we use single queue mode on PPv2.1
  (bnc#1012628).
- net: gemini: Allow multiple ports to instantiate (bnc#1012628).
- gpiolib: Mark gpio_suffixes array with __maybe_unused
  (bnc#1012628).
- gpio: pxa: Fix potential NULL dereference (bnc#1012628).
- staging: bcm2835-audio: Don't leak workqueue if open fails
  (bnc#1012628).
- lightnvm: pblk: enable line minor version detection
  (bnc#1012628).
- lightnvm: pblk: assume that chunks are closed on 1.2 devices
  (bnc#1012628).
- ASoC: qdsp6: q6afe-dai: fix a range check in
  of_q6afe_parse_dai_data() (bnc#1012628).
- drm/amd/display: support access ddc for mst branch
  (bnc#1012628).
- tools/testing/nvdimm: Fix support for emulating controller
  temperature (bnc#1012628).
- f2fs: do checkpoint in kill_sb (bnc#1012628).
- coresight: ETM: Add support for Arm Cortex-A73 and Cortex-A35
  (bnc#1012628).
- coresight: tpiu: Fix disabling timeouts (bnc#1012628).
- coresight: Handle errors in finding input/output ports
  (bnc#1012628).
- sched/fair: Fix util_avg of new tasks for asymmetric systems
  (bnc#1012628).
- parport: sunbpp: fix error return code (bnc#1012628).
- tls: Fix zerocopy_from_iter iov handling (bnc#1012628).
- drm/nouveau: tegra: Detach from ARM DMA/IOMMU mapping
  (bnc#1012628).
- drm/nouveau/debugfs: Wake up GPU before doing any reclocking
  (bnc#1012628).
- drm/nouveau: Fix runtime PM leak in drm_open() (bnc#1012628).
- mmc: sdhci: do not try to use 3.3V signaling if not supported
  (bnc#1012628).
- mmc: tegra: prevent HS200 on Tegra 3 (bnc#1012628).
- mmc: sdhci-of-esdhc: set proper dma mask for ls104x chips
  (bnc#1012628).
- tty: fix termios input-speed encoding (bnc#1012628).
- tty: fix termios input-speed encoding when using BOTHER
  (bnc#1012628).
- serial: 8250: of: Correct of_platform_serial_setup() error
  handling (bnc#1012628).
- ASoC: hdmi-codec: fix routing (bnc#1012628).
- gpu: ipu-v3: csi: pass back mbus_code_to_bus_cfg error codes
  (bnc#1012628).
- liquidio: fix hang when re-binding VF host drv after running
  DPDK VF driver (bnc#1012628).
- ARM: hisi: check of_iomap and fix missing of_node_put
  (bnc#1012628).
- net: hns3: Fix return value error in hns3_reset_notify_down_enet
  (bnc#1012628).
- ARM: hisi: fix error handling and missing of_node_put
  (bnc#1012628).
- ARM: hisi: handle of_iomap and fix missing of_node_put
  (bnc#1012628).
- net: hns3: Fix for reset_level default assignment probelm
  (bnc#1012628).
- net: hns3: Reset net device with rtnl_lock (bnc#1012628).
- efi/esrt: Only call efi_mem_reserve() for boot services memory
  (bnc#1012628).
- sched/core: Use smp_mb() in wake_woken_function() (bnc#1012628).
- arm64: dts: mt7622: update a clock property for UART0
  (bnc#1012628).
- pinctrl: rza1: Fix selector use for groups and functions
  (bnc#1012628).
- pinctrl: mt7622: Fix probe fail by misuse the selector
  (bnc#1012628).
- configfs: fix registered group removal (bnc#1012628).
- MIPS: loongson64: cs5536: Fix PCI_OHCI_INT_REG reads
  (bnc#1012628).
- KVM: PPC: Book3S: Fix matching of hardware and emulated TCE
  tables (bnc#1012628).
- PM / devfreq: use put_device() instead of kfree() (bnc#1012628).
- security: check for kstrdup() failure in lsm_append()
  (bnc#1012628).
- KVM: PPC: Book3S HV: Add of_node_put() in success path
  (bnc#1012628).
- evm: Don't deadlock if a crypto algorithm is unavailable
  (bnc#1012628).
- Bluetooth: Use lock_sock_nested in bt_accept_enqueue
  (bnc#1012628).
- spi: dw: fix possible race condition (bnc#1012628).
- bpf: fix rcu annotations in compute_effective_progs()
  (bnc#1012628).
- vfs: fix freeze protection in mnt_want_write_file() for
  overlayfs (bnc#1012628).
- mtdchar: fix overflows in adjustment of `count` (bnc#1012628).
- audit: fix use-after-free in audit_add_watch (bnc#1012628).
- arm64: dts: uniphier: Add missing cooling device properties
  for CPUs (bnc#1012628).
- net/mlx5: Add missing SET_DRIVER_VERSION command translation
  (bnc#1012628).
- binfmt_elf: Respect error return from `regset->active'
  (bnc#1012628).
- mmc: meson-mx-sdio: fix OF child-node lookup (bnc#1012628).
- of: add helper to lookup compatible child node (bnc#1012628).
- NFSv4.1 fix infinite loop on I/O (bnc#1012628).
- NFSv4: Fix a tracepoint Oops in initiate_file_draining()
  (bnc#1012628).
- x86/EISA: Don't probe EISA bus for Xen PV guests (bnc#1012628).
- of: fix phandle cache creation for DTs with no phandles
  (bnc#1012628).
- perf tools: Fix maps__find_symbol_by_name() (bnc#1012628).
- perf/core: Force USER_DS when recording user stack data
  (bnc#1012628).
- xtensa: ISS: don't allocate memory in platform_setup
  (bnc#1012628).
- cifs: integer overflow in in SMB2_ioctl() (bnc#1012628).
- CIFS: fix wrapping bugs in num_entries() (bnc#1012628).
- cifs: prevent integer overflow in nxt_dir_entry() (bnc#1012628).
- Revert "cdc-acm: implement put_char() and flush_chars()"
  (bnc#1012628).
- usb: cdc-wdm: Fix a sleep-in-atomic-context bug in
  service_outstanding_interrupt() (bnc#1012628).
- USB: yurex: Fix buffer over-read in yurex_write() (bnc#1012628).
- USB: serial: ti_usb_3410_5052: fix array underflow in completion
  handler (bnc#1012628).
- usb: misc: uss720: Fix two sleep-in-atomic-context bugs
  (bnc#1012628).
- USB: serial: io_ti: fix array underflow in completion handler
  (bnc#1012628).
- USB: net2280: Fix erroneous synchronization change
  (bnc#1012628).
- usb: gadget: udc: renesas_usb3: fix maxpacket size of ep0
  (bnc#1012628).
- USB: add quirk for WORLDE Controller KS49 or Prodipe MIDI 49C
  USB controller (bnc#1012628).
- usb: host: u132-hcd: Fix a sleep-in-atomic-context bug in
  u132_get_frame() (bnc#1012628).
- usb: Avoid use-after-free by flushing endpoints early in
  usb_set_interface() (bnc#1012628).
- usb: uas: add support for more quirk flags (bnc#1012628).
- USB: Add quirk to support DJI CineSSD (bnc#1012628).
- dm verity: fix crash on bufio buffer that was allocated with
  vmalloc (bnc#1012628).
- mei: bus: need to unlink client before freeing (bnc#1012628).
- mei: bus: fix hw module get/put balance (bnc#1012628).
- mei: ignore not found client in the enumeration (bnc#1012628).
- usb: mtu3: fix error of xhci port id when enable U3 dual role
  (bnc#1012628).
- usb: xhci: fix interrupt transfer error happened on MTK
  platforms (bnc#1012628).
- usb: Don't die twice if PCI xhci host is not responding in
  resume (bnc#1012628).
- xhci: Fix use after free for URB cancellation on a reallocated
  endpoint (bnc#1012628).
- misc: hmc6352: fix potential Spectre v1 (bnc#1012628).
- misc: ibmvsm: Fix wrong assignment of return code (bnc#1012628).
- Tools: hv: Fix a bug in the key delete code (bnc#1012628).
- vmbus: don't return values for uninitalized channels
  (bnc#1012628).
- ovl: fix oopses in ovl_fill_super() failure paths (bnc#1012628).
- ipmi: Fix I2C client removal in the SSIF driver (bnc#1012628).
- ipmi: Move BT capabilities detection to the detect call
  (bnc#1012628).
- ipmi: Rework SMI registration failure (bnc#1012628).
- mmc: omap_hsmmc: fix wakeirq handling on removal (bnc#1012628).
- s390/crypto: Fix return code checking in cbc_paes_crypt()
  (bnc#1012628).
- IB/ipoib: Avoid a race condition between start_xmit and
  cm_rep_handler (bnc#1012628).
- xen/netfront: fix waiting for xenbus state change (bnc#1012628).
- pstore: Fix incorrect persistent ram buffer mapping
  (bnc#1012628).
- RDMA/cma: Protect cma dev list with lock (bnc#1012628).
- xen-netfront: fix warn message as irq device name has '/'
  (bnc#1012628).
- PCI/AER: Honor "pcie_ports=native" even if HEST sets
  FIRMWARE_FIRST (bnc#1012628).
- x86/mm/pti: Add an overflow check to pti_clone_pmds()
  (bnc#1012628).
- x86/pti: Check the return value of pti_user_pagetable_walk_pmd()
  (bnc#1012628).
- x86/pti: Check the return value of pti_user_pagetable_walk_p4d()
  (bnc#1012628).
- crypto: sharah - Unregister correct algorithms for SAHARA 3
  (bnc#1012628).
- dmaengine: mv_xor_v2: kill the tasklets upon exit (bnc#1012628).
- iommu/ipmmu-vmsa: IMUCTRn.TTSEL needs a special usage on R-Car
  Gen3 (bnc#1012628).
- regulator: qcom_spmi: Fix warning Bad of_node_put()
  (bnc#1012628).
- regulator: qcom_spmi: Use correct regmap when checking for error
  (bnc#1012628).
- drm/amd/pp: Set Max clock level to display by default
  (bnc#1012628).
- i2c: aspeed: Fix initial values of master and slave state
  (bnc#1012628).
- drivers/base: stop new probing during shutdown (bnc#1012628).
- KVM: arm/arm64: Fix vgic init race (bnc#1012628).
- platform/x86: toshiba_acpi: Fix defined but not used build
  warnings (bnc#1012628).
- s390/qeth: reset layer2 attribute on layer switch (bnc#1012628).
- s390/qeth: fix race in used-buffer accounting (bnc#1012628).
- soc: qcom: smem: Correct check for global partition
  (bnc#1012628).
- ARM: dts: qcom: msm8974-hammerhead: increase load on l20 for
  sdhci (bnc#1012628).
- arm64: dts: qcom: db410c: Fix Bluetooth LED trigger
  (bnc#1012628).
- xen-netfront: fix queue name setting (bnc#1012628).
- nfp: avoid buffer leak when FW communication fails
  (bnc#1012628).
- ALSA: usb-audio: Generic DSD detection for Thesycon-based
  implementations (bnc#1012628).
- efi/arm: preserve early mapping of UEFI memory map longer for
  BGRT (bnc#1012628).
- reset: imx7: Fix always writing bits as 0 (bnc#1012628).
- arm64: fix possible spectre-v1 write in ptrace_hbp_set_event()
  (bnc#1012628).
- wan/fsl_ucc_hdlc: use IS_ERR_VALUE() to check return value of
  qe_muram_alloc (bnc#1012628).
- Smack: Fix handling of IPv4 traffic received by PF_INET6 sockets
  (bnc#1012628).
- mac80211: restrict delayed tailroom needed decrement
  (bnc#1012628).
- MIPS: jz4740: Bump zload address (bnc#1012628).
- ASoC: rt5514: Fix the issue of the delay volume applied
  (bnc#1012628).
- staging: bcm2835-camera: handle wait_for_completion_timeout
  return properly (bnc#1012628).
- staging: bcm2835-camera: fix timeout handling in
  wait_for_completion_timeout (bnc#1012628).
- perf script: Show correct offsets for DWARF-based unwinding
  (bnc#1012628).
- powerpc/powernv: opal_put_chars partial write fix (bnc#1012628).
- KVM: arm/arm64: vgic: Fix possible spectre-v1 write in
  vgic_mmio_write_apr() (bnc#1012628).
- nvme-rdma: unquiesce queues when deleting the controller
  (bnc#1012628).
- nvmet: fix file discard return status (bnc#1012628).
- perf powerpc: Fix callchain ip filtering (bnc#1012628).
- ARM: exynos: Clear global variable on init error path
  (bnc#1012628).
- omapfb: rename omap2 module to omap2fb.ko (bnc#1012628).
- fbdev: Distinguish between interlaced and progressive modes
  (bnc#1012628).
- video: fbdev: pxafb: clear allocated memory for video modes
  (bnc#1012628).
- perf powerpc: Fix callchain ip filtering when return address
  is in a register (bnc#1012628).
- fbdev/via: fix defined but not used warning (bnc#1012628).
- video: goldfishfb: fix memory leak on driver remove
  (bnc#1012628).
- perf tools: Fix struct comm_str removal crash (bnc#1012628).
- fbdev: omapfb: off by one in omapfb_register_client()
  (bnc#1012628).
- perf tests: Fix record+probe_libc_inet_pton.sh to ensure
  cleanups (bnc#1012628).
- perf tests: Fix record+probe_libc_inet_pton.sh when event exists
  (bnc#1012628).
- perf tests: Fix record+probe_libc_inet_pton.sh for powerpc64
  (bnc#1012628).
- perf tools: Synthesize GROUP_DESC feature in pipe mode
  (bnc#1012628).
- gfs2: Don't reject a supposedly full bitmap if we have blocks
  reserved (bnc#1012628).
- perf test: Fix subtest number when showing results
  (bnc#1012628).
- media: ov5645: Supported external clock is 24MHz (bnc#1012628).
- mtd/maps: fix solutionengine.c printk format warnings
  (bnc#1012628).
- IB/ipoib: Fix error return code in ipoib_dev_init()
  (bnc#1012628).
- block: allow max_discard_segments to be stacked (bnc#1012628).
- IB/rxe: Drop QP0 silently (bnc#1012628).
- media: videobuf2-core: check for q->error in vb2_core_qbuf()
  (bnc#1012628).
- MIPS: ath79: fix system restart (bnc#1012628).
- dmaengine: pl330: fix irq race with terminate_all (bnc#1012628).
- media: tw686x: Fix oops on buffer alloc failure (bnc#1012628).
- kbuild: do not update config when running install targets
  (bnc#1012628).
- kbuild: add .DELETE_ON_ERROR special target (bnc#1012628).
- clk: clk-fixed-factor: Clear OF_POPULATED flag in case of
  failure (bnc#1012628).
- clk: core: Potentially free connection id (bnc#1012628).
- Input: pxrc - fix freeing URB on device teardown (bnc#1012628).
- clk: mvebu: armada-37xx-periph: Fix wrong return value in
  get_parent (bnc#1012628).
- clk: imx6sll: fix missing of_node_put() (bnc#1012628).
- clk: imx6ul: fix missing of_node_put() (bnc#1012628).
- gfs2: Special-case rindex for gfs2_grow (bnc#1012628).
- iwlwifi: cancel the injective function between hw pointers to
  tfd entry index (bnc#1012628).
- nfp: don't fail probe on pci_sriov_set_totalvfs() errors
  (bnc#1012628).
- amd-xgbe: use dma_mapping_error to check map errors
  (bnc#1012628).
- xfrm: fix 'passing zero to ERR_PTR()' warning (bnc#1012628).
- ALSA: usb-audio: Fix multiple definitions in AU0828_DEVICE()
  macro (bnc#1012628).
- ALSA: usb-audio: Add support for Encore mDSD USB DAC
  (bnc#1012628).
- ALSA: msnd: Fix the default sample sizes (bnc#1012628).
- iommu/io-pgtable-arm: Fix pgtable allocation in selftest
  (bnc#1012628).
- iommu/io-pgtable-arm-v7s: Abort allocation when table address
  overflows the PTE (bnc#1012628).
- iommu/arm-smmu-v3: sync the OVACKFLG to PRIQ consumer register
  (bnc#1012628).
- usb: dwc3: change stream event enable bit back to 13
  (bnc#1012628).
- net/mlx5: Use u16 for Work Queue buffer fragment size
  (bnc#1012628).
- net/mlx5: Fix possible deadlock from lockdep when adding fte
  to fg (bnc#1012628).
- net/mlx5: Fix not releasing read lock when adding flow rules
  (bnc#1012628).
- tcp: really ignore MSG_ZEROCOPY if no SO_ZEROCOPY (bnc#1012628).
- erspan: return PACKET_REJECT when the appropriate tunnel is
  not found (bnc#1012628).
- erspan: fix error handling for erspan tunnel (bnc#1012628).
- net/mlx5: Fix debugfs cleanup in the device init/remove flow
  (bnc#1012628).
- net/mlx5: Check for error in mlx5_attach_interface
  (bnc#1012628).
- net/tls: Set count of SG entries if sk_alloc_sg returns -ENOSPC
  (bnc#1012628).
- net/mlx5: E-Switch, Fix memory leak when creating switchdev
  mode FDB tables (bnc#1012628).
- tipc: orphan sock in tipc_release() (bnc#1012628).
- rds: fix two RCU related problems (bnc#1012628).
- net: qca_spi: Fix race condition in spi transfers (bnc#1012628).
- net/mlx5: Fix use-after-free in self-healing flow (bnc#1012628).
- be2net: Fix memory leak in be_cmd_get_profile_config()
  (bnc#1012628).
- commit 3aeb311
* Mon Sep 24 2018 mkubecek@suse.cz
- Update to 4.19-rc5
- commit b44d7bc
* Thu Sep 20 2018 jslaby@suse.cz
- Linux 4.18.9 (bnc#1012628).
- i2c: xiic: Make the start and the byte count write atomic
  (bnc#1012628).
- i2c: i801: fix DNV's SMBCTRL register offset (bnc#1012628).
- HID: multitouch: fix Elan panels with 2 input modes declaration
  (bnc#1012628).
- HID: core: fix grouping by application (bnc#1012628).
- HID: i2c-hid: Fix flooded incomplete report after S3 on Rayd
  touchscreen (bnc#1012628).
- HID: input: fix leaking custom input node name (bnc#1012628).
- mm/hugetlb: filter out hugetlb pages if HUGEPAGE migration is
  not supported (bnc#1012628).
- memory_hotplug: fix kernel_panic on offline page processing
  (bnc#1012628).
- mac80211: don't update the PM state of a peer upon a multicast
  frame (bnc#1012628).
- scsi: lpfc: Correct MDS diag and nvmet configuration
  (bnc#1012628).
- nbd: don't allow invalid blocksize settings (bnc#1012628).
- block: don't warn when doing fsync on read-only devices
  (bnc#1012628).
- block: bfq: swap puts in bfqg_and_blkg_put (bnc#1012628).
- android: binder: fix the race mmap and alloc_new_buf_locked
  (bnc#1012628).
- MIPS: VDSO: Match data page cache colouring when D$ aliases
  (bnc#1012628).
- SMB3: Backup intent flag missing for directory opens with
  backupuid mounts (bnc#1012628).
- smb3: check for and properly advertise directory lease support
  (bnc#1012628).
- cifs: connect to servername instead of IP for IPC$ share
  (bnc#1012628).
- btrfs: fix qgroup_free wrong num_bytes in
  btrfs_subvolume_reserve_metadata (bnc#1012628).
- Btrfs: fix data corruption when deduplicating between different
  files (bnc#1012628).
- KVM: arm/arm64: Clean dcache to PoC when changing PTE due to
  CoW (bnc#1012628).
- KVM: PPC: Book3S HV: Use correct pagesize in kvm_unmap_radix()
  (bnc#1012628).
- KVM: s390: vsie: copy wrapping keys to right place
  (bnc#1012628).
- KVM: x86: SVM: Set EMULTYPE_NO_REEXECUTE for RSM emulation
  (bnc#1012628).
- KVM: VMX: Do not allow reexecute_instruction() when skipping
  MMIO instr (bnc#1012628).
- KVM: x86: Invert emulation re-execute behavior to make it opt-in
  (bnc#1012628).
- KVM: x86: Merge EMULTYPE_RETRY and EMULTYPE_ALLOW_REEXECUTE
  (bnc#1012628).
- KVM: x86: Default to not allowing emulation retry in
  kvm_mmu_page_fault (bnc#1012628).
- KVM: x86: Do not re-{try,execute} after failed emulation in L2
  (bnc#1012628).
- ARC: [plat-axs*/plat-hsdk]: Allow U-Boot to pass MAC-address
  to the kernel (bnc#1012628).
- ACPI / LPSS: Force LPSS quirks on boot (bnc#1012628).
- memory: ti-aemif: fix a potential NULL-pointer dereference
  (bnc#1012628).
- ALSA: hda - Fix cancel_work_sync() stall from jackpoll work
  (bnc#1012628).
- cpu/hotplug: Adjust misplaced smb() in cpuhp_thread_fun()
  (bnc#1012628).
- cpu/hotplug: Prevent state corruption on error rollback
  (bnc#1012628).
- x86/microcode: Make sure boot_cpu_data.microcode is up-to-date
  (bnc#1012628).
- x86/microcode: Update the new microcode revision unconditionally
  (bnc#1012628).
- x86/process: Don't mix user/kernel regs in 64bit __show_regs()
  (bnc#1012628).
- x86/apic/vector: Make error return value negative (bnc#1012628).
- switchtec: Fix Spectre v1 vulnerability (bnc#1012628).
- ARC: [plat-axs*]: Enable SWAP (bnc#1012628).
- tc-testing: flush gact actions on test teardown (bnc#1012628).
- tc-testing: remove duplicate spaces in connmark match patterns
  (bnc#1012628).
- misc: mic: SCIF Fix scif_get_new_port() error handling
  (bnc#1012628).
- ALSA: hda/realtek - Add mute LED quirk for HP Spectre x360
  (bnc#1012628).
- ethtool: Remove trailing semicolon for static inline
  (bnc#1012628).
- i2c: aspeed: Add an explicit type casting for *get_clk_reg_val
  (bnc#1012628).
- Bluetooth: h5: Fix missing dependency on BT_HCIUART_SERDEV
  (bnc#1012628).
- pinctrl: berlin: fix 'pctrl->functions' allocation in
  berlin_pinctrl_build_state (bnc#1012628).
- gpio: tegra: Move driver registration to subsys_init level
  (bnc#1012628).
- powerpc/powernv: Fix concurrency issue with npu->mmio_atsd_usage
  (bnc#1012628).
- powerpc/4xx: Fix error return path in ppc4xx_msi_probe()
  (bnc#1012628).
- selftests/bpf: fix a typo in map in map test (bnc#1012628).
- media: davinci: vpif_display: Mix memory leak on probe error
  path (bnc#1012628).
- media: dw2102: Fix memleak on sequence of probes (bnc#1012628).
- net: phy: Fix the register offsets in Broadcom iProc mdio mux
  driver (bnc#1012628).
- scsi: qla2xxx: Fix unintended Logout (bnc#1012628).
- scsi: qla2xxx: Fix session state stuck in Get Port DB
  (bnc#1012628).
- scsi: qla2xxx: Silent erroneous message (bnc#1012628).
- clk: scmi: Fix the rounding of clock rate (bnc#1012628).
- blk-mq: fix updating tags depth (bnc#1012628).
- scsi: lpfc: Fix driver crash when re-registering NVME rports
  (bnc#1012628).
- scsi: target: fix __transport_register_session locking
  (bnc#1012628).
- md/raid5: fix data corruption of replacements after originals
  dropped (bnc#1012628).
- timers: Clear timer_base::must_forward_clk with timer_base::lock
  held (bnc#1012628).
- media: camss: csid: Configure data type and decode format
  properly (bnc#1012628).
- gpu: ipu-v3: default to id 0 on missing OF alias (bnc#1012628).
- misc: ti-st: Fix memory leak in the error path of probe()
  (bnc#1012628).
- uio: potential double frees if __uio_register_device() fails
  (bnc#1012628).
- firmware: vpd: Fix section enabled flag on vpd_section_destroy
  (bnc#1012628).
- Drivers: hv: vmbus: Cleanup synic memory free path
  (bnc#1012628).
- tty: rocket: Fix possible buffer overwrite on register_PCI
  (bnc#1012628).
- uio: fix possible circular locking dependency (bnc#1012628).
- iwlwifi: pcie: don't access periphery registers when not
  available (bnc#1012628).
- IB/IPoIB: Set ah valid flag in multicast send flow
  (bnc#1012628).
- f2fs: fix to active page in lru list for read path
  (bnc#1012628).
- f2fs: do not set free of current section (bnc#1012628).
- f2fs: Keep alloc_valid_block_count in sync (bnc#1012628).
- f2fs: issue discard align to section in LFS mode (bnc#1012628).
- f2fs: fix defined but not used build warnings (bnc#1012628).
- f2fs: fix to detect looped node chain correctly (bnc#1012628).
- ASoC: soc-pcm: Use delay set in component pointer function
  (bnc#1012628).
- perf tools: Allow overriding MAX_NR_CPUS at compile time
  (bnc#1012628).
- device-dax: avoid hang on error before devm_memremap_pages()
  (bnc#1012628).
- NFSv4.0 fix client reference leak in callback (bnc#1012628).
- perf c2c report: Fix crash for empty browser (bnc#1012628).
- perf evlist: Fix error out while applying initial delay and LBR
  (bnc#1012628).
- powerpc/pseries: fix EEH recovery of some IOV devices
  (bnc#1012628).
- macintosh/via-pmu: Add missing mmio accessors (bnc#1012628).
- perf build: Fix installation directory for eBPF (bnc#1012628).
- ath9k: report tx status on EOSP (bnc#1012628).
- ath9k_hw: fix channel maximum power level test (bnc#1012628).
- ath10k: prevent active scans on potential unusable channels
  (bnc#1012628).
- wlcore: Set rx_status boottime_ns field on rx (bnc#1012628).
- rpmsg: core: add support to power domains for devices
  (bnc#1012628).
- mtd: rawnand: make subop helpers return unsigned values
  (bnc#1012628).
- scsi: tcmu: do not set max_blocks if data_bitmap has been setup
  (bnc#1012628).
- MIPS: Fix ISA virt/bus conversion for non-zero PHYS_OFFSET
  (bnc#1012628).
- ata: libahci: Allow reconfigure of DEVSLP register
  (bnc#1012628).
- ata: libahci: Correct setting of DEVSLP register (bnc#1012628).
- nfs: Referrals not inheriting proto setting from parent
  (bnc#1012628).
- scsi: 3ware: fix return 0 on the error path of probe
  (bnc#1012628).
- tools/testing/nvdimm: kaddr and pfn can be NULL to
  - >direct_access() (bnc#1012628).
- ath10k: disable bundle mgmt tx completion event support
  (bnc#1012628).
- media: em28xx: explicitly disable TS packet filter
  (bnc#1012628).
- PCI: mobiveil: Add missing ../pci.h include (bnc#1012628).
- PCI: mobiveil: Fix struct mobiveil_pcie.pcie_reg_base address
  type (bnc#1012628).
- powerpc/mm: Don't report PUDs as memory leaks when using
  kmemleak (bnc#1012628).
- Bluetooth: hidp: Fix handling of strncpy for hid->name
  information (bnc#1012628).
- x86/mm: Remove in_nmi() warning from vmalloc_fault()
  (bnc#1012628).
- regulator: tps65217: Fix NULL pointer dereference on probe
  (bnc#1012628).
- pinctrl: imx: off by one in imx_pinconf_group_dbg_show()
  (bnc#1012628).
- gpio: pxa: disable pinctrl calls for PXA3xx (bnc#1012628).
- gpio: ml-ioh: Fix buffer underwrite on probe error path
  (bnc#1012628).
- pinctrl/amd: only handle irq if it is pending and unmasked
  (bnc#1012628).
- net: mvneta: fix mtu change on port without link (bnc#1012628).
- f2fs: try grabbing node page lock aggressively in sync scenario
  (bnc#1012628).
- pktcdvd: Fix possible Spectre-v1 for pkt_devs (bnc#1012628).
- f2fs: fix to skip GC if type in SSA and SIT is inconsistent
  (bnc#1012628).
- tpm_tis_spi: Pass the SPI IRQ down to the driver (bnc#1012628).
- tpm/tpm_i2c_infineon: switch to i2c_lock_bus(...,
  I2C_LOCK_SEGMENT) (bnc#1012628).
- f2fs: fix to do sanity check with reserved blkaddr of inline
  inode (bnc#1012628).
- MIPS: Octeon: add missing of_node_put() (bnc#1012628).
- MIPS: generic: fix missing of_node_put() (bnc#1012628).
- thermal: rcar_thermal: avoid NULL dereference in absence of
  IRQ resources (bnc#1012628).
- thermal_hwmon: Sanitize attribute name passed to hwmon
  (bnc#1012628).
- net: dcb: For wild-card lookups, use priority -1, not 0
  (bnc#1012628).
- dm cache: only allow a single io_mode cache feature to be
  requested (bnc#1012628).
- Input: atmel_mxt_ts - only use first T9 instance (bnc#1012628).
- media: s5p-mfc: Fix buffer look up in s5p_mfc_handle_frame_{new,
  copy_time} functions (bnc#1012628).
- partitions/aix: append null character to print data from disk
  (bnc#1012628).
- partitions/aix: fix usage of uninitialized lv_info and lvname
  structures (bnc#1012628).
- media: rcar-csi2: update stream start for V3M (bnc#1012628).
- media: helene: fix xtal frequency setting at power on
  (bnc#1012628).
- drm/amd/display: Prevent PSR from being enabled if
  initialization fails (bnc#1012628).
- media: em28xx: Fix dual transport stream operation
  (bnc#1012628).
- iommu/arm-smmu-v3: Abort all transactions if SMMU is enabled
  in kdump kernel (bnc#1012628).
- f2fs: fix to wait on page writeback before updating page
  (bnc#1012628).
- f2fs: Fix uninitialized return in f2fs_ioc_shutdown()
  (bnc#1012628).
- media: em28xx: Fix DualHD disconnect oops (bnc#1012628).
- f2fs: avoid potential deadlock in f2fs_sbi_store (bnc#1012628).
- f2fs: fix to do sanity check with secs_per_zone (bnc#1012628).
- mfd: rave-sp: Initialize flow control and parity of the port
  (bnc#1012628).
- iommu/ipmmu-vmsa: Fix allocation in atomic context
  (bnc#1012628).
- mfd: ti_am335x_tscadc: Fix struct clk memory leak (bnc#1012628).
- f2fs: fix to do sanity check with {sit,nat}_ver_bitmap_bytesize
  (bnc#1012628).
- f2fs: fix to propagate return value of scan_nat_page()
  (bnc#1012628).
- f2fs: fix to do sanity check with extra_attr feature
  (bnc#1012628).
- RDMA/hns: Add illegal hop_num judgement (bnc#1012628).
- NFSv4.1: Fix a potential layoutget/layoutrecall deadlock
  (bnc#1012628).
- RDMA/hns: Update the data type of immediate data (bnc#1012628).
- MIPS: WARN_ON invalid DMA cache maintenance, not BUG_ON
  (bnc#1012628).
- MIPS: mscc: ocelot: fix length of memory address space for MIIM
  (bnc#1012628).
- RDMA/cma: Do not ignore net namespace for unbound cm_id
  (bnc#1012628).
- clocksource: Revert "Remove kthread" (bnc#1012628).
- autofs: fix autofs_sbi() does not check super block type
  (bnc#1012628).
- mm: get rid of vmacache_flush_all() entirely (bnc#1012628).
- commit 67901ec
* Mon Sep 17 2018 mkubecek@suse.cz
- Update to 4.19-rc4
- Eliminated 1 patch
- Config changes:
  - Filesystems:
  - EROFS_FS=m
  - EROFS_FS_DEBUG=n
  - EROFS_FS_XATTR=y
  - EROFS_FS_POSIX_ACL=y
  - EROFS_FS_SECURITY=y
  - EROFS_FS_USE_VM_MAP_RAM=n
  - EROFS_FAULT_INJECTION=n
  - EROFS_FS_ZIP=n
- commit 625b101
* Sat Sep 15 2018 jslaby@suse.cz
- Linux 4.18.8 (bnc#1012628).
- ASoC: wm8994: Fix missing break in switch (bnc#1012628).
- HID: redragon: fix num lock and caps lock LEDs (bnc#1012628).
- x86: kvm: avoid unused variable warning (bnc#1012628).
- kvm: x86: Set highest physical address bits in
  non-present/reserved SPTEs (bnc#1012628).
- kbuild: make missing $DEPMOD a Warning instead of an Error
  (bnc#1012628).
- x86/xen: don't write ptes directly in 32-bit PV guests
  (bnc#1012628).
- x86/pae: use 64 bit atomic xchg function in
  native_ptep_get_and_clear (bnc#1012628).
- debugobjects: Make stack check warning more informative
  (bnc#1012628).
- drm/amdgpu: Don't warn on destroying a pinned BO (bnc#1012628).
- drm/amdgpu: Warn and update pin_size values when destroying
  a pinned BO (bnc#1012628).
- drm/amdgpu: Make pin_size values atomic (bnc#1012628).
- drm/amdgpu: Keep track of amount of pinned CPU visible VRAM
  (bnc#1012628).
- x86/tsc: Prevent result truncation on 32bit (bnc#1012628).
- drm/i915: set DP Main Stream Attribute for color range on DDI
  platforms (bnc#1012628).
- mm: respect arch_dup_mmap() return value (bnc#1012628).
- uapi/linux/keyctl.h: don't use C++ reserved keyword as a struct
  member name (bnc#1012628).
- drm/i915: Re-apply "Perform link quality check, unconditionally
  during long pulse" (bnc#1012628).
- drm/amdgpu: fix incorrect use of drm_file->pid (bnc#1012628).
- drm/amdgpu: fix incorrect use of fcheck (bnc#1012628).
- drm/amdgpu:add VCN booting with firmware loaded by PSP
  (bnc#1012628).
- drm/amdgpu:add VCN support in PSP driver (bnc#1012628).
- drm/amdgpu:add new firmware id for VCN (bnc#1012628).
- drm/amdgpu:add tmr mc address into amdgpu_firmware_info
  (bnc#1012628).
- drm/amdgpu: update tmr mc address (bnc#1012628).
- drm/amd/display: Check if clock source in use before disabling
  (bnc#1012628).
- drm/amd/display: Pass connector id when executing VBIOS CT
  (bnc#1012628).
- drm/rockchip: vop: fix irq disabled after vop driver probed
  (bnc#1012628).
- drm/rockchip: vop: split out core clock enablement into separate
  functions (bnc#1012628).
- drm/rockchip: lvds: add missing of_node_put (bnc#1012628).
- drm/amd/display: Report non-DP display as disconnected without
  EDID (bnc#1012628).
- drm/amd/display: Use requested HDMI aspect ratio (bnc#1012628).
- drm/amd/display: update clk for various HDMI color depths
  (bnc#1012628).
- drm/amd/display: Don't share clk source between DP and HDMI
  (bnc#1012628).
- drm/amd/display: fix type of variable (bnc#1012628).
- drm/edid: Add 6 bpc quirk for SDC panel in Lenovo B50-80
  (bnc#1012628).
- drm/edid: Quirk Vive Pro VR headset non-desktop (bnc#1012628).
- drm/amd/pp/Polaris12: Fix a chunk of registers missed to program
  (bnc#1012628).
- drm/amd/powerplay: fixed uninitialized value (bnc#1012628).
- drm/amd/pp: Convert voltage unit in mV*4 to mV on CZ/ST
  (bnc#1012628).
- drm/amdgpu: Fix RLC safe mode test in
  gfx_v9_0_enter_rlc_safe_mode (bnc#1012628).
- drm/amdgpu: fix a reversed condition (bnc#1012628).
- drm/amdgpu: update uvd_v6_0_ring_vm_funcs to use new nop packet
  (bnc#1012628).
- drm/i915: Free write_buf that we allocated with kzalloc
  (bnc#1012628).
- drm/i915: Increase LSPCON timeout (bnc#1012628).
- drm/i915: Nuke the LVDS lid notifier (bnc#1012628).
- drm/i915/lpe: Mark LPE audio runtime pm as "no callbacks"
  (bnc#1012628).
- btrfs: fix mount and ioctl device scan ioctl race (bnc#1012628).
- btrfs: reorder initialization before the mount locks uuid_mutex
  (bnc#1012628).
- btrfs: lift uuid_mutex to callers of btrfs_parse_early_options
  (bnc#1012628).
- btrfs: lift uuid_mutex to callers of btrfs_scan_one_device
  (bnc#1012628).
- btrfs: use device_list_mutex when removing stale devices
  (bnc#1012628).
- btrfs: rename local devices for fs_devices in
  btrfs_free_stale_devices( (bnc#1012628).
- btrfs: extend locked section when adding a new device in
  device_list_add (bnc#1012628).
- btrfs: do btrfs_free_stale_devices outside of device_list_add
  (bnc#1012628).
- ARM: rockchip: Force CONFIG_PM on Rockchip systems
  (bnc#1012628).
- arm64: rockchip: Force CONFIG_PM on Rockchip systems
  (bnc#1012628).
- btrfs: Fix a C compliance issue (bnc#1012628).
- btrfs: Don't remove block group that still has pinned down bytes
  (bnc#1012628).
- btrfs: lift uuid_mutex to callers of btrfs_open_devices
  (bnc#1012628).
- btrfs: check-integrity: Fix NULL pointer dereference for
  degraded mount (bnc#1012628).
- btrfs: tree-checker: Detect invalid and empty essential trees
  (bnc#1012628).
- btrfs: relocation: Only remove reloc rb_trees if reloc control
  has been initialized (bnc#1012628).
- btrfs: fix in-memory value of total_devices after seed device
  deletion (bnc#1012628).
- btrfs: replace: Reset on-disk dev stats value after replace
  (bnc#1012628).
- btrfs: Exit gracefully when chunk map cannot be inserted to
  the tree (bnc#1012628).
- drm/etnaviv: fix crash in GPU suspend when init failed due to
  buffer placement (bnc#1012628).
- kvm: nVMX: Fix fault vector for VMX operation at CPL > 0
  (bnc#1012628).
- KVM: vmx: track host_state.loaded using a loaded_vmcs pointer
  (bnc#1012628).
- drm/amd/display: Read back max backlight value at boot
  (bnc#1012628).
- clk: rockchip: Add pclk_rkpwm_pmu to PMU critical clocks in
  rk3399 (bnc#1012628).
- powerpc/pseries: Avoid using the size greater than
  RTAS_ERROR_LOG_MAX (bnc#1012628).
- um: fix parallel building with O= option (bnc#1012628).
- powerpc/64s: Make rfi_flush_fallback a little more robust
  (bnc#1012628).
- powerpc/platforms/85xx: fix t1042rdb_diu.c build errors &
  warning (bnc#1012628).
- smb3: if server does not support posix do not allow posix
  mount option (bnc#1012628).
- SMB3: Number of requests sent should be displayed for SMB3
  not just CIFS (bnc#1012628).
- CIFS: fix memory leak and remove dead code (bnc#1012628).
- smb3: fix reset of bytes read and written stats (bnc#1012628).
- cfq: Suppress compiler warnings about comparisons (bnc#1012628).
- RDS: IB: fix 'passing zero to ERR_PTR()' warning (bnc#1012628).
- selinux: cleanup dentry and inodes on error in selinuxfs
  (bnc#1012628).
- selftests/powerpc: Kill child processes on SIGINT (bnc#1012628).
- iommu/omap: Fix cache flushes on L2 table entries (bnc#1012628).
- ASoC: rt5677: Fix initialization of rt5677_of_match.data
  (bnc#1012628).
- staging: comedi: ni_mio_common: fix subdevice flags for PFI
  subdevice (bnc#1012628).
- dm kcopyd: avoid softlockup in run_complete_job (bnc#1012628).
- PCI: mvebu: Fix I/O space end address calculation (bnc#1012628).
- xen/balloon: fix balloon initialization for PVH Dom0
  (bnc#1012628).
- Input: do not use WARN() in input_alloc_absinfo() (bnc#1012628).
- NFSv4: Fix error handling in nfs4_sp4_select_mode()
  (bnc#1012628).
- scsi: aic94xx: fix an error code in aic94xx_init()
  (bnc#1012628).
- blk-mq: count the hctx as active before allocating tag
  (bnc#1012628).
- ACPI / scan: Initialize status to ACPI_STA_DEFAULT
  (bnc#1012628).
- s390/dasd: fix panic for failed online processing (bnc#1012628).
- s390/dasd: fix hanging offline processing due to canceled worker
  (bnc#1012628).
- brcmfmac: fix brcmf_wiphy_wowl_params() NULL pointer dereference
  (bnc#1012628).
- block: bvec_nr_vecs() returns value for wrong slab
  (bnc#1012628).
- perf probe powerpc: Fix trace event post-processing
  (bnc#1012628).
- powerpc: Fix size calculation using resource_size()
  (bnc#1012628).
- powerpc/uaccess: Enable get_user(u64, *p) on 32-bit
  (bnc#1012628).
- bpf: fix bpffs non-array map seq_show issue (bnc#1012628).
- pinctrl: axp209: Fix NULL pointer dereference after allocation
  (bnc#1012628).
- f2fs: fix to clear PG_checked flag in set_page_dirty()
  (bnc#1012628).
- net/9p: fix error path of p9_virtio_probe (bnc#1012628).
- net/9p/trans_fd.c: fix race by holding the lock (bnc#1012628).
- irqchip/bcm7038-l1: Hide cpu offline callback when building
  for !SMP (bnc#1012628).
- irqchip/stm32: Fix init error handling (bnc#1012628).
- RISC-V: Use KBUILD_CFLAGS instead of KCFLAGS when building
  the vDSO (bnc#1012628).
- f2fs: fix avoid race between truncate and background GC
  (bnc#1012628).
- f2fs: avoid race between zero_range and background GC
  (bnc#1012628).
- perf tools: Check for null when copying nsinfo (bnc#1012628).
- coccicheck: return proper error code on fail (bnc#1012628).
- drm/amd/display: Guard against null crtc in CRC IRQ
  (bnc#1012628).
- PCI: Match Root Port's MPS to endpoint's MPSS as necessary
  (bnc#1012628).
- net: hns3: Fix for phy link issue when using marvell phy driver
  (bnc#1012628).
- block: don't warn for flush on read-only device (bnc#1012628).
- net: hns3: Fix for command format parsing error in
  hclge_is_all_function_id_zero (bnc#1012628).
- perf arm spe: Fix uninitialized record error variable
  (bnc#1012628).
- ACPICA: ACPICA: add status check for acpi_hw_read before
  assigning return value (bnc#1012628).
- RDMA/hns: Fix usage of bitmap allocation functions return values
  (bnc#1012628).
- ubi: Initialize Fastmap checkmapping correctly (bnc#1012628).
- tcp, ulp: add alias for all ulp modules (bnc#1012628).
- netfilter: fix memory leaks on netlink_dump_start error
  (bnc#1012628).
- platform/x86: asus-nb-wmi: Add keymap entry for lid flip action
  on UX360 (bnc#1012628).
- netfilter: x_tables: do not fail xt_alloc_table_info too easilly
  (bnc#1012628).
- mfd: sm501: Set coherent_dma_mask when creating subdevices
  (bnc#1012628).
- ipvs: fix race between ip_vs_conn_new() and ip_vs_del_dest()
  (bnc#1012628).
- s390/kdump: Fix memleak in nt_vmcoreinfo (bnc#1012628).
- netfilter: ip6t_rpfilter: set F_IFACE for linklocal addresses
  (bnc#1012628).
- samples/bpf: all XDP samples should unload xdp/bpf prog on
  SIGTERM (bnc#1012628).
- bpf, sockmap: fix leakage of smap_psock_map_entry (bnc#1012628).
- net/xdp: Fix suspicious RCU usage warning (bnc#1012628).
- bpf, sockmap: fix sock_map_ctx_update_elem race with
  exist/noexist (bnc#1012628).
- tcp, ulp: fix leftover icsk_ulp_ops preventing sock from
  reattach (bnc#1012628).
- bpf, sockmap: fix map elem deletion race with smap_stop_sock
  (bnc#1012628).
- platform/x86: intel_punit_ipc: fix build errors (bnc#1012628).
- fs/dcache.c: fix kmemcheck splat at take_dentry_name_snapshot()
  (bnc#1012628).
- mm: make DEFERRED_STRUCT_PAGE_INIT explicitly depend on
  SPARSEMEM (bnc#1012628).
- mm/fadvise.c: fix signed overflow UBSAN complaint (bnc#1012628).
- powerpc/topology: Get topology for shared processors at boot
  (bnc#1012628).
- pwm: meson: Fix mux clock names (bnc#1012628).
- IB/hfi1: Invalid NUMA node information can cause a divide by
  zero (bnc#1012628).
- i2c: core: ACPI: Make acpi_gsb_i2c_read_bytes() check
  i2c_transfer return value (bnc#1012628).
- x86/mce: Add notifier_block forward declaration (bnc#1012628).
- virtio: pci-legacy: Validate queue pfn (bnc#1012628).
- apparmor: fix an error code in __aa_create_ns() (bnc#1012628).
- scripts: modpost: check memory allocation results (bnc#1012628).
- workqueue: re-add lockdep dependencies for flushing
  (bnc#1012628).
- workqueue: skip lockdep wq dependency in cancel_work_sync()
  (bnc#1012628).
- fat: validate ->i_start before using (bnc#1012628).
- fs/proc/kcore.c: use __pa_symbol() for KCORE_TEXT list entries
  (bnc#1012628).
- iommu/rockchip: Move irq request past pm_runtime_enable
  (bnc#1012628).
- hfsplus: fix NULL dereference in hfsplus_lookup() (bnc#1012628).
- iommu/rockchip: Handle errors returned from PM framework
  (bnc#1012628).
- reiserfs: change j_timestamp type to time64_t (bnc#1012628).
- fs/proc/vmcore.c: hide vmcoredd_mmap_dumps() for nommu builds
  (bnc#1012628).
- fork: don't copy inconsistent signal handler state to child
  (bnc#1012628).
- sunrpc: Don't use stack buffer with scatterlist (bnc#1012628).
- hfs: prevent crash on exit from failed search (bnc#1012628).
- hfsplus: don't return 0 when fill_super() failed (bnc#1012628).
- cifs: check if SMB2 PDU size has been padded and suppress the
  warning (bnc#1012628).
- hv_netvsc: ignore devices that are not PCI (bnc#1012628).
- vhost: correctly check the iova range when waking virtqueue
  (bnc#1012628).
- mlxsw: spectrum_switchdev: Do not leak RIFs when removing bridge
  (bnc#1012628).
- sctp: hold transport before accessing its asoc in
  sctp_transport_get_next (bnc#1012628).
- nfp: wait for posted reconfigs when disabling the device
  (bnc#1012628).
- ip6_vti: fix a null pointer deference when destroy vti6 tunnel
  (bnc#1012628).
- ip6_vti: fix creating fallback tunnel device for vti6
  (bnc#1012628).
- Revert "net: stmmac: Do not keep rearming the coalesce timer
  in stmmac_xmit" (bnc#1012628).
- r8169: set RxConfig after tx/rx is enabled for RTL8169sb/8110sb
  devices (bnc#1012628).
- net/mlx5: Fix SQ offset in QPs with small RQ (bnc#1012628).
- net/ipv6: Put lwtstate when destroying fib6_info (bnc#1012628).
- net/ipv6: Only update MTU metric if it set (bnc#1012628).
- net/ipv6: init ip6 anycast rt->dst.input as ip6_input
  (bnc#1012628).
- ipv6: don't get lwtstate twice in ip6_rt_copy_init()
  (bnc#1012628).
- net: macb: Fix regression breaking non-MDIO fixed-link PHYs
  (bnc#1012628).
- erspan: set erspan_ver to 1 by default when adding an erspan
  dev (bnc#1012628).
- sctp: remove useless start_fail from sctp_ht_iter in proc
  (bnc#1012628).
- tipc: fix the big/little endian issue in tipc_dest
  (bnc#1012628).
- hv_netvsc: Fix a deadlock by getting rtnl lock earlier in
  netvsc_probe() (bnc#1012628).
- tipc: fix a missing rhashtable_walk_exit() (bnc#1012628).
- net/sched: act_pedit: fix dump of extended layered op
  (bnc#1012628).
- bnxt_en: Do not adjust max_cp_rings by the ones used by RDMA
  (bnc#1012628).
- bnxt_en: Clean up unused functions (bnc#1012628).
- net: sched: action_ife: take reference to meta module
  (bnc#1012628).
- act_ife: fix a potential deadlock (bnc#1012628).
- act_ife: move tcfa_lock down to where necessary (bnc#1012628).
- vti6: remove !skb->ignore_df check from vti6_xmit()
  (bnc#1012628).
- tcp: do not restart timewait timer on rst reception
  (bnc#1012628).
- r8169: add support for NCube 8168 network card (bnc#1012628).
- r8152: disable RX aggregation on new Dell TB16 dock
  (bnc#1012628).
- qlge: Fix netdev features configuration (bnc#1012628).
- net: sched: Fix memory exposure from short TCA_U32_SEL
  (bnc#1012628).
- net: macb: do not disable MDIO bus at open/close time
  (bnc#1012628).
- net: bcmgenet: use MAC link status for fixed phy (bnc#1012628).
- ipv4: tcp: send zero IPID for RST and ACK sent in SYN-RECV
  and TIME-WAIT state (bnc#1012628).
- act_ife: fix a potential use-after-free (bnc#1012628).
- commit f486469
* Fri Sep 14 2018 mkubecek@suse.cz
- ip: frags: fix crash in ip_do_fragment() (bsc#1108533).
- commit ba41502
* Fri Sep 14 2018 msuchanek@suse.de
- doc/README.SUSE: Remove mentions of cloneconfig (bsc#1103636).
- commit 3371adc
* Thu Sep 13 2018 jbohac@suse.cz
- Delete patches.suse/x86_64-hpet-64bit-timer.patch.
  We removed the patch from SLE15 in commit
  20efbd0c034fea7c97243120a025587d0dbac1c2
  and we don't need it in future versions of SLE.
- commit aa4eb67
* Mon Sep 10 2018 msuchanek@suse.de
- macros.kernel-source: pass -b properly in kernel module package
  (bsc#1107870).
- commit 66709cd
* Mon Sep 10 2018 mkubecek@suse.cz
- Update to 4.19-rc3
- refresh configs
- commit d3995d7
* Sun Sep  9 2018 jslaby@suse.cz
- Linux 4.18.7 (bnc#1012628).
- rcu: Make expedited GPs handle CPU 0 being offline
  (bnc#1012628).
- net: 6lowpan: fix reserved space for single frames
  (bnc#1012628).
- net: mac802154: tx: expand tailroom if necessary (bnc#1012628).
- 9p/net: Fix zero-copy path in the 9p virtio transport
  (bnc#1012628).
- spi: davinci: fix a NULL pointer dereference (bnc#1012628).
- spi: pxa2xx: Add support for Intel Ice Lake (bnc#1012628).
- spi: spi-fsl-dspi: Fix imprecise abort on VF500 during probe
  (bnc#1012628).
- spi: cadence: Change usleep_range() to udelay(), for atomic
  context (bnc#1012628).
- mmc: block: Fix unsupported parallel dispatch of requests
  (bnc#1012628).
- mmc: renesas_sdhi_internal_dmac: mask DMAC interrupts
  (bnc#1012628).
- mmc: renesas_sdhi_internal_dmac: fix #define RST_RESERVED_BITS
  (bnc#1012628).
- readahead: stricter check for bdi io_pages (bnc#1012628).
- block: fix infinite loop if the device loses discard capability
  (bnc#1012628).
- block: blk_init_allocated_queue() set q->fq as NULL in the
  fail case (bnc#1012628).
- block: really disable runtime-pm for blk-mq (bnc#1012628).
- blkcg: Introduce blkg_root_lookup() (bnc#1012628).
- block: Introduce blk_exit_queue() (bnc#1012628).
- block: Ensure that a request queue is dissociated from the
  cgroup controller (bnc#1012628).
- apparmor: fix bad debug check in apparmor_secid_to_secctx()
  (bnc#1012628).
- dma-buf: Move BUG_ON from _add_shared_fence to
  _add_shared_inplace (bnc#1012628).
- libertas: fix suspend and resume for SDIO connected cards
  (bnc#1012628).
- media: Revert "[media] tvp5150: fix pad format frame height"
  (bnc#1012628).
- mailbox: xgene-slimpro: Fix potential NULL pointer dereference
  (bnc#1012628).
- Replace magic for trusting the secondary keyring with #define
  (bnc#1012628).
- Fix kexec forbidding kernels signed with keys in the secondary
  keyring to boot (bnc#1012628).
- powerpc/fadump: handle crash memory ranges array index overflow
  (bnc#1012628).
- powerpc/64s: Fix page table fragment refcount race vs
  speculative references (bnc#1012628).
- powerpc/pseries: Fix endianness while restoring of r3 in MCE
  handler (bnc#1012628).
- powerpc/pkeys: Give all threads control of their key permissions
  (bnc#1012628).
- powerpc/pkeys: Deny read/write/execute by default (bnc#1012628).
- powerpc/pkeys: key allocation/deallocation must not change
  pkey registers (bnc#1012628).
- powerpc/pkeys: Save the pkey registers before fork
  (bnc#1012628).
- powerpc/pkeys: Fix calculation of total pkeys (bnc#1012628).
- powerpc/pkeys: Preallocate execute-only key (bnc#1012628).
- powerpc/nohash: fix pte_access_permitted() (bnc#1012628).
- powerpc64/ftrace: Include ftrace.h needed for enable/disable
  calls (bnc#1012628).
- powerpc/powernv/pci: Work around races in PCI bridge enabling
  (bnc#1012628).
- cxl: Fix wrong comparison in cxl_adapter_context_get()
  (bnc#1012628).
- ocxl: Fix page fault handler in case of fault on dying process
  (bnc#1012628).
- IB/mlx5: Honor cnt_set_id_valid flag instead of set_id
  (bnc#1012628).
- IB/mlx5: Fix leaking stack memory to userspace (bnc#1012628).
- IB/srpt: Fix srpt_cm_req_recv() error path (1/2) (bnc#1012628).
- IB/srpt: Fix srpt_cm_req_recv() error path (2/2) (bnc#1012628).
- IB/srpt: Support HCAs with more than two ports (bnc#1012628).
- overflow.h: Add arithmetic shift helper (bnc#1012628).
- RDMA/mlx5: Fix shift overflow in mlx5_ib_create_wq
  (bnc#1012628).
- ib_srpt: Fix a use-after-free in srpt_close_ch() (bnc#1012628).
- ib_srpt: Fix a use-after-free in __srpt_close_all_ch()
  (bnc#1012628).
- RDMA/rxe: Set wqe->status correctly if an unexpected response
  is received (bnc#1012628).
- 9p: fix multiple NULL-pointer-dereferences (bnc#1012628).
- fs/9p/xattr.c: catch the error of p9_client_clunk when setting
  xattr failed (bnc#1012628).
- 9p/virtio: fix off-by-one error in sg list bounds check
  (bnc#1012628).
- net/9p/client.c: version pointer uninitialized (bnc#1012628).
- net/9p/trans_fd.c: fix race-condition by flushing workqueue
  before the kfree() (bnc#1012628).
- dm integrity: change 'suspending' variable from bool to int
  (bnc#1012628).
- dm thin: stop no_space_timeout worker when switching to
  write-mode (bnc#1012628).
- dm cache metadata: save in-core policy_hint_size to on-disk
  superblock (bnc#1012628).
- dm cache metadata: set dirty on all cache blocks after a crash
  (bnc#1012628).
- dm crypt: don't decrease device limits (bnc#1012628).
- dm writecache: fix a crash due to reading past end of
  dirty_bitmap (bnc#1012628).
- uart: fix race between uart_put_char() and uart_shutdown()
  (bnc#1012628).
- Drivers: hv: vmbus: Fix the offer_in_progress in
  vmbus_process_offer() (bnc#1012628).
- Drivers: hv: vmbus: Reset the channel callback in
  vmbus_onoffer_rescind() (bnc#1012628).
- iio: sca3000: Fix missing return in switch (bnc#1012628).
- iio: ad9523: Fix displayed phase (bnc#1012628).
- iio: ad9523: Fix return value for ad952x_store() (bnc#1012628).
- extcon: Release locking when sending the notification of
  connector state (bnc#1012628).
- eventpoll.h: wrap casts in () properly (bnc#1012628).
- vmw_balloon: fix inflation of 64-bit GFNs (bnc#1012628).
- vmw_balloon: do not use 2MB without batching (bnc#1012628).
- vmw_balloon: VMCI_DOORBELL_SET does not check status
  (bnc#1012628).
- vmw_balloon: fix VMCI use when balloon built into kernel
  (bnc#1012628).
- rtc: omap: fix resource leak in registration error path
  (bnc#1012628).
- rtc: omap: fix potential crash on power off (bnc#1012628).
- tracing: Do not call start/stop() functions when tracing_on
  does not change (bnc#1012628).
- tracing/blktrace: Fix to allow setting same value (bnc#1012628).
- printk/tracing: Do not trace printk_nmi_enter() (bnc#1012628).
- livepatch: Validate module/old func name length (bnc#1012628).
- uprobes: Use synchronize_rcu() not synchronize_sched()
  (bnc#1012628).
- mfd: hi655x: Fix regmap area declared size for hi655x
  (bnc#1012628).
- ovl: fix wrong use of impure dir cache in ovl_iterate()
  (bnc#1012628).
- ACPICA: AML Parser: skip opcodes that open a scope upon parse
  failure (bnc#1012628).
- drivers/block/zram/zram_drv.c: fix bug storing backing_dev
  (bnc#1012628).
- sched: idle: Avoid retaining the tick when it has been stopped
  (bnc#1012628).
- cpuidle: menu: Handle stopped tick more aggressively
  (bnc#1012628).
- cpufreq: governor: Avoid accessing invalid governor_data
  (bnc#1012628).
- PM / sleep: wakeup: Fix build error caused by missing SRCU
  support (bnc#1012628).
- ALSA: ac97: fix device initialization in the compat layer
  (bnc#1012628).
- ALSA: ac97: fix check of pm_runtime_get_sync failure
  (bnc#1012628).
- ALSA: ac97: fix unbalanced pm_runtime_enable (bnc#1012628).
- i2c: designware: Re-init controllers with pm_disabled set on
  resume (bnc#1012628).
- KVM: VMX: fixes for vmentry_l1d_flush module parameter
  (bnc#1012628).
- KVM: PPC: Book3S: Fix guest DMA when guest partially backed
  by THP pages (bnc#1012628).
- xtensa: limit offsets in __loop_cache_{all,page} (bnc#1012628).
- xtensa: increase ranges in ___invalidate_{i,d}cache_all
  (bnc#1012628).
- block, bfq: return nbytes and not zero from struct cftype
  .write() method (bnc#1012628).
- pnfs/blocklayout: off by one in bl_map_stripe() (bnc#1012628).
- nfsd: fix leaked file lock with nfs exported overlayfs
  (bnc#1012628).
- NFSv4 client live hangs after live data migration recovery
  (bnc#1012628).
- NFSv4: Fix locking in pnfs_generic_recover_commit_reqs
  (bnc#1012628).
- NFSv4: Fix a sleep in atomic context in nfs4_callback_sequence()
  (bnc#1012628).
- ARM: tegra: Fix Tegra30 Cardhu PCA954x reset (bnc#1012628).
- ARM: dts: am57xx-idk: Enable dual role for USB2 port
  (bnc#1012628).
- pwm: omap-dmtimer: Return -EPROBE_DEFER if no dmtimer platform
  data (bnc#1012628).
- mm/tlb: Remove tlb_remove_table() non-concurrent condition
  (bnc#1012628).
- iommu/ipmmu-vmsa: Don't register as BUS IOMMU if machine
  doesn't have IPMMU-VMSA (bnc#1012628).
- iommu/vt-d: Add definitions for PFSID (bnc#1012628).
- iommu/vt-d: Fix dev iotlb pfsid use (bnc#1012628).
- sys: don't hold uts_sem while accessing userspace memory
  (bnc#1012628).
- userns: move user access out of the mutex (bnc#1012628).
- ubifs: Fix memory leak in lprobs self-check (bnc#1012628).
- Revert "UBIFS: Fix potential integer overflow in allocation"
  (bnc#1012628).
- ubifs: Check data node size before truncate (bnc#1012628).
- ubifs: xattr: Don't operate on deleted inodes (bnc#1012628).
- ubifs: Fix directory size calculation for symlinks
  (bnc#1012628).
- ubifs: Fix synced_i_size calculation for xattr inodes
  (bnc#1012628).
- pwm: tiehrpwm: Don't use emulation mode bits to control PWM
  output (bnc#1012628).
- pwm: tiehrpwm: Fix disabling of output of PWMs (bnc#1012628).
- fb: fix lost console when the user unplugs a USB adapter
  (bnc#1012628).
- udlfb: fix semaphore value leak (bnc#1012628).
- udlfb: fix display corruption of the last line (bnc#1012628).
- udlfb: don't switch if we are switching to the same videomode
  (bnc#1012628).
- udlfb: set optimal write delay (bnc#1012628).
- udlfb: make a local copy of fb_ops (bnc#1012628).
- udlfb: handle allocation failure (bnc#1012628).
- udlfb: set line_length in dlfb_ops_set_par (bnc#1012628).
- getxattr: use correct xattr length (bnc#1012628).
- libnvdimm: Use max contiguous area for namespace size
  (bnc#1012628).
- libnvdimm: fix ars_status output length calculation
  (bnc#1012628).
- bcache: release dc->writeback_lock properly in
  bch_writeback_thread() (bnc#1012628).
- kconfig: fix "Can't open ..." in parallel build (bnc#1012628).
- cap_inode_getsecurity: use d_find_any_alias() instead of
  d_find_alias() (bnc#1012628).
- mm, dev_pagemap: Do not clear ->mapping on final put
  (bnc#1012628).
- perf auxtrace: Fix queue resize (bnc#1012628).
- crypto: vmx - Fix sleep-in-atomic bugs (bnc#1012628).
- crypto: aesni - Use unaligned loads from gcm_context_data
  (bnc#1012628).
- crypto: arm64/sm4-ce - check for the right CPU feature bit
  (bnc#1012628).
- crypto: caam - fix DMA mapping direction for RSA forms 2 & 3
  (bnc#1012628).
- crypto: caam/jr - fix descriptor DMA unmapping (bnc#1012628).
- crypto: caam/qi - fix error path in xts setkey (bnc#1012628).
- fs/quota: Fix spectre gadget in do_quotactl (bnc#1012628).
- udf: Fix mounting of Win7 created UDF filesystems (bnc#1012628).
- cpuidle: menu: Retain tick when shallow state is selected
  (bnc#1012628).
- arm64: mm: always enable CONFIG_HOLES_IN_ZONE (bnc#1012628).
- commit 952d850
* Fri Sep  7 2018 jeffm@suse.com
- config: disable HFS_FS
  It has no maintainer and has been a source of fuzzer bugs.  hfsplus handles
  the HFS+ file system that became the default on MacOS in 1998.
- commit 07fd1d6
* Fri Sep  7 2018 tiwai@suse.de
- supported.conf: Add bpfilter to kernel-default-base (bsc#1106751)
- commit 8f1f1b6
* Wed Sep  5 2018 jslaby@suse.cz
- Linux 4.18.6 (bnc#1012628).
- PATCH scripts/kernel-doc (bnc#1012628).
- scripts/kernel-doc: Escape all literal braces in regexes
  (bnc#1012628).
- scsi: libsas: dynamically allocate and free ata host
  (bnc#1012628).
- xprtrdma: Fix disconnect regression (bnc#1012628).
- mei: don't update offset in write (bnc#1012628).
- cifs: add missing support for ACLs in SMB 3.11 (bnc#1012628).
- CIFS: fix uninitialized ptr deref in smb2 signing (bnc#1012628).
- cifs: add missing debug entries for kconfig options
  (bnc#1012628).
- cifs: use a refcount to protect open/closing the cached file
  handle (bnc#1012628).
- cifs: check kmalloc before use (bnc#1012628).
- smb3: enumerating snapshots was leaving part of the data off
  end (bnc#1012628).
- smb3: Do not send SMB3 SET_INFO if nothing changed
  (bnc#1012628).
- smb3: don't request leases in symlink creation and query
  (bnc#1012628).
- smb3: fill in statfs fsid and correct namelen (bnc#1012628).
- btrfs: use correct compare function of dirty_metadata_bytes
  (bnc#1012628).
- btrfs: don't leak ret from do_chunk_alloc (bnc#1012628).
- Btrfs: fix mount failure after fsync due to hard link recreation
  (bnc#1012628).
- Btrfs: fix btrfs_write_inode vs delayed iput deadlock
  (bnc#1012628).
- Btrfs: fix send failure when root has deleted files still open
  (bnc#1012628).
- Btrfs: send, fix incorrect file layout after hole punching
  beyond eof (bnc#1012628).
- hwmon: (k10temp) 27C Offset needed for Threadripper2
  (bnc#1012628).
- bpf, arm32: fix stack var offset in jit (bnc#1012628).
- regulator: arizona-ldo1: Use correct device to get enable GPIO
  (bnc#1012628).
- iommu/arm-smmu: Error out only if not enough context interrupts
  (bnc#1012628).
- printk: Split the code for storing a message into the log buffer
  (bnc#1012628).
- printk: Create helper function to queue deferred console
  handling (bnc#1012628).
- printk/nmi: Prevent deadlock when accessing the main log buffer
  in NMI (bnc#1012628).
- kprobes/arm64: Fix %%p uses in error messages (bnc#1012628).
- arm64: Fix mismatched cache line size detection (bnc#1012628).
- arm64: Handle mismatched cache type (bnc#1012628).
- arm64: mm: check for upper PAGE_SHIFT bits in pfn_valid()
  (bnc#1012628).
- arm64: dts: rockchip: corrected uart1 clock-names for rk3328
  (bnc#1012628).
- KVM: arm/arm64: Fix potential loss of ptimer interrupts
  (bnc#1012628).
- KVM: arm/arm64: Fix lost IRQs from emulated physcial timer
  when blocked (bnc#1012628).
- KVM: arm/arm64: Skip updating PMD entry if no change
  (bnc#1012628).
- KVM: arm/arm64: Skip updating PTE entry if no change
  (bnc#1012628).
- s390/kvm: fix deadlock when killed by oom (bnc#1012628).
- perf kvm: Fix subcommands on s390 (bnc#1012628).
- stop_machine: Reflow cpu_stop_queue_two_works() (bnc#1012628).
- stop_machine: Atomically queue and wake stopper threads
  (bnc#1012628).
- ext4: check for NUL characters in extended attribute's name
  (bnc#1012628).
- ext4: use ext4_warning() for sb_getblk failure (bnc#1012628).
- ext4: sysfs: print ext4_super_block fields as little-endian
  (bnc#1012628).
- ext4: reset error code in ext4_find_entry in fallback
  (bnc#1012628).
- ext4: fix race when setting the bitmap corrupted flag
  (bnc#1012628).
- nvme-pci: add a memory barrier to
  nvme_dbbuf_update_and_check_event (bnc#1012628).
- x86/gpu: reserve ICL's graphics stolen memory (bnc#1012628).
- platform/x86: wmi: Do not mix pages and kmalloc (bnc#1012628).
- mm: move tlb_table_flush to tlb_flush_mmu_free (bnc#1012628).
- mm/tlb, x86/mm: Support invalidating TLB caches for
  RCU_TABLE_FREE (bnc#1012628).
- x86/vdso: Fix vDSO build if a retpoline is emitted
  (bnc#1012628).
- x86/process: Re-export start_thread() (bnc#1012628).
- KVM: x86: ensure all MSRs can always be KVM_GET/SET_MSR'd
  (bnc#1012628).
- KVM: x86: SVM: Call x86_spec_ctrl_set_guest/host() with
  interrupts disabled (bnc#1012628).
- fuse: Don't access pipe->buffers without pipe_lock()
  (bnc#1012628).
- fuse: fix initial parallel dirops (bnc#1012628).
- fuse: fix double request_end() (bnc#1012628).
- fuse: fix unlocked access to processing queue (bnc#1012628).
- fuse: umount should wait for all requests (bnc#1012628).
- fuse: Fix oops at process_init_reply() (bnc#1012628).
- fuse: Add missed unlock_page() to fuse_readpages_fill()
  (bnc#1012628).
- lib/vsprintf: Do not handle %%pO[^F] as %%px (bnc#1012628).
- udl-kms: change down_interruptible to down (bnc#1012628).
- udl-kms: handle allocation failure (bnc#1012628).
- udl-kms: fix crash due to uninitialized memory (bnc#1012628).
- udl-kms: avoid division (bnc#1012628).
- b43legacy/leds: Ensure NUL-termination of LED name string
  (bnc#1012628).
- b43/leds: Ensure NUL-termination of LED name string
  (bnc#1012628).
- ASoC: dpcm: don't merge format from invalid codec dai
  (bnc#1012628).
- ASoC: zte: Fix incorrect PCM format bit usages (bnc#1012628).
- ASoC: sirf: Fix potential NULL pointer dereference
  (bnc#1012628).
- ASoC: wm_adsp: Correct DSP pointer for preloader control
  (bnc#1012628).
- soc: qcom: rmtfs-mem: fix memleak in probe error paths
  (bnc#1012628).
- pinctrl: freescale: off by one in imx1_pinconf_group_dbg_show()
  (bnc#1012628).
- scsi: qla2xxx: Fix stalled relogin (bnc#1012628).
- x86/vdso: Fix lsl operand order (bnc#1012628).
- x86/nmi: Fix NMI uaccess race against CR3 switching
  (bnc#1012628).
- x86/irqflags: Mark native_restore_fl extern inline
  (bnc#1012628).
- x86/spectre: Add missing family 6 check to microcode check
  (bnc#1012628).
- x86/speculation/l1tf: Increase l1tf memory limit for Nehalem+
  (bnc#1012628).
- hwmon: (nct6775) Fix potential Spectre v1 (bnc#1012628).
- x86/entry/64: Wipe KASAN stack shadow before
  rewind_stack_do_exit() (bnc#1012628).
- x86: Allow generating user-space headers without a compiler
  (bnc#1012628).
- s390/mm: fix addressing exception after suspend/resume
  (bnc#1012628).
- s390/lib: use expoline for all bcr instructions (bnc#1012628).
- s390: fix br_r1_trampoline for machines without exrl
  (bnc#1012628).
- s390/qdio: reset old sbal_state flags (bnc#1012628).
- s390/numa: move initial setup of node_to_cpumask_map
  (bnc#1012628).
- s390/pci: fix out of bounds access during irq setup
  (bnc#1012628).
- s390/purgatory: Fix crash with expoline enabled (bnc#1012628).
- s390/purgatory: Add missing FORCE to Makefile targets
  (bnc#1012628).
- kprobes: Show blacklist addresses as same as kallsyms does
  (bnc#1012628).
- kprobes: Replace %%p with other pointer types (bnc#1012628).
- kprobes/arm: Fix %%p uses in error messages (bnc#1012628).
- kprobes: Make list and blacklist root user read only
  (bnc#1012628).
- MIPS: Correct the 64-bit DSP accumulator register size
  (bnc#1012628).
- MIPS: memset.S: Fix byte_fixup for MIPSr6 (bnc#1012628).
- MIPS: Always use -march=<arch>, not -<arch> shortcuts
  (bnc#1012628).
- MIPS: Change definition of cpu_relax() for Loongson-3
  (bnc#1012628).
- MIPS: lib: Provide MIPS64r6 __multi3() for GCC < 7
  (bnc#1012628).
- tpm: Return the actual size when receiving an unsupported
  command (bnc#1012628).
- tpm: separate cmd_ready/go_idle from runtime_pm (bnc#1012628).
- scsi: mpt3sas: Fix calltrace observed while running IO & reset
  (bnc#1012628).
- scsi: mpt3sas: Fix _transport_smp_handler() error path
  (bnc#1012628).
- scsi: sysfs: Introduce sysfs_{un,}break_active_protection()
  (bnc#1012628).
- scsi: core: Avoid that SCSI device removal through sysfs
  triggers a deadlock (bnc#1012628).
- iscsi target: fix session creation failure handling
  (bnc#1012628).
- mtd: rawnand: hynix: Use ->exec_op() in
  hynix_nand_reg_write_op() (bnc#1012628).
- mtd: rawnand: fsmc: Stop using chip->read_buf() (bnc#1012628).
- mtd: rawnand: marvell: add suspend and resume hooks
  (bnc#1012628).
- mtd: rawnand: qcom: wait for desc completion in all BAM channels
  (bnc#1012628).
- clk: rockchip: fix clk_i2sout parent selection bits on rk3399
  (bnc#1012628).
- clk: npcm7xx: fix memory allocation (bnc#1012628).
- PM / clk: signedness bug in of_pm_clk_add_clks() (bnc#1012628).
- power: generic-adc-battery: fix out-of-bounds write when
  copying channel properties (bnc#1012628).
- power: generic-adc-battery: check for duplicate properties
  copied from iio channels (bnc#1012628).
- watchdog: Mark watchdog touch functions as notrace
  (bnc#1012628).
- cdrom: Fix info leak/OOB read in cdrom_ioctl_drive_status
  (bnc#1012628).
- x86/dumpstack: Don't dump kernel memory based on usermode RIP
  (bnc#1012628).
- Refresh
  patches.suse/0006-x86-stacktrace-Enable-HAVE_RELIABLE_STACKTRACE-for-t.patch.
- Update config files.
- commit 70ab8ae
* Mon Sep  3 2018 jslaby@suse.cz
- rpm/kernel-binary.spec.in: fix call of split-modules
  split-modules is called with some parameters depending on config
  options. But since we do not use backslash consistelny, the call to
  split-modules might be evaluated so that also the following cat
  command is appended. Avoid this behaviour by using backslashes
  everywhere and add %%nil to the end.
  This perhaps never happens, but stay on the safe side.
- commit 32df888
* Mon Sep  3 2018 mkubecek@suse.cz
- Update to 4.19-rc2
- refresh configs
- commit a9462db
* Sun Sep  2 2018 agraf@suse.de
- arm64: KVM: Only force FPEXC32_EL2.EN if trapping FPSIMD
  (bsc#1106841).
- commit dd0155c
* Sat Sep  1 2018 afaerber@suse.de
- config: arm64: Increase SERIAL_8250_RUNTIME_UARTS to 32 (boo#1073193)
  (cherry picked from commit 0dbc49ba128ef0931ca04cf22ec5c638534f5b23)
- config: arm64: Increase SERIAL_8250_RUNTIME_UARTS to 32 (boo#1073193)
- commit 6aae50e
* Sat Sep  1 2018 afaerber@suse.de
- config: Enable SERIAL_SC16IS7XX_SPI on arm and x86 (bsc#1105672, fate#326668)
  (cherry picked from commit cdc9eced6d892ff77abbeef5f0d5eb38c114602c)
- config: Enable SERIAL_SC16IS7XX_SPI on arm and x86 (bsc#1105672, fate#326668)
- commit 22a4d36
* Sat Sep  1 2018 afaerber@suse.de
- config: Consistently increase SERIAL_8250_NR_UARTS to 32 (boo#1073193)
  (cherry picked from commit acb36abf212a3a7428d958798d678d82351f4658)
- config: Consistently increase SERIAL_8250_NR_UARTS to 32 (boo#1073193)
- commit 090b553
* Sat Sep  1 2018 afaerber@suse.de
- config: armv7hl: Update to 4.19-rc1
- commit d1f42dc
* Sat Sep  1 2018 afaerber@suse.de
- config: armv7hl: Update to 4.18.5 (bsc#1012628)
  (cherry picked from commit fa0ebc5508eedec2c9108cafdf854a8c53a28a83)
  [AF: Don't re-enable the configs yet]
- config: armv7hl: Update to 4.18.5 (bsc#1012628)
- commit f2722e4
* Sat Sep  1 2018 afaerber@suse.de
- config: armv6hl: Update to 4.19-rc1
- commit 2f56919
* Fri Aug 31 2018 afaerber@suse.de
- config: armv6hl: Update to 4.18.5 (bsc#1012628)
  (cherry picked from commit e9071067714392290f6b0d525c77c8abfa8cf075)
  [AF: Don't re-enable configs yet]
- config: armv6hl: Update to 4.18.5 (bsc#1012628)
- commit d01db43
* Fri Aug 31 2018 afaerber@suse.de
- config: arm64: Update to 4.19-rc1
- commit a6a88d1
* Wed Aug 29 2018 mkubecek@suse.cz
- powerpc/boot: Fix missing crc32poly.h when building with
  KERNEL_XZ.
- Delete
  patches.rpmify/Revert-lib-Use-existing-define-with-polynomial.patch.
- commit cba84f7
* Wed Aug 29 2018 mkubecek@suse.cz
- kernel-binary: check also bzImage on s390/s390x
  Starting with 4.19-rc1, uncompressed image is no longer built on s390x.
  If file "image" is not found in arch/s390/boot after the build, try bzImage
  instead.
  For now, install bzImage under the name image-* until we know grub2 and our
  grub2 scripts can handle correct name.
- commit d7ccf81
* Tue Aug 28 2018 jbeulich@suse.com
- Refresh patches.suse/supported-flag after upstream commit b2c5cdcfd4.
- Refresh
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch.
- commit 8b0e2e5
* Mon Aug 27 2018 mkubecek@suse.cz
- Revert "lib: Use existing define with polynomial".
- commit 1dc6366
* Mon Aug 27 2018 mkubecek@suse.cz
- Update to 4.19-rc1
- Eliminated 179 patches (167 stable, 12 other)
- ARM configs need updating
- Config changes:
  - Block:
  - BLK_CGROUP_IOLATENCY=y
  - Networking:
  - XFRM_INTERFACE=m
  - NETFILTER_NETLINK_OSF=m
  - NFT_TUNNEL=m
  - NFT_OSF=m
  - NFT_TPROXY=m
  - NET_SCH_ETF=m
  - NET_SCH_SKBPRIO=m
  - NET_SCH_CAKE=m
  - CAN_UCAN=m
  - BT_HCIUART_RTL=y
  - BT_MTKUART=m
  - BCMGENET=m
  - SYSTEMPORT=m
  - BNXT_HWMON=y
  - NET_VENDOR_CADENCE=y	(rename)
  - BE2NET_BE2=y
  - BE2NET_BE3=y
  - BE2NET_LANCER=y
  - BE2NET_SKYHAWK=y
  - MLX5_EN_ARFS=y
  - MLX5_EN_RXNFC=y
  - NET_VENDOR_NETERION=y
  - NET_VENDOR_PACKET_ENGINES=y
  - MT76x0U=m
  - MT76x2U=m
  - IEEE802154_HWSIM=m
  - File systems:
  - OVERLAY_FS_METACOPY=n
  - UBIFS_FS_XATTR=y
  - PSTORE_ZSTD_COMPRESS=y
  - CIFS_ALLOW_INSECURE_LEGACY=y
  - Security:
  - RANDOM_TRUST_CPU=n
  - IMA_APPRAISE_BUILD_POLICY=n
  - Hacking:
  - CONSOLE_LOGLEVEL_QUIET=4
  - KPROBE_EVENTS_ON_NOTRACE=n
  - TEST_BITFIELD=n
  - TEST_IDA=n
  - Library:
  - CRC64=m
  - Graphics:
  - VIDEO_CROS_EC_CEC=m
  - DRM_DP_CEC=y
  - DRM_VKMS=m
  - TINYDRM_ILI9341=n
  - FRAMEBUFFER_CONSOLE_DEFERRED_TAKEOVER=y
  - Sound:
  - SND_SOC_INTEL_GLK_RT5682_MAX98357A_MACH=m
  - SND_SOC_ES7241=n
  - SND_SOC_SIMPLE_AMPLIFIER=n
  - Input:
  - TOUCHSCREEN_ADC=m
  - TOUCHSCREEN_BU21029=m
  - HID_COUGAR=m
  - USB:
  - TYPEC_DP_ALTMODE=m
  - Multifunction:
  - MFD_MADERA=m
  - MFD_MADERA_I2C=m
  - MFD_MADERA_SPI=m
  - GPIO_MADERA=m
  - MFD_CS47L35=y
  - MFD_CS47L85=y
  - MFD_CS47L90=y
  - IIO:
  - BME680=m
  - AD5758=n
  - SI1133=n
  - ISL29501=m
  - FPGA:
  - FPGA_DFL=m
  - FPGA_DFL_FME=m
  - FPGA_DFL_FME_MGR=m
  - FPGA_DFL_FME_BRIDGE=m
  - FPGA_DFL_FME_REGION=m
  - FPGA_DFL_AFU=m
  - FPGA_DFL_PCI=m
  - XILINX_PR_DECOUPLER=m
  - Power management:
  - IDLE_INJECT=y
  - CHARGER_ADP5061=m
  - CHARGER_CROS_USBPD=m
  - SENSORS_MLXREG_FAN=m
  - SENSORS_NPCM7XX=m
  - Misc drivers:
  - GNSS=m
  - GNSS_SERIAL=m
  - GNSS_SIRF_SERIAL=m
  - GNSS_UBX_SERIAL=m
  - MTD_SPI_NAND=m
  - NVM_PBLK_DEBUG=n
  - PINCTRL_ICELAKE=m
  - COMMON_CLK_MAX9485=n
  - IOMMU_DEFAULT_PASSTHROUGH=n
  - XEN:
  - XEN_GRANT_DMA_ALLOC=y
  - XEN_GNTDEV_DMABUF=y
  - x86:
  - STAGING_GASKET_FRAMEWORK=m
  - STAGING_APEX_DRIVER=m
  - XIL_AXIS_FIFO=m
  - TOUCHSCREEN_DMI=y
  - I2C_MULTI_INSTANTIATE=m
  - CROS_EC_I2C=m
  - CROS_EC_SPI=m
  - MLXREG_IO=m
  - i386:
  - PCIE_XILINX=y
  - MFD_ROHM_BD718XX=n
  - DRM_PANEL_ILITEK_ILI9881C=n
  - MMC_SDHCI_OF_DWCMSHC=n
  - PAGE_TABLE_ISOLATION=y
  - PowerPC:
  - I2C_MUX_PINCTRL=m
  - I2C_DEMUX_PINCTRL=m
  - I2C_FSI=m
  - DEBUG_PINCTRL=n
  - PINCTRL_AMD=m
  - PINCTRL_MCP23S08=n
  - PINCTRL_SINGLE=n
  - PINCTRL_SX150X=n
  - LEDS_AAT1290=n
  - FSI_NEW_DEV_NODE=n
  - FSI_SBEFIFO=m
  - S/390:
  - KERNEL_GZIP=y
  - S2IO=m
  - VXGE=m
  - VXGE_DEBUG_TRACE_ALL=n
  - HAMACHI=m
  - YELLOWFIN=m
  - MDIO_BCM_UNIMAC=m
  - ISM=m
  - */debug:
  - NVM_PBLK_DEBUG=y
  - IOMMU_DEBUGFS=y
  - PREEMPTIRQ_DELAY_TEST=m
- commit a3b9cac
* Fri Aug 24 2018 jslaby@suse.cz
- Linux 4.18.5 (bnc#1012628).
- reiserfs: fix broken xattr handling (heap corruption, bad
  retval) (bnc#1012628).
- i2c: imx: Fix race condition in dma read (bnc#1012628).
- i2c: core: ACPI: Properly set status byte to 0 for multi-byte
  writes (bnc#1012628).
- PCI: pciehp: Fix unprotected list iteration in IRQ handler
  (bnc#1012628).
- PCI: pciehp: Fix use-after-free on unplug (bnc#1012628).
- PCI: Skip MPS logic for Virtual Functions (VFs) (bnc#1012628).
- PCI: aardvark: Size bridges before resources allocation
  (bnc#1012628).
- PCI: hotplug: Don't leak pci_slot on registration failure
  (bnc#1012628).
- PCI / ACPI / PM: Resume all bridges on suspend-to-RAM
  (bnc#1012628).
- PCI: Restore resized BAR state on resume (bnc#1012628).
- parisc: Remove ordered stores from syscall.S (bnc#1012628).
- parisc: Remove unnecessary barriers from spinlock.h
  (bnc#1012628).
- drm/amdgpu/pm: Fix potential Spectre v1 (bnc#1012628).
- drm/i915/kvmgt: Fix potential Spectre v1 (bnc#1012628).
- ext4: fix spectre gadget in ext4_mb_regular_allocator()
  (bnc#1012628).
- powerpc64s: Show ori31 availability in spectre_v1 sysfs file
  not v2 (bnc#1012628).
- x86/mm/init: Remove freed kernel image areas from alias mapping
  (bnc#1012628).
- x86/mm/init: Add helper for freeing kernel image pages
  (bnc#1012628).
- x86/mm/init: Pass unconverted symbol addresses to
  free_init_pages() (bnc#1012628).
- mm: Allow non-direct-map arguments to free_reserved_area()
  (bnc#1012628).
- pty: fix O_CLOEXEC for TIOCGPTPEER (bnc#1012628).
- EDAC: Add missing MEM_LRDDR4 entry in edac_mem_types[]
  (bnc#1012628).
- commit d918293
* Fri Aug 24 2018 vbabka@suse.cz
- x86/speculation/l1tf: Suggest what to do on systems with too
  much RAM (bsc#1105536).
- x86/speculation/l1tf: Fix off-by-one error when warning that
  system has too much RAM (bsc#1105536).
- x86/speculation/l1tf: Fix overflow in l1tf_pfn_limit() on 32bit
  (OBS failures reported on IRC).
- commit f3b24ad
* Fri Aug 24 2018 jslaby@suse.cz
- Update config files.
- Delete
  patches.suse/revert-mm-relax-deferred-struct-page-requirements.patch.
  We actually do not this non-upstream revert. We only need the config
  change. That is: leave DEFERRED_STRUCT_PAGE_INIT=n for i386 as it was
  before 4.16.
- commit 161b8ee
* Wed Aug 22 2018 jslaby@suse.cz
- Linux 4.18.4 (bnc#1012628).
- l2tp: use sk_dst_check() to avoid race on sk->sk_dst_cache
  (bnc#1012628).
- net_sched: fix NULL pointer dereference when delete tcindex
  filter (bnc#1012628).
- net_sched: Fix missing res info when create new tc_index filter
  (bnc#1012628).
- r8169: don't use MSI-X on RTL8168g (bnc#1012628).
- ALSA: hda - Sleep for 10ms after entering D3 on Conexant codecs
  (bnc#1012628).
- ALSA: hda - Turn CX8200 into D3 as well upon reboot
  (bnc#1012628).
- ALSA: vx222: Fix invalid endian conversions (bnc#1012628).
- ALSA: virmidi: Fix too long output trigger loop (bnc#1012628).
- ALSA: cs5535audio: Fix invalid endian conversion (bnc#1012628).
- ALSA: dice: fix wrong copy to rx parameters for Alesis iO26
  (bnc#1012628).
- ALSA: hda: Correct Asrock B85M-ITX power_save blacklist entry
  (bnc#1012628).
- ALSA: memalloc: Don't exceed over the requested size
  (bnc#1012628).
- ALSA: vxpocket: Fix invalid endian conversions (bnc#1012628).
- ALSA: seq: Fix poll() error return (bnc#1012628).
- media: gl861: fix probe of dvb_usb_gl861 (bnc#1012628).
- USB: serial: sierra: fix potential deadlock at close
  (bnc#1012628).
- USB: serial: pl2303: add a new device id for ATEN (bnc#1012628).
- USB: option: add support for DW5821e (bnc#1012628).
- ACPI / PM: save NVS memory for ASUS 1025C laptop (bnc#1012628).
- tty: serial: 8250: Revert NXP SC16C2552 workaround
  (bnc#1012628).
- serial: 8250_exar: Read INT0 from slave device, too
  (bnc#1012628).
- serial: 8250_dw: always set baud rate in dw8250_set_termios
  (bnc#1012628).
- serial: 8250_dw: Add ACPI support for uart on Broadcom SoC
  (bnc#1012628).
- uio: fix wrong return value from uio_mmap() (bnc#1012628).
- misc: sram: fix resource leaks in probe error path
  (bnc#1012628).
- Revert "uio: use request_threaded_irq instead" (bnc#1012628).
- Bluetooth: avoid killing an already killed socket (bnc#1012628).
- isdn: Disable IIOCDBGVAR (bnc#1012628).
- net: sock_diag: Fix spectre v1 gadget in __sock_diag_cmd()
  (bnc#1012628).
- r8169: don't use MSI-X on RTL8106e (bnc#1012628).
- ip_vti: fix a null pointer deferrence when create vti fallback
  tunnel (bnc#1012628).
- net: ethernet: mvneta: Fix napi structure mixup on armada 3700
  (bnc#1012628).
- net: mvneta: fix mvneta_config_rss on armada 3700 (bnc#1012628).
- cls_matchall: fix tcf_unbind_filter missing (bnc#1012628).
- commit a7b92e4
* Wed Aug 22 2018 jslaby@suse.cz
- Linux 4.18.3 (bnc#1012628).
- x86/speculation/l1tf: Exempt zeroed PTEs from inversion
  (bnc#1012628).
- commit a14f6a3
* Wed Aug 22 2018 jslaby@suse.cz
- Linux 4.18.2 (bnc#1012628).
- x86/mm: Add TLB purge to free pmd/pte page interfaces
  (bnc#1012628).
- ioremap: Update pgtable free interfaces with addr (bnc#1012628).
- Bluetooth: hidp: buffer overflow in hidp_process_report
  (bnc#1012628).
- crypto: skcipher - fix crash flushing dcache in error path
  (bnc#1012628).
- crypto: skcipher - fix aligning block size in skcipher_copy_iv()
  (bnc#1012628).
- crypto: ablkcipher - fix crash flushing dcache in error path
  (bnc#1012628).
- crypto: blkcipher - fix crash flushing dcache in error path
  (bnc#1012628).
- crypto: vmac - separate tfm and request context (bnc#1012628).
- crypto: vmac - require a block cipher with 128-bit block size
  (bnc#1012628).
- crypto: x86/sha256-mb - fix digest copy in
  sha256_mb_mgr_get_comp_job_avx2() (bnc#1012628).
- crypto: ccp - Fix command completion detection race
  (bnc#1012628).
- crypto: ccp - Check for NULL PSP pointer at module unload
  (bnc#1012628).
- crypto: ccree - fix iv handling (bnc#1012628).
- crypto: ccree - fix finup (bnc#1012628).
- kbuild: verify that $DEPMOD is installed (bnc#1012628).
- x86/mm: Disable ioremap free page handling on x86-PAE
  (bnc#1012628).
- xen/pv: Call get_cpu_address_sizes to set x86_virt/phys_bits
  (bnc#1012628).
- x86/mm/pti: Clear Global bit more aggressively (bnc#1012628).
- x86/platform/UV: Mark memblock related init code and data
  correctly (bnc#1012628).
- x86/hyper-v: Check for VP_INVAL in hyperv_flush_tlb_others()
  (bnc#1012628).
- x86: i8259: Add missing include file (bnc#1012628).
- x86/l1tf: Fix build error seen if CONFIG_KVM_INTEL is disabled
  (bnc#1012628).
- commit 51ef786
* Wed Aug 22 2018 jslaby@suse.cz
- Linux 4.18.1 (bnc#1012628).
- x86/init: fix build with CONFIG_SWAP=n (bnc#1012628).
- cpu/hotplug: Non-SMP machines do not make use of booted_once
  (bnc#1012628).
- x86/smp: fix non-SMP broken build due to redefinition of
  apic_id_is_primary_thread (bnc#1012628).
- commit 7e40689
* Wed Aug 22 2018 jslaby@suse.cz
- Linux 4.18.4 (bnc#1012628).
- l2tp: use sk_dst_check() to avoid race on sk->sk_dst_cache
  (bnc#1012628).
- net_sched: fix NULL pointer dereference when delete tcindex
  filter (bnc#1012628).
- net_sched: Fix missing res info when create new tc_index filter
  (bnc#1012628).
- r8169: don't use MSI-X on RTL8168g (bnc#1012628).
- ALSA: hda - Sleep for 10ms after entering D3 on Conexant codecs
  (bnc#1012628).
- ALSA: hda - Turn CX8200 into D3 as well upon reboot
  (bnc#1012628).
- ALSA: vx222: Fix invalid endian conversions (bnc#1012628).
- ALSA: virmidi: Fix too long output trigger loop (bnc#1012628).
- ALSA: cs5535audio: Fix invalid endian conversion (bnc#1012628).
- ALSA: dice: fix wrong copy to rx parameters for Alesis iO26
  (bnc#1012628).
- ALSA: hda: Correct Asrock B85M-ITX power_save blacklist entry
  (bnc#1012628).
- ALSA: memalloc: Don't exceed over the requested size
  (bnc#1012628).
- ALSA: vxpocket: Fix invalid endian conversions (bnc#1012628).
- ALSA: seq: Fix poll() error return (bnc#1012628).
- media: gl861: fix probe of dvb_usb_gl861 (bnc#1012628).
- USB: serial: sierra: fix potential deadlock at close
  (bnc#1012628).
- USB: serial: pl2303: add a new device id for ATEN (bnc#1012628).
- USB: option: add support for DW5821e (bnc#1012628).
- ACPI / PM: save NVS memory for ASUS 1025C laptop (bnc#1012628).
- tty: serial: 8250: Revert NXP SC16C2552 workaround
  (bnc#1012628).
- serial: 8250_exar: Read INT0 from slave device, too
  (bnc#1012628).
- serial: 8250_dw: always set baud rate in dw8250_set_termios
  (bnc#1012628).
- serial: 8250_dw: Add ACPI support for uart on Broadcom SoC
  (bnc#1012628).
- uio: fix wrong return value from uio_mmap() (bnc#1012628).
- misc: sram: fix resource leaks in probe error path
  (bnc#1012628).
- Revert "uio: use request_threaded_irq instead" (bnc#1012628).
- Bluetooth: avoid killing an already killed socket (bnc#1012628).
- isdn: Disable IIOCDBGVAR (bnc#1012628).
- net: sock_diag: Fix spectre v1 gadget in __sock_diag_cmd()
  (bnc#1012628).
- r8169: don't use MSI-X on RTL8106e (bnc#1012628).
- ip_vti: fix a null pointer deferrence when create vti fallback
  tunnel (bnc#1012628).
- net: ethernet: mvneta: Fix napi structure mixup on armada 3700
  (bnc#1012628).
- net: mvneta: fix mvneta_config_rss on armada 3700 (bnc#1012628).
- cls_matchall: fix tcf_unbind_filter missing (bnc#1012628).
- commit 06f7c50
* Tue Aug 21 2018 msuchanek@suse.de
- ACPICA: Clear status of all events when entering sleep states
  (boo#1104529).
- commit 5d7a9a7
* Tue Aug 21 2018 msuchanek@suse.de
- Delete patches.suse/Revert-ACPICA-Events-Stop-unconditionally-clearing-A.patch.
- commit fb1dc2b
* Mon Aug 20 2018 jslaby@suse.cz
- Linux 4.18.3 (bnc#1012628).
- x86/speculation/l1tf: Exempt zeroed PTEs from inversion
  (bnc#1012628).
- commit 3914d9b
* Mon Aug 20 2018 jslaby@suse.cz
- Linux 4.18.2 (bnc#1012628).
- x86/mm: Add TLB purge to free pmd/pte page interfaces
  (bnc#1012628).
- ioremap: Update pgtable free interfaces with addr (bnc#1012628).
- Bluetooth: hidp: buffer overflow in hidp_process_report
  (bnc#1012628).
- crypto: skcipher - fix crash flushing dcache in error path
  (bnc#1012628).
- crypto: skcipher - fix aligning block size in skcipher_copy_iv()
  (bnc#1012628).
- crypto: ablkcipher - fix crash flushing dcache in error path
  (bnc#1012628).
- crypto: blkcipher - fix crash flushing dcache in error path
  (bnc#1012628).
- crypto: vmac - separate tfm and request context (bnc#1012628).
- crypto: vmac - require a block cipher with 128-bit block size
  (bnc#1012628).
- crypto: x86/sha256-mb - fix digest copy in
  sha256_mb_mgr_get_comp_job_avx2() (bnc#1012628).
- crypto: ccp - Fix command completion detection race
  (bnc#1012628).
- crypto: ccp - Check for NULL PSP pointer at module unload
  (bnc#1012628).
- crypto: ccree - fix iv handling (bnc#1012628).
- crypto: ccree - fix finup (bnc#1012628).
- kbuild: verify that $DEPMOD is installed (bnc#1012628).
- x86/mm: Disable ioremap free page handling on x86-PAE
  (bnc#1012628).
- xen/pv: Call get_cpu_address_sizes to set x86_virt/phys_bits
  (bnc#1012628).
- x86/mm/pti: Clear Global bit more aggressively (bnc#1012628).
- x86/platform/UV: Mark memblock related init code and data
  correctly (bnc#1012628).
- x86/hyper-v: Check for VP_INVAL in hyperv_flush_tlb_others()
  (bnc#1012628).
- x86: i8259: Add missing include file (bnc#1012628).
- x86/l1tf: Fix build error seen if CONFIG_KVM_INTEL is disabled
  (bnc#1012628).
- commit 403355b
* Fri Aug 17 2018 mkubecek@suse.cz
- rpm/constraints.in: raise memory constraints
  Build statistics show that most architectures already need more than 2 GB.
  Require 4 GB except s390x where the memory usage is much lower and we might
  have trouble finding any compliant worker.
- commit 494fb32
* Thu Aug 16 2018 msuchanek@suse.de
- Revert "ACPICA: Events: Stop unconditionally clearing ACPI
  IRQs during suspend/resume" (boo#1104529, bko#196249).
- commit 5dac824
* Thu Aug 16 2018 jslaby@suse.cz
- Linux 4.18.1 (bnc#1012628).
- x86/init: fix build with CONFIG_SWAP=n (bnc#1012628).
- cpu/hotplug: Non-SMP machines do not make use of booted_once
  (bnc#1012628).
- x86/smp: fix non-SMP broken build due to redefinition of
  apic_id_is_primary_thread (bnc#1012628).
- commit 2f1304f
* Wed Aug 15 2018 mkubecek@suse.cz
- Update config files.
- commit 07db4aa
* Wed Aug 15 2018 jslaby@suse.cz
- Linux 4.18.1-rc1
  It contains the L1TF fixes, so push the rc1 for now.
- x86/paravirt: Fix spectre-v2 mitigations for paravirt guests
  (bnc#1012628).
- x86/speculation: Protect against userspace-userspace spectreRSB
  (bnc#1012628).
- kprobes/x86: Fix %%p uses in error messages (bnc#1012628).
- x86/irqflags: Provide a declaration for native_save_fl
  (bnc#1012628).
- x86/speculation/l1tf: Increase 32bit PAE __PHYSICAL_PAGE_SHIFT
  (bnc#1012628).
- x86/speculation/l1tf: Change order of offset/type in swap entry
  (bnc#1012628).
- x86/speculation/l1tf: Protect swap entries against L1TF
  (bnc#1012628).
- x86/speculation/l1tf: Protect PROT_NONE PTEs against speculation
  (bnc#1012628).
- x86/speculation/l1tf: Make sure the first page is always
  reserved (bnc#1012628).
- x86/speculation/l1tf: Add sysfs reporting for l1tf
  (bnc#1012628).
- x86/speculation/l1tf: Disallow non privileged high MMIO
  PROT_NONE mappings (bnc#1012628).
- x86/speculation/l1tf: Limit swap file size to MAX_PA/2
  (bnc#1012628).
- x86/bugs: Move the l1tf function and define pr_fmt properly
  (bnc#1012628).
- sched/smt: Update sched_smt_present at runtime (bnc#1012628).
- x86/smp: Provide topology_is_primary_thread() (bnc#1012628).
- x86/topology: Provide topology_smt_supported() (bnc#1012628).
- cpu/hotplug: Make bringup/teardown of smp threads symmetric
  (bnc#1012628).
- cpu/hotplug: Split do_cpu_down() (bnc#1012628).
- cpu/hotplug: Provide knobs to control SMT (bnc#1012628).
- x86/cpu: Remove the pointless CPU printout (bnc#1012628).
- x86/cpu/AMD: Remove the pointless detect_ht() call
  (bnc#1012628).
- x86/cpu/common: Provide detect_ht_early() (bnc#1012628).
- x86/cpu/topology: Provide detect_extended_topology_early()
  (bnc#1012628).
- x86/cpu/intel: Evaluate smp_num_siblings early (bnc#1012628).
- x86/CPU/AMD: Do not check CPUID max ext level before parsing
  SMP info (bnc#1012628).
- x86/cpu/AMD: Evaluate smp_num_siblings early (bnc#1012628).
- x86/apic: Ignore secondary threads if nosmt=force (bnc#1012628).
- x86/speculation/l1tf: Extend 64bit swap file size limit
  (bnc#1012628).
- x86/cpufeatures: Add detection of L1D cache flush support
  (bnc#1012628).
- x86/CPU/AMD: Move TOPOEXT reenablement before reading
  smp_num_siblings (bnc#1012628).
- x86/speculation/l1tf: Protect PAE swap entries against L1TF
  (bnc#1012628).
- x86/speculation/l1tf: Fix up pte->pfn conversion for PAE
  (bnc#1012628).
- Revert "x86/apic: Ignore secondary threads if nosmt=force"
  (bnc#1012628).
- cpu/hotplug: Boot HT siblings at least once (bnc#1012628).
- x86/KVM: Warn user if KVM is loaded SMT and L1TF CPU bug being
  present (bnc#1012628).
- x86/KVM/VMX: Add module argument for L1TF mitigation
  (bnc#1012628).
- x86/KVM/VMX: Add L1D flush algorithm (bnc#1012628).
- x86/KVM/VMX: Add L1D MSR based flush (bnc#1012628).
- x86/KVM/VMX: Add L1D flush logic (bnc#1012628).
- x86/KVM/VMX: Split the VMX MSR LOAD structures to have an
  host/guest numbers (bnc#1012628).
- x86/KVM/VMX: Add find_msr() helper function (bnc#1012628).
- x86/KVM/VMX: Separate the VMX AUTOLOAD guest/host number
  accounting (bnc#1012628).
- x86/KVM/VMX: Extend add_atomic_switch_msr() to allow VMENTER
  only MSRs (bnc#1012628).
- x86/KVM/VMX: Use MSR save list for IA32_FLUSH_CMD if required
  (bnc#1012628).
- cpu/hotplug: Online siblings when SMT control is turned on
  (bnc#1012628).
- x86/litf: Introduce vmx status variable (bnc#1012628).
- x86/kvm: Drop L1TF MSR list approach (bnc#1012628).
- x86/l1tf: Handle EPT disabled state proper (bnc#1012628).
- x86/kvm: Move l1tf setup function (bnc#1012628).
- x86/kvm: Add static key for flush always (bnc#1012628).
- x86/kvm: Serialize L1D flush parameter setter (bnc#1012628).
- x86/kvm: Allow runtime control of L1D flush (bnc#1012628).
- cpu/hotplug: Expose SMT control init function (bnc#1012628).
- cpu/hotplug: Set CPU_SMT_NOT_SUPPORTED early (bnc#1012628).
- x86/bugs, kvm: Introduce boot-time control of L1TF mitigations
  (bnc#1012628).
- Documentation: Add section about CPU vulnerabilities
  (bnc#1012628).
- x86/speculation/l1tf: Unbreak !__HAVE_ARCH_PFN_MODIFY_ALLOWED
  architectures (bnc#1012628).
- x86/KVM/VMX: Initialize the vmx_l1d_flush_pages' content
  (bnc#1012628).
- Documentation/l1tf: Fix typos (bnc#1012628).
- cpu/hotplug: detect SMT disabled by BIOS (bnc#1012628).
- x86/KVM/VMX: Don't set l1tf_flush_l1d to true from
  vmx_l1d_flush() (bnc#1012628).
- x86/KVM/VMX: Replace 'vmx_l1d_flush_always' with
  'vmx_l1d_flush_cond' (bnc#1012628).
- x86/KVM/VMX: Move the l1tf_flush_l1d test to vmx_l1d_flush()
  (bnc#1012628).
- x86/irq: Demote irq_cpustat_t::__softirq_pending to u16
  (bnc#1012628).
- x86/KVM/VMX: Introduce per-host-cpu analogue of l1tf_flush_l1d
  (bnc#1012628).
- x86: Don't include linux/irq.h from asm/hardirq.h (bnc#1012628).
- x86/irq: Let interrupt handlers set kvm_cpu_l1tf_flush_l1d
  (bnc#1012628).
- x86/KVM/VMX: Don't set l1tf_flush_l1d from
  vmx_handle_external_intr() (bnc#1012628).
- Documentation/l1tf: Remove Yonah processors from not vulnerable
  list (bnc#1012628).
- x86/speculation: Simplify sysfs report of VMX L1TF vulnerability
  (bnc#1012628).
- x86/speculation: Use ARCH_CAPABILITIES to skip L1D flush on
  vmentry (bnc#1012628).
- KVM: VMX: Tell the nested hypervisor to skip L1D flush on
  vmentry (bnc#1012628).
- cpu/hotplug: Fix SMT supported evaluation (bnc#1012628).
- x86/speculation/l1tf: Invert all not present mappings
  (bnc#1012628).
- x86/speculation/l1tf: Make pmd/pud_mknotpresent() invert
  (bnc#1012628).
- x86/mm/pat: Make set_memory_np() L1TF safe (bnc#1012628).
- x86/mm/kmmio: Make the tracer robust against L1TF (bnc#1012628).
- tools headers: Synchronise x86 cpufeatures.h for L1TF additions
  (bnc#1012628).
- x86/microcode: Allow late microcode loading with SMT disabled
  (bnc#1012628).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Update config files.
- commit a23e15c
* Tue Aug 14 2018 mkubecek@suse.cz
- Update upstream reference:
  patches.suse/hv-netvsc-Fix-NULL-dereference-at-single-queue-mode-.patch.
- commit 0425184
* Tue Aug 14 2018 tiwai@suse.de
- hv/netvsc: Fix NULL dereference at single queue mode fallback
  (bsc#1104708).
- commit a0cb9f6
* Mon Aug 13 2018 jslaby@suse.cz
- Refresh
  patches.suse/platform-x86-ideapad-laptop-Apply-no_hw_rfkill-to-Y2.
  Update upstream info.
- commit 799dc2a
* Mon Aug 13 2018 mkubecek@suse.cz
- Update to 4.18-final.
- Refresh configs
- commit 06ab9b3
* Thu Aug  9 2018 jslaby@suse.cz
- Linux 4.17.14 (bnc#1012628).
- jfs: Fix inconsistency between memory allocation and
  ea_buf->max_size (bnc#1012628).
- xfs: validate cached inodes are free when allocated
  (bnc#1012628).
- xfs: don't call xfs_da_shrink_inode with NULL bp (bnc#1012628).
- Partially revert "block: fail op_is_write() requests to
  read-only partitions" (bnc#1012628).
- Btrfs: fix file data corruption after cloning a range and fsync
  (bnc#1012628).
- i2c: imx: Fix reinit_completion() use (bnc#1012628).
- ring_buffer: tracing: Inherit the tracing setting to next ring
  buffer (bnc#1012628).
- netlink: Don't shift on 64 for ngroups (bnc#1012628).
- nohz: Fix missing tick reprogram when interrupting an inline
  softirq (bnc#1012628).
- nohz: Fix local_timer_softirq_pending() (bnc#1012628).
- perf/x86/intel/uncore: Fix hardcoded index of Broadwell extra
  PCI devices (bnc#1012628).
- genirq: Make force irq threading setup more robust
  (bnc#1012628).
- jfs: Fix usercopy whitelist for inline inode data (bnc#1012628).
- scsi: qla2xxx: Return error when TMF returns (bnc#1012628).
- scsi: qla2xxx: Fix ISP recovery on unload (bnc#1012628).
- scsi: qla2xxx: Fix driver unload by shutting down chip
  (bnc#1012628).
- scsi: qla2xxx: Fix NPIV deletion by calling
  wait_for_sess_deletion (bnc#1012628).
- scsi: qla2xxx: Fix unintialized List head crash (bnc#1012628).
- commit dc49b43
* Tue Aug  7 2018 mkubecek@suse.cz
- config: refresh s390x/vanilla
  Add new option CONFIG_SYSTEM_DATA_VERIFICATION=n
- commit 3ee2023
* Mon Aug  6 2018 jslaby@suse.cz
- Linux 4.17.13 (bnc#1012628).
- scsi: sg: fix minor memory leak in error path (bnc#1012628).
- drm/atomic: Initialize variables in
  drm_atomic_helper_async_check() to make gcc happy (bnc#1012628).
- drm/atomic: Check old_plane_state->crtc in
  drm_atomic_helper_async_check() (bnc#1012628).
- drm/vc4: Reset ->{x, y}_scaling[1] when dealing with uniplanar
  formats (bnc#1012628).
- crypto: padlock-aes - Fix Nano workaround data corruption
  (bnc#1012628).
- RDMA/uverbs: Expand primary and alt AV port checks
  (bnc#1012628).
- brcmfmac: fix regression in parsing NVRAM for multiple devices
  (bnc#1012628).
- iwlwifi: add more card IDs for 9000 series (bnc#1012628).
- userfaultfd: remove uffd flags from vma->vm_flags if
  UFFD_EVENT_FORK fails (bnc#1012628).
- ipc/shm.c add ->pagesize function to shm_vm_ops (bnc#1012628).
- audit: fix potential null dereference 'context->module.name'
  (bnc#1012628).
- kvm: x86: vmx: fix vpid leak (bnc#1012628).
- x86/entry/64: Remove %%ebx handling from error_entry/exit
  (bnc#1012628).
- x86/apic: Future-proof the TSC_DEADLINE quirk for SKX
  (bnc#1012628).
- x86/efi: Access EFI MMIO data as unencrypted when SEV is active
  (bnc#1012628).
- virtio_balloon: fix another race between migration and
  ballooning (bnc#1012628).
- net: socket: Fix potential spectre v1 gadget in
  sock_is_registered (bnc#1012628).
- net: socket: fix potential spectre v1 gadget in socketcall
  (bnc#1012628).
- can: ems_usb: Fix memory leak on ems_usb_disconnect()
  (bnc#1012628).
- squashfs: more metadata hardenings (bnc#1012628).
- squashfs: more metadata hardening (bnc#1012628).
- net/mlx5e: IPoIB, Set the netdevice sw mtu in ipoib enhanced
  flow (bnc#1012628).
- net/mlx5e: Set port trust mode to PCP as default (bnc#1012628).
- net/mlx5e: E-Switch, Initialize eswitch only if eswitch manager
  (bnc#1012628).
- rxrpc: Fix user call ID check in rxrpc_service_prealloc_one
  (bnc#1012628).
- net: stmmac: Fix WoL for PCI-based setups (bnc#1012628).
- netlink: Fix spectre v1 gadget in netlink_create()
  (bnc#1012628).
- net: dsa: Do not suspend/resume closed slave_dev (bnc#1012628).
- ipv4: frags: handle possible skb truesize change (bnc#1012628).
- inet: frag: enforce memory limits earlier (bnc#1012628).
- bonding: avoid lockdep confusion in bond_get_stats()
  (bnc#1012628).
- commit 9079348
* Mon Aug  6 2018 mkubecek@suse.cz
- Update to 4.18-rc8
- commit 9928e10
* Fri Aug  3 2018 jslaby@suse.cz
- Linux 4.17.12 (bnc#1012628).
- ACPICA: AML Parser: ignore control method status in module-level
  code (bnc#1012628).
- ACPI / LPSS: Avoid PM quirks on suspend and resume from
  hibernation (bnc#1012628).
- tcp: ack immediately when a cwr packet arrives (bnc#1012628).
- tcp: add one more quick ack after after ECN events
  (bnc#1012628).
- tcp: refactor tcp_ecn_check_ce to remove sk type cast
  (bnc#1012628).
- tcp: do not aggressively quick ack after ECN events
  (bnc#1012628).
- tcp: add max_quickacks param to tcp_incr_quickack and
  tcp_enter_quickack_mode (bnc#1012628).
- tcp: do not force quickack when receiving out-of-order packets
  (bnc#1012628).
- netlink: Don't shift with UB on nlk->ngroups (bnc#1012628).
- netlink: Do not subscribe to non-existent groups (bnc#1012628).
- net: rollback orig value on failure of
  dev_qdisc_change_tx_queue_len (bnc#1012628).
- cxgb4: Added missing break in ndo_udp_tunnel_{add/del}
  (bnc#1012628).
- xen-netfront: wait xenbus state change when load module manually
  (bnc#1012628).
- virtio_net: Fix incosistent received bytes counter
  (bnc#1012628).
- tcp_bbr: fix bw probing to raise in-flight data for very small
  BDPs (bnc#1012628).
- RDS: RDMA: Fix the NULL-ptr deref in rds_ib_get_mr
  (bnc#1012628).
- NET: stmmac: align DMA stuff to largest cache line length
  (bnc#1012628).
- net: mdio-mux: bcm-iproc: fix wrong getter and setter pair
  (bnc#1012628).
- net: lan78xx: fix rx handling before first packet is send
  (bnc#1012628).
- net: fix amd-xgbe flow-control issue (bnc#1012628).
- net: ena: Fix use of uninitialized DMA address bits field
  (bnc#1012628).
- netdevsim: don't leak devlink resources (bnc#1012628).
- ipv4: remove BUG_ON() from fib_compute_spec_dst (bnc#1012628).
- net: dsa: qca8k: Allow overwriting CPU port setting
  (bnc#1012628).
- net: dsa: qca8k: Add QCA8334 binding documentation
  (bnc#1012628).
- net: dsa: qca8k: Enable RXMAC when bringing up a port
  (bnc#1012628).
- net: dsa: qca8k: Force CPU port to its highest bandwidth
  (bnc#1012628).
- RDMA/uverbs: Protect from attempts to create flows on
  unsupported QP (bnc#1012628).
- gpio: uniphier: set legitimate irq trigger type in .to_irq hook
  (bnc#1012628).
- gpio: of: Handle fixed regulator flags properly (bnc#1012628).
- ext4: fix check to prevent initializing reserved inodes
  (bnc#1012628).
- ext4: check for allocation block validity with block group
  locked (bnc#1012628).
- ext4: fix inline data updates with checksums enabled
  (bnc#1012628).
- ext4: fix false negatives *and* false positives in
  ext4_check_descriptors() (bnc#1012628).
- squashfs: be more careful about metadata corruption
  (bnc#1012628).
- random: mix rdrand with entropy sent in from userspace
  (bnc#1012628).
- i2c: rcar: handle RXDMA HW behaviour on Gen3 (bnc#1012628).
- nvmet-fc: fix target sgl list on large transfers (bnc#1012628).
- block: reset bi_iter.bi_done after splitting bio (bnc#1012628).
- blkdev: __blkdev_direct_IO_simple: fix leak in error case
  (bnc#1012628).
- block: bio_iov_iter_get_pages: fix size of last iovec
  (bnc#1012628).
- drm/amdgpu: Avoid reclaim while holding locks taken in MMU
  notifier (bnc#1012628).
- drm/dp/mst: Fix off-by-one typo when dump payload table
  (bnc#1012628).
- drm/atomic-helper: Drop plane->fb references only for
  drm_atomic_helper_shutdown() (bnc#1012628).
- drm: Add DP PSR2 sink enable bit (bnc#1012628).
- ARM: dts: imx6qdl-wandboard: Let the codec control MCLK pinctrl
  (bnc#1012628).
- ASoC: topology: Add missing clock gating parameter when parsing
  hw_configs (bnc#1012628).
- ASoC: topology: Fix bclk and fsync inversion in
  set_link_hw_format() (bnc#1012628).
- net: socionext: reset hardware in ndo_stop (bnc#1012628).
- media: si470x: fix __be16 annotations (bnc#1012628).
- media: cec: fix smatch error (bnc#1012628).
- media: atomisp: compat32: fix __user annotations (bnc#1012628).
- PCI/ASPM: Disable ASPM L1.2 Substate if we don't have LTR
  (bnc#1012628).
- scsi: cxlflash: Avoid clobbering context control register value
  (bnc#1012628).
- scsi: cxlflash: Synchronize reset and remove ops (bnc#1012628).
- scsi: megaraid_sas: Increase timeout by 1 sec for non-RAID
  fastpath IOs (bnc#1012628).
- scsi: scsi_dh: replace too broad "TP9" string with the exact
  models (bnc#1012628).
- drm/stm: ltdc: fix warning in ltdc_crtc_update_clut()
  (bnc#1012628).
- ath10k: search all IEs for variant before falling back
  (bnc#1012628).
- regulator: Don't return or expect -errno from of_map_mode()
  (bnc#1012628).
- media: omap3isp: fix unbalanced dma_iommu_mapping (bnc#1012628).
- media: rc: mce_kbd decoder: low timeout values cause double
  keydowns (bnc#1012628).
- y2038: ipc: Use ktime_get_real_seconds consistently
  (bnc#1012628).
- crypto: authenc - don't leak pointers to authenc keys
  (bnc#1012628).
- crypto: authencesn - don't leak pointers to authenc keys
  (bnc#1012628).
- usb: hub: Don't wait for connect state at resume for powered-off
  ports (bnc#1012628).
- microblaze: Fix simpleImage format generation (bnc#1012628).
- soc: imx: gpcv2: Do not pass static memory as platform data
  (bnc#1012628).
- serial: core: Make sure compiler barfs for 16-byte earlycon
  names (bnc#1012628).
- staging: ks7010: fix error handling in ks7010_upload_firmware
  (bnc#1012628).
- staging: lustre: ldlm: free resource when ldlm_lock_create()
  fails (bnc#1012628).
- staging: lustre: llite: correct removexattr detection
  (bnc#1012628).
- staging: vchiq_core: Fix missing semaphore release in error case
  (bnc#1012628).
- platform/x86: dell-smbios: Match on www.dell.com in OEM strings
  too (bnc#1012628).
- drm/rockchip: analogix_dp: Do not call Analogix code before bind
  (bnc#1012628).
- audit: allow not equal op for audit by executable (bnc#1012628).
- rsi: fix nommu_map_sg overflow kernel panic (bnc#1012628).
- rsi: Fix 'invalid vdd' warning in mmc (bnc#1012628).
- ipconfig: Correctly initialise ic_nameservers (bnc#1012628).
- drm/gma500: fix psb_intel_lvds_mode_valid()'s return type
  (bnc#1012628).
- qtnfmac: pearl: pcie: fix memory leak in qtnf_fw_work_handler
  (bnc#1012628).
- igb: Fix queue selection on MAC filters on i210 (bnc#1012628).
- ASoC: compress: Only call free for components which have been
  opened (bnc#1012628).
- arm64: defconfig: Enable Rockchip io-domain driver
  (bnc#1012628).
- ASoC: fsl_ssi: Use u32 variable type when using regmap_read()
  (bnc#1012628).
- nvme: lightnvm: add granby support (bnc#1012628).
- memory: tegra: Apply interrupts mask per SoC (bnc#1012628).
- memory: tegra: Do not handle spurious interrupts (bnc#1012628).
- ath10k: fix kernel panic while reading tpc_stats (bnc#1012628).
- delayacct: Use raw_spinlocks (bnc#1012628).
- stop_machine: Use raw spinlocks (bnc#1012628).
- backlight: pwm_bl: Don't use GPIOF_* with gpiod_get_direction
  (bnc#1012628).
- mt76: add rcu locking around tx scheduling (bnc#1012628).
- i40e: avoid overflow in i40e_ptp_adjfreq() (bnc#1012628).
- i40e: Add advertising 10G LR mode (bnc#1012628).
- dt-bindings: net: meson-dwmac: new compatible name for AXG SoC
  (bnc#1012628).
- net: hns3: Fixes the out of bounds access in hclge_map_tqp
  (bnc#1012628).
- spi: meson-spicc: Fix error handling in meson_spicc_probe()
  (bnc#1012628).
- dt-bindings: pinctrl: meson: add support for the Meson8m2 SoC
  (bnc#1012628).
- mmc: pwrseq: Use kmalloc_array instead of stack VLA
  (bnc#1012628).
- mmc: dw_mmc: update actual clock for mmc debugfs (bnc#1012628).
- ALSA: hda/ca0132: fix build failure when a local macro is
  defined (bnc#1012628).
- mlxsw: spectrum_router: Return an error for non-default FIB
  rules (bnc#1012628).
- f2fs: check cap_resource only for data blocks (bnc#1012628).
- mmc: sdhci-omap: Fix when capabilities are obtained from
  SDHCI_CAPABILITIES reg (bnc#1012628).
- drm/atomic: Handling the case when setting old crtc for plane
  (bnc#1012628).
- mt76x2: fix avg_rssi estimation (bnc#1012628).
- media: siano: get rid of __le32/__le16 cast warnings
  (bnc#1012628).
- media: em28xx: fix a regression with HVR-950 (bnc#1012628).
- f2fs: avoid fsync() failure caused by EAGAIN in writepage()
  (bnc#1012628).
- bpf: fix references to free_bpf_prog_info() in comments
  (bnc#1012628).
- regulator: add dummy function of_find_regulator_by_node
  (bnc#1012628).
- thermal: exynos: fix setting rising_threshold for Exynos5433
  (bnc#1012628).
- staging: lustre: o2iblnd: Fix FastReg map/unmap for MLX5
  (bnc#1012628).
- staging: lustre: o2iblnd: fix race at kiblnd_connect_peer
  (bnc#1012628).
- dma-direct: try reallocation with GFP_DMA32 if possible
  (bnc#1012628).
- scsi: qedf: Set the UNLOADING flag when removing a vport
  (bnc#1012628).
- soc/tegra: pmc: Don't allocate struct tegra_powergate on stack
  (bnc#1012628).
- scsi: hisi_sas: config ATA de-reset as an constrained command
  for v3 hw (bnc#1012628).
- scsi: megaraid: silence a static checker bug (bnc#1012628).
- scsi: 3w-xxxx: fix a missing-check bug (bnc#1012628).
- scsi: 3w-9xxx: fix a missing-check bug (bnc#1012628).
- staging: most: cdev: fix chrdev_region leak (bnc#1012628).
- mm, powerpc, x86: define VM_PKEY_BITx bits if
  CONFIG_ARCH_HAS_PKEYS is enabled (bnc#1012628).
- bnxt_en: Always forward VF MAC address to the PF (bnc#1012628).
- bnxt_en: Check unsupported speeds in bnxt_update_link() on PF
  only (bnc#1012628).
- net: phy: sfp: handle cases where neither BR, min nor BR,
  max is given (bnc#1012628).
- perf: fix invalid bit in diagnostic entry (bnc#1012628).
- s390/cpum_sf: Add data entry sizes to sampling trailer entry
  (bnc#1012628).
- brcmfmac: Add support for bcm43364 wireless chipset
  (bnc#1012628).
- mtd: rawnand: fsl_ifc: fix FSL NAND driver to read all ONFI
  parameter pages (bnc#1012628).
- media: em28xx: Fix DualHD broken second tuner (bnc#1012628).
- media: renesas-ceu: Set mbus_fmt on subdev operations
  (bnc#1012628).
- media: saa7164: Fix driver name in debug output (bnc#1012628).
- media: media-device: fix ioctl function types (bnc#1012628).
- ACPI / LPSS: Only call pwm_add_table() for Bay Trail PWM if
  PMIC HRV is 2 (bnc#1012628).
- libata: Fix command retry decision (bnc#1012628).
- media: rcar_jpu: Add missing clk_disable_unprepare() on error
  in jpu_open() (bnc#1012628).
- net: phy: phylink: Release link GPIO (bnc#1012628).
- dma-iommu: Fix compilation when !CONFIG_IOMMU_DMA (bnc#1012628).
- tty: Fix data race in tty_insert_flip_string_fixed_flag
  (bnc#1012628).
- i40e: free the skb after clearing the bitlock (bnc#1012628).
- ARM: dts: imx53: Fix LDB OF graph warning (bnc#1012628).
- nvmem: properly handle returned value nvmem_reg_read
  (bnc#1012628).
- ARM: dts: sh73a0: Add missing interrupt-affinity to PMU node
  (bnc#1012628).
- ARM: dts: emev2: Add missing interrupt-affinity to PMU node
  (bnc#1012628).
- ARM: dts: stih407-pinctrl: Fix complain about IRQ_TYPE_NONE
  usage (bnc#1012628).
- ARM: dts: stih410: Fix complain about IRQ_TYPE_NONE usage
  (bnc#1012628).
- rsi: Add null check for virtual interfaces in wowlan config
  (bnc#1012628).
- EDAC, altera: Fix ARM64 build warning (bnc#1012628).
- HID: i2c-hid: check if device is there before really probing
  (bnc#1012628).
- powerpc/embedded6xx/hlwd-pic: Prevent interrupts from being
  handled by Starlet (bnc#1012628).
- IB: Fix RDMA_RXE and INFINIBAND_RDMAVT dependencies for
  DMA_VIRT_OPS (bnc#1012628).
- drm/amd/display: Fix dim display on DCE11 (bnc#1012628).
- drm/amdgpu: Remove VRAM from shared bo domains (bnc#1012628).
- drm/radeon: fix mode_valid's return type (bnc#1012628).
- drm/amd/display: remove need of modeset flag for overlay planes
  (V2) (bnc#1012628).
- arm64: dts: renesas: salvator-common: use audio-graph-card
  for Sound (bnc#1012628).
- HID: hid-plantronics: Re-resend Update to map button for PTT
  products (bnc#1012628).
- arm64: cmpwait: Clear event register before arming exclusive
  monitor (bnc#1012628).
- media: staging: atomisp: Comment out several unused sensor
  resolutions (bnc#1012628).
- media: atomisp: ov2680: don't declare unused vars (bnc#1012628).
- net: hns3: Fix for fiber link up problem (bnc#1012628).
- ALSA: usb-audio: Apply rate limit to warning messages in URB
  complete callback (bnc#1012628).
- net: ethernet: ti: cpsw-phy-sel: check bus_find_device()
  ret value (bnc#1012628).
- clocksource: Move inline keyword to the beginning of function
  declarations (bnc#1012628).
- PCI/DPC: Clear interrupt status in interrupt handler top half
  (bnc#1012628).
- media: smiapp: fix timeout checking in smiapp_read_nvm
  (bnc#1012628).
- gpu: host1x: Acquire a reference to the IOVA cache
  (bnc#1012628).
- ixgbevf: fix MAC address changes through ixgbevf_set_mac()
  (bnc#1012628).
- md: fix NULL dereference of mddev->pers in
  remove_and_add_spares() (bnc#1012628).
- md/raid1: add error handling of read error from FailFast device
  (bnc#1012628).
- regulator: pfuze100: add .is_enable() for
  pfuze100_swb_regulator_ops (bnc#1012628).
- ALSA: emu10k1: Rate-limit error messages about page errors
  (bnc#1012628).
- rtc: tps65910: fix possible race condition (bnc#1012628).
- rtc: vr41xx: fix possible race condition (bnc#1012628).
- rtc: tps6586x: fix possible race condition (bnc#1012628).
- Bluetooth: btusb: add ID for LiteOn 04ca:301a (bnc#1012628).
- drm/nouveau/fifo/gk104-: poll for runlist update completion
  (bnc#1012628).
- drm/nouveau/gem: lookup VMAs for buffers referenced by pushbuf
  ioctl (bnc#1012628).
- drm/nouveau: remove fence wait code from deferred client work
  handler (bnc#1012628).
- scsi: zfcp: assert that the ERP lock is held when tracing a
  recovery trigger (bnc#1012628).
- scsi: ufs: fix exception event handling (bnc#1012628).
- scsi: ufs: ufshcd: fix possible unclocked register access
  (bnc#1012628).
- net: mvpp2: Add missing VLAN tag detection (bnc#1012628).
- fscrypt: use unbound workqueue for decryption (bnc#1012628).
- net: hns3: Fix for hns3 module is loaded multiple times problem
  (bnc#1012628).
- net: hns3: Fix the missing client list node initialization
  (bnc#1012628).
- net: hns3: Fix for CMDQ and Misc. interrupt init order problem
  (bnc#1012628).
- spi: Add missing pm_runtime_put_noidle() after failed get
  (bnc#1012628).
- drivers/perf: arm-ccn: don't log to dmesg in event_init
  (bnc#1012628).
- watchdog: renesas-wdt: Add support for the R8A77965 WDT
  (bnc#1012628).
- ima: based on policy verify firmware signatures (pre-allocated
  buffer) (bnc#1012628).
- mt76x2: apply coverage class on slot time too (bnc#1012628).
- mwifiex: correct histogram data with appropriate index
  (bnc#1012628).
- net: dsa: qca8k: Add support for QCA8334 switch (bnc#1012628).
- PCI: pciehp: Request control of native hotplug only if supported
  (bnc#1012628).
- bpf: powerpc64: pad function address loads with NOPs
  (bnc#1012628).
- bpf: fix multi-function JITed dump obtained via syscall
  (bnc#1012628).
- pinctrl: msm: fix gpio-hog related boot issues (bnc#1012628).
- pinctrl: at91-pio4: add missing of_node_put (bnc#1012628).
- powerpc/8xx: fix invalid register expression in head_8xx.S
  (bnc#1012628).
- spi: sh-msiof: Fix setting SIRMDR1.SYNCAC to match
  SITMDR1.SYNCAC (bnc#1012628).
- KVM: x86: prevent integer overflows in
  KVM_MEMORY_ENCRYPT_REG_REGION (bnc#1012628).
- powerpc: Add __printf verification to prom_printf (bnc#1012628).
- powerpc/powermac: Mark variable x as unused (bnc#1012628).
- powerpc/powermac: Add missing prototype for note_bootable_part()
  (bnc#1012628).
- powerpc/chrp/time: Make some functions static, add missing
  header include (bnc#1012628).
- powerpc/32: Add a missing include header (bnc#1012628).
- sched/cpufreq: Modify aggregate utilization to always include
  blocked FAIR utilization (bnc#1012628).
- ath: Add regulatory mapping for Bahamas (bnc#1012628).
- ath: Add regulatory mapping for Bermuda (bnc#1012628).
- ath: Add regulatory mapping for Serbia (bnc#1012628).
- ath: Add regulatory mapping for Tanzania (bnc#1012628).
- ath: Add regulatory mapping for Uganda (bnc#1012628).
- ath: Add regulatory mapping for APL2_FCCA (bnc#1012628).
- ath: Add regulatory mapping for APL13_WORLD (bnc#1012628).
- ath: Add regulatory mapping for ETSI8_WORLD (bnc#1012628).
- ath: Add regulatory mapping for FCC3_ETSIC (bnc#1012628).
- nvme-pci: Fix AER reset handling (bnc#1012628).
- nvme-rdma: stop admin queue before freeing it (bnc#1012628).
- soc: qcom: smem: byte swap values properly (bnc#1012628).
- soc: qcom: smem: fix qcom_smem_set_global_partition()
  (bnc#1012628).
- soc: qcom: qmi: fix a buffer sizing bug (bnc#1012628).
- PCI: Prevent sysfs disable of device while driver is attached
  (bnc#1012628).
- PM / wakeup: Make s2idle_lock a RAW_SPINLOCK (bnc#1012628).
- x86/microcode: Make the late update update_lock a raw lock
  for RT (bnc#1012628).
- btrfs: qgroup: Finish rescan when hit the last leaf of extent
  tree (bnc#1012628).
- btrfs: add barriers to btrfs_sync_log before log_commit_wait
  wakeups (bnc#1012628).
- Btrfs: don't BUG_ON() in btrfs_truncate_inode_items()
  (bnc#1012628).
- Btrfs: don't return ino to ino cache if inode item removal fails
  (bnc#1012628).
- media: videobuf2-core: don't call memop 'finish' when queueing
  (bnc#1012628).
- media: cec-pin-error-inj: avoid a false-positive Spectre
  detection (bnc#1012628).
- media: tw686x: Fix incorrect vb2_mem_ops GFP flags
  (bnc#1012628).
- net: hns3: Fixes the init of the VALID BD info in the descriptor
  (bnc#1012628).
- net: hns3: Fixes initalization of RoCE handle and makes it
  conditional (bnc#1012628).
- wlcore: sdio: check for valid platform device data before
  suspend (bnc#1012628).
- mwifiex: handle race during mwifiex_usb_disconnect
  (bnc#1012628).
- mfd: cros_ec: Fail early if we cannot identify the EC
  (bnc#1012628).
- ASoC: dpcm: fix BE dai not hw_free and shutdown (bnc#1012628).
- Bluetooth: btusb: Add a new Realtek 8723DE ID 2ff8:b011
  (bnc#1012628).
- drivers/bus: arm-cci: fix build warnings (bnc#1012628).
- drm/amd/display: Do not program interrupt status on disabled
  crtc (bnc#1012628).
- Bluetooth: hci_qca: Fix "Sleep inside atomic section" warning
  (bnc#1012628).
- iwlwifi: mvm: open BA session only when sta is authorized
  (bnc#1012628).
- iwlwifi: pcie: fix race in Rx buffer allocator (bnc#1012628).
- btrfs: balance dirty metadata pages in btrfs_finish_ordered_io
  (bnc#1012628).
- PCI: Fix devm_pci_alloc_host_bridge() memory leak (bnc#1012628).
- qtnfmac: fix invalid STA state on EAPOL failure (bnc#1012628).
- selftests/filesystems: devpts_pts included wrong header
  (bnc#1012628).
- selftests: filesystems: return Kselftest Skip code for skipped
  tests (bnc#1012628).
- selftests: intel_pstate: return Kselftest Skip code for skipped
  tests (bnc#1012628).
- selftests: kvm: return Kselftest Skip code for skipped tests
  (bnc#1012628).
- selftests: memfd: return Kselftest Skip code for skipped tests
  (bnc#1012628).
- selftests/intel_pstate: Improve test, minor fixes (bnc#1012628).
- perf/x86/intel/uncore: Correct fixed counter index check for
  NHM (bnc#1012628).
- perf/x86/intel/uncore: Correct fixed counter index check in
  generic code (bnc#1012628).
- usbip: dynamically allocate idev by nports found in sysfs
  (bnc#1012628).
- usbip: usbip_detach: Fix memory, udev context and udev leak
  (bnc#1012628).
- block, bfq: remove wrong lock in bfq_requests_merged
  (bnc#1012628).
- f2fs: fix race in between GC and atomic open (bnc#1012628).
- f2fs: fix to detect failure of dquot_initialize (bnc#1012628).
- f2fs: fix missing clear FI_NO_PREALLOC in some error case
  (bnc#1012628).
- f2fs: Fix deadlock in shutdown ioctl (bnc#1012628).
- f2fs: fix to wait page writeback during revoking atomic write
  (bnc#1012628).
- f2fs: fix to don't trigger writeback during recovery
  (bnc#1012628).
- f2fs: don't drop dentry pages after fs shutdown (bnc#1012628).
- f2fs: fix error path of move_data_page (bnc#1012628).
- disable loading f2fs module on PAGE_SIZE > 4KB (bnc#1012628).
- NFS: Fix up nfs_post_op_update_inode() to force ctime updates
  (bnc#1012628).
- pnfs: Don't release the sequence slot until we've processed
  layoutget on open (bnc#1012628).
- netfilter: nf_tables: check msg_type before nft_trans_set(trans)
  (bnc#1012628).
- lightnvm: pblk: warn in case of corrupted write buffer
  (bnc#1012628).
- lightnvm: proper error handling for pblk_bio_add_pages
  (bnc#1012628).
- lightnvm: fix partial read error path (bnc#1012628).
- RDMA/mad: Convert BUG_ONs to error flows (bnc#1012628).
- net: hns3: Fix for service_task not running problem after
  resetting (bnc#1012628).
- net: hns3: Fix for phy not link up problem after resetting
  (bnc#1012628).
- clk: ingenic: jz4770: Modify C1CLK clock to disable CPU clock
  stop on idle (bnc#1012628).
- clk-si544: Properly round requested frequency to nearest match
  (bnc#1012628).
- powerpc/64s: Fix compiler store ordering to SLB shadow area
  (bnc#1012628).
- hvc_opal: don't set tb_ticks_per_usec in udbg_init_opal_common()
  (bnc#1012628).
- powerpc/eeh: Fix use-after-release of EEH driver (bnc#1012628).
- powerpc/64s: Add barrier_nospec (bnc#1012628).
- powerpc/lib: Adjust .balign inside string functions for PPC32
  (bnc#1012628).
- infiniband: fix a possible use-after-free bug (bnc#1012628).
- e1000e: Ignore TSYNCRXCTL when getting I219 clock attributes
  (bnc#1012628).
- ceph: fix use-after-free in ceph_statfs() (bnc#1012628).
- ceph: fix alignment of rasize (bnc#1012628).
- bpf, arm32: fix inconsistent naming about emit_a32_lsr_{r64,i64}
  (bnc#1012628).
- printk: drop in_nmi check from printk_safe_flush_on_panic()
  (bnc#1012628).
- media: arch: sh: migor: Fix TW9910 PDN gpio (bnc#1012628).
- watchdog: da9063: Fix updating timeout value (bnc#1012628).
- irqchip/ls-scfg-msi: Map MSIs in the iommu (bnc#1012628).
- netfilter: ipset: List timing out entries with "timeout 1"
  instead of zero (bnc#1012628).
- netfilter: ipset: forbid family for hash:mac sets (bnc#1012628).
- perf tools: Fix pmu events parsing rule (bnc#1012628).
- net: hns3: Fix for VF mailbox cannot receiving PF response
  (bnc#1012628).
- rxrpc: Fix terminal retransmission connection ID to include
  the channel (bnc#1012628).
- rtc: ensure rtc_set_alarm fails when alarms are not supported
  (bnc#1012628).
- mm/slub.c: add __printf verification to slab_err()
  (bnc#1012628).
- mm: vmalloc: avoid racy handling of debugobjects in vunmap
  (bnc#1012628).
- mm: /proc/pid/pagemap: hide swap entries from unprivileged users
  (bnc#1012628).
- mem_cgroup: make sure moving_account, move_lock_task and
  stat_cpu in the same cacheline (bnc#1012628).
- kernel/hung_task.c: show all hung tasks before panic
  (bnc#1012628).
- vfio/type1: Fix task tracking for QEMU vCPU hotplug
  (bnc#1012628).
- vfio/mdev: Check globally for duplicate devices (bnc#1012628).
- vfio: platform: Fix reset module leak in error path
  (bnc#1012628).
- nfsd: fix potential use-after-free in nfsd4_decode_getdeviceinfo
  (bnc#1012628).
- nfsd: fix error handling in nfs4_set_delegation() (bnc#1012628).
- NFSv4.1: Fix the client behaviour on NFS4ERR_SEQ_FALSE_RETRY
  (bnc#1012628).
- ALSA: fm801: add error handling for snd_ctl_add (bnc#1012628).
- ALSA: emu10k1: add error handling for snd_ctl_add (bnc#1012628).
- ixgbe: Fix setting of TC configuration for macvlan case
  (bnc#1012628).
- skip LAYOUTRETURN if layout is invalid (bnc#1012628).
- hv_netvsc: fix network namespace issues with VF support
  (bnc#1012628).
- xen/netfront: raise max number of slots in
  xennet_get_responses() (bnc#1012628).
- drm/amd/powerplay: Set higher SCLK&MCLK frequency than dpm7
  in OD (v2) (bnc#1012628).
- mm: check for SIGKILL inside dup_mmap() loop (bnc#1012628).
- kcov: ensure irq code sees a valid area (bnc#1012628).
- mlxsw: spectrum_switchdev: Fix port_vlan refcounting
  (bnc#1012628).
- drm/i915/glk: Add Quirk for GLK NUC HDMI port issues
  (bnc#1012628).
- arm64: fix vmemmap BUILD_BUG_ON() triggering on !vmemmap setups
  (bnc#1012628).
- tracing: Quiet gcc warning about maybe unused link variable
  (bnc#1012628).
- tracing/kprobes: Fix trace_probe flags on enable_trace_kprobe()
  failure (bnc#1012628).
- kthread, tracing: Don't expose half-written comm when creating
  kthreads (bnc#1012628).
- tracing: Fix possible double free in event_enable_trigger_func()
  (bnc#1012628).
- tracing: Fix double free of event_trigger_data (bnc#1012628).
- delayacct: fix crash in delayacct_blkio_end() after delayacct
  init failure (bnc#1012628).
- kvm, mm: account shadow page tables to kmemcg (bnc#1012628).
- mm: disallow mappings that conflict for devm_memremap_pages()
  (bnc#1012628).
- Input: elan_i2c - add another ACPI ID for Lenovo Ideapad
  330-15AST (bnc#1012628).
- Input: i8042 - add Lenovo LaVie Z to the i8042 reset list
  (bnc#1012628).
- Input: elan_i2c - add ACPI ID for lenovo ideapad 330
  (bnc#1012628).
- spi: spi-s3c64xx: Fix system resume support (bnc#1012628).
- commit ef4920c
* Mon Jul 30 2018 jslaby@suse.cz
- Update config files.
  Run oldconfig on s390x's vanilla.
- commit 6676306
* Mon Jul 30 2018 mkubecek@suse.cz
- Update to 4.18-rc7
- commit 68c9705
* Sun Jul 29 2018 jslaby@suse.cz
- Linux 4.17.11 (bnc#1012628).
- can: m_can.c: fix setup of CCCR register: clear CCCR NISO bit
  before checking can.ctrlmode (bnc#1012628).
- can: m_can: Fix runtime resume call (bnc#1012628).
- can: peak_canfd: fix firmware < v3.3.0: limit allocation to
  32-bit DMA addr only (bnc#1012628).
- can: xilinx_can: fix RX overflow interrupt not being enabled
  (bnc#1012628).
- can: xilinx_can: fix incorrect clear of non-processed interrupts
  (bnc#1012628).
- can: xilinx_can: keep only 1-2 frames in TX FIFO to fix TX
  accounting (bnc#1012628).
- can: xilinx_can: fix device dropping off bus on RX overrun
  (bnc#1012628).
- can: xilinx_can: fix recovery from error states not being
  propagated (bnc#1012628).
- can: xilinx_can: fix power management handling (bnc#1012628).
- can: xilinx_can: fix RX loop if RXNEMP is asserted without RXOK
  (bnc#1012628).
- driver core: Partially revert "driver core: correct device's
  shutdown order" (bnc#1012628).
- ACPICA: AML Parser: ignore dispatcher error status during
  table load (bnc#1012628).
- usb: gadget: f_fs: Only return delayed status when len is 0
  (bnc#1012628).
- usb: gadget: Fix OS descriptors support (bnc#1012628).
- usb: xhci: Fix memory leak in xhci_endpoint_reset()
  (bnc#1012628).
- usb: dwc2: Fix DMA alignment to start at allocated boundary
  (bnc#1012628).
- usb: core: handle hub C_PORT_OVER_CURRENT condition
  (bnc#1012628).
- usb: cdc_acm: Add quirk for Castles VEGA3000 (bnc#1012628).
- staging: speakup: fix wraparound in uaccess length check
  (bnc#1012628).
- Revert "staging:r8188eu: Use lib80211 to support TKIP"
  (bnc#1012628).
- tcp: add tcp_ooo_try_coalesce() helper (bnc#1012628).
- tcp: call tcp_drop() from tcp_data_queue_ofo() (bnc#1012628).
- tcp: detect malicious patterns in tcp_collapse_ofo_queue()
  (bnc#1012628).
- tcp: avoid collapses in tcp_prune_queue() if possible
  (bnc#1012628).
- tcp: free batches of packets in tcp_prune_ofo_queue()
  (bnc#1012628).
- vxlan: fix default fdb entry netlink notify ordering during
  netdev create (bnc#1012628).
- vxlan: make netlink notify in vxlan_fdb_destroy optional
  (bnc#1012628).
- vxlan: add new fdb alloc and create helpers (bnc#1012628).
- rtnetlink: add rtnl_link_state check in rtnl_configure_link
  (bnc#1012628).
- net/mlx5: Adjust clock overflow work period (bnc#1012628).
- net/mlx5e: Fix quota counting in aRFS expire flow (bnc#1012628).
- net/mlx5e: Don't allow aRFS for encapsulated packets
  (bnc#1012628).
- net/ipv6: Fix linklocal to global address with VRF
  (bnc#1012628).
- multicast: do not restore deleted record source filter mode
  to new one (bnc#1012628).
- net: phy: consider PHY_IGNORE_INTERRUPT in phy_start_aneg_priv
  (bnc#1012628).
- sock: fix sg page frag coalescing in sk_alloc_sg (bnc#1012628).
- nfp: flower: ensure dead neighbour entries are not offloaded
  (bnc#1012628).
- net/mlx5e: Refine ets validation function (bnc#1012628).
- net/mlx5e: Only allow offloading decap egress (egdev) flows
  (bnc#1012628).
- net/mlx5e: Add ingress/egress indication for offloaded TC flows
  (bnc#1012628).
- tls: check RCV_SHUTDOWN in tls_wait_data (bnc#1012628).
- r8169: restore previous behavior to accept BIOS WoL settings
  (bnc#1012628).
- net/mlx5: E-Switch, UBSAN fix undefined behavior in
  mlx5_eswitch_mode (bnc#1012628).
- tcp: do not delay ACK in DCTCP upon CE status change
  (bnc#1012628).
- tcp: do not cancel delay-AcK on DCTCP special ACK (bnc#1012628).
- tcp: helpers to send special DCTCP ack (bnc#1012628).
- tcp: fix dctcp delayed ACK schedule (bnc#1012628).
- net: skb_segment() should not return NULL (bnc#1012628).
- net-next/hinic: fix a problem in hinic_xmit_frame()
  (bnc#1012628).
- net/mlx4_core: Save the qpn from the input modifier in RST2INIT
  wrapper (bnc#1012628).
- net: dsa: mv88e6xxx: fix races between lock and irq freeing
  (bnc#1012628).
- ip: in cmsg IP(V6)_ORIGDSTADDR call pskb_may_pull (bnc#1012628).
- ip: hash fragments consistently (bnc#1012628).
- bonding: set default miimon value for non-arp modes if not set
  (bnc#1012628).
- clk: meson-gxbb: set fclk_div2 as CLK_IS_CRITICAL (bnc#1012628).
- drm/nouveau: Set DRIVER_ATOMIC cap earlier to fix debugfs
  (bnc#1012628).
- drm/nouveau/drm/nouveau: Fix runtime PM leak in
  nv50_disp_atomic_commit() (bnc#1012628).
- KVM: PPC: Check if IOMMU page is contained in the pinned
  physical page (bnc#1012628).
- xen/PVH: Set up GS segment for stack canary (bnc#1012628).
- clk: aspeed: Support HPLL strapping on ast2400 (bnc#1012628).
- clk: aspeed: Mark bclk (PCIe) and dclk (VGA) as critical
  (bnc#1012628).
- clk: mvebu: armada-37xx-periph: Fix switching CPU rate from
  300Mhz to 1.2GHz (bnc#1012628).
- MIPS: Fix off-by-one in pci_resource_to_user() (bnc#1012628).
- MIPS: ath79: fix register address in ath79_ddr_wb_flush()
  (bnc#1012628).
- Revert "iommu/intel-iommu: Enable CONFIG_DMA_DIRECT_OPS=y and
  clean up intel_{alloc,free}_coherent()" (bnc#1012628).
- KVM: VMX: support MSR_IA32_ARCH_CAPABILITIES as a feature MSR
  (bnc#1012628).
- commit d626dd8
* Thu Jul 26 2018 msuchanek@suse.de
- Revert "Revert "Pass x86 as architecture on x86_64 and i386 (bsc#1093118).""
  This reverts commit f604b8a2baa6f01a438c2d495a34820ed722aef5.
- commit b5ab6f7
* Thu Jul 26 2018 msuchanek@suse.de
- Update config files.
- commit c195a0c
* Thu Jul 26 2018 jslaby@suse.cz
- Revert "Pass x86 as architecture on x86_64 and i386 (bsc#1093118)."
  This reverts commit 5f24fb07e56ac11cd19527c51f5a547f1d0946d4. It
  breaks all i586 builds.
- commit f604b8a
* Wed Jul 25 2018 jslaby@suse.cz
- Linux 4.17.10 (bnc#1012628).
- xhci: Fix perceived dead host due to runtime suspend race with
  event handler (bnc#1012628).
- cxl_getfile(): fix double-iput() on alloc_file() failures
  (bnc#1012628).
- drm_mode_create_lease_ioctl(): fix open-coded filp_clone_open()
  (bnc#1012628).
- alpha: fix osf_wait4() breakage (bnc#1012628).
- net: usb: asix: replace mii_nway_restart in resume path
  (bnc#1012628).
- ipv6: make DAD fail with enhanced DAD when nonce length differs
  (bnc#1012628).
- net: systemport: Fix CRC forwarding check for SYSTEMPORT Lite
  (bnc#1012628).
- net/mlx4_en: Don't reuse RX page when XDP is set (bnc#1012628).
- net: aquantia: vlan unicast address list correct handling
  (bnc#1012628).
- hv_netvsc: Fix napi reschedule while receive completion is busy
  (bnc#1012628).
- sctp: fix the issue that pathmtu may be set lower than
  MINSEGMENT (bnc#1012628).
- sctp: introduce sctp_dst_mtu (bnc#1012628).
- net: ip6_gre: get ipv6hdr after skb_cow_head() (bnc#1012628).
- tg3: Add higher cpu clock for 5762 (bnc#1012628).
- sch_fq_codel: zero q->flows_cnt when fq_codel_init fails
  (bnc#1012628).
- rhashtable: add restart routine in rhashtable_free_and_destroy()
  (bnc#1012628).
- qmi_wwan: add support for Quectel EG91 (bnc#1012628).
- ptp: fix missing break in switch (bnc#1012628).
- net: phy: fix flag masking in __set_phy_supported (bnc#1012628).
- net/ipv6: Do not allow device only routes via the multipath API
  (bnc#1012628).
- net/ipv4: Set oif in fib_compute_spec_dst (bnc#1012628).
- skbuff: Unconditionally copy pfmemalloc in __skb_clone()
  (bnc#1012628).
- net: Don't copy pfmemalloc flag in __copy_skb_header()
  (bnc#1012628).
- net: diag: Don't double-free TCP_NEW_SYN_RECV sockets in
  tcp_abort (bnc#1012628).
- lib/rhashtable: consider param->min_size when setting initial
  table size (bnc#1012628).
- ipv6: ila: select CONFIG_DST_CACHE (bnc#1012628).
- ipv6: fix useless rol32 call on hash (bnc#1012628).
- ipv4: Return EINVAL when ping_group_range sysctl doesn't map
  to user ns (bnc#1012628).
- gen_stats: Fix netlink stats dumping in the presence of padding
  (bnc#1012628).
- drm/nouveau: Avoid looping through fake MST connectors
  (bnc#1012628).
- drm/nouveau: Use drm_connector_list_iter_* for iterating
  connectors (bnc#1012628).
- drm/nouveau: Remove bogus crtc check in pmops_runtime_idle
  (bnc#1012628).
- Revert "drm/amd/display: Don't return ddc result and read_bytes
  in same return value" (bnc#1012628).
- drm/i915: Fix hotplug irq ack on i965/g4x (bnc#1012628).
- drm/amdgpu: Reserve VM root shared fence slot for command
  submission (v3) (bnc#1012628).
- powerpc/powernv: Fix save/restore of SPRG3 on entry/exit from
  stop (idle) (bnc#1012628).
- stop_machine: Disable preemption when waking two stopper threads
  (bnc#1012628).
- vfio/spapr: Use IOMMU pageshift rather than pagesize
  (bnc#1012628).
- vfio/pci: Fix potential Spectre v1 (bnc#1012628).
- cpufreq: intel_pstate: Register when ACPI PCCH is present
  (bnc#1012628).
- mm/huge_memory.c: fix data loss when splitting a file pmd
  (bnc#1012628).
- mm: memcg: fix use after free in mem_cgroup_iter()
  (bnc#1012628).
- ARC: mm: allow mprotect to make stack mappings executable
  (bnc#1012628).
- ARC: configs: Remove CONFIG_INITRAMFS_SOURCE from defconfigs
  (bnc#1012628).
- ARC: Fix CONFIG_SWAP (bnc#1012628).
- ARCv2: [plat-hsdk]: Save accl reg pair by default (bnc#1012628).
- ALSA: hda: add mute led support for HP ProBook 455 G5
  (bnc#1012628).
- ALSA: hda/realtek - Yet another Clevo P950 quirk entry
  (bnc#1012628).
- ALSA: hda/realtek - Add Panasonic CF-SZ6 headset jack quirk
  (bnc#1012628).
- ALSA: rawmidi: Change resized buffers atomically (bnc#1012628).
- fat: fix memory allocation failure handling of match_strdup()
  (bnc#1012628).
- x86/MCE: Remove min interval polling limitation (bnc#1012628).
- x86/events/intel/ds: Fix bts_interrupt_threshold alignment
  (bnc#1012628).
- x86/apm: Don't access __preempt_count with zeroed fs
  (bnc#1012628).
- x86/kvmclock: set pvti_cpu0_va after enabling kvmclock
  (bnc#1012628).
- x86/kvm/vmx: don't read current->thread.{fs,gs}base of legacy
  tasks (bnc#1012628).
- KVM: VMX: Mark VMXArea with revision_id of physical CPU even
  when eVMCS enabled (bnc#1012628).
- KVM: irqfd: fix race between EPOLLHUP and
  irq_bypass_register_consumer (bnc#1012628).
- KVM/Eventfd: Avoid crash when assign and deassign specific
  eventfd in parallel (bnc#1012628).
- scsi: qla2xxx: Fix NULL pointer dereference for fcport search
  (bnc#1012628).
- scsi: qla2xxx: Fix kernel crash due to late workqueue allocation
  (bnc#1012628).
- scsi: qla2xxx: Fix inconsistent DMA mem alloc/free
  (bnc#1012628).
- scsi: sd_zbc: Fix variable type and bogus comment (bnc#1012628).
- commit 0a7f415
* Tue Jul 24 2018 dmueller@suse.com
- Reenable v8.1/v8.2 aarch64 extensions
  These were enabled already in SLE15 and we want to default to the
  upstream defaults, which enable these features.
  Config changes:
  - aarch64:
    HW_AFDBM=y
    PAN=y
    LSE_ATOMICS=y
    VHE=y
    UAO=y
    SVE=y
- commit 7fdc027
* Mon Jul 23 2018 msuchanek@suse.de
- Update config files.
- commit 8efadc7
* Mon Jul 23 2018 tiwai@suse.de
- rpm/kernel-source.spec.in: Add more stuff to Recommends
  ... and move bc to Recommends as well.  All these packages are needed for
  building a kernel manually from scratch with kernel-source files.
- commit 6fcec9a
* Mon Jul 23 2018 jslaby@suse.cz
- Revert "rpm/kernel-source.spec.in: require bc for kernel-source"
  This reverts commit 2fa4028b0f8fcb4b6a9f2bd2a401a71181e0cdcd. Why
  would kernel-source need bc? The discussion is ongoing on
  opensuse-kernel. See:
  7230252.SMnhE4Fjuc@alaris
- commit 7144bb1
* Mon Jul 23 2018 mkubecek@suse.cz
- Update to 4.18-rc6
- Config changes:
  - NF_TABLES_SET=m (replaces NFT_SET_{RBTREE,HASH,BITMAP})
- commit 31ad2a8
* Sun Jul 22 2018 jslaby@suse.cz
- Linux 4.17.9 (bnc#1012628).
- bpf: undo prog rejection on read-only lock failure
  (bnc#1012628).
- bpf, arm32: fix to use bpf_jit_binary_lock_ro api (bnc#1012628).
- bpf: enforce correct alignment for instructions (bnc#1012628).
- arm64: KVM: Add ARCH_WORKAROUND_2 discovery through
  ARCH_FEATURES_FUNC_ID (bnc#1012628).
- arm64: KVM: Handle guest's ARCH_WORKAROUND_2 requests
  (bnc#1012628).
- arm64: KVM: Add ARCH_WORKAROUND_2 support for guests
  (bnc#1012628).
- arm64: KVM: Add HYP per-cpu accessors (bnc#1012628).
- arm64: ssbd: Add prctl interface for per-thread mitigation
  (bnc#1012628).
- arm64: ssbd: Introduce thread flag to control userspace
  mitigation (bnc#1012628).
- arm64: ssbd: Restore mitigation status on CPU resume
  (bnc#1012628).
- arm64: ssbd: Skip apply_ssbd if not using dynamic mitigation
  (bnc#1012628).
- arm64: ssbd: Add global mitigation state accessor (bnc#1012628).
- arm64: Add 'ssbd' command-line option (bnc#1012628).
- arm64: Add ARCH_WORKAROUND_2 probing (bnc#1012628).
  Update config files.
  ARM64_SSBD=y
- arm64: Add per-cpu infrastructure to call ARCH_WORKAROUND_2
  (bnc#1012628).
- arm64: Call ARCH_WORKAROUND_2 on transitions between EL0 and
  EL1 (bnc#1012628).
- arm/arm64: smccc: Add SMCCC-specific return codes (bnc#1012628).
- ipvs: initialize tbl->entries in ip_vs_lblc_init_svc()
  (bnc#1012628).
- ipvs: initialize tbl->entries after allocation (bnc#1012628).
- net/nfc: Avoid stalls when nfc_alloc_send_skb() returned NULL
  (bnc#1012628).
- bpf: don't leave partial mangled prog in jit_subprogs error path
  (bnc#1012628).
- bpf: sockmap, consume_skb in close path (bnc#1012628).
- bpf: sockmap, fix crash when ipv6 sock is added (bnc#1012628).
- block: don't use blocking queue entered for recursive bio
  submits (bnc#1012628).
- rds: avoid unenecessary cong_update in loop transport
  (bnc#1012628).
- bpf: reject any prog that failed read-only lock (bnc#1012628).
- bdi: Fix another oops in wb_workfn() (bnc#1012628).
- netfilter: ipv6: nf_defrag: drop skb dst before queueing
  (bnc#1012628).
- nsh: set mac len based on inner packet (bnc#1012628).
- autofs: fix slab out of bounds read in getname_kernel()
  (bnc#1012628).
- tls: Stricter error checking in zerocopy sendmsg path
  (bnc#1012628).
- KEYS: DNS: fix parsing multiple options (bnc#1012628).
- reiserfs: fix buffer overflow with long warning messages
  (bnc#1012628).
- netfilter: ebtables: reject non-bridge targets (bnc#1012628).
- PCI: hv: Disable/enable IRQs rather than BH in
  hv_compose_msi_msg() (bnc#1012628).
- crypto: af_alg - Initialize sg_num_bytes in error code path
  (bnc#1012628).
- net: lan78xx: Fix race in tx pending skb size calculation
  (bnc#1012628).
- rtlwifi: rtl8821ae: fix firmware is not ready to run
  (bnc#1012628).
- rtlwifi: Fix kernel Oops "Fw download fail!!" (bnc#1012628).
- net: cxgb3_main: fix potential Spectre v1 (bnc#1012628).
- x86/kvm/Kconfig: Ensure CRYPTO_DEV_CCP_DD state at minimum
  matches KVM_AMD (bnc#1012628).
- virtio_net: split XDP_TX kick and XDP_REDIRECT map flushing
  (bnc#1012628).
- sfc: correctly initialise filter rwsem for farch (bnc#1012628).
- s390/qeth: fix race when setting MAC address (bnc#1012628).
- s390/qeth: avoid using is_multicast_ether_addr_64bits on
  (u8 *)[6] (bnc#1012628).
- Revert "s390/qeth: use Read device to query hypervisor for MAC"
  (bnc#1012628).
- IB/mlx5: Avoid dealing with vport representors if not being
  e-switch manager (bnc#1012628).
- i40e: split XDP_TX tail and XDP_REDIRECT map flushing
  (bnc#1012628).
- enic: do not overwrite error code (bnc#1012628).
- xen-netfront: Update features after registering netdev
  (bnc#1012628).
- xen-netfront: Fix mismatched rtnl_unlock (bnc#1012628).
- nfp: reject binding to shared blocks (bnc#1012628).
- net: use dev_change_tx_queue_len() for SIOCSIFTXQLEN
  (bnc#1012628).
- net: macb: initialize bp->queues[0].bp for at91rm9200
  (bnc#1012628).
- nfp: flower: fix mpls ether type detection (bnc#1012628).
- hinic: reset irq affinity before freeing irq (bnc#1012628).
- VSOCK: fix loopback on big-endian systems (bnc#1012628).
- vhost_net: validate sock before trying to put its fd
  (bnc#1012628).
- tcp: prevent bogus FRTO undos with non-SACK flows (bnc#1012628).
- tcp: fix Fast Open key endianness (bnc#1012628).
- strparser: Remove early eaten to fix full tcp receive buffer
  stall (bnc#1012628).
- stmmac: fix DMA channel hang in half-duplex mode (bnc#1012628).
- s390/qeth: don't clobber buffer on async TX completion
  (bnc#1012628).
- r8152: napi hangup fix after disconnect (bnc#1012628).
- qmi_wwan: add support for the Dell Wireless 5821e module
  (bnc#1012628).
- qed: Limit msix vectors in kdump kernel to the minimum required
  count (bnc#1012628).
- qed: Fix use of incorrect size in memcpy call (bnc#1012628).
- qed: Fix setting of incorrect eswitch mode (bnc#1012628).
- qede: Adverstise software timestamp caps when PHC is not
  available (bnc#1012628).
- net/tcp: Fix socket lookups with SO_BINDTODEVICE (bnc#1012628).
- net: sungem: fix rx checksum support (bnc#1012628).
- net_sched: blackhole: tell upper qdisc about dropped packets
  (bnc#1012628).
- net/sched: act_ife: preserve the action control in case of error
  (bnc#1012628).
- net/sched: act_ife: fix recursive lock and idr leak
  (bnc#1012628).
- net/packet: fix use-after-free (bnc#1012628).
- net: mvneta: fix the Rx desc DMA address in the Rx path
  (bnc#1012628).
- net/mlx5: Fix wrong size allocation for QoS ETC TC regitster
  (bnc#1012628).
- net/mlx5: Fix required capability for manipulating MPFS
  (bnc#1012628).
- net/mlx5: Fix incorrect raw command length parsing
  (bnc#1012628).
- net/mlx5: Fix command interface race in polling mode
  (bnc#1012628).
- net/mlx5: E-Switch, Avoid setup attempt if not being e-switch
  manager (bnc#1012628).
- net/mlx5e: Don't attempt to dereference the ppriv struct if
  not being eswitch manager (bnc#1012628).
- net/mlx5e: Avoid dealing with vport representors if not being
  e-switch manager (bnc#1012628).
- net: macb: Fix ptp time adjustment for large negative delta
  (bnc#1012628).
- net: fix use-after-free in GRO with ESP (bnc#1012628).
- net: dccp: switch rx_tstamp_last_feedback to monotonic clock
  (bnc#1012628).
- net: dccp: avoid crash in ccid3_hc_rx_send_feedback()
  (bnc#1012628).
- ixgbe: split XDP_TX tail and XDP_REDIRECT map flushing
  (bnc#1012628).
- ipvlan: fix IFLA_MTU ignored on NEWLINK (bnc#1012628).
- ipv6: sr: fix passing wrong flags to crypto_alloc_shash()
  (bnc#1012628).
- hv_netvsc: split sub-channel setup into async and sync
  (bnc#1012628).
- atm: zatm: Fix potential Spectre v1 (bnc#1012628).
- atm: Preserve value of skb->truesize when accounting to vcc
  (bnc#1012628).
- alx: take rtnl before calling __alx_open from resume
  (bnc#1012628).
- pinctrl: mt7622: fix a kernel panic when gpio-hog is being
  applied (bnc#1012628).
- pinctrl: mt7622: stop using the deprecated
  pinctrl_add_gpio_range (bnc#1012628).
- pinctrl: mt7622: fix error path on failing at groups building
  (bnc#1012628).
- pinctrl: sh-pfc: r8a77970: remove SH_PFC_PIN_CFG_DRIVE_STRENGTH
  flag (bnc#1012628).
- x86/paravirt: Make native_save_fl() extern inline (bnc#1012628).
- x86/asm: Add _ASM_ARG* constants for argument registers to
  <asm/asm.h> (bnc#1012628).
- compiler-gcc.h: Add __attribute__((gnu_inline)) to all inline
  declarations (bnc#1012628).
- commit 059e5b8
* Sun Jul 22 2018 tiwai@suse.de
- rpm/kernel-source.spec.in: require bc for kernel-source
  This is needed for building include/generated/timeconst.h from
  kernel/time/timeconst.bc.
- commit d725e3b
* Wed Jul 18 2018 jslaby@suse.cz
- Linux 4.17.8 (bnc#1012628).
- commit 38e4cdc
* Tue Jul 17 2018 tiwai@suse.de
- Update config files: enable CONFIG_I2C_PXA for arm64 (bsc#1101465)
- commit d02f285
* Tue Jul 17 2018 jslaby@suse.cz
- mm: don't do zero_resv_unavail if memmap is not allocated
  (stable fix).
- commit 9c2de41
* Tue Jul 17 2018 jslaby@suse.cz
- Linux 4.17.7 (bnc#1012628).
- bpf: reject passing modified ctx to helper functions
  (bnc#1012628).
- MIPS: Call dump_stack() from show_regs() (bnc#1012628).
- MIPS: Use async IPIs for arch_trigger_cpumask_backtrace()
  (bnc#1012628).
- MIPS: Fix ioremap() RAM check (bnc#1012628).
- drm/etnaviv: Check for platform_device_register_simple()
  failure (bnc#1012628).
- drm/etnaviv: Fix driver unregistering (bnc#1012628).
- drm/etnaviv: bring back progress check in job timeout handler
  (bnc#1012628).
- mmc: sdhci-esdhc-imx: allow 1.8V modes without 100/200MHz
  pinctrl states (bnc#1012628).
- mmc: dw_mmc: fix card threshold control configuration
  (bnc#1012628).
- mmc: renesas_sdhi_internal_dmac: Cannot clear the RX_IN_USE
  in abort (bnc#1012628).
- ibmasm: don't write out of bounds in read handler (bnc#1012628).
- staging: rtl8723bs: Prevent an underflow in
  rtw_check_beacon_data() (bnc#1012628).
- staging: r8822be: Fix RTL8822be can't find any wireless AP
  (bnc#1012628).
- ata: Fix ZBC_OUT command block check (bnc#1012628).
- ata: Fix ZBC_OUT all bit handling (bnc#1012628).
- mei: discard messages from not connected client during power
  down (bnc#1012628).
- mtd: spi-nor: cadence-quadspi: Fix direct mode write timeouts
  (bnc#1012628).
- tracing/kprobe: Release kprobe print_fmt properly (bnc#1012628).
- vmw_balloon: fix inflation with batching (bnc#1012628).
- ahci: Add Intel Ice Lake LP PCI ID (bnc#1012628).
- ahci: Disable LPM on Lenovo 50 series laptops with a too old
  BIOS (bnc#1012628).
- thunderbolt: Notify userspace when boot_acl is changed
  (bnc#1012628).
- USB: serial: ch341: fix type promotion bug in ch341_control_in()
  (bnc#1012628).
- USB: serial: cp210x: add another USB ID for Qivicon ZigBee stick
  (bnc#1012628).
- USB: serial: keyspan_pda: fix modem-status error handling
  (bnc#1012628).
- USB: yurex: fix out-of-bounds uaccess in read handler
  (bnc#1012628).
- USB: serial: mos7840: fix status-register error handling
  (bnc#1012628).
- usb: quirks: add delay quirks for Corsair Strafe (bnc#1012628).
- xhci: xhci-mem: off by one in xhci_stream_id_to_ring()
  (bnc#1012628).
- Fix up non-directory creation in SGID directories (bnc#1012628).
- mm: zero unavailable pages before memmap init (bnc#1012628).
- ALSA: hda/realtek - two more lenovo models need fixup of
  MIC_LOCATION (bnc#1012628).
- ALSA: hda - Handle pm failure during hotplug (bnc#1012628).
- mm: do not drop unused pages when userfaultd is running
  (bnc#1012628).
- fs/proc/task_mmu.c: fix Locked field in /proc/pid/smaps*
  (bnc#1012628).
- x86/purgatory: add missing FORCE to Makefile target
  (bnc#1012628).
- fs, elf: make sure to page align bss in load_elf_library
  (bnc#1012628).
- mm: do not bug_on on incorrect length in __mm_populate()
  (bnc#1012628).
- tracing: Reorder display of TGID to be after PID (bnc#1012628).
- kbuild: delete INSTALL_FW_PATH from kbuild documentation
  (bnc#1012628).
- acpi, nfit: Fix scrub idle detection (bnc#1012628).
- arm64: neon: Fix function may_use_simd() return error status
  (bnc#1012628).
- tools build: fix # escaping in .cmd files for future Make
  (bnc#1012628).
- IB/hfi1: Fix incorrect mixing of ERR_PTR and NULL return values
  (bnc#1012628).
- i2c: tegra: Fix NACK error handling (bnc#1012628).
- i2c: recovery: if possible send STOP with recovery pulses
  (bnc#1012628).
- iw_cxgb4: correctly enforce the max reg_mr depth (bnc#1012628).
- xen: remove global bit from __default_kernel_pte_mask for pv
  guests (bnc#1012628).
- xen: setup pv irq ops vector earlier (bnc#1012628).
- bsg: fix bogus EINVAL on non-data commands (bnc#1012628).
- crypto: x86/salsa20 - remove x86 salsa20 implementations
  (bnc#1012628).
- uprobes/x86: Remove incorrect WARN_ON() in uprobe_init_insn()
  (bnc#1012628).
- netfilter: nf_queue: augment nfqa_cfg_policy (bnc#1012628).
- crypto: don't optimize keccakf() (bnc#1012628).
- netfilter: x_tables: initialise match/target check parameter
  struct (bnc#1012628).
- loop: add recursion validation to LOOP_CHANGE_FD (bnc#1012628).
- xfs: fix inobt magic number check (bnc#1012628).
- PM / hibernate: Fix oops at snapshot_write() (bnc#1012628).
- RDMA/ucm: Mark UCM interface as BROKEN (bnc#1012628).
- loop: remember whether sysfs_create_group() was done
  (bnc#1012628).
- kvm: vmx: Nested VM-entry prereqs for event inj (bnc#1012628).
- f2fs: give message and set need_fsck given broken node id
  (bnc#1012628).
- f2fs: avoid bug_on on corrupted inode (bnc#1012628).
- f2fs: sanity check on sit entry (bnc#1012628).
- f2fs: sanity check for total valid node blocks (bnc#1012628).
- ARM: dts: armada-38x: use the new thermal binding (bnc#1012628).
- commit 7a74fb0
* Mon Jul 16 2018 rgoldwyn@suse.com
- apparmor: patch to provide compatibility with v2.x net rules (bsc#1100944).
- Delete patches.suse/0001-AppArmor-basic-networking-rules.patch.
- Delete
  patches.suse/0002-apparmor-update-apparmor-basic-networking-rules-for-.patch.
- Delete
  patches.suse/0003-apparmor-Fix-quieting-of-audit-messages-for-network-.patch.
- Delete patches.suse/apparmor-check-all-net-profiles.patch.
- commit 1947b35
* Mon Jul 16 2018 msuchanek@suse.de
- Pass x86 as architecture on x86_64 and i386 (bsc#1093118).
- commit 5f24fb0
* Mon Jul 16 2018 msuchanek@suse.de
- Revert "kconfig: only write '# CONFIG_FOO is not set' for
  visible symbols" (bsc#1093118).
- commit 2b9e26a
* Mon Jul 16 2018 mkubecek@suse.cz
- Update to 4.18-rc5
- commit b3f752f
* Wed Jul 11 2018 jslaby@suse.cz
- Linux 4.17.6 (bnc#1012628).
- userfaultfd: hugetlbfs: fix userfaultfd_huge_must_wait()
  pte access (bnc#1012628).
- mm: hugetlb: yield when prepping struct pages (bnc#1012628).
- mm: teach dump_page() to correctly output poisoned struct pages
  (bnc#1012628).
- PCI / ACPI / PM: Resume bridges w/o drivers on suspend-to-RAM
  (bnc#1012628).
- ACPICA: Drop leading newlines from error messages (bnc#1012628).
- ACPI / battery: Safe unregistering of hooks (bnc#1012628).
- drm/amdgpu: Make struct amdgpu_atif private to amdgpu_acpi.c
  (bnc#1012628).
- tracing: Avoid string overflow (bnc#1012628).
- tracing: Fix missing return symbol in function_graph output
  (bnc#1012628).
- scsi: sg: mitigate read/write abuse (bnc#1012628).
- scsi: aacraid: Fix PD performance regression over incorrect
  qd being set (bnc#1012628).
- scsi: target: Fix truncated PR-in ReadKeys response
  (bnc#1012628).
- drbd: fix access after free (bnc#1012628).
- vfio: Use get_user_pages_longterm correctly (bnc#1012628).
- ARM: dts: imx51-zii-rdu1: fix touchscreen pinctrl (bnc#1012628).
- ARM: dts: omap3: Fix am3517 mdio and emac clock references
  (bnc#1012628).
- ARM: dts: dra7: Disable metastability workaround for USB2
  (bnc#1012628).
- cifs: Fix use after free of a mid_q_entry (bnc#1012628).
- cifs: Fix memory leak in smb2_set_ea() (bnc#1012628).
- cifs: Fix slab-out-of-bounds in send_set_info() on SMB2 ACE
  setting (bnc#1012628).
- cifs: Fix infinite loop when using hard mount option
  (bnc#1012628).
- drm: Use kvzalloc for allocating blob property memory
  (bnc#1012628).
- drm/udl: fix display corruption of the last line (bnc#1012628).
- drm/amdgpu: Add amdgpu_atpx_get_dhandle() (bnc#1012628).
- drm/amdgpu: Dynamically probe for ATIF handle (v2)
  (bnc#1012628).
- jbd2: don't mark block as modified if the handle is out of
  credits (bnc#1012628).
- ext4: add corruption check in ext4_xattr_set_entry()
  (bnc#1012628).
- ext4: always verify the magic number in xattr blocks
  (bnc#1012628).
- ext4: make sure bitmaps and the inode table don't overlap with
  bg descriptors (bnc#1012628).
- ext4: always check block group bounds in
  ext4_init_block_bitmap() (bnc#1012628).
- ext4: only look at the bg_flags field if it is valid
  (bnc#1012628).
- ext4: verify the depth of extent tree in ext4_find_extent()
  (bnc#1012628).
- ext4: include the illegal physical block in the bad map
  ext4_error msg (bnc#1012628).
- ext4: clear i_data in ext4_inode_info when removing inline data
  (bnc#1012628).
- ext4: never move the system.data xattr out of the inode body
  (bnc#1012628).
- ext4: avoid running out of journal credits when appending to
  an inline file (bnc#1012628).
- ext4: add more inode number paranoia checks (bnc#1012628).
- ext4: add more mount time checks of the superblock
  (bnc#1012628).
- ext4: check superblock mapped prior to committing (bnc#1012628).
- HID: i2c-hid: Fix "incomplete report" noise (bnc#1012628).
- HID: hiddev: fix potential Spectre v1 (bnc#1012628).
- HID: debug: check length before copy_to_user() (bnc#1012628).
- HID: core: allow concurrent registration of drivers
  (bnc#1012628).
- i2c: core: smbus: fix a potential missing-check bug
  (bnc#1012628).
- i2c: smbus: kill memory leak on emulated and failed DMA SMBus
  xfers (bnc#1012628).
- fs: allow per-device dax status checking for filesystems
  (bnc#1012628).
- dax: change bdev_dax_supported() to support boolean returns
  (bnc#1012628).
- dax: check for QUEUE_FLAG_DAX in bdev_dax_supported()
  (bnc#1012628).
- dm: prevent DAX mounts if not supported (bnc#1012628).
- mtd: cfi_cmdset_0002: Change definition naming to retry write
  operation (bnc#1012628).
- mtd: cfi_cmdset_0002: Change erase functions to retry for error
  (bnc#1012628).
- mtd: cfi_cmdset_0002: Change erase functions to check chip
  good only (bnc#1012628).
- netfilter: nf_log: don't hold nf_log_mutex during user access
  (bnc#1012628).
- staging: comedi: quatech_daqp_cs: fix no-op loop
  daqp_ao_insn_write() (bnc#1012628).
- Revert mm/vmstat.c: fix vmstat_update() preemption BUG
  (bnc#1012628).
- commit 8a8b6ec
* Mon Jul  9 2018 tiwai@suse.de
- alarmtimer: Prevent overflow for relative nanosleep
  (CVE-2018-13053 bsc#1099924).
- commit e98ba10
* Mon Jul  9 2018 mkubecek@suse.cz
- Update to 4.18-rc4
- Eliminated 1 patch
- Config changes:
  - s390x:
  - RSEQ=y
  - DEBUG_REQ=n
- commit 36e98dd
* Mon Jul  9 2018 jslaby@suse.cz
- Linux 4.17.5 (bnc#1012628).
- ARM: dts: imx6q: Use correct SDMA script for SPI5 core
  (bnc#1012628).
- x86/mm: Don't free P4D table when it is folded at runtime
  (bnc#1012628).
- ARM64: dts: meson-gxl-s905x-p212: Add phy-supply for usb0
  (bnc#1012628).
- netfilter: nf_tables: use WARN_ON_ONCE instead of BUG_ON in
  nft_do_chain() (bnc#1012628).
- netfilter: xt_connmark: fix list corruption on rmmod
  (bnc#1012628).
- netfilter: ip6t_rpfilter: provide input interface for route
  lookup (bnc#1012628).
- drm/i915: Enable provoking vertex fix on Gen9 systems
  (bnc#1012628).
- drm/i915: Turn off g4x DP port in .post_disable() (bnc#1012628).
- drm/i915: Disallow interlaced modes on g4x DP outputs
  (bnc#1012628).
- drm/i915: Fix PIPESTAT irq ack on i965/g4x (bnc#1012628).
- drm/i915: Allow DBLSCAN user modes with eDP/LVDS/DSI
  (bnc#1012628).
- drm/amd/display: release spinlock before committing updates
  to stream (bnc#1012628).
- drm/amdgpu: Count disabled CRTCs in commit tail earlier
  (bnc#1012628).
- drm/amdgpu: GPU vs CPU page size fixes in
  amdgpu_vm_bo_split_mapping (bnc#1012628).
- drm/amdgpu: Update pin_size values before unpinning BO
  (bnc#1012628).
- drm/amdgpu: Make amdgpu_vram_mgr_bo_invisible_size always
  accurate (bnc#1012628).
- drm/amdgpu: Refactor amdgpu_vram_mgr_bo_invisible_size helper
  (bnc#1012628).
- drm/amdgpu: Use kvmalloc_array for allocating VRAM manager
  nodes array (bnc#1012628).
- drm/amdgpu: Don't default to DC support for Kaveri and older
  (bnc#1012628).
- Revert "drm/sun4i: Handle DRM_BUS_FLAG_PIXDATA_*EDGE"
  (bnc#1012628).
- drm/atmel-hlcdc: check stride values in the first plane
  (bnc#1012628).
- drm/qxl: Call qxl_bo_unref outside atomic context (bnc#1012628).
- drm/i915/dp: Send DPCD ON for MST before phy_up (bnc#1012628).
- drm/amd/display: Clear connector's edid pointer (bnc#1012628).
- drm/sti: Depend on OF rather than selecting it (bnc#1012628).
- drm/amdgpu: fix clear_all and replace handling in the VM (v2)
  (bnc#1012628).
- drm/amdgpu: Grab/put runtime PM references in
  atomic_commit_tail() (bnc#1012628).
- drm/amdgpu: fix the missed vcn fw version report (bnc#1012628).
- drm/amdgpu: Add APU support in vi_set_vce_clocks (bnc#1012628).
- drm/amdgpu: Add APU support in vi_set_uvd_clocks (bnc#1012628).
- vt: prevent leaking uninitialized data to userspace via
  /dev/vcs* (bnc#1012628).
- serdev: fix memleak on module unload (bnc#1012628).
- serial: 8250_pci: Remove stalled entries in blacklist
  (bnc#1012628).
- iio: mma8452: Fix ignoring MMA8452_INT_DRDY (bnc#1012628).
- staging: android: ion: Return an ERR_PTR in ion_map_kernel
  (bnc#1012628).
- n_tty: Access echo_* variables carefully (bnc#1012628).
- n_tty: Fix stall at n_tty_receive_char_special() (bnc#1012628).
- xhci: Fix kernel oops in trace_xhci_free_virt_device
  (bnc#1012628).
- usb: typec: ucsi: Fix for incorrect status data issue
  (bnc#1012628).
- usb: typec: ucsi: acpi: Workaround for cache mode issue
  (bnc#1012628).
- acpi: Add helper for deactivating memory region (bnc#1012628).
- usb: typec: tcpm: fix logbuffer index is wrong if _tcpm_log
  is re-entered (bnc#1012628).
- usb: dwc2: fix the incorrect bitmaps for the ports of multi_tt
  hub (bnc#1012628).
- USB: serial: cp210x: add Silicon Labs IDs for Windows Update
  (bnc#1012628).
- USB: serial: cp210x: add CESINEL device ids (bnc#1012628).
- usb: cdc_acm: Add quirk for Uniden UBC125 scanner (bnc#1012628).
- commit 3ff6a16
* Mon Jul  9 2018 tiwai@suse.de
- ACPICA: Clear status of all events when entering S5
  (bsc#1099930).
- commit 0c3e49d
* Wed Jul  4 2018 dsterba@suse.com
- Update patches.suse/btrfs-8447-serialize-subvolume-mounts-with-potentially-mi.patch (bsc#951844 bsc#1024015 bsc#1099745).
  Refresh and update for Tumbleweed. No better patch version yet.
- commit dd5896f
* Tue Jul  3 2018 jslaby@suse.cz
- Linux 4.17.4 (bnc#1012628).
- x86/spectre_v1: Disable compiler optimizations over
  array_index_mask_nospec() (bnc#1012628).
- x86/xen: Add call of speculative_store_bypass_ht_init() to PV
  paths (bnc#1012628).
- x86/platform/UV: Add adjustable set memory block size function
  (bnc#1012628).
- x86/platform/UV: Use new set memory block size function
  (bnc#1012628).
- x86/platform/UV: Add kernel parameter to set memory block size
  (bnc#1012628).
- x86/mce: Improve error message when kernel cannot recover
  (bnc#1012628).
- x86/mce: Check for alternate indication of machine check
  recovery on Skylake (bnc#1012628).
- x86/mce: Fix incorrect "Machine check from unknown source"
  message (bnc#1012628).
- x86/mce: Do not overwrite MCi_STATUS in mce_no_way_out()
  (bnc#1012628).
- x86: Call fixup_exception() before notify_die() in math_error()
  (bnc#1012628).
- m68k/mm: Adjust VM area to be unmapped by gap size for
  __iounmap() (bnc#1012628).
- m68k/mac: Fix SWIM memory resource end address (bnc#1012628).
- platform/chrome: cros_ec_lpc: do not try DMI match when ACPI
  device found (bnc#1012628).
- hwmon: (k10temp) Add support for Stoney Ridge and Bristol
  Ridge CPUs (bnc#1012628).
- serial: sh-sci: Use spin_{try}lock_irqsave instead of open
  coding version (bnc#1012628).
- signal/xtensa: Consistenly use SIGBUS in do_unaligned_user
  (bnc#1012628).
- PM / Domains: Fix error path during attach in genpd
  (bnc#1012628).
- PCI / PM: Do not clear state_saved for devices that remain
  suspended (bnc#1012628).
- ACPI / LPSS: Avoid PM quirks on suspend and resume from S3
  (bnc#1012628).
- PM / core: Fix supplier device runtime PM usage counter
  imbalance (bnc#1012628).
- PM / OPP: Update voltage in case freq == old_freq (bnc#1012628).
- mmc: renesas_sdhi: really fix WP logic regressions
  (bnc#1012628).
- usb: do not reset if a low-speed or full-speed device timed out
  (bnc#1012628).
- 1wire: family module autoload fails because of upper/lower
  case mismatch (bnc#1012628).
- ASoC: dapm: delete dapm_kcontrol_data paths list before freeing
  it (bnc#1012628).
- ASoC: cs35l35: Add use_single_rw to regmap config (bnc#1012628).
- ASoC: mediatek: preallocate pages use platform device
  (bnc#1012628).
- ASoC: cirrus: i2s: Fix LRCLK configuration (bnc#1012628).
- ASoC: cirrus: i2s: Fix {TX|RX}LinCtrlData setup (bnc#1012628).
- thermal: bcm2835: Stop using printk format %%pCr (bnc#1012628).
- clk: renesas: cpg-mssr: Stop using printk format %%pCr
  (bnc#1012628).
- lib/vsprintf: Remove atomic-unsafe support for %%pCr
  (bnc#1012628).
- ftrace/selftest: Have the reset_trigger code be a bit more
  careful (bnc#1012628).
- mips: ftrace: fix static function graph tracing (bnc#1012628).
- branch-check: fix long->int truncation when profiling branches
  (bnc#1012628).
- ipmi:bt: Set the timeout before doing a capabilities check
  (bnc#1012628).
- Bluetooth: hci_qca: Avoid missing rampatch failure with
  userspace fw loader (bnc#1012628).
- printk: fix possible reuse of va_list variable (bnc#1012628).
- fuse: fix congested state leak on aborted connections
  (bnc#1012628).
- fuse: atomic_o_trunc should truncate pagecache (bnc#1012628).
- fuse: don't keep dead fuse_conn at fuse_fill_super()
  (bnc#1012628).
- fuse: fix control dir setup and teardown (bnc#1012628).
- powerpc/mm/hash: Add missing isync prior to kernel stack SLB
  switch (bnc#1012628).
- powerpc/pkeys: Detach execute_only key on !PROT_EXEC
  (bnc#1012628).
- powerpc/ptrace: Fix setting 512B aligned breakpoints with
  PTRACE_SET_DEBUGREG (bnc#1012628).
- powerpc/perf: Fix memory allocation for core-imc based on
  num_possible_cpus() (bnc#1012628).
- powerpc/ptrace: Fix enforcement of DAWR constraints
  (bnc#1012628).
- powerpc/powernv/ioda2: Remove redundant free of TCE pages
  (bnc#1012628).
- powerpc/powernv: copy/paste - Mask SO bit in CR (bnc#1012628).
- powerpc/powernv/cpuidle: Init all present cpus for deep states
  (bnc#1012628).
- cpuidle: powernv: Fix promotion from snooze if next state
  disabled (bnc#1012628).
- powerpc/fadump: Unregister fadump on kexec down path
  (bnc#1012628).
- libnvdimm, pmem: Do not flush power-fail protected CPU caches
  (bnc#1012628).
- soc: rockchip: power-domain: Fix wrong value when power up pd
  with writemask (bnc#1012628).
- powerpc/64s/radix: Fix radix_kvm_prefetch_workaround paca
  access of not possible CPU (bnc#1012628).
- powerpc/e500mc: Set assembler machine type to e500mc
  (bnc#1012628).
- powerpc/64s: Fix DT CPU features Power9 DD2.1 logic
  (bnc#1012628).
- cxl: Configure PSL to not use APC virtual machines
  (bnc#1012628).
- cxl: Disable prefault_mode in Radix mode (bnc#1012628).
- ARM: 8764/1: kgdb: fix NUMREGBYTES so that gdb_regs[] is the
  correct size (bnc#1012628).
- ARM: dts: sun8i: h3: fix ALL-H3-CC H3 ver VDD-CPUX voltage
  (bnc#1012628).
- ARM: dts: sun8i: h3: fix ALL-H3-CC H3 ver VCC-1V2 regulator
  voltage (bnc#1012628).
- ARM: dts: Fix SPI node for Arria10 (bnc#1012628).
- ARM: dts: socfpga: Fix NAND controller node compatible
  (bnc#1012628).
- ARM: dts: socfpga: Fix NAND controller clock supply
  (bnc#1012628).
- ARM: dts: socfpga: Fix NAND controller node compatible for
  Arria10 (bnc#1012628).
- hwrng: core - Always drop the RNG in hwrng_unregister()
  (bnc#1012628).
- softirq: Reorder trace_softirqs_on to prevent lockdep splat
  (bnc#1012628).
- arm64: Fix syscall restarting around signal suppressed by tracer
  (bnc#1012628).
- crypto: arm64/aes-blk - fix and move skcipher_walk_done out
  of kernel_neon_begin, _end (bnc#1012628).
- arm64: kpti: Use early_param for kpti= command-line option
  (bnc#1012628).
- arm64: mm: Ensure writes to swapper are ordered wrt subsequent
  cache maintenance (bnc#1012628).
- arm64: dts: marvell: fix CP110 ICU node size (bnc#1012628).
- arm64: dts: stratix10: Fix SPI nodes for Stratix10
  (bnc#1012628).
- ARM64: dts: meson: disable sd-uhs modes on the libretech-cc
  (bnc#1012628).
- ARM64: dts: meson-gx: fix ATF reserved memory region
  (bnc#1012628).
- of: overlay: validate offset from property fixups (bnc#1012628).
- of: unittest: for strings, account for trailing \0 in property
  length field (bnc#1012628).
- of: platform: stop accessing invalid dev in
  of_platform_device_destroy (bnc#1012628).
- tpm: fix use after free in tpm2_load_context() (bnc#1012628).
- tpm: fix race condition in tpm_common_write() (bnc#1012628).
- efi/libstub/tpm: Initialize efi_physical_addr_t vars to zero
  for mixed mode (bnc#1012628).
- IB/qib: Fix DMA api warning with debug kernel (bnc#1012628).
- IB/{hfi1, qib}: Add handling of kernel restart (bnc#1012628).
- IB/mlx4: Mark user MR as writable if actual virtual memory is
  writable (bnc#1012628).
- IB/core: Make testing MR flags for writability a static inline
  function (bnc#1012628).
- IB/mlx5: Fetch soft WQE's on fatal error state (bnc#1012628).
- IB/isert: Fix for lib/dma_debug check_sync warning
  (bnc#1012628).
- IB/isert: fix T10-pi check mask setting (bnc#1012628).
- IB/hfi1: Fix fault injection init/exit issues (bnc#1012628).
- IB/hfi1: Reorder incorrect send context disable (bnc#1012628).
- IB/hfi1: Optimize kthread pointer locking when queuing CQ
  entries (bnc#1012628).
- IB/hfi1: Fix user context tail allocation for DMA_RTAIL
  (bnc#1012628).
- IB/uverbs: Fix ordering of ucontext check in ib_uverbs_write
  (bnc#1012628).
- RDMA/mlx4: Discard unknown SQP work requests (bnc#1012628).
- xprtrdma: Return -ENOBUFS when no pages are available
  (bnc#1012628).
- RDMA/core: Save kernel caller name when creating CQ using
  ib_create_cq() (bnc#1012628).
- mtd: rawnand: Do not check FAIL bit when executing a
  SET_FEATURES op (bnc#1012628).
- mtd: cfi_cmdset_0002: Change write buffer to check correct value
  (bnc#1012628).
- mtd: rawnand: denali_dt: set clk_x_rate to 200 MHz
  unconditionally (bnc#1012628).
- mtd: rawnand: fix return value check for bad block status
  (bnc#1012628).
- mtd: rawnand: mxc: set spare area size register explicitly
  (bnc#1012628).
- mtd: rawnand: micron: add ONFI_FEATURE_ON_DIE_ECC to supported
  features (bnc#1012628).
- mtd: rawnand: All AC chips have a broken GET_FEATURES(TIMINGS)
  (bnc#1012628).
- mtd: cfi_cmdset_0002: Use right chip in do_ppb_xxlock()
  (bnc#1012628).
- mtd: cfi_cmdset_0002: fix SEGV unlocking multiple chips
  (bnc#1012628).
- mtd: cfi_cmdset_0002: Fix unlocking requests crossing a chip
  boudary (bnc#1012628).
- mtd: cfi_cmdset_0002: Avoid walking all chips when unlocking
  (bnc#1012628).
- MIPS: BCM47XX: Enable 74K Core ExternalSync for PCIe erratum
  (bnc#1012628).
- clk:aspeed: Fix reset bits for PCI/VGA and PECI (bnc#1012628).
- PCI: hv: Make sure the bus domain is really unique
  (bnc#1012628).
- PCI: Add ACS quirk for Intel 7th & 8th Gen mobile (bnc#1012628).
- PCI: Add ACS quirk for Intel 300 series (bnc#1012628).
- PCI: pciehp: Clear Presence Detect and Data Link Layer Status
  Changed on resume (bnc#1012628).
- PCI: Account for all bridges on bus when distributing bus
  numbers (bnc#1012628).
- auxdisplay: fix broken menu (bnc#1012628).
- pinctrl: armada-37xx: Fix spurious irq management (bnc#1012628).
- pinctrl: samsung: Correct EINTG banks order (bnc#1012628).
- pinctrl: devicetree: Fix pctldev pointer overwrite
  (bnc#1012628).
- cpufreq: intel_pstate: Fix scaling max/min limits with Turbo
  3.0 (bnc#1012628).
- MIPS: pb44: Fix i2c-gpio GPIO descriptor table (bnc#1012628).
- MIPS: io: Add barrier after register read in inX()
  (bnc#1012628).
- time: Make sure jiffies_to_msecs() preserves non-zero time
  periods (bnc#1012628).
- irqchip/gic-v3-its: Don't bind LPI to unavailable NUMA node
  (bnc#1012628).
- locking/rwsem: Fix up_read_non_owner() warning with DEBUG_RWSEMS
  (bnc#1012628).
- X.509: unpack RSA signatureValue field from BIT STRING
  (bnc#1012628).
- Btrfs: fix return value on rename exchange failure
  (bnc#1012628).
- iio: adc: ad7791: remove sample freq sysfs attributes
  (bnc#1012628).
- iio: sca3000: Fix an error handling path in 'sca3000_probe()'
  (bnc#1012628).
- mm: fix __gup_device_huge vs unmap (bnc#1012628).
- scsi: scsi_debug: Fix memory leak on module unload
  (bnc#1012628).
- scsi: hpsa: disable device during shutdown (bnc#1012628).
- scsi: qla2xxx: Delete session for nport id change (bnc#1012628).
- scsi: qla2xxx: Fix setting lower transfer speed if GPSC fails
  (bnc#1012628).
- scsi: qla2xxx: Mask off Scope bits in retry delay (bnc#1012628).
- scsi: qla2xxx: Spinlock recursion in qla_target (bnc#1012628).
- scsi: zfcp: fix missing SCSI trace for result of
  eh_host_reset_handler (bnc#1012628).
- scsi: zfcp: fix missing SCSI trace for retry of abort /
  scsi_eh TMF (bnc#1012628).
- scsi: zfcp: fix misleading REC trigger trace where erp_action
  setup failed (bnc#1012628).
- scsi: zfcp: fix missing REC trigger trace on terminate_rport_io
  early return (bnc#1012628).
- scsi: zfcp: fix missing REC trigger trace on terminate_rport_io
  for ERP_FAILED (bnc#1012628).
- scsi: zfcp: fix missing REC trigger trace for all objects in
  ERP_FAILED (bnc#1012628).
- scsi: zfcp: fix missing REC trigger trace on enqueue without
  ERP thread (bnc#1012628).
- linvdimm, pmem: Preserve read-only setting for pmem devices
  (bnc#1012628).
- libnvdimm, pmem: Unconditionally deep flush on *sync
  (bnc#1012628).
- clk: meson: meson8b: mark fclk_div2 gate clocks as
  CLK_IS_CRITICAL (bnc#1012628).
- clk: at91: PLL recalc_rate() now using cached MUL and DIV values
  (bnc#1012628).
- rtc: sun6i: Fix bit_idx value for clk_register_gate
  (bnc#1012628).
- md: fix two problems with setting the "re-add" device state
  (bnc#1012628).
- rpmsg: smd: do not use mananged resources for endpoints and
  channels (bnc#1012628).
- ubi: fastmap: Cancel work upon detach (bnc#1012628).
- ubi: fastmap: Correctly handle interrupted erasures in EBA
  (bnc#1012628).
- UBIFS: Fix potential integer overflow in allocation
  (bnc#1012628).
- backlight: as3711_bl: Fix Device Tree node lookup (bnc#1012628).
- backlight: max8925_bl: Fix Device Tree node lookup
  (bnc#1012628).
- backlight: tps65217_bl: Fix Device Tree node lookup
  (bnc#1012628).
- Revert "iommu/amd_iommu: Use CONFIG_DMA_DIRECT_OPS=y and
  dma_direct_{alloc,free}()" (bnc#1012628).
- f2fs: don't use GFP_ZERO for page caches (bnc#1012628).
- um: Fix initialization of vector queues (bnc#1012628).
- um: Fix raw interface options (bnc#1012628).
- mfd: twl-core: Fix clock initialization (bnc#1012628).
- mfd: intel-lpss: Program REMAP register in PIO mode
  (bnc#1012628).
- mfd: intel-lpss: Fix Intel Cannon Lake LPSS I2C input clock
  (bnc#1012628).
- remoteproc: Prevent incorrect rproc state on xfer mem ownership
  failure (bnc#1012628).
- arm: dts: mt7623: fix invalid memory node being generated
  (bnc#1012628).
- perf tools: Fix symbol and object code resolution for vdso32
  and vdsox32 (bnc#1012628).
- perf intel-pt: Fix sync_switch INTEL_PT_SS_NOT_TRACING
  (bnc#1012628).
- perf intel-pt: Fix decoding to accept CBR between FUP and
  corresponding TIP (bnc#1012628).
- perf intel-pt: Fix MTC timing after overflow (bnc#1012628).
- perf intel-pt: Fix "Unexpected indirect branch" error
  (bnc#1012628).
- perf intel-pt: Fix packet decoding of CYC packets (bnc#1012628).
- media: vsp1: Release buffers for each video node (bnc#1012628).
- media: cx231xx: Ignore an i2c mux adapter (bnc#1012628).
- media: v4l2-compat-ioctl32: prevent go past max size
  (bnc#1012628).
- media: cx231xx: Add support for AverMedia DVD EZMaker 7
  (bnc#1012628).
- media: rc: mce_kbd decoder: fix stuck keys (bnc#1012628).
- media: dvb_frontend: fix locking issues at
  dvb_frontend_get_event() (bnc#1012628).
- nfsd: restrict rd_maxcount to svc_max_payload in
  nfsd_encode_readdir (bnc#1012628).
- NFSv4: Fix possible 1-byte stack overflow in
  nfs_idmap_read_and_verify_message (bnc#1012628).
- NFSv4: Revert commit 5f83d86cf531d ("NFSv4.x: Fix wraparound
  issues..") (bnc#1012628).
- NFSv4: Fix a typo in nfs41_sequence_process (bnc#1012628).
- video: uvesafb: Fix integer overflow in allocation
  (bnc#1012628).
- ACPI / LPSS: Add missing prv_offset setting for byt/cht PWM
  devices (bnc#1012628).
- Input: silead - add MSSL0002 ACPI HID (bnc#1012628).
- Input: elan_i2c - add ELAN0618 (Lenovo v330 15IKB) ACPI ID
  (bnc#1012628).
- pwm: lpss: platform: Save/restore the ctrl register over a
  suspend/resume (bnc#1012628).
- rbd: flush rbd_dev->watch_dwork after watch is unregistered
  (bnc#1012628).
- mm/ksm.c: ignore STABLE_FLAG of rmap_item->address in
  rmap_walk_ksm() (bnc#1012628).
- mm: fix devmem_is_allowed() for sub-page System RAM
  intersections (bnc#1012628).
- xen: Remove unnecessary BUG_ON from __unbind_from_irq()
  (bnc#1012628).
- net: ethernet: fix suspend/resume in davinci_emac (bnc#1012628).
- udf: Detect incorrect directory size (bnc#1012628).
- Input: xpad - fix GPD Win 2 controller name (bnc#1012628).
- Input: elan_i2c_smbus - fix more potential stack buffer
  overflows (bnc#1012628).
- Input: elantech - enable middle button of touchpads on ThinkPad
  P52 (bnc#1012628).
- Input: elantech - fix V4 report decoding for module with middle
  key (bnc#1012628).
- ALSA: timer: Fix UBSAN warning at SNDRV_TIMER_IOCTL_NEXT_DEVICE
  ioctl (bnc#1012628).
- ALSA: hda - Force to link down at runtime suspend on ATI/AMD
  HDMI (bnc#1012628).
- ALSA: hda/realtek - Fix pop noise on Lenovo P50 & co
  (bnc#1012628).
- ALSA: hda/realtek - Add a quirk for FSC ESPRIMO U9210
  (bnc#1012628).
- ALSA: hda/realtek - Fix the problem of two front mics on more
  machines (bnc#1012628).
- Revert "i2c: algo-bit: init the bus to a known state"
  (bnc#1012628).
- i2c: gpio: initialize SCL to HIGH again (bnc#1012628).
- slub: fix failure when we delete and create a slab cache
  (bnc#1012628).
- kasan: depend on CONFIG_SLUB_DEBUG (bnc#1012628).
- dm: use bio_split() when splitting out the already processed
  bio (bnc#1012628).
- pmem: only set QUEUE_FLAG_DAX for fsdax mode (bnc#1012628).
- block: Fix transfer when chunk sectors exceeds max
  (bnc#1012628).
- block: Fix cloning of requests with a special payload
  (bnc#1012628).
- x86/e820: put !E820_TYPE_RAM regions into memblock.reserved
  (bnc#1012628).
- selinux: move user accesses in selinuxfs out of locked regions
  (bnc#1012628).
- x86/entry/64/compat: Fix "x86/entry/64/compat: Preserve r8-r11
  in int $0x80" (bnc#1012628).
- x86/efi: Fix efi_call_phys_epilog() with CONFIG_X86_5LEVEL=y
  (bnc#1012628).
- dm zoned: avoid triggering reclaim from inside dmz_map()
  (bnc#1012628).
- dm thin: handle running out of data space vs concurrent discard
  (bnc#1012628).
- virt: vbox: Only copy_from_user the request-header once
  (bnc#1012628).
- commit 882c99b
* Mon Jul  2 2018 mkubecek@suse.cz
- Update to 4.18-rc3
- Eliminated 6 patches
- Config changes:
  - Input:
  - INPUT_SC27XX_VIBRA=m (aarch64 only)
- commit d44a642
* Fri Jun 29 2018 jslaby@suse.cz
- Refresh
  patches.suse/input-psmouse-fix-button-reporting-for-basic-protoco.patch.
  Update upstream status.
- commit 3037396
* Wed Jun 27 2018 mkubecek@suse.cz
- bpf: enforce correct alignment for instructions (bsc#1099078).
- commit 55e3263
* Tue Jun 26 2018 tiwai@suse.de
- media: uvcvideo: Support realtek's UVC 1.5 device (bsc#1099109).
- commit 7c619f0
* Tue Jun 26 2018 tiwai@suse.de
- tracing: Check for no filter when processing event filters
  (CVE-2018-12714,bsc#1098933).
- commit 5b8d655
* Tue Jun 26 2018 jslaby@suse.cz
- Linux 4.17.3 (bnc#1012628).
- net: aquantia: fix unsigned numvecs comparison with less than
  zero (bnc#1012628).
- bonding: re-evaluate force_primary when the primary slave name
  changes (bnc#1012628).
- cdc_ncm: avoid padding beyond end of skb (bnc#1012628).
- ipv6: allow PMTU exceptions to local routes (bnc#1012628).
- net: dsa: add error handling for pskb_trim_rcsum (bnc#1012628).
- net: phy: dp83822: use BMCR_ANENABLE instead of BMSR_ANEGCAPABLE
  for DP83620 (bnc#1012628).
- net/sched: act_simple: fix parsing of TCA_DEF_DATA
  (bnc#1012628).
- tcp: verify the checksum of the first data segment in a new
  connection (bnc#1012628).
- tls: fix use-after-free in tls_push_record (bnc#1012628).
- tls: fix waitall behavior in tls_sw_recvmsg (bnc#1012628).
- udp: fix rx queue len reported by diag and proc interface
  (bnc#1012628).
- net: in virtio_net_hdr only add VLAN_HLEN to csum_start if
  payload holds vlan (bnc#1012628).
- hv_netvsc: Fix a network regression after ifdown/ifup
  (bnc#1012628).
- ext4: fix hole length detection in ext4_ind_map_blocks()
  (bnc#1012628).
- ext4: update mtime in ext4_punch_hole even if no blocks are
  released (bnc#1012628).
- ext4: do not allow external inodes for inline data
  (bnc#1012628).
- ext4: bubble errors from ext4_find_inline_data_nolock() up to
  ext4_iget() (bnc#1012628).
- ext4: correctly handle a zero-length xattr with a non-zero
  e_value_offs (bnc#1012628).
- ext4: fix fencepost error in check for inode count overflow
  during resize (bnc#1012628).
- driver core: Don't ignore class_dir_create_and_add() failure
  (bnc#1012628).
- Btrfs: allow empty subvol= again (bnc#1012628).
- Btrfs: fix clone vs chattr NODATASUM race (bnc#1012628).
- Btrfs: fix memory and mount leak in btrfs_ioctl_rm_dev_v2()
  (bnc#1012628).
- btrfs: return error value if create_io_em failed in
  cow_file_range (bnc#1012628).
- btrfs: scrub: Don't use inode pages for device replace
  (bnc#1012628).
- ALSA: usb-audio: Disable the quirk for Nura headset
  (bnc#1012628).
- ALSA: hda/realtek - Enable mic-mute hotkey for several Lenovo
  AIOs (bnc#1012628).
- ALSA: hda/conexant - Add fixup for HP Z2 G4 workstation
  (bnc#1012628).
- ALSA: hda - Handle kzalloc() failure in
  snd_hda_attach_pcm_stream() (bnc#1012628).
- ALSA: hda: add dock and led support for HP EliteBook 830 G5
  (bnc#1012628).
- ALSA: hda: add dock and led support for HP ProBook 640 G4
  (bnc#1012628).
- x86/MCE: Fix stack out-of-bounds write in mce-inject.c:
  Flags_read() (bnc#1012628).
- smb3: fix various xid leaks (bnc#1012628).
- smb3: on reconnect set PreviousSessionId field (bnc#1012628).
- CIFS: 511c54a2f69195b28afb9dd119f03787b1625bb4 adds a check
  for session expiry (bnc#1012628).
- cifs: For SMB2 security informaion query, check for minimum
  sized security descriptor instead of sizeof FileAllInformation
  class (bnc#1012628).
- nbd: fix nbd device deletion (bnc#1012628).
- nbd: update size when connected (bnc#1012628).
- nbd: use bd_set_size when updating disk size (bnc#1012628).
- blk-mq: reinit q->tag_set_list entry only after grace period
  (bnc#1012628).
- bdi: Move cgroup bdi_writeback to a dedicated low concurrency
  workqueue (bnc#1012628).
- cpufreq: Fix new policy initialization during limits updates
  via sysfs (bnc#1012628).
- cpufreq: ti-cpufreq: Fix an incorrect error return value
  (bnc#1012628).
- cpufreq: governors: Fix long idle detection logic in load
  calculation (bnc#1012628).
- libata: zpodd: small read overflow in eject_tray()
  (bnc#1012628).
- libata: Drop SanDisk SD7UB3Q*G1001 NOLPM quirk (bnc#1012628).
- nvme/pci: Sync controller reset for AER slot_reset
  (bnc#1012628).
- w1: mxc_w1: Enable clock before calling clk_get_rate() on it
  (bnc#1012628).
- x86/vector: Fix the args of vector_alloc tracepoint
  (bnc#1012628).
- x86/apic/vector: Prevent hlist corruption and leaks
  (bnc#1012628).
- x86/apic: Provide apic_ack_irq() (bnc#1012628).
- x86/ioapic: Use apic_ack_irq() (bnc#1012628).
- x86/platform/uv: Use apic_ack_irq() (bnc#1012628).
- irq_remapping: Use apic_ack_irq() (bnc#1012628).
- genirq/generic_pending: Do not lose pending affinity update
  (bnc#1012628).
- genirq/affinity: Defer affinity setting if irq chip is busy
  (bnc#1012628).
- genirq/migration: Avoid out of line call if pending is not set
  (bnc#1012628).
- x86/intel_rdt: Enable CMT and MBM on new Skylake stepping
  (bnc#1012628).
- media: uvcvideo: Prevent setting unavailable flags
  (bnc#1012628).
- media: rc: ensure input/lirc device can be opened after register
  (bnc#1012628).
- iwlwifi: fw: harden page loading code (bnc#1012628).
- orangefs: set i_size on new symlink (bnc#1012628).
- orangefs: report attributes_mask and attributes for statx
  (bnc#1012628).
- HID: intel_ish-hid: ipc: register more pm callbacks to support
  hibernation (bnc#1012628).
- HID: wacom: Correct logical maximum Y for 2nd-gen Intuos Pro
  large (bnc#1012628).
- fs/binfmt_misc.c: do not allow offset overflow (bnc#1012628).
- mm, page_alloc: do not break __GFP_THISNODE by zonelist reset
  (bnc#1012628).
- commit e8dc1b5
* Tue Jun 26 2018 tiwai@suse.de
- platform/x86: ideapad-laptop: Apply no_hw_rfkill to Y20-15IKBM,
  too (bsc#1098626).
- commit 0d1073f
* Mon Jun 25 2018 jslaby@suse.cz
- Input: psmouse - fix button reporting for basic protocols
  (bnc#1098392).
- commit 7faa585
* Mon Jun 25 2018 msuchanek@suse.de
- rpm/kernel-source.changes.old: Add pre-SLE15 history (bsc#1098995).
- commit 631659e
* Mon Jun 25 2018 msuchanek@suse.de
- Refresh patches.suse/s390-fix-random-crashes-illegal-operation-0001-ilc-1.patch.
- commit ff0a7a4
* Mon Jun 25 2018 bp@suse.de
- vhost: fix info leak due to uninitialized memory (bsc#1092472
  CVE-2018-1118).
- commit 7372950
* Sun Jun 24 2018 mkubecek@suse.cz
- Update to 4.18-rc2
- Eliminated 1 patch
- Config changes:
  - aarch64: reenable DWMAC_SOCFPGA (=m)
- commit cc9e91e
* Sun Jun 24 2018 afaerber@suse.de
- config: arm64: Update to 4.18-rc1
- commit b301d60
* Sat Jun 23 2018 mkubecek@suse.cz
- proc: fix missing final NUL in get_mm_cmdline() rewrite
  (https://www.mail-archive.com/linux-kernel@vger.kernel.org/msg1715032.html).
- commit f348790
* Sat Jun 23 2018 mkubecek@suse.cz
- Documentation: e1000: Fix docs build error.
- Documentation: e100: Fix docs build error.
- Documentation: e1000: Use correct heading adornment.
- Documentation: e100: Use correct heading adornment.
- commit 95284f7
* Sat Jun 23 2018 jslaby@suse.cz
- x86/stacktrace: Do not unwind after user regs (bnc#1058115).
- x86/stacktrace: Remove STACKTRACE_DUMP_ONCE (bnc#1058115).
- x86/stacktrace: Clarify the reliable success paths
  (bnc#1058115).
- x86/stacktrace: Do not fail for ORC with regs on stack
  (bnc#1058115).
- x86/unwind/orc: Detect the end of the stack (bnc#1058115).
- x86/stacktrace: Enable HAVE_RELIABLE_STACKTRACE for the ORC
  unwinder (bnc#1058115).
- Delete
  patches.suse/0001-x86-stacktrace-do-now-unwind-after-user-regs.patch.
- Delete
  patches.suse/0002-x86-stacktrace-make-clear-the-success-paths.patch.
- Delete
  patches.suse/0003-x86-stacktrace-remove-STACKTRACE_DUMP_ONCE-from-__sa.patch.
- Delete
  patches.suse/0004-x86-stacktrace-do-not-fail-for-ORC-with-regs-on-stac.patch.
- Delete
  patches.suse/0005-x86-stacktrace-orc-mark-it-as-reliable.patch.
  Replace the ORC patches by the upstream patches. Finally...
- commit 33a2d86
* Thu Jun 21 2018 msuchanek@suse.de
- s390: Correct register corruption in critical section cleanup
  (boo#1095717).
- commit 4594a9e
* Wed Jun 20 2018 tiwai@suse.de
- ACPICA: AML parser: attempt to continue loading table after
  error (bsc#1098074).
- commit fc39d10
* Mon Jun 18 2018 msuchanek@suse.de
- macros.kernel-source: define linux_arch for KMPs (boo#1098050).
  CONFIG_64BIT is no longer defined so KMP spec files need to include
  %%{?linux_make_arch} in any make call to build modules or descent into
  the kernel directory for any reason.
- commit 5dc40af
* Mon Jun 18 2018 mkubecek@suse.cz
- config: update ppc64le configs
- commit fa9e020
* Mon Jun 18 2018 mkubecek@suse.cz
- config: enable NETDEVSIM (as module)
- commit e218eff
* Mon Jun 18 2018 mkubecek@suse.cz
- Update to 4.18-rc1.
- Eliminated 66 patches (62 stable, 4 other).
- ARM configs need updating.
- Config changes:
  - General:
  - RSEQ=y
  - i386:
  - BPF_JIT=y
  - BPF_JIT_ALWAYS_ON=y
  - powerpc:
  - LD_DEAD_CODE_DATA_ELIMINATION=n (experimental)
  - s390:
  - FW_LOADER_USER_HELPER=y
  - PCI:
  - PCI_HOST_GENERIC=y
  - Network:
  - TLS_DEVICE=y
  - XDP_SOCKETS=y
  - NFT_CONNLIMIT=m
  - NFT_SOCKET=m
  - IP_VS_MH=m
  - IP_VS_MH_TAB_INDEX=12 (default)
  - NF_TPROXY_IPV4=m
  - NF_TPROXY_IPV6=m
  - BPFILTER=y
  - BPFILTER_UMH=m
  - FAILOVER=m
  - MLX5_EN_TLS=y
  - NET_VENDOR_MICROSEMI=y
  - MSCC_OCELOT_SWITCH=m
  - MSCC_OCELOT_SWITCH_OCELOT=m
  - NFP_APP_ABM_NIC=y
  - MDIO_MSCC_MIIM=m
  - ASIX_PHY=m
  - DP83TC811_PHY=m
  - MICROCHIP_T1_PHY=m
  - NET_FAILOVER=m
  - Block:
  - DM_WRITECACHE=m
  - Input:
  - MOUSE_PS2_ELANTECH_SMBUS=y
  - TOUCHSCREEN_CHIPONE_ICN8505=m
  - HID_STEAM=m
  - Misc:
  - SPI_MEM=y
  - GPIOLIB_FASTPATH_LIMIT=512 (default)
  - VIDEO_CADENCE=y
  - LCD_OTM3225A=n
  - CHROMEOS_TBMC=m
  - FPGA_MGR_MACHXO2_SPI=m
  - Graphics:
  - DRM_I2C_NXP_TDA9950=m
  - DRM_I915_DEBUG_GUC=n
  - DRM_CDNS_DSI=n
  - DRM_THINE_THC63LVD1024=n
  - DRM_XEN=y
  - DRM_XEN_FRONTEND=m
  - Sound:
  - SND_SOC_SSM2305=n
  - SND_SOC_TSCS454=n
  - SND_SOC_WM8782=n
  - SND_SOC_MT6351=n
  - SND_XEN_FRONTEND=m
  - LED:
  - LEDS_CR0014114=m
  - LEDS_LM3601X=m
  - USB:
  - TYPEC_RT1711H=m
  - IIO:
  - AD5686_SPI=n
  - AD5696_I2C=n
  - TI_DAC5571=n
  - TSL2772=n
  - IIO_RESCALE=n
  - Filesystems:
  - PROC_VMCORE_DEVICE_DUMP=y
  - EVM_ADD_XATTRS=y
  - Testing:
  - TEST_OVERFLOW=n
  - Crypto:
  - CRYPTO_AEGIS128=m
  - CRYPTO_AEGIS128L=m
  - CRYPTO_AEGIS256=m
  - CRYPTO_AEGIS128_AESNI_SSE2=m
  - CRYPTO_AEGIS128L_AESNI_SSE2=m
  - CRYPTO_AEGIS256_AESNI_SSE2=m
  - CRYPTO_MORUS640=m
  - CRYPTO_MORUS640_SSE2=m
  - CRYPTO_MORUS1280=m
  - CRYPTO_MORUS1280_SSE2=m
  - CRYPTO_MORUS1280_AVX2=m
  - CRYPTO_ZSTD=m
- commit 549a5bb
* Mon Jun 18 2018 mkubecek@suse.cz
- rpm: ignore CONFIG_GCC_VERSION when checking for oldconfig changes
  Since 4.18-rc1, "make oldconfig" writes gcc version and capabilities into
  generated .config. Thus whenever we build the package or run checks with
  different gcc version than used to update config/*/*, check for "outdated
  configs" fails.
  As a quick band-aid, omit the lines with CONFIG_GCC_VERSION from both
  configs before comparing them. This way, the check won't fail unless run
  with newer gcc which would add new capabilities. More robust solution will
  require a wider discussion.
- commit 546ef32
* Sat Jun 16 2018 jslaby@suse.cz
- Revert "mm: relax deferred struct page requirements"
  (bnc#1092466).
- Update config files.
- commit 802b05f
* Sat Jun 16 2018 jslaby@suse.cz
- Linux 4.17.2 (bnc#1012628).
- crypto: omap-sham - fix memleak (bnc#1012628).
- crypto: vmx - Remove overly verbose printk from AES XTS init
  (bnc#1012628).
- crypto: vmx - Remove overly verbose printk from AES init
  routines (bnc#1012628).
- crypto: cavium - Limit result reading attempts (bnc#1012628).
- crypto: cavium - Fix fallout from CONFIG_VMAP_STACK
  (bnc#1012628).
- crypto: caam - fix size of RSA prime factor q (bnc#1012628).
- crypto: caam/qi - fix IV DMA mapping and updating (bnc#1012628).
- crypto: caam - fix IV DMA mapping and updating (bnc#1012628).
- crypto: caam - fix DMA mapping dir for generated IV
  (bnc#1012628).
- crypto: caam - strip input zeros from RSA input buffer
  (bnc#1012628).
- Input: elan_i2c - add ELAN0612 (Lenovo v330 14IKB) ACPI ID
  (bnc#1012628).
- Input: goodix - add new ACPI id for GPD Win 2 touch screen
  (bnc#1012628).
- crypto: ccree - correct host regs offset (bnc#1012628).
- tty: pl011: Avoid spuriously stuck-off interrupts (bnc#1012628).
- arm64: defconfig: Enable CONFIG_PINCTRL_MT7622 by default
  (bnc#1012628).
- doc: fix sysfs ABI documentation (bnc#1012628).
- vmw_balloon: fixing double free when batching mode is off
  (bnc#1012628).
- serial: 8250: omap: Fix idling of clocks for unused uarts
  (bnc#1012628).
- serial: samsung: fix maxburst parameter for DMA transactions
  (bnc#1012628).
- tty/serial: atmel: use port->name as name in request_irq()
  (bnc#1012628).
- serial: sh-sci: Stop using printk format %%pCr (bnc#1012628).
- usb: gadget: udc: renesas_usb3: disable the controller's irqs
  for reconnecting (bnc#1012628).
- usb: gadget: udc: renesas_usb3: should fail if devm_phy_get()
  returns error (bnc#1012628).
- usb: gadget: udc: renesas_usb3: should call devm_phy_get()
  before add udc (bnc#1012628).
- usb: gadget: udc: renesas_usb3: should call pm_runtime_enable()
  before add udc (bnc#1012628).
- usb: gadget: udc: renesas_usb3: should remove debugfs
  (bnc#1012628).
- usb: gadget: udc: renesas_usb3: fix double phy_put()
  (bnc#1012628).
- usb: gadget: function: printer: avoid wrong list handling in
  printer_write() (bnc#1012628).
- usb: typec: wcove: Remove dependency on HW FSM (bnc#1012628).
- usb: core: message: remove extra endianness conversion in
  usb_set_isoch_delay (bnc#1012628).
- phy: qcom-qusb2: Fix crash if nvmem cell not specified
  (bnc#1012628).
- Input: xpad - add GPD Win 2 Controller USB IDs (bnc#1012628).
- usb-storage: Add compatibility quirk flags for G-Technologies
  G-Drive (bnc#1012628).
- usb-storage: Add support for FL_ALWAYS_SYNC flag in the UAS
  driver (bnc#1012628).
- usbip: vhci_sysfs: fix potential Spectre v1 (bnc#1012628).
- NFC: pn533: don't send USB data off of the stack (bnc#1012628).
- staging: android: ion: Switch to pr_warn_once in
  ion_buffer_destroy (bnc#1012628).
- kvm: x86: use correct privilege level for
  sgdt/sidt/fxsave/fxrstor access (bnc#1012628).
- KVM: x86: pass kvm_vcpu to kvm_read_guest_virt and
  kvm_write_guest_virt_system (bnc#1012628).
- kvm: nVMX: Enforce cpl=0 for VMX instructions (bnc#1012628).
- kvm: fix typo in flag name (bnc#1012628).
- KVM: x86: introduce linear_{read,write}_system (bnc#1012628).
- KVM: X86: Fix reserved bits check for MOV to CR3 (bnc#1012628).
- blkdev_report_zones_ioctl(): Use vmalloc() to allocate large
  buffers (bnc#1012628).
- crypto: chelsio - request to HW should wrap (bnc#1012628).
- commit 202985c
* Thu Jun 14 2018 mkubecek@suse.cz
- socket: close race condition between sock_close() and
  sockfs_setattr() (CVE-2018-12232 bsc#1097593).
- commit 94bf968
* Thu Jun 14 2018 jslaby@suse.cz
- config.conf: disable syzkaller
  I doubt anybody else (other than me) uses the flavor, so save a lot of
  build resources by this. Leaving syzkaller configs and stuff in place
  so people still can build it if they want.
  The build is currently broken, so this "fixes" it too:
  ERROR: "__sanitizer_cov_trace_cmpd" [drivers/gpu/drm/amd/amdgpu/amdgpu.ko] undefined!
  ERROR: "__sanitizer_cov_trace_cmpf" [drivers/gpu/drm/amd/amdgpu/amdgpu.ko] undefined!
- commit bdee95f
* Tue Jun 12 2018 jslaby@suse.cz
- Linux 4.17.1 (bnc#1012628).
- netfilter: nf_flow_table: attach dst to skbs (bnc#1012628).
- bnx2x: use the right constant (bnc#1012628).
- ip6mr: only set ip6mr_table from setsockopt when ip6mr_new_table
  succeeds (bnc#1012628).
- ipv6: omit traffic class when calculating flow hash (bnc#1012628
  bsc#1095042).
- l2tp: fix refcount leakage on PPPoL2TP sockets (bnc#1012628).
- netdev-FAQ: clarify DaveM's position for stable backports
  (bnc#1012628).
- net: metrics: add proper netlink validation (bnc#1012628).
- net/packet: refine check for priv area size (bnc#1012628).
- rtnetlink: validate attributes in do_setlink() (bnc#1012628).
- sctp: not allow transport timeout value less than HZ/5 for
  hb_timer (bnc#1012628).
- team: use netdev_features_t instead of u32 (bnc#1012628).
- vrf: check the original netdevice for generating redirect
  (bnc#1012628).
- net: dsa: b53: Fix for brcm tag issue in Cygnus SoC
  (bnc#1012628).
- ipmr: fix error path when ipmr_new_table fails (bnc#1012628).
- PCI: hv: Do not wait forever on a device that has disappeared
  (bnc#1012628).
- Delete
  patches.suse/ipv6-omit-traffic-class-when-calculating-flow-hash.patch.
- commit 17c8abe
* Fri Jun  8 2018 tiwai@suse.de
- mtd: spi-nor: intel-spi: Fix atomic sequence handling
  (bsc#1073836).
- commit c31c53d
* Fri Jun  8 2018 mkubecek@suse.cz
- ipv6: omit traffic class when calculating flow hash
  (bsc#1095042).
- commit 1307c29
* Fri Jun  8 2018 tiwai@suse.de
- Delete patches.suse/iwlwifi-expose-default-fallback-ucode-api.
  The workaround is no longer needed as the upstream driver code catches
  up the actual firmware version
- commit d6e069d
* Fri Jun  8 2018 tiwai@suse.de
- Update patch tag of the upstreamed btusb fix
- commit f531f64
* Mon Jun  4 2018 mkubecek@suse.cz
- config: enable preemption in i386/debug
- commit b181e22
* Mon Jun  4 2018 mkubecek@suse.cz
- Update to 4.17-final
- commit fb45ad0
* Sat Jun  2 2018 mkubecek@suse.cz
- packet: fix reserve calculation (bsc#1095592).
- commit f670a16
* Fri Jun  1 2018 mcgrof@suse.com
- xfs: enhance dinode verifier (bsc#1090749,CVE-2018-10322).
- commit d565016
* Thu May 31 2018 jslaby@suse.cz
- Linux 4.16.13 (bnc#1012628).
- drm/vmwgfx: Set dmabuf_size when vmw_dmabuf_init is successful
  (bnc#1012628).
- kdb: make "mdr" command repeat (bnc#1012628).
- pinctrl: mcp23s08: spi: Fix regmap debugfs entries
  (bnc#1012628).
- pinctrl: msm: Use dynamic GPIO numbering (bnc#1012628).
- regulator: of: Add a missing 'of_node_put()' in an error
  handling path of 'of_regulator_match()' (bnc#1012628).
- ARM: dts: porter: Fix HDMI output routing (bnc#1012628).
- ARM: dts: imx7d: cl-som-imx7: fix pinctrl_enet (bnc#1012628).
- i40e: Add delay after EMP reset for firmware to recover
  (bnc#1012628).
- soc: amlogic: meson-gx-pwrc-vpu: fix error on shutdown when
  domain is powered off (bnc#1012628).
- regmap: Correct comparison in regmap_cached (bnc#1012628).
- ARM: dts: at91: tse850: use the correct compatible for the
  eeprom (bnc#1012628).
- ARM: dts: at91: nattis: use the correct compatible for the
  eeprom (bnc#1012628).
- selftests: Add FIB onlink tests (bnc#1012628).
- drm: rcar-du: lvds: Fix LVDS startup on R-Car Gen2
  (bnc#1012628).
- drm: rcar-du: lvds: Fix LVDS startup on R-Car Gen3
  (bnc#1012628).
- netlabel: If PF_INET6, check sk_buff ip header version
  (bnc#1012628).
- drm/vblank: Data type fixes for 64-bit vblank sequences
  (bnc#1012628).
- selftests/net: fixes psock_fanout eBPF test case (bnc#1012628).
- perf tests: Fix dwarf unwind for stripped binaries
  (bnc#1012628).
- perf report: Fix memory corruption in --branch-history mode
  - -branch-history (bnc#1012628).
- perf tests: Use arch__compare_symbol_names to compare symbols
  (bnc#1012628).
- perf report: Fix wrong jump arrow (bnc#1012628).
- perf test: Fix test case inet_pton to accept inlines
  (bnc#1012628).
- x86/apic: Set up through-local-APIC mode on the boot CPU if
  'noapic' specified (bnc#1012628).
- drm/rockchip: Respect page offset for PRIME mmap calls
  (bnc#1012628).
- soc: renesas: r8a77970-sysc: fix power area parents
  (bnc#1012628).
- MIPS: Octeon: Fix logging messages with spurious periods after
  newlines (bnc#1012628).
- dpaa_eth: fix pause capability advertisement logic
  (bnc#1012628).
- drm/amd/display: Set vsc pack revision when DPCD revision is >=
  1.2 (bnc#1012628).
- dt-bindings: display: msm/dsi: Fix the PHY regulator supply
  props (bnc#1012628).
- pinctrl: sh-pfc: r8a7796: Fix MOD_SEL register pin assignment
  for SSI pins group (bnc#1012628).
- rcu: Call touch_nmi_watchdog() while printing stall warnings
  (bnc#1012628).
- net: stmmac: call correct function in
  stmmac_mac_config_rx_queues_routing() (bnc#1012628).
- audit: return on memory error to avoid null pointer dereference
  (bnc#1012628).
- hwrng: bcm2835 - Handle deferred clock properly (bnc#1012628).
- PCMCIA / PM: Avoid noirq suspend aborts during suspend-to-idle
  (bnc#1012628).
- ARM: dts: bcm283x: Fix pin function of JTAG pins (bnc#1012628).
- ARM: dts: bcm283x: Fix probing of bcm2835-i2s (bnc#1012628).
- power: supply: ltc2941-battery-gauge: Fix temperature units
  (bnc#1012628).
- sh_eth: fix TSU init on SH7734/R8A7740 (bnc#1012628).
- ixgbe: prevent ptp_rx_hang from running when in FILTER_ALL mode
  (bnc#1012628).
- udf: Provide saner default for invalid uid / gid (bnc#1012628).
- PCI: Add function 1 DMA alias quirk for Marvell 88SE9220
  (bnc#1012628).
- dpaa_eth: fix SG mapping (bnc#1012628).
- cpufreq: Reorder cpufreq_online() error code path (bnc#1012628).
- net: stmmac: ensure that the MSS desc is the last desc to set
  the own bit (bnc#1012628).
- net: stmmac: ensure that the device has released ownership
  before reading data (bnc#1012628).
- ibmvnic: Allocate statistics buffers during probe (bnc#1012628).
- drm/amdgpu: adjust timeout for ib_ring_tests(v2) (bnc#1012628).
- drm/amdgpu: disable GFX ring and disable PQ wptr in hw_fini
  (bnc#1012628).
- ARM: dts: dra71-evm: Correct evm_sd regulator max voltage
  (bnc#1012628).
- drm: omapdrm: dss: Move initialization code from component
  bind to probe (bnc#1012628).
- dmaengine: qcom: bam_dma: get num-channels and num-ees from dt
  (bnc#1012628).
- vfio-ccw: fence off transport mode (bnc#1012628).
- pinctrl: artpec6: dt: add missing pin group uart5nocts
  (bnc#1012628).
- pinctrl: devicetree: Fix dt_to_map_one_config handling of hogs
  (bnc#1012628).
- hwrng: stm32 - add reset during probe (bnc#1012628).
- watchdog: asm9260_wdt: fix error handling in asm9260_wdt_probe()
  (bnc#1012628).
- enic: enable rq before updating rq descriptors (bnc#1012628).
- dmaengine: rcar-dmac: Check the done lists in
  rcar_dmac_chan_get_residue() (bnc#1012628).
- powerpc/mm/slice: Fix hugepage allocation at hint address on
  8xx (bnc#1012628).
- powerpc/mm/slice: Enhance for supporting PPC32 (bnc#1012628).
- powerpc/mm/slice: create header files dedicated to slices
  (bnc#1012628).
- powerpc/mm/slice: Remove intermediate bitmap copy (bnc#1012628).
- ARM: dts: keystone-k2e-clocks: Fix missing unit address
  separator (bnc#1012628).
- dmaengine: pl330: fix a race condition in case of threaded irqs
  (bnc#1012628).
- block: null_blk: fix 'Invalid parameters' when loading module
  (bnc#1012628).
- tools: hv: fix compiler warnings about major/target_fname
  (bnc#1012628).
- drm/amdgpu: Clean sdma wptr register when only enable wptr
  polling (bnc#1012628).
- drm/bridge: sii902x: Retry status read after DDI I2C
  (bnc#1012628).
- phy: qcom-qmp: Fix phy pipe clock gating (bnc#1012628).
- ALSA: vmaster: Propagate slave error (bnc#1012628).
- phy: rockchip-emmc: retry calpad busy trimming (bnc#1012628).
- x86/devicetree: Fix device IRQ settings in DT (bnc#1012628).
- x86/devicetree: Initialize device tree before using it
  (bnc#1012628).
- gfs2: Fix fallocate chunk size (bnc#1012628).
- soc: qcom: wcnss_ctrl: Fix increment in NV upload (bnc#1012628).
- arm64: dts: qcom: Fix SPI5 config on MSM8996 (bnc#1012628).
- perf/x86/intel: Fix event update for auto-reload (bnc#1012628).
- perf/x86/intel: Fix large period handling on Broadwell CPUs
  (bnc#1012628).
- efi/arm*: Only register page tables when they exist
  (bnc#1012628).
- cdrom: do not call check_disk_change() inside cdrom_open()
  (bnc#1012628).
- perf/x86/intel: Properly save/restore the PMU state in the
  NMI handler (bnc#1012628).
- hwmon: (pmbus/adm1275) Accept negative page register values
  (bnc#1012628).
- hwmon: (pmbus/max8688) Accept negative page register values
  (bnc#1012628).
- drm/panel: simple: Fix the bus format for the Ontat panel
  (bnc#1012628).
- perf/core: Fix perf_output_read_group() (bnc#1012628).
- max17042: propagate of_node to power supply device
  (bnc#1012628).
- perf/core: Fix installing cgroup events on CPU (bnc#1012628).
- f2fs: fix to check extent cache in f2fs_drop_extent_tree
  (bnc#1012628).
- f2fs: fix to clear CP_TRIMMED_FLAG (bnc#1012628).
- f2fs: fix to set KEEP_SIZE bit in f2fs_zero_range (bnc#1012628).
- cxl: Check if PSL data-cache is available before issue flush
  request (bnc#1012628).
- f2fs: flush cp pack except cp pack 2 page at first
  (bnc#1012628).
- powerpc/powernv/npu: Fix deadlock in mmio_invalidate()
  (bnc#1012628).
- powerpc: Add missing prototype for arch_irq_work_raise()
  (bnc#1012628).
- drm/meson: Fix an un-handled error path in
  'meson_drv_bind_master()' (bnc#1012628).
- drm/meson: Fix some error handling paths in
  'meson_drv_bind_master()' (bnc#1012628).
- ipmi_ssif: Fix kernel panic at msg_done_handler (bnc#1012628).
- watchdog: aspeed: Fix translation of reset mode to ctrl register
  (bnc#1012628).
- watchdog: dw: RMW the control register (bnc#1012628).
- watchdog: sprd_wdt: Fix error handling in sprd_wdt_enable()
  (bnc#1012628).
- PCI: Restore config space on runtime resume despite being
  unbound (bnc#1012628).
- powerpc/vas: Fix cleanup when VAS is not configured
  (bnc#1012628).
- MIPS: ath79: Fix AR724X_PLL_REG_PCIE_CONFIG offset
  (bnc#1012628).
- net/smc: pay attention to MAX_ORDER for CQ entries
  (bnc#1012628).
- spi: bcm-qspi: fIX some error handling paths (bnc#1012628).
- regulator: gpio: Fix some error handling paths in
  'gpio_regulator_probe()' (bnc#1012628).
- ibmvnic: Fix reset return from closed state (bnc#1012628).
- coresight: Use %%px to print pcsr instead of %%p (bnc#1012628).
- drm/amdkfd: add missing include of mm.h (bnc#1012628).
- IB/core: Honor port_num while resolving GID for IB link layer
  (bnc#1012628).
- perf stat: Fix core dump when flag T is used (bnc#1012628).
- perf top: Fix top.call-graph config option reading
  (bnc#1012628).
- KVM: lapic: stop advertising DIRECTED_EOI when in-kernel IOAPIC
  is in use (bnc#1012628).
- i2c: mv64xxx: Apply errata delay only in standard mode
  (bnc#1012628).
- cxgb4: Fix queue free path of ULD drivers (bnc#1012628).
- ACPICA: acpi: acpica: fix acpi operand cache leak in nseval.c
  (bnc#1012628).
- bcache: stop dc->writeback_rate_update properly (bnc#1012628).
- ACPICA: Fix memory leak on unusual memory leak (bnc#1012628).
- ACPICA: Events: add a return on failure from
  acpi_hw_register_read (bnc#1012628).
- bcache: fix cached_dev->count usage for bch_cache_set_error()
  (bnc#1012628).
- dt-bindings: add device tree binding for Allwinner H6 main CCU
  (bnc#1012628).
- remoteproc: imx_rproc: Fix an error handling path in
  'imx_rproc_probe()' (bnc#1012628).
- bcache: quit dc->writeback_thread when BCACHE_DEV_DETACHING
  is set (bnc#1012628).
- zorro: Set up z->dev.dma_mask for the DMA API (bnc#1012628).
- IB/mlx5: Set the default active rate and width to QDR and 4X
  (bnc#1012628).
- firmware: fix checking for return values for fw_add_devm_name()
  (bnc#1012628).
- cpufreq: cppc_cpufreq: Fix cppc_cpufreq_init() failure path
  (bnc#1012628).
- iommu/mediatek: Fix protect memory setting (bnc#1012628).
- drm/vmwgfx: Unpin the screen object backup buffer when not used
  (bnc#1012628).
- ext4: don't complain about incorrect features when probing
  (bnc#1012628).
- ima: clear IMA_HASH (bnc#1012628).
- arm: dts: socfpga: fix GIC PPI warning (bnc#1012628).
- virtio-net: Fix operstate for virtio when no VIRTIO_NET_F_STATUS
  (bnc#1012628).
- gfs2: Check for the end of metadata in punch_hole (bnc#1012628).
- watchdog: aspeed: Allow configuring for alternate boot
  (bnc#1012628).
- ima: Fallback to the builtin hash algorithm (bnc#1012628).
- ima: Fix Kconfig to select TPM 2.0 CRB interface (bnc#1012628).
- Update config files (TCG_CRB=y).
- hv_netvsc: Fix the return status in RX path (bnc#1012628).
- cxgb4: Setup FW queues before registering netdev (bnc#1012628).
- btrfs: fix null pointer deref when target device is missing
  (bnc#1012628).
- ath9k: fix crash in spectral scan (bnc#1012628).
- nvme-pci: disable APST for Samsung NVMe SSD 960 EVO + ASUS
  PRIME Z370-A (bnc#1012628).
- nvme_fc: fix abort race on teardown with lld reject
  (bnc#1012628).
- ath10k: Fix kernel panic while using worker
  (ath10k_sta_rc_update_wk) (bnc#1012628).
- net: qualcomm: rmnet: check for null ep to avoid null pointer
  dereference (bnc#1012628).
- net: hns3: fix for returning wrong value problem in
  hns3_get_rss_key_size (bnc#1012628).
- net: hns3: fix for returning wrong value problem in
  hns3_get_rss_indir_size (bnc#1012628).
- net: hns3: fix for the wrong shift problem in
  hns3_set_txbd_baseinfo (bnc#1012628).
- watchdog: davinci_wdt: fix error handling in davinci_wdt_probe()
  (bnc#1012628).
- net/mlx5: Protect from command bit overflow (bnc#1012628).
- i40e: hold the RTNL lock while changing interrupt schemes
  (bnc#1012628).
- selftests: Print the test we're running to /dev/kmsg
  (bnc#1012628).
- tools/thermal: tmon: fix for segfault (bnc#1012628).
- rsi: fix kernel panic observed on 64bit machine (bnc#1012628).
- powerpc/perf: Fix kernel address leak via sampling registers
  (bnc#1012628).
- powerpc/perf: Prevent kernel address leak to userspace via
  BHRB buffer (bnc#1012628).
- mt76x2: fix warning in ieee80211_get_key_rx_seq() (bnc#1012628).
- mt76x2: fix possible NULL pointer dereferencing in mt76x2_tx()
  (bnc#1012628).
- hwmon: (nct6775) Fix writing pwmX_mode (bnc#1012628).
- perf mmap: Fix accessing unmapped mmap in perf_mmap__read_done()
  (bnc#1012628).
- parisc/pci: Switch LBA PCI bus from Hard Fail to Soft Fail mode
  (bnc#1012628).
- net/mlx5e: Move all TX timeout logic to be under state lock
  (bnc#1012628).
- iwlwifi: mvm: take RCU lock before dereferencing (bnc#1012628).
- iwlwifi: mvm: check if mac80211_queue is valid in
  iwl_mvm_disable_txq (bnc#1012628).
- m68k: set dma and coherent masks for platform FEC ethernets
  (bnc#1012628).
- intel_th: Use correct method of finding hub (bnc#1012628).
- iommu/amd: Take into account that alloc_dev_data() may return
  NULL (bnc#1012628).
- ath10k: advertize beacon_int_min_gcd (bnc#1012628).
- ieee802154: ca8210: fix uninitialised data read (bnc#1012628).
- powerpc/mpic: Check if cpu_possible() in mpic_physmask()
  (bnc#1012628).
- ACPI: acpi_pad: Fix memory leak in power saving threads
  (bnc#1012628).
- drivers: macintosh: rack-meter: really fix bogus memsets
  (bnc#1012628).
- xen/acpi: off by one in read_acpi_id() (bnc#1012628).
- rxrpc: Don't treat call aborts as conn aborts (bnc#1012628).
- rxrpc: Fix Tx ring annotation after initial Tx failure
  (bnc#1012628).
- rxrpc: Fix resend event time calculation (bnc#1012628).
- btrfs: qgroup: Fix root item corruption when multiple same
  source snapshots are created with quota enabled (bnc#1012628).
- btrfs: fix lockdep splat in btrfs_alloc_subvolume_writers
  (bnc#1012628).
- Btrfs: fix copy_items() return value when logging an inode
  (bnc#1012628).
- btrfs: tests/qgroup: Fix wrong tree backref level (bnc#1012628).
- powerpc/64s: sreset panic if there is no debugger or crash
  dump handlers (bnc#1012628).
- bnxt_en: fix clear flags in ethtool reset handling
  (bnc#1012628).
- net: bgmac: Correctly annotate register space (bnc#1012628).
- net: bgmac: Fix endian access in bgmac_dma_tx_ring_free()
  (bnc#1012628).
- platform/x86: dell-smbios: Fix memory leaks in
  build_tokens_sysfs() (bnc#1012628).
- riscv/spinlock: Strengthen implementations with fences
  (bnc#1012628).
- sparc64: Make atomic_xchg() an inline function rather than a
  macro (bnc#1012628).
- dmaengine: rcar-dmac: Fix too early/late system suspend/resume
  callbacks (bnc#1012628).
- fscache: Fix hanging wait on page discarded by writeback
  (bnc#1012628).
- lan78xx: Connect phy early (bnc#1012628).
- KVM: VMX: raise internal error for exception during invalid
  protected mode state (bnc#1012628).
- x86/mm: Fix bogus warning during EFI bootup, use boot_cpu_has()
  instead of this_cpu_has() in build_cr3_noflush() (bnc#1012628).
- sched/rt: Fix rq->clock_update_flags < RQCF_ACT_SKIP warning
  (bnc#1012628).
- powerpc/64s/idle: Fix restore of AMOR on POWER9 after deep sleep
  (bnc#1012628).
- ocfs2/dlm: don't handle migrate lockres if already in shutdown
  (bnc#1012628).
- IB/rxe: Fix for oops in rxe_register_device on ppc64le arch
  (bnc#1012628).
- btrfs: Fix possible softlock on single core machines
  (bnc#1012628).
- Btrfs: fix NULL pointer dereference in log_dir_items
  (bnc#1012628).
- Btrfs: bail out on error during replay_dir_deletes
  (bnc#1012628).
- mm: thp: fix potential clearing to referenced flag in
  page_idle_clear_pte_refs_one() (bnc#1012628).
- mm: fix races between address_space dereference and free in
  page_evicatable (bnc#1012628).
- mm/ksm: fix interaction with THP (bnc#1012628).
- genirq/affinity: Don't return with empty affinity masks on error
  (bnc#1012628).
- ibmvnic: Zero used TX descriptor counter on reset (bnc#1012628).
- dp83640: Ensure against premature access to PHY registers
  after reset (bnc#1012628).
- perf clang: Add support for recent clang versions (bnc#1012628).
- perf tools: Fix perf builds with clang support (bnc#1012628).
- powerpc/fscr: Enable interrupts earlier before calling
  get_user() (bnc#1012628).
- cpufreq: CPPC: Initialize shared perf capabilities of CPUs
  (bnc#1012628).
- Force log to disk before reading the AGF during a fstrim
  (bnc#1012628).
- sr: get/drop reference to device in revalidate and check_events
  (bnc#1012628).
- z3fold: fix memory leak (bnc#1012628).
- swap: divide-by-zero when zero length swap file on ssd
  (bnc#1012628).
- kasan, slub: fix handling of kasan_slab_free hook (bnc#1012628).
- kasan: fix invalid-free test crashing the kernel (bnc#1012628).
- fs/proc/proc_sysctl.c: fix potential page fault while
  unregistering sysctl table (bnc#1012628).
- nvme: expand nvmf_check_if_ready checks (bnc#1012628).
- bnxt_en: Ignore src port field in decap filter nodes
  (bnc#1012628).
- x86/mm: Do not forbid _PAGE_RW before init for __ro_after_init
  (bnc#1012628).
- x86/pgtable: Don't set huge PUD/PMD on non-leaf entries
  (bnc#1012628).
- Btrfs: fix loss of prealloc extents past i_size after fsync
  log replay (bnc#1012628).
- Btrfs: clean up resources during umount after trans is aborted
  (bnc#1012628).
- nvme: don't send keep-alives to the discovery controller
  (bnc#1012628).
- firmware: dmi_scan: Fix UUID length safety check (bnc#1012628).
- sh: fix debug trap failure to process signals before return
  to user (bnc#1012628).
- ARM: dts: sun4i: Fix incorrect clocks for displays
  (bnc#1012628).
- x86/kvm: fix LAPIC timer drift when guest uses periodic mode
  (bnc#1012628).
- kvm: x86: IA32_ARCH_CAPABILITIES is always supported
  (bnc#1012628).
- KVM: x86: Update cpuid properly when CR4.OSXAVE or CR4.PKE is
  changed (bnc#1012628).
- KVM: s390: vsie: fix < 8k check for the itdba (bnc#1012628).
- KVM/VMX: Expose SSBD properly to guests (bnc#1012628).
- PM / core: Fix direct_complete handling for devices with no
  callbacks (bnc#1012628).
- kernel/sys.c: fix potential Spectre v1 issue (bnc#1012628).
- kasan: fix memory hotplug during boot (bnc#1012628).
- kasan: free allocated shadow memory on MEM_CANCEL_ONLINE
  (bnc#1012628).
- mm/kasan: don't vfree() nonexistent vm_area (bnc#1012628).
- ipc/shm: fix shmat() nil address after round-down when remapping
  (bnc#1012628).
- Revert "ipc/shm: Fix shmat mmap nil-page protection"
  (bnc#1012628).
- idr: fix invalid ptr dereference on item delete (bnc#1012628).
- bcma: fix buffer size caused crash in bcma_core_mips_print_irq()
  (bnc#1012628).
- sr: pass down correctly sized SCSI sense buffer (bnc#1012628).
- IB/umem: Use the correct mm during ib_umem_release
  (bnc#1012628).
- IB/hfi1: Use after free race condition in send context error
  path (bnc#1012628).
- powerpc/64s: Clear PCR on boot (bnc#1012628).
- arm64: export tishift functions to modules (bnc#1012628).
- arm64: lse: Add early clobbers to some input/output asm operands
  (bnc#1012628).
- drm/vmwgfx: Fix 32-bit VMW_PORT_HB_[IN|OUT] macros
  (bnc#1012628).
- xen-swiotlb: fix the check condition for
  xen_swiotlb_free_coherent (bnc#1012628).
- libata: blacklist Micron 500IT SSD with MU01 firmware
  (bnc#1012628).
- libata: Blacklist some Sandisk SSDs for NCQ (bnc#1012628).
- ahci: Add PCI ID for Cannon Lake PCH-LP AHCI (bnc#1012628).
- mmc: sdhci-iproc: add SDHCI_QUIRK2_HOST_OFF_CARD_ON for cygnus
  (bnc#1012628).
- mmc: sdhci-iproc: fix 32bit writes for TRANSFER_MODE register
  (bnc#1012628).
- mmc: sdhci-iproc: remove hard coded mmc cap 1.8v (bnc#1012628).
- mmc: block: propagate correct returned value in mmc_rpmb_ioctl
  (bnc#1012628).
- do d_instantiate/unlock_new_inode combinations safely
  (bnc#1012628).
- ALSA: timer: Fix pause event notification (bnc#1012628).
- Btrfs: fix error handling in btrfs_truncate() (bnc#1012628).
- aio: fix io_destroy(2) vs. lookup_ioctx() race (bnc#1012628).
- fs: don't scan the inode cache before SB_BORN is set
  (bnc#1012628).
- fix breakage caused by d_find_alias() semantics change
  (bnc#1012628).
- affs_lookup(): close a race with affs_remove_link()
  (bnc#1012628).
- KVM: Fix spelling mistake: "cop_unsuable" -> "cop_unusable"
  (bnc#1012628).
- MIPS: Fix ptrace(2) PTRACE_PEEKUSR and PTRACE_POKEUSR accesses
  to o32 FGRs (bnc#1012628).
- MIPS: ptrace: Expose FIR register through FP regset
  (bnc#1012628).
- MIPS: Fix build with DEBUG_ZBOOT and MACH_JZ4770 (bnc#1012628).
- MIPS: c-r4k: Fix data corruption related to cache coherence
  (bnc#1012628).
- MIPS: xilfpga: Actually include FDT in fitImage (bnc#1012628).
- MIPS: xilfpga: Stop generating useless dtb.o (bnc#1012628).
- commit e33cb3e
* Mon May 28 2018 mkubecek@suse.cz
- Update to 4.17-rc7
- Eliminated 1 patch
- Config changes:
  - reenable SSB_DRIVER_PCICORE and dependencies after revert of
    commit 882164a4a928
- commit c78299c
* Fri May 25 2018 jslaby@suse.cz
- Update config files.
- commit 39c7522
* Fri May 25 2018 jslaby@suse.cz
- Linux 4.16.12 (bnc#1012628).
- rtc: goldfish: Add missing MODULE_LICENSE (bnc#1012628).
- rtc: rp5c01: fix possible race condition (bnc#1012628).
- rtc: tx4939: avoid unintended sign extension on a 24 bit shift
  (bnc#1012628).
- rtc: m41t80: fix race conditions (bnc#1012628).
- rtc: rk808: fix possible race condition (bnc#1012628).
- rtc: hctosys: Ensure system time doesn't overflow time_t
  (bnc#1012628).
- rtc: snvs: Fix usage of snvs_rtc_enable (bnc#1012628).
- serial: altera: ensure port->regshift is honored consistently
  (bnc#1012628).
- serial: 8250: Don't service RX FIFO if interrupts are disabled
  (bnc#1012628).
- serial: arc_uart: Fix out-of-bounds access through DT alias
  (bnc#1012628).
- serial: fsl_lpuart: Fix out-of-bounds access through DT alias
  (bnc#1012628).
- serial: imx: Fix out-of-bounds access through serial port index
  (bnc#1012628).
- serial: mxs-auart: Fix out-of-bounds access through serial
  port index (bnc#1012628).
- serial: samsung: Fix out-of-bounds access through serial port
  index (bnc#1012628).
- serial: sh-sci: Fix out-of-bounds access through DT alias
  (bnc#1012628).
- serial: xuartps: Fix out-of-bounds access through DT alias
  (bnc#1012628).
- serial: mvebu-uart: fix tx lost characters (bnc#1012628).
- media: cx25821: prevent out-of-bounds read on array card
  (bnc#1012628).
- media: vivid: fix incorrect capabilities for radio
  (bnc#1012628).
- media: vb2: Fix videobuf2 to map correct area (bnc#1012628).
- media: i2c: adv748x: fix HDMI field heights (bnc#1012628).
- media: v4l: vsp1: Fix display stalls when requesting too many
  inputs (bnc#1012628).
- media: em28xx: Add Hauppauge SoloHD/DualHD bulk models
  (bnc#1012628).
- media: lgdt3306a: Fix a double kfree on i2c device remove
  (bnc#1012628).
- media: s3c-camif: fix out-of-bounds array access (bnc#1012628).
- media: cx23885: Set subdev host data to clk_freq pointer
  (bnc#1012628).
- media: cx23885: Override 888 ImpactVCBe crystal frequency
  (bnc#1012628).
- media: ov5645: add missing of_node_put() in error path
  (bnc#1012628).
- clk: meson: axg: add the fractional part of the fixed_pll
  (bnc#1012628).
- clk: meson: axg: fix the od shift of the sys_pll (bnc#1012628).
- clk: samsung: exynos3250: Fix PLL rates (bnc#1012628).
- clk: samsung: exynos5250: Fix PLL rates (bnc#1012628).
- clk: samsung: exynos5433: Fix PLL rates (bnc#1012628).
- clk: samsung: exynos5260: Fix PLL rates (bnc#1012628).
- clk: samsung: exynos7: Fix PLL rates (bnc#1012628).
- clk: samsung: s3c2410: Fix PLL rates (bnc#1012628).
- clk: rockchip: Prevent calculating mmc phase if clock rate is
  zero (bnc#1012628).
- clk: tegra: Fix pll_u rate configuration (bnc#1012628).
- clk: hisilicon: mark wdt_mux_p[] as const (bnc#1012628).
- clk: Don't show the incorrect clock phase (bnc#1012628).
- clk: rockchip: Fix wrong parent for SDMMC phase clock for rk3228
  (bnc#1012628).
- ASoC: samsung: i2s: Ensure the RCLK rate is properly determined
  (bnc#1012628).
- ASoC: topology: create TLV data for dapm widgets (bnc#1012628).
- ASoC: samsung: odroid: Fix 32000 sample rate handling
  (bnc#1012628).
- ASoC: rockchip: rk3288-hdmi-analog: Select needed codecs
  (bnc#1012628).
- scsi: lpfc: Fix frequency of Release WQE CQEs (bnc#1012628).
- scsi: lpfc: Fix IO failure during hba reset testing with nvme io
  (bnc#1012628).
- scsi: lpfc: Fix soft lockup in lpfc worker thread during LIP
  testing (bnc#1012628).
- scsi: lpfc: Fix nonrecovery of NVME controller after cable swap
  (bnc#1012628).
- scsi: lpfc: Fix issue_lip if link is disabled (bnc#1012628).
- scsi: mvsas: fix wrong endianness of sgpio api (bnc#1012628).
- scsi: core: Make SCSI Status CONDITION MET equivalent to GOOD
  (bnc#1012628).
- scsi: lpfc: Fix NVME Initiator FirstBurst (bnc#1012628).
- scsi: devinfo: add HP DISK-SUBSYSTEM device, for HP XP arrays
  (bnc#1012628).
- scsi: aacraid: Insure command thread is not recursively stopped
  (bnc#1012628).
- crypto: inside-secure - fix the invalidation step during
  cra_exit (bnc#1012628).
- crypto: sunxi-ss - Add MODULE_ALIAS to sun4i-ss (bnc#1012628).
- crypto: inside-secure - do not overwrite the threshold value
  (bnc#1012628).
- crypto: inside-secure - fix the extra cache computation
  (bnc#1012628).
- crypto: inside-secure - fix the cache_len computation
  (bnc#1012628).
- crypto: inside-secure - do not process request if no command
  was issued (bnc#1012628).
- crypto: ccp - don't disable interrupts while setting up debugfs
  (bnc#1012628).
- crypto: atmel-aes - fix the keys zeroing on errors
  (bnc#1012628).
- crypto: inside-secure - wait for the request to complete if
  in the backlog (bnc#1012628).
- crypto: inside-secure - move the digest to the request context
  (bnc#1012628).
- staging: lustre: lmv: correctly iput lmo_root (bnc#1012628).
- staging: ks7010: Use constants from ieee80211_eid instead of
  literal ints (bnc#1012628).
- staging: rtl8192u: return -ENOMEM on failed allocation of
  priv->oldaddr (bnc#1012628).
- staging: fsl-dpaa2/eth: Fix incorrect casts (bnc#1012628).
- staging: lustre: fix bug in osc_enter_cache_try (bnc#1012628).
- staging: fsl-dpaa2/eth: Fix incorrect kfree (bnc#1012628).
- staging: bcm2835-audio: Release resources on module_exit()
  (bnc#1012628).
- x86/kexec: Avoid double free_page() upon do_kexec_load()
  failure (bnc#1012628).
- hfsplus: stop workqueue when fill_super() failed (bnc#1012628).
- cfg80211: limit wiphy names to 128 bytes (bnc#1012628).
- loop: fix LOOP_GET_STATUS lock imbalance (bnc#1012628).
- loop: don't call into filesystem while holding lo_ctl_mutex
  (bnc#1012628).
- xhci: Show what USB release number the xHC supports from
  protocol capablity (bnc#1012628).
- Bluetooth: btusb: Add support for Intel Bluetooth device 22560
  [8087:0026] (bnc#1012628).
- Bluetooth: btusb: Add device ID for RTL8822BE (bnc#1012628).
- media: em28xx: USB bulk packet size fix (bnc#1012628).
- media: lgdt3306a: Fix module count mismatch on usb unplug
  (bnc#1012628).
- usb: gadget: composite: fix incorrect handling of OS desc
  requests (bnc#1012628).
- usb: gadget: udc: change comparison to bitshift when dealing
  with a mask (bnc#1012628).
- usbip: Correct maximum value of CONFIG_USBIP_VHCI_HC_PORTS
  (bnc#1012628).
- usb: gadget: ffs: Execute copy_to_user() with USER_DS set
  (bnc#1012628).
- usb: gadget: ffs: Let setup() return USB_GADGET_DELAYED_STATUS
  (bnc#1012628).
- usb: dwc2: host: Fix transaction errors in host mode
  (bnc#1012628).
- usb: dwc2: hcd: Fix host channel halt flow (bnc#1012628).
- usb: dwc2: Fix interval type issue (bnc#1012628).
- xhci: zero usb device slot_id member when disabling and freeing
  a xhci slot (bnc#1012628).
- usb: dwc3: Makefile: fix link error on randconfig (bnc#1012628).
- usb: dwc3: Update DWC_usb31 GTXFIFOSIZ reg fields (bnc#1012628).
- usb: dwc3: Add SoftReset PHY synchonization delay (bnc#1012628).
- ALSA: usb-audio: Add native DSD support for Luxman DA-06
  (bnc#1012628).
- Bluetooth: btusb: Add USB ID 7392:a611 for Edimax EW-7611ULB
  (bnc#1012628).
- scsi: zfcp: fix infinite iteration on ERP ready list
  (bnc#1012628).
- scsi: sg: allocate with __GFP_ZERO in sg_build_indirect()
  (bnc#1012628).
- s390: use expoline thunks in the BPF JIT (bnc#1012628).
- s390: extend expoline to BC instructions (bnc#1012628).
- s390: move spectre sysfs attribute code (bnc#1012628).
- s390/kernel: use expoline for indirect branches (bnc#1012628).
- s390/ftrace: use expoline for indirect branches (bnc#1012628).
- s390/lib: use expoline for indirect branches (bnc#1012628).
- s390/crc32-vx: use expoline for indirect branches (bnc#1012628).
- s390: move expoline assembler macros to a header (bnc#1012628).
- s390: correct module section names for expoline code revert
  (bnc#1012628).
- s390: correct nospec auto detection init order (bnc#1012628).
- s390: add assembler macros for CPU alternatives (bnc#1012628).
- s390: add sysfs attributes for spectre (bnc#1012628).
- s390: report spectre mitigation via syslog (bnc#1012628).
- s390: add automatic detection of the spectre defense
  (bnc#1012628).
- s390: move nobp parameter functions to nospec-branch.c
  (bnc#1012628).
- powerpc/64s: Add support for a store forwarding barrier at
  kernel entry/exit (bnc#1012628).
- powerpc: Move default security feature flags (bnc#1012628).
- powerpc/pseries: Fix clearing of security feature flags
  (bnc#1012628).
- powerpc/64s: Wire up cpu_show_spectre_v2() (bnc#1012628).
- powerpc/64s: Wire up cpu_show_spectre_v1() (bnc#1012628).
- powerpc/pseries: Use the security flags in
  pseries_setup_rfi_flush() (bnc#1012628).
- powerpc/powernv: Use the security flags in pnv_setup_rfi_flush()
  (bnc#1012628).
- powerpc/64s: Enhance the information in cpu_show_meltdown()
  (bnc#1012628).
- powerpc/64s: Move cpu_show_meltdown() (bnc#1012628).
- powerpc/powernv: Set or clear security feature flags
  (bnc#1012628).
- powerpc/pseries: Set or clear security feature flags
  (bnc#1012628).
- powerpc/pseries: Add new H_GET_CPU_CHARACTERISTICS flags
  (bnc#1012628).
- powerpc: Add security feature flags for Spectre/Meltdown
  (bnc#1012628).
- powerpc/rfi-flush: Always enable fallback flush on pseries
  (bnc#1012628).
- ext2: fix a block leak (bnc#1012628).
- sparc: vio: use put_device() instead of kfree() (bnc#1012628).
- qed: Fix LL2 race during connection terminate (bnc#1012628).
- qed: Fix possibility of list corruption during rmmod flows
  (bnc#1012628).
- qed: LL2 flush isles when connection is closed (bnc#1012628).
- net: ip6_gre: fix tunnel metadata device sharing (bnc#1012628).
- net: ip6_gre: Fix ip6erspan hlen calculation (bnc#1012628).
- net: ip6_gre: Split up ip6gre_changelink() (bnc#1012628).
- net: ip6_gre: Split up ip6gre_newlink() (bnc#1012628).
- net: ip6_gre: Split up ip6gre_tnl_change() (bnc#1012628).
- net: ip6_gre: Split up ip6gre_tnl_link_config() (bnc#1012628).
- net: ip6_gre: Fix headroom request in ip6erspan_tunnel_xmit()
  (bnc#1012628).
- net: ip6_gre: Request headroom in __gre6_xmit() (bnc#1012628).
- vmxnet3: use DMA memory barriers where required (bnc#1012628).
- vmxnet3: set the DMA mask before the first DMA map operation
  (bnc#1012628).
- cxgb4: fix offset in collecting TX rate limit info
  (bnc#1012628).
- 3c59x: convert to generic DMA API (bnc#1012628).
- net: dsa: bcm_sf2: Fix IPv6 rule half deletion (bnc#1012628).
- net: dsa: bcm_sf2: Fix IPv6 rules and chain ID (bnc#1012628).
- net: dsa: Do not register devlink for unused ports
  (bnc#1012628).
- net: dsa: bcm_sf2: Fix RX_CLS_LOC_ANY overwrite for last rule
  (bnc#1012628).
- cxgb4: Correct ntuple mask validation for hash filters
  (bnc#1012628).
- tuntap: fix use after free during release (bnc#1012628).
- tun: fix use after free for ptr_ring (bnc#1012628).
- tcp: purge write queue in tcp_connect_init() (bnc#1012628).
- sock_diag: fix use-after-free read in __sk_free (bnc#1012628).
- packet: in packet_snd start writing at link layer allocation
  (bnc#1012628).
- net: test tailroom before appending to linear skb (bnc#1012628).
- net/smc: check for missing nlattrs in SMC_PNETID messages
  (bnc#1012628).
- net: sched: red: avoid hashing NULL child (bnc#1012628).
- net/sched: fix refcnt leak in the error path of tcf_vlan_init()
  (bnc#1012628).
- net/mlx4_core: Fix error handling in mlx4_init_port_info
  (bnc#1012628).
- net: Fix a bug in removing queues from XPS map (bnc#1012628).
- net/mlx5: Fix build break when CONFIG_SMP=n (bnc#1012628).
- commit 9e125b1
* Thu May 24 2018 tiwai@suse.de
- Bluetooth: Apply QCA Rome patches for some ATH3012 models
  (bsc#1082504).
- commit e2f793c
* Wed May 23 2018 msuchanek@suse.de
- mkspec: only build docs for default variant kernel.
- commit 045f5ac
* Tue May 22 2018 jslaby@suse.cz
- Linux 4.16.11 (bnc#1012628).
- xhci: Fix USB3 NULL pointer dereference at logical disconnect
  (bnc#1012628).
- usbip: usbip_host: refine probe and disconnect debug msgs to
  be useful (bnc#1012628).
- usbip: usbip_host: delete device from busid_table after rebind
  (bnc#1012628).
- usbip: usbip_host: run rebind from exit when module is removed
  (bnc#1012628).
- usbip: usbip_host: fix NULL-ptr deref and use-after-free errors
  (bnc#1012628).
- usbip: usbip_host: fix bad unlock balance during stub_probe()
  (bnc#1012628).
- ALSA: usb: mixer: volume quirk for CM102-A+/102S+ (bnc#1012628).
- ALSA: hda/realtek - Clevo P950ER ALC1220 Fixup (bnc#1012628).
- ALSA: hda: Add Lenovo C50 All in one to the power_save blacklist
  (bnc#1012628).
- ALSA: control: fix a redundant-copy issue (bnc#1012628).
- spi: pxa2xx: Allow 64-bit DMA (bnc#1012628).
- spi: bcm-qspi: Avoid setting MSPI_CDRAM_PCS for spi-nor master
  (bnc#1012628).
- spi: bcm-qspi: Always read and set BSPI_MAST_N_BOOT_CTRL
  (bnc#1012628).
- KVM: vmx: update sec exec controls for UMIP iff emulating UMIP
  (bnc#1012628).
- KVM: arm/arm64: Properly protect VGIC locks from IRQs
  (bnc#1012628).
- KVM: arm/arm64: VGIC/ITS: Promote irq_lock() in update_affinity
  (bnc#1012628).
- KVM: arm/arm64: VGIC/ITS save/restore: protect kvm_read_guest()
  calls (bnc#1012628).
- KVM: arm/arm64: VGIC/ITS: protect kvm_read_guest() calls with
  SRCU lock (bnc#1012628).
- hwmon: (k10temp) Fix reading critical temperature register
  (bnc#1012628).
- hwmon: (k10temp) Use API function to access System Management
  Network (bnc#1012628).
- vfio: ccw: fix cleanup if cp_prefetch fails (bnc#1012628).
- tracing/x86/xen: Remove zero data size trace events
  trace_xen_mmu_flush_tlb{_all} (bnc#1012628).
- vsprintf: Replace memory barrier with static_key for
  random_ptr_key update (bnc#1012628).
- x86/amd_nb: Add support for Raven Ridge CPUs (bnc#1012628).
- tee: shm: fix use-after-free via temporarily dropped reference
  (bnc#1012628).
- netfilter: nf_tables: free set name in error path (bnc#1012628).
- netfilter: nf_tables: can't fail after linking rule into active
  rule list (bnc#1012628).
- netfilter: nf_tables: nf_tables_obj_lookup_byhandle() can be
  static (bnc#1012628).
- ARM64: dts: marvell: armada-cp110: Add clocks for the xmdio node
  (bnc#1012628).
- ARM64: dts: marvell: armada-cp110: Add mg_core_clk for ethernet
  node (bnc#1012628).
- i2c: designware: fix poll-after-enable regression (bnc#1012628).
- mtd: rawnand: marvell: Fix read logic for layouts with ->nchunks
  > 2 (bnc#1012628).
- powerpc/powernv: Fix NVRAM sleep in invalid context when
  crashing (bnc#1012628).
- drm: Match sysfs name in link removal to link creation
  (bnc#1012628).
- cpufreq: armada-37xx: driver relies on cpufreq-dt (bnc#1012628).
- lib/test_bitmap.c: fix bitmap optimisation tests to report
  errors correctly (bnc#1012628).
- radix tree: fix multi-order iteration race (bnc#1012628).
- mm: don't allow deferred pages with NEED_PER_CPU_KM
  (bnc#1012628).
- drm/i915/gen9: Add WaClearHIZ_WM_CHICKEN3 for bxt and glk
  (bnc#1012628).
- s390/qdio: fix access to uninitialized qdio_q fields
  (bnc#1012628).
- s390/cpum_sf: ensure sample frequency of perf event attributes
  is non-zero (bnc#1012628).
- s390/qdio: don't release memory in qdio_setup_irq()
  (bnc#1012628).
- s390: remove indirect branch from do_softirq_own_stack
  (bnc#1012628).
- bcache: return 0 from bch_debug_init() if CONFIG_DEBUG_FS=n
  (bnc#1012628).
- x86/pkeys: Override pkey when moving away from PROT_EXEC
  (bnc#1012628).
- x86/pkeys: Do not special case protection key 0 (bnc#1012628).
- efi: Avoid potential crashes, fix the 'struct
  efi_pci_io_protocol_32' definition for mixed mode (bnc#1012628).
- ARM: 8771/1: kprobes: Prohibit kprobes on do_undefinstr
  (bnc#1012628).
- x86/apic/x2apic: Initialize cluster ID properly (bnc#1012628).
- x86/mm: Drop TS_COMPAT on 64-bit exec() syscall (bnc#1012628).
- tick/broadcast: Use for_each_cpu() specially on UP kernels
  (bnc#1012628).
- ARM: 8769/1: kprobes: Fix to use get_kprobe_ctlblk after
  irq-disabed (bnc#1012628).
- ARM: 8770/1: kprobes: Prohibit probing on optimized_callback
  (bnc#1012628).
- ARM: 8772/1: kprobes: Prohibit kprobes on get_user functions
  (bnc#1012628).
- Btrfs: fix xattr loss after power failure (bnc#1012628).
- Btrfs: send, fix invalid access to commit roots due to
  concurrent snapshotting (bnc#1012628).
- btrfs: property: Set incompat flag if lzo/zstd compression is
  set (bnc#1012628).
- btrfs: fix crash when trying to resume balance without the
  resume flag (bnc#1012628).
- btrfs: Split btrfs_del_delalloc_inode into 2 functions
  (bnc#1012628).
- btrfs: Fix delalloc inodes invalidation during transaction abort
  (bnc#1012628).
- btrfs: fix reading stale metadata blocks after degraded raid1
  mounts (bnc#1012628).
- x86/nospec: Simplify alternative_msr_write() (bnc#1012628).
- x86/bugs: Concentrate bug detection into a separate function
  (bnc#1012628).
- x86/bugs: Concentrate bug reporting into a separate function
  (bnc#1012628).
- x86/bugs: Read SPEC_CTRL MSR during boot and re-use reserved
  bits (bnc#1012628).
- x86/bugs, KVM: Support the combination of guest and host IBRS
  (bnc#1012628).
- x86/bugs: Expose /sys/../spec_store_bypass (bnc#1012628).
- x86/cpufeatures: Add X86_FEATURE_RDS (bnc#1012628).
- x86/bugs: Provide boot parameters for the
  spec_store_bypass_disable mitigation (bnc#1012628).
- x86/bugs/intel: Set proper CPU features and setup RDS
  (bnc#1012628).
- x86/bugs: Whitelist allowed SPEC_CTRL MSR values (bnc#1012628).
- x86/bugs/AMD: Add support to disable RDS on Fam[15,16,17]h if
  requested (bnc#1012628).
- x86/KVM/VMX: Expose SPEC_CTRL Bit(2) to the guest (bnc#1012628).
- x86/speculation: Create spec-ctrl.h to avoid include hell
  (bnc#1012628).
- prctl: Add speculation control prctls (bnc#1012628).
- x86/process: Allow runtime control of Speculative Store Bypass
  (bnc#1012628).
- x86/speculation: Add prctl for Speculative Store Bypass
  mitigation (bnc#1012628).
- nospec: Allow getting/setting on non-current task (bnc#1012628).
- proc: Provide details on speculation flaw mitigations
  (bnc#1012628).
- seccomp: Enable speculation flaw mitigations (bnc#1012628).
- x86/bugs: Make boot modes __ro_after_init (bnc#1012628).
- prctl: Add force disable speculation (bnc#1012628).
- seccomp: Use PR_SPEC_FORCE_DISABLE (bnc#1012628).
- seccomp: Add filter flag to opt-out of SSB mitigation
  (bnc#1012628).
- seccomp: Move speculation migitation control to arch code
  (bnc#1012628).
- x86/speculation: Make "seccomp" the default mode for Speculative
  Store Bypass (bnc#1012628).
- x86/bugs: Rename _RDS to _SSBD (bnc#1012628).
- proc: Use underscores for SSBD in 'status' (bnc#1012628).
- Documentation/spec_ctrl: Do some minor cleanups (bnc#1012628).
- x86/bugs: Fix __ssb_select_mitigation() return type
  (bnc#1012628).
- x86/bugs: Make cpu_show_common() static (bnc#1012628).
- x86/bugs: Fix the parameters alignment and missing void
  (bnc#1012628).
- x86/cpu: Make alternative_msr_write work for 32-bit code
  (bnc#1012628).
- KVM: SVM: Move spec control call after restore of GS
  (bnc#1012628).
- x86/speculation: Use synthetic bits for IBRS/IBPB/STIBP
  (bnc#1012628).
- x86/cpufeatures: Disentangle MSR_SPEC_CTRL enumeration from IBRS
  (bnc#1012628).
- x86/cpufeatures: Disentangle SSBD enumeration (bnc#1012628).
- x86/cpufeatures: Add FEATURE_ZEN (bnc#1012628).
- x86/speculation: Handle HT correctly on AMD (bnc#1012628).
- x86/bugs, KVM: Extend speculation control for VIRT_SPEC_CTRL
  (bnc#1012628).
- x86/speculation: Add virtualized speculative store bypass
  disable support (bnc#1012628).
- x86/speculation: Rework speculative_store_bypass_update()
  (bnc#1012628).
- x86/bugs: Unify x86_spec_ctrl_{set_guest,restore_host}
  (bnc#1012628).
- x86/bugs: Expose x86_spec_ctrl_base directly (bnc#1012628).
- x86/bugs: Remove x86_spec_ctrl_set() (bnc#1012628).
- x86/bugs: Rework spec_ctrl base and mask logic (bnc#1012628).
- x86/speculation, KVM: Implement support for
  VIRT_SPEC_CTRL/LS_CFG (bnc#1012628).
- KVM: SVM: Implement VIRT_SPEC_CTRL support for SSBD
  (bnc#1012628).
- x86/bugs: Rename SSBD_NO to SSB_NO (bnc#1012628).
- bpf: Prevent memory disambiguation attack (bnc#1012628).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Refresh
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- commit f86282c
* Mon May 21 2018 mkubecek@suse.cz
- Makefile: disable PIE before testing asm goto (bsc#1092456).
- commit 67bdb0d
* Mon May 21 2018 mkubecek@suse.cz
- Update to 4.17-rc6
- commit 6912f6b
* Sun May 20 2018 jslaby@suse.cz
- Linux 4.16.10 (bnc#1012628).
- proc: do not access cmdline nor environ from file-backed areas
  (bnc#1012628).
- scsi: aacraid: Correct hba_send to include iu_type
  (bnc#1012628).
- net/smc: keep clcsock reference in smc_tcp_listen_work()
  (bnc#1012628).
- net: phy: sfp: fix the BR,min computation (bnc#1012628).
- net/mlx5: Fix mlx5_get_vector_affinity function (bnc#1012628).
- mlxsw: core: Fix an error handling path in
  'mlxsw_core_bus_device_register()' (bnc#1012628).
- ipv4: reset fnhe_mtu_locked after cache route flushed
  (bnc#1012628).
- hv_netvsc: Fix net device attach on older Windows hosts
  (bnc#1012628).
- tipc: fix one byte leak in tipc_sk_set_orig_addr()
  (bnc#1012628).
- tcp: restore autocorking (bnc#1012628).
- sctp: clear the new asoc's stream outcnt in sctp_stream_update
  (bnc#1012628).
- nfp: flower: set tunnel ttl value to net default (bnc#1012628).
- net: systemport: Correclty disambiguate driver instances
  (bnc#1012628).
- net/mlx5e: DCBNL fix min inline header size for dscp
  (bnc#1012628).
- mlxsw: spectrum_switchdev: Do not remove mrouter port from
  MDB's ports list (bnc#1012628).
- udp: fix SO_BINDTODEVICE (bnc#1012628).
- nsh: fix infinite loop (bnc#1012628).
- net/mlx5e: Allow offloading ipv4 header re-write for icmp
  (bnc#1012628).
- ipv6: fix uninit-value in ip6_multipath_l3_keys() (bnc#1012628).
- hv_netvsc: set master device (bnc#1012628).
- net/mlx5: Avoid cleaning flow steering table twice during
  error flow (bnc#1012628).
- net/mlx5e: TX, Use correct counter in dma_map error flow
  (bnc#1012628).
- net: sched: fix error path in tcf_proto_create() when modules
  are not configured (bnc#1012628).
- bonding: send learning packets for vlans on slave (bnc#1012628).
- bonding: do not allow rlb updates to invalid mac (bnc#1012628).
- tg3: Fix vunmap() BUG_ON() triggered from tg3_free_consistent()
  (bnc#1012628).
- tcp: ignore Fast Open on repair mode (bnc#1012628).
- tcp_bbr: fix to zero idle_restart only upon S/ACKed data
  (bnc#1012628).
- sctp: use the old asoc when making the cookie-ack chunk in
  dupcook_d (bnc#1012628).
- sctp: remove sctp_chunk_put from fail_mark err path in
  sctp_ulpevent_make_rcvmsg (bnc#1012628).
- sctp: handle two v4 addrs comparison in sctp_inet6_cmp_addr
  (bnc#1012628).
- sctp: fix the issue that the cookie-ack with auth can't get
  processed (bnc#1012628).
- sctp: delay the authentication for the duplicated cookie-echo
  chunk (bnc#1012628).
- rds: do not leak kernel memory to user land (bnc#1012628).
- r8169: fix powering up RTL8168h (bnc#1012628).
- qmi_wwan: do not steal interfaces from class drivers
  (bnc#1012628).
- openvswitch: Don't swap table in nlattr_set() after
  OVS_ATTR_NESTED is found (bnc#1012628).
- net/tls: Fix connection stall on partial tls record
  (bnc#1012628).
- net/tls: Don't recursively call push_record during
  tls_write_space callbacks (bnc#1012628).
- net: support compat 64-bit time in {s,g}etsockopt (bnc#1012628).
- net/smc: restrict non-blocking connect finish (bnc#1012628).
- net_sched: fq: take care of throttled flows before reuse
  (bnc#1012628).
- net sched actions: fix refcnt leak in skbmod (bnc#1012628).
- net/mlx5: E-Switch, Include VF RDMA stats in vport statistics
  (bnc#1012628).
- net/mlx5e: Err if asked to offload TC match on frag being first
  (bnc#1012628).
- net/mlx4_en: Verify coalescing parameters are in range
  (bnc#1012628).
- net/mlx4_en: Fix an error handling path in
  'mlx4_en_init_netdev()' (bnc#1012628).
- net: ethernet: ti: cpsw: fix packet leaking in dual_mac mode
  (bnc#1012628).
- net: ethernet: sun: niu set correct packet size in skb
  (bnc#1012628).
- llc: better deal with too small mtu (bnc#1012628).
- ipv4: fix memory leaks in udp_sendmsg, ping_v4_sendmsg
  (bnc#1012628).
- ipv4: fix fnhe usage by non-cached routes (bnc#1012628).
- dccp: fix tasklet usage (bnc#1012628).
- bridge: check iface upper dev when setting master via ioctl
  (bnc#1012628).
- 8139too: Use disable_irq_nosync() in rtl8139_poll_controller()
  (bnc#1012628).
- commit 68e48d7
* Thu May 17 2018 msuchanek@suse.de
- kernel-{binary,docs}.spec sort dependencies.
- commit d2ab971
* Thu May 17 2018 mgalbraith@suse.de
- Fix config/x86_64/debug, turn PREEMPT_NONE off, and PREEMPT_DEBUG on.
- commit 3ec7274
* Wed May 16 2018 jslaby@suse.cz
- Linux 4.16.9 (bnc#1012628).
- perf/x86: Fix possible Spectre-v1 indexing for
  x86_pmu::event_map() (bnc#1012628).
- perf/core: Fix possible Spectre-v1 indexing for ->aux_pages[]
  (bnc#1012628).
- perf/x86/msr: Fix possible Spectre-v1 indexing in the MSR driver
  (bnc#1012628).
- perf/x86/cstate: Fix possible Spectre-v1 indexing for pkg_msr
  (bnc#1012628).
- perf/x86: Fix possible Spectre-v1 indexing for hw_perf_event
  cache_* (bnc#1012628).
- tracing/uprobe_event: Fix strncpy corner case (bnc#1012628).
- sched/autogroup: Fix possible Spectre-v1 indexing for
  sched_prio_to_weight[] (bnc#1012628).
- sched/core: Fix possible Spectre-v1 indexing for
  sched_prio_to_weight[] (bnc#1012628).
- swiotlb: silent unwanted warning "buffer is full" (bnc#1012628).
- smb3: directory sync should not return an error (bnc#1012628).
- nvme: Fix sync controller reset return (bnc#1012628).
- nvme: add quirk to force medium priority for SQ creation
  (bnc#1012628).
- thermal: exynos: Propagate error value from tmu_read()
  (bnc#1012628).
- thermal: exynos: Reading temperature makes sense only when
  TMU is turned on (bnc#1012628).
- Bluetooth: btusb: Only check needs_reset_resume DMI table for
  QCA rome chipsets (bnc#1012628).
- Bluetooth: btusb: Add Dell XPS 13 9360 to
  btusb_needs_reset_resume_table (bnc#1012628).
- Revert "Bluetooth: btusb: Fix quirk for Atheros 1525/QCA6174"
  (bnc#1012628).
- arm: dts: imx[35]*: declare flexcan devices to be compatible
  to imx25's flexcan (bnc#1012628).
- cpufreq: schedutil: Avoid using invalid next_freq (bnc#1012628).
- PCI / PM: Check device_may_wakeup() in pci_enable_wake()
  (bnc#1012628).
- PCI / PM: Always check PME wakeup capability for runtime wakeup
  support (bnc#1012628).
- atm: zatm: Fix potential Spectre v1 (bnc#1012628).
- net: atm: Fix potential Spectre v1 (bnc#1012628).
- drm/atomic: Clean private obj old_state/new_state in
  drm_atomic_state_default_clear() (bnc#1012628).
- drm/atomic: Clean old_state/new_state in
  drm_atomic_state_default_clear() (bnc#1012628).
- drm/nouveau/ttm: don't dereference nvbo::cli, it can outlive
  client (bnc#1012628).
- drm/nouveau: Fix deadlock in nv50_mstm_register_connector()
  (bnc#1012628).
- drm/i915: Adjust eDP's logical vco in a reliable place
  (bnc#1012628).
- drm/i915: Fix drm:intel_enable_lvds ERROR message in kernel log
  (bnc#1012628).
- drm/ttm: Use GFP_TRANSHUGE_LIGHT for allocating huge pages
  (bnc#1012628).
- drm/vc4: Fix scaling of uni-planar formats (bnc#1012628).
- mtd: rawnand: marvell: fix command xtype in BCH write hook
  (bnc#1012628).
- mtd: rawnand: marvell: pass ms delay to wait_op (bnc#1012628).
- can: hi311x: Work around TX complete interrupt erratum
  (bnc#1012628).
- can: hi311x: Acquire SPI lock on ->do_get_berr_counter
  (bnc#1012628).
- can: kvaser_usb: Increase correct stats counter in
  kvaser_usb_rx_can_msg() (bnc#1012628).
- can: flexcan: fix endianess detection (bnc#1012628).
- ceph: fix rsize/wsize capping in ceph_direct_read_write()
  (bnc#1012628).
- mm, oom: fix concurrent munlock and oom reaper unmap, v3
  (bnc#1012628).
- mm: sections are not offlined during memory hotremove
  (bnc#1012628).
- z3fold: fix reclaim lock-ups (bnc#1012628).
- tracing: Fix regex_match_front() to not over compare the test
  string (bnc#1012628).
- dm integrity: use kvfree for kvmalloc'd memory (bnc#1012628).
- libata: Apply NOLPM quirk for SanDisk SD7UB3Q*G1001 SSDs
  (bnc#1012628).
- rfkill: gpio: fix memory leak in probe error path (bnc#1012628).
- gpio: fix error path in lineevent_create (bnc#1012628).
- gpio: fix aspeed_gpio unmask irq (bnc#1012628).
- gpioib: do not free unrequested descriptors (bnc#1012628).
- compat: fix 4-byte infoleak via uninitialized struct field
  (bnc#1012628).
- bdi: Fix oops in wb_workfn() (bnc#1012628).
- bdi: Fix use after free bug in debugfs_remove() (bnc#1012628).
- bdi: wake up concurrent wb_shutdown() callers (bnc#1012628).
- tcp: fix TCP_REPAIR_QUEUE bound checking (bnc#1012628).
- i2c: dev: prevent ZERO_SIZE_PTR deref in i2cdev_ioctl_rdwr()
  (bnc#1012628).
- perf: Remove superfluous allocation error check (bnc#1012628).
- memcg: fix per_node_info cleanup (bnc#1012628).
- bpf/tracing: fix a deadlock in perf_event_detach_bpf_prog
  (bnc#1012628).
- inetpeer: fix uninit-value in inet_getpeer (bnc#1012628).
- soreuseport: initialise timewait reuseport field (bnc#1012628).
- ipv4: fix uninit-value in ip_route_output_key_hash_rcu()
  (bnc#1012628).
- dccp: initialize ireq->ir_mark (bnc#1012628).
- net: fix uninit-value in __hw_addr_add_ex() (bnc#1012628).
- net: initialize skb->peeked when cloning (bnc#1012628).
- net: fix rtnh_ok() (bnc#1012628).
- netlink: fix uninit-value in netlink_sendmsg (bnc#1012628).
- crypto: af_alg - fix possible uninit-value in alg_bind()
  (bnc#1012628).
- rds: tcp: must use spin_lock_irq* and not spin_lock_bh with
  rds_tcp_conn_lock (bnc#1012628).
- kcm: Call strp_stop before strp_done in kcm_attach
  (bnc#1012628).
- clk: ti: fix flag space conflict with clkctrl clocks
  (bnc#1012628).
- netfilter: ebtables: don't attempt to allocate 0-sized compat
  array (bnc#1012628).
- ipvs: fix rtnl_lock lockups caused by start_sync_thread
  (bnc#1012628).
- commit 4f45b1e
* Wed May 16 2018 msuchanek@suse.de
- macros.kernel-source: Fix building non-x86 KMPs
- commit 8631d05
* Tue May 15 2018 jeffm@suse.com
- reiserfs: package in separate KMP (FATE#323394).
- commit d14f152
* Mon May 14 2018 msuchanek@suse.de
- macros.kernel-source: ignore errors when using make to print kernel release
  There is no way to handle the errors anyway and including the error into
  package version does not give good results.
- commit 282e9a6
* Mon May 14 2018 palcantara@suse.de
- cifs: smb2ops: Fix listxattr() when there are no EAs
  (bsc#1091442).
- commit c6f0d32
* Mon May 14 2018 mkubecek@suse.cz
- Update to 4.17-rc5
- commit 80e3a99
* Fri May 11 2018 msuchanek@suse.de
- Revert "kernel-binary: do not package extract-cert when not signing modules"
  This reverts commit 10a8bc496a553b8069d490a8ae7508bdb19f58d9.
- commit 1f7acca
* Wed May  9 2018 jslaby@suse.cz
- Linux 4.16.8 (bnc#1012628).
- ACPI / button: make module loadable when booted in non-ACPI mode
  (bnc#1012628).
- arm64: Add work around for Arm Cortex-A55 Erratum 1024718
  (bnc#1012628).
- ALSA: hda - Fix incorrect usage of IS_REACHABLE() (bnc#1012628).
- ALSA: pcm: Check PCM state at xfern compat ioctl (bnc#1012628).
- ALSA: seq: Fix races at MIDI encoding in
  snd_virmidi_output_trigger() (bnc#1012628).
- ALSA: dice: fix kernel NULL pointer dereference due to invalid
  calculation for array index (bnc#1012628).
- ALSA: aloop: Mark paused device as inactive (bnc#1012628).
- ALSA: aloop: Add missing cable lock to ctl API callbacks
  (bnc#1012628).
- errseq: Always report a writeback error once (bnc#1012628).
- tracepoint: Do not warn on ENOMEM (bnc#1012628).
- scsi: target: Fix fortify_panic kernel exception (bnc#1012628).
- Input: leds - fix out of bound access (bnc#1012628).
- Input: atmel_mxt_ts - add touchpad button mapping for Samsung
  Chromebook Pro (bnc#1012628).
- swiotlb: fix inversed DMA_ATTR_NO_WARN test (bnc#1012628).
- rtlwifi: cleanup 8723be ant_sel definition (bnc#1012628).
- xfs: prevent creating negative-sized file via INSERT_RANGE
  (bnc#1012628).
- tools: power/acpi, revert to LD = gcc (bnc#1012628).
- RDMA/cxgb4: release hw resources on device removal
  (bnc#1012628).
- RDMA/ucma: Allow resolving address w/o specifying source address
  (bnc#1012628).
- RDMA/mlx5: Fix multiple NULL-ptr deref errors in rereg_mr flow
  (bnc#1012628).
- RDMA/mlx4: Add missed RSS hash inner header flag (bnc#1012628).
- RDMA/mlx5: Protect from shift operand overflow (bnc#1012628).
- NET: usb: qmi_wwan: add support for ublox R410M PID 0x90b2
  (bnc#1012628).
- IB/mlx5: Use unlimited rate when static rate is not supported
  (bnc#1012628).
- infiniband: mlx5: fix build errors when INFINIBAND_USER_ACCESS=m
  (bnc#1012628).
- IB/hfi1: Fix handling of FECN marked multicast packet
  (bnc#1012628).
- IB/hfi1: Fix loss of BECN with AHG (bnc#1012628).
- IB/hfi1: Fix NULL pointer dereference when invalid num_vls is
  used (bnc#1012628).
- iw_cxgb4: Atomically flush per QP HW CQEs (bnc#1012628).
- btrfs: Take trans lock before access running trans in
  check_delayed_ref (bnc#1012628).
- drm/vc4: Make sure vc4_bo_{inc,dec}_usecnt() calls are balanced
  (bnc#1012628).
- drm/vmwgfx: Fix a buffer object leak (bnc#1012628).
- drm/bridge: vga-dac: Fix edid memory leak (bnc#1012628).
- test_firmware: fix setting old custom fw path back on exit,
  second try (bnc#1012628).
- xhci: Fix use-after-free in xhci_free_virt_device (bnc#1012628).
- USB: serial: visor: handle potential invalid device
  configuration (bnc#1012628).
- usb: dwc3: gadget: Fix list_del corruption in dwc3_ep_dequeue
  (bnc#1012628).
- USB: Accept bulk endpoints with 1024-byte maxpacket
  (bnc#1012628).
- USB: serial: option: reimplement interface masking
  (bnc#1012628).
- USB: serial: option: adding support for ublox R410M
  (bnc#1012628).
- usb: musb: host: fix potential NULL pointer dereference
  (bnc#1012628).
- usb: musb: trace: fix NULL pointer dereference in musb_g_tx()
  (bnc#1012628).
- platform/x86: asus-wireless: Fix NULL pointer dereference
  (bnc#1012628).
- platform/x86: Kconfig: Fix dell-laptop dependency chain
  (bnc#1012628).
- KVM: x86: remove APIC Timer periodic/oneshot spikes
  (bnc#1012628).
- x86/tsc: Always unregister clocksource_tsc_early (bnc#1012628).
- x86/tsc: Fix mark_tsc_unstable() (bnc#1012628).
- irqchip/qcom: Fix check for spurious interrupts (bnc#1012628).
- clocksource: Allow clocksource_mark_unstable() on unregistered
  clocksources (bnc#1012628).
- clocksource: Initialize cs->wd_list (bnc#1012628).
- clocksource: Consistent de-rate when marking unstable
  (bnc#1012628).
- tracing: Fix bad use of igrab in trace_uprobe.c (bnc#1012628).
- Delete patches.suse/tools-power-acpi-revert-to-LD-gcc.patch.
- Update config files.
- commit 9269cc1
* Mon May  7 2018 mkubecek@suse.cz
- Update to 4.17-rc4
- Eliminated 2 patches
- Update to 4.17-rc3
- Eliminated 2 patches
- commit a993a00
* Wed May  2 2018 jslaby@suse.cz
- Linux 4.16.7 (bnc#1012628).
- ext4: prevent right-shifting extents beyond EXT_MAX_BLOCKS
  (bnc#1012628).
- ext4: set h_journal if there is a failure starting a reserved
  handle (bnc#1012628).
- ext4: add MODULE_SOFTDEP to ensure crc32c is included in the
  initramfs (bnc#1012628).
- ext4: add validity checks for bitmap block numbers
  (bnc#1012628).
- ext4: fix bitmap position validation (bnc#1012628).
- random: set up the NUMA crng instances after the CRNG is fully
  initialized (bnc#1012628).
- random: fix possible sleeping allocation from irq context
  (bnc#1012628).
- random: rate limit unseeded randomness warnings (bnc#1012628).
- usbip: usbip_event: fix to not print kernel pointer address
  (bnc#1012628).
- usbip: usbip_host: fix to hold parent lock for device_attach()
  calls (bnc#1012628).
- usbip: vhci_hcd: Fix usb device and sockfd leaks (bnc#1012628).
- usbip: vhci_hcd: check rhport before using in vhci_hub_control()
  (bnc#1012628).
- Revert "xhci: plat: Register shutdown for xhci_plat"
  (bnc#1012628).
- xhci: Fix Kernel oops in xhci dbgtty (bnc#1012628).
- xhci: Fix USB ports for Dell Inspiron 5775 (bnc#1012628).
- USB: serial: simple: add libtransistor console (bnc#1012628).
- USB: serial: ftdi_sio: use jtag quirk for Arrow USB Blaster
  (bnc#1012628).
- USB: serial: cp210x: add ID for NI USB serial console
  (bnc#1012628).
- serial: mvebu-uart: Fix local flags handling on termios update
  (bnc#1012628).
- usb: typec: ucsi: Increase command completion timeout value
  (bnc#1012628).
- usb: core: Add quirk for HP v222w 16GB Mini (bnc#1012628).
- USB: Increment wakeup count on remote wakeup (bnc#1012628).
- virtio: add ability to iterate over vqs (bnc#1012628).
- virtio_console: don't tie bufs to a vq (bnc#1012628).
- virtio_console: free buffers after reset (bnc#1012628).
- virtio_console: drop custom control queue cleanup (bnc#1012628).
- virtio_console: move removal code (bnc#1012628).
- virtio_console: reset on out of memory (bnc#1012628).
- drm/virtio: fix vq wait_event condition (bnc#1012628).
- tty: Don't call panic() at tty_ldisc_init() (bnc#1012628).
- tty: n_gsm: Fix long delays with control frame timeouts in
  ADM mode (bnc#1012628).
- tty: n_gsm: Fix DLCI handling for ADM mode if debug & 2 is
  not set (bnc#1012628).
- tty: Avoid possible error pointer dereference at
  tty_ldisc_restore() (bnc#1012628).
- tty: Use __GFP_NOFAIL for tty_ldisc_get() (bnc#1012628).
- cifs: smbd: Avoid allocating iov on the stack (bnc#1012628).
- cifs: smbd: Don't use RDMA read/write when signing is used
  (bnc#1012628).
- ALSA: dice: fix OUI for TC group (bnc#1012628).
- ALSA: dice: fix error path to destroy initialized stream data
  (bnc#1012628).
- ALSA: hda - Skip jack and others for non-existing PCM streams
  (bnc#1012628).
- ALSA: opl3: Hardening for potential Spectre v1 (bnc#1012628).
- ALSA: asihpi: Hardening for potential Spectre v1 (bnc#1012628).
- ALSA: hdspm: Hardening for potential Spectre v1 (bnc#1012628).
- ALSA: rme9652: Hardening for potential Spectre v1 (bnc#1012628).
- ALSA: control: Hardening for potential Spectre v1 (bnc#1012628).
- ALSA: pcm: Return negative delays from SNDRV_PCM_IOCTL_DELAY
  (bnc#1012628).
- ALSA: core: Report audio_tstamp in snd_pcm_sync_ptr
  (bnc#1012628).
- ALSA: seq: oss: Fix unbalanced use lock for synth MIDI device
  (bnc#1012628).
- ALSA: seq: oss: Hardening for potential Spectre v1
  (bnc#1012628).
- ALSA: hda: Hardening for potential Spectre v1 (bnc#1012628).
- ALSA: hda/realtek - Add some fixes for ALC233 (bnc#1012628).
- ALSA: hda/realtek - Update ALC255 depop optimize (bnc#1012628).
- ALSA: hda/realtek - change the location for one of two front
  mics (bnc#1012628).
- mtd: spi-nor: cadence-quadspi: Fix page fault kernel panic
  (bnc#1012628).
- mtd: cfi: cmdset_0001: Do not allow read/write to suspend
  erase block (bnc#1012628).
- mtd: cfi: cmdset_0001: Workaround Micron Erase suspend bug
  (bnc#1012628).
- mtd: cfi: cmdset_0002: Do not allow read/write to suspend
  erase block (bnc#1012628).
- mtd: rawnand: tango: Fix struct clk memory leak (bnc#1012628).
- mtd: rawnand: marvell: fix the chip-select DT parsing logic
  (bnc#1012628).
- kobject: don't use WARN for registration failures (bnc#1012628).
- scsi: sd_zbc: Avoid that resetting a zone fails sporadically
  (bnc#1012628).
- scsi: sd: Defer spinning up drive while SANITIZE is in progress
  (bnc#1012628).
- blk-mq: start request gstate with gen 1 (bnc#1012628).
- bfq-iosched: ensure to clear bic/bfqq pointers when preparing
  request (bnc#1012628).
- block: do not use interruptible wait anywhere (bnc#1012628).
- vfio: ccw: process ssch with interrupts disabled (bnc#1012628).
- SMB311: Fix reconnect (bnc#1012628).
- ANDROID: binder: prevent transactions into own process
  (bnc#1012628).
- PCI: aardvark: Fix logic in advk_pcie_{rd,wr}_conf()
  (bnc#1012628).
- PCI: aardvark: Set PIO_ADDR_LS correctly in advk_pcie_rd_conf()
  (bnc#1012628).
- PCI: aardvark: Use ISR1 instead of ISR0 interrupt in legacy
  irq mode (bnc#1012628).
- PCI: aardvark: Fix PCIe Max Read Request Size setting
  (bnc#1012628).
- ARM: amba: Make driver_override output consistent with other
  buses (bnc#1012628).
- ARM: amba: Fix race condition with driver_override
  (bnc#1012628).
- ARM: amba: Don't read past the end of sysfs "driver_override"
  buffer (bnc#1012628).
- ARM: dts: Fix NAS4220B pin config (bnc#1012628).
- ARM: socfpga_defconfig: Remove QSPI Sector 4K size force
  (bnc#1012628).
- KVM: arm/arm64: Close VMID generation race (bnc#1012628).
- slimbus: Fix out-of-bounds access in slim_slicesize()
  (bnc#1012628).
- powerpc/mm: Flush cache on memory hot(un)plug (bnc#1012628).
- powerpc/mce: Fix a bug where mce loops on memory UE
  (bnc#1012628).
- powerpc/powernv/npu: Do a PID GPU TLB flush when invalidating
  a large address range (bnc#1012628).
- crypto: drbg - set freed buffers to NULL (bnc#1012628).
- ASoC: dmic: Fix clock parenting (bnc#1012628).
- ASoC: fsl_esai: Fix divisor calculation failure at lower ratio
  (bnc#1012628).
- libceph: un-backoff on tick when we have a authenticated session
  (bnc#1012628).
- libceph: reschedule a tick in finish_hunting() (bnc#1012628).
- libceph: validate con->state at the top of try_write()
  (bnc#1012628).
- PCI / PM: Do not clear state_saved in pci_pm_freeze() when
  smart suspend is set (bnc#1012628).
- virt: vbox: Move declarations of vboxguest private functions
  to private header (bnc#1012628).
- virt: vbox: Add vbg_req_free() helper function (bnc#1012628).
- virt: vbox: Use __get_free_pages instead of kmalloc for DMA32
  memory (bnc#1012628).
- fpga-manager: altera-ps-spi: preserve nCONFIG state
  (bnc#1012628).
- module: Fix display of wrong module .text address (bnc#1012628).
- earlycon: Use a pointer table to fix __earlycon_table stride
  (bnc#1012628).
- cpufreq: powernv: Fix hardlockup due to synchronous smp_call
  in timer interrupt (bnc#1012628).
- rtc: opal: Fix OPAL RTC driver OPAL_BUSY loops (bnc#1012628).
- drm/edid: Reset more of the display info (bnc#1012628).
- drm/amdgpu: set COMPUTE_PGM_RSRC1 for SGPR/VGPR clearing shaders
  (bnc#1012628).
- drm/i915/fbdev: Enable late fbdev initial configuration
  (bnc#1012628).
- drm/i915/audio: set minimum CD clock to twice the BCLK
  (bnc#1012628).
- drm/i915: Enable display WA#1183 from its correct spot
  (bnc#1012628).
- drm/amd/display: Fix deadlock when flushing irq (bnc#1012628).
- drm/amd/display: Don't read EDID in atomic_check (bnc#1012628).
- drm/amd/display: Disallow enabling CRTC without primary plane
  with FB (bnc#1012628).
- x86/ipc: Fix x32 version of shmid64_ds and msqid64_ds
  (bnc#1012628).
- x86/smpboot: Don't use mwait_play_dead() on AMD systems
  (bnc#1012628).
- x86/microcode/intel: Save microcode patch unconditionally
  (bnc#1012628).
- x86/microcode: Do not exit early from __reload_late()
  (bnc#1012628).
- tick/sched: Do not mess with an enqueued hrtimer (bnc#1012628).
- crypto: ccp - add check to get PSP master only when PSP is
  detected (bnc#1012628).
- arm/arm64: KVM: Add PSCI version selection API (bnc#1012628).
- sparc64: Fix mistake in oradax license text (bnc#1012628).
- commit 938738d
* Wed May  2 2018 msuchanek@suse.de
- kernel-binary: also default klp_symbols to 0 here.
- commit e35f14a
* Wed May  2 2018 msuchanek@suse.de
- klp_symbols: make --klp-symbols argument semantic sane
  It selects build of klp symbols and defaults to off
- commit 0e53042
* Wed May  2 2018 jslaby@suse.cz
- tools: power/acpi, revert to LD = gcc (build fix).
- Delete
  patches.suse/revert-tools-fix-cross-compile-var-clobbering.patch.
  Replace by the upstream commit.
- commit ad991e8
* Mon Apr 30 2018 jslaby@suse.cz
- Linux 4.16.6 (bnc#1012628).
- Revert "pinctrl: intel: Initialize GPIO properly when used
  through irqchip" (bnc#1012628).
- drm: bridge: dw-hdmi: Fix overflow workaround for Amlogic
  Meson GX SoCs (bnc#1012628).
- i40e: Fix attach VF to VM issue (bnc#1012628).
- tpm: cmd_ready command can be issued only after granting
  locality (bnc#1012628).
- tpm: tpm-interface: fix tpm_transmit/_cmd kdoc (bnc#1012628).
- tpm: add retry logic (bnc#1012628).
- bonding: do not set slave_dev npinfo before slave_enable_netpoll
  in bond_enslave (bnc#1012628).
- docs: ip-sysctl.txt: fix name of some ipv6 variables
  (bnc#1012628).
- ipv6: add RTA_TABLE and RTA_PREFSRC to rtm_ipv6_policy
  (bnc#1012628).
- ipv6: sr: fix NULL pointer dereference in seg6_do_srh_encap()-
  v4 pkts (bnc#1012628).
- KEYS: DNS: limit the length of option strings (bnc#1012628).
- l2tp: check sockaddr length in pppol2tp_connect() (bnc#1012628).
- llc: delete timers synchronously in llc_sk_free() (bnc#1012628).
- net: af_packet: fix race in PACKET_{R|T}X_RING (bnc#1012628).
- net: fix deadlock while clearing neighbor proxy table
  (bnc#1012628).
- net: mvpp2: Fix DMA address mask size (bnc#1012628).
- net: qmi_wwan: add Wistron Neweb D19Q1 (bnc#1012628).
- net/smc: fix shutdown in state SMC_LISTEN (bnc#1012628).
- net: stmmac: Disable ACS Feature for GMAC >= 4 (bnc#1012628).
- packet: fix bitfield update race (bnc#1012628).
- pppoe: check sockaddr length in pppoe_connect() (bnc#1012628).
- Revert "macsec: missing dev_put() on error in macsec_newlink()"
  (bnc#1012628).
- sctp: do not check port in sctp_inet6_cmp_addr (bnc#1012628).
- strparser: Do not call mod_delayed_work with a timeout of
  LONG_MAX (bnc#1012628).
- strparser: Fix incorrect strp->need_bytes value (bnc#1012628).
- tcp: clear tp->packets_out when purging write queue
  (bnc#1012628).
- tcp: don't read out-of-bounds opsize (bnc#1012628).
- tcp: md5: reject TCP_MD5SIG or TCP_MD5SIG_EXT on established
  sockets (bnc#1012628).
- team: avoid adding twice the same option to the event list
  (bnc#1012628).
- team: fix netconsole setup over team (bnc#1012628).
- tipc: add policy for TIPC_NLA_NET_ADDR (bnc#1012628).
- vlan: Fix reading memory beyond skb->tail in
  skb_vlan_tagged_multi (bnc#1012628).
- vmxnet3: fix incorrect dereference when rxvlan is disabled
  (bnc#1012628).
- amd-xgbe: Add pre/post auto-negotiation phy hooks (bnc#1012628).
- amd-xgbe: Improve KR auto-negotiation and training
  (bnc#1012628).
- amd-xgbe: Only use the SFP supported transceiver signals
  (bnc#1012628).
- net: sched: ife: signal not finding metaid (bnc#1012628).
- net: sched: ife: handle malformed tlv length (bnc#1012628).
- net: sched: ife: check on metadata length (bnc#1012628).
- l2tp: hold reference on tunnels in netlink dumps (bnc#1012628).
- l2tp: hold reference on tunnels printed in pppol2tp proc file
  (bnc#1012628).
- l2tp: hold reference on tunnels printed in l2tp/tunnels debugfs
  file (bnc#1012628).
- l2tp: fix {pppol2tp, l2tp_dfs}_seq_stop() in case of seq_file
  overflow (bnc#1012628).
- llc: hold llc_sap before release_sock() (bnc#1012628).
- llc: fix NULL pointer deref for SOCK_ZAPPED (bnc#1012628).
- s390/qeth: fix error handling in adapter command callbacks
  (bnc#1012628).
- s390/qeth: avoid control IO completion stalls (bnc#1012628).
- s390/qeth: handle failure on workqueue creation (bnc#1012628).
- net: ethernet: ti: cpsw: fix tx vlan priority mapping
  (bnc#1012628).
- net: validate attribute sizes in neigh_dump_table()
  (bnc#1012628).
- bnxt_en: Fix memory fault in bnxt_ethtool_init() (bnc#1012628).
- virtio-net: add missing virtqueue kick when flushing packets
  (bnc#1012628).
- VSOCK: make af_vsock.ko removable again (bnc#1012628).
- net: aquantia: Regression on reset with 1.x firmware
  (bnc#1012628).
- tun: fix vlan packet truncation (bnc#1012628).
- net: aquantia: oops when shutdown on already stopped device
  (bnc#1012628).
- virtio_net: split out ctrl buffer (bnc#1012628).
- virtio_net: fix adding vids on big-endian (bnc#1012628).
- Revert "mm/hmm: fix header file if/else/endif maze"
  (bnc#1012628).
- commoncap: Handle memory allocation failure (bnc#1012628).
- scsi: mptsas: Disable WRITE SAME (bnc#1012628).
- cdrom: information leak in cdrom_ioctl_media_changed()
  (bnc#1012628).
- fsnotify: Fix fsnotify_mark_connector race (bnc#1012628).
- m68k/mac: Don't remap SWIM MMIO region (bnc#1012628).
- block/swim: Check drive type (bnc#1012628).
- block/swim: Don't log an error message for an invalid ioctl
  (bnc#1012628).
- block/swim: Remove extra put_disk() call from error path
  (bnc#1012628).
- block/swim: Rename macros to avoid inconsistent inverted logic
  (bnc#1012628).
- block/swim: Select appropriate drive on device open
  (bnc#1012628).
- block/swim: Fix array bounds check (bnc#1012628).
- block/swim: Fix IO error at end of medium (bnc#1012628).
- tracing: Fix missing tab for hwlat_detector print format
  (bnc#1012628).
- hwmon: (k10temp) Add temperature offset for Ryzen 2700X
  (bnc#1012628).
- hwmon: (k10temp) Add support for AMD Ryzen w/ Vega graphics
  (bnc#1012628).
- s390/cio: update chpid descriptor after resource accessibility
  event (bnc#1012628).
- s390/dasd: fix IO error for newly defined devices (bnc#1012628).
- s390/uprobes: implement arch_uretprobe_is_alive() (bnc#1012628).
- s390/cpum_cf: rename IBM z13/z14 counter names (bnc#1012628).
- kprobes: Fix random address output of blacklist file
  (bnc#1012628).
- ACPI / video: Only default only_lcd to true on Win8-ready
  _desktops_ (bnc#1012628).
- commit 566acbc
* Mon Apr 30 2018 mkubecek@suse.cz
- Update to 4.17-rc3
- Eliminated 1 patch
- Config changes:
  - x86_64 and i386
  - SND_SST_ATOM_HIFI2_PLATFORM_ACPI=m
  - armv7hl
  - CONFIG_NFT_REDIR_IPV4=m (sync with other configs)
  - CONFIG_NFT_REDIR_IPV6=m (sync with other configs)
- commit 088acbb
* Sun Apr 29 2018 afaerber@suse.de
- config: armv7hl: Update to 4.17-rc2
- commit e76ffdc
* Sun Apr 29 2018 afaerber@suse.de
- config: armv6hl: Update to 4.17-rc2
- commit 7ac1254
* Sun Apr 29 2018 afaerber@suse.de
- config: arm64: Update to 4.17-rc2
- commit 8535e20
* Fri Apr 27 2018 msuchanek@suse.de
- kernel-binary: only install modules.fips on modular kernels.
- commit 2cb2bec
* Thu Apr 26 2018 jslaby@suse.cz
- Linux 4.16.5 (bnc#1012628).
- cifs: smbd: Check for iov length on sending the last iov
  (bnc#1012628).
- cifs: do not allow creating sockets except with SMB1 posix
  exensions (bnc#1012628).
- btrfs: fix unaligned access in readdir (bnc#1012628).
- btrfs: Fix race condition between delayed refs and blockgroup
  removal (bnc#1012628).
- x86/acpi: Prevent X2APIC id 0xffffffff from being accounted
  (bnc#1012628).
- clocksource/imx-tpm: Correct -ETIME return condition check
  (bnc#1012628).
- posix-cpu-timers: Ensure set_process_cpu_timer is always
  evaluated (bnc#1012628).
- x86/tsc: Prevent 32bit truncation in calc_hpet_ref()
  (bnc#1012628).
- drm/vc4: Fix memory leak during BO teardown (bnc#1012628).
- drm/i915/gvt: throw error on unhandled vfio ioctls
  (bnc#1012628).
- drm/i915/gvt: Add drm_format_mod update (bnc#1012628).
- drm/i915/bios: filter out invalid DDC pins from VBT child
  devices (bnc#1012628).
- drm/i915/audio: Fix audio detection issue on GLK (bnc#1012628).
- drm/i915: Do no use kfree() to free a kmem_cache_alloc()
  return value (bnc#1012628).
- drm/i915: Fix LSPCON TMDS output buffer enabling from low-power
  state (bnc#1012628).
- alarmtimer: Init nanosleep alarm timer on stack (bnc#1012628).
- mm,vmscan: Allow preallocating memory for register_shrinker()
  (bnc#1012628).
- netfilter: x_tables: cap allocations at 512 mbyte (bnc#1012628).
- netfilter: x_tables: add counters allocation wrapper
  (bnc#1012628).
- netfilter: compat: prepare xt_compat_init_offsets to return
  errors (bnc#1012628).
- netfilter: compat: reject huge allocation requests
  (bnc#1012628).
- netfilter: x_tables: limit allocation requests for blob rule
  heads (bnc#1012628).
- perf: Fix sample_max_stack maximum check (bnc#1012628).
- perf: Return proper values for user stack errors (bnc#1012628).
- RDMA/mlx5: Fix NULL dereference while accessing XRC_TGT QPs
  (bnc#1012628).
- Revert "KVM: X86: Fix SMRAM accessing even if VM is shutdown"
  (bnc#1012628).
- mac80211_hwsim: fix use-after-free bug in hwsim_exit_net
  (bnc#1012628).
- Refresh
  patches.suse/btrfs-fs-super.c-add-new-super-block-devices-super_block_d.patch.
- commit 16c5ff9
* Wed Apr 25 2018 tiwai@suse.de
- Revert "ath10k: send (re)assoc peer command when NSS changed"
  (bsc#1090458).
- commit 3f3a85c
* Tue Apr 24 2018 msuchanek@suse.de
- split-modules: use MAKE_ARGS
- commit d8fe174
* Tue Apr 24 2018 mcgrof@suse.com
- xfs: set format back to extents if xfs_bmap_extents_to_btree (bsc#1090717, CVE-2018-10323).
- xfs: set format back to extents if xfs_bmap_extents_to_btree
  (bsc#1090717, CVE-2018-10323).
- commit ddcd6f2
* Tue Apr 24 2018 msuchanek@suse.de
- kernel-binary: pass MAKE_ARGS to install script as well.
- commit ce62ae7
* Tue Apr 24 2018 mkubecek@suse.cz
- Update config files.
- commit becf16d
* Tue Apr 24 2018 msuchanek@suse.de
- kernel-binary: pass ARCH= to kernel build
  Recent kernel does not save CONFIG_64BIT so it has to be specified by
  arch.
- commit fb21b73
* Tue Apr 24 2018 tiwai@suse.de
- ALSA: usb-audio: Skip broken EU on Dell dock USB-audio
  (bsc#1090658).
- commit 5639170
* Tue Apr 24 2018 mkubecek@suse.cz
- config: fix i386 configs
  Since mainline commit f467c5640c29 ("kconfig: only write '# CONFIG_FOO is
  not set' for visible symbols"), make silentoldconfig (or make syncconfig as
  it is called now) doesn't add CONFIG_64BIT line into i386 configs if called
  with ARCH=i386.
  During the build, it's called without ARCH=i386 so that it requests this
  option to be entered manually and the build fails. Long term solution would
  probably be passing ARCH=%%{cpu_arch} to all make commands; for now, just
  add CONFIG_64BIT line to i386/pae to fix the build as is.
- commit d9a33ad
* Tue Apr 24 2018 jslaby@suse.cz
- Linux 4.16.4 (bnc#1012628).
- Bluetooth: hci_bcm: Add irq_polarity module option
  (bnc#1012628).
- cpufreq: CPPC: Use transition_delay_us depending
  transition_latency (bnc#1012628).
- cpufreq: armada-37xx: Fix clock leak (bnc#1012628).
- ubifs: Check ubifs_wbuf_sync() return code (bnc#1012628).
- ubi: fastmap: Don't flush fastmap work on detach (bnc#1012628).
- ubi: Fix error for write access (bnc#1012628).
- ubi: Reject MLC NAND (bnc#1012628).
- mm/ksm.c: fix inconsistent accounting of zero pages
  (bnc#1012628).
- mm/hmm: fix header file if/else/endif maze (bnc#1012628).
- mm/hmm: hmm_pfns_bad() was accessing wrong struct (bnc#1012628).
- mm: hwpoison: disable memory error handling on 1GB hugepage
  (bnc#1012628).
- task_struct: only use anon struct under randstruct plugin
  (bnc#1012628).
- fs/reiserfs/journal.c: add missing resierfs_warning() arg
  (bnc#1012628).
- ipc/shm: fix use-after-free of shm file via remap_file_pages()
  (bnc#1012628).
- mm, slab: reschedule cache_reap() on the same CPU (bnc#1012628).
- usb: musb: gadget: misplaced out of bounds check (bnc#1012628).
- phy: allwinner: sun4i-usb: poll vbus changes on A23/A33 when
  driving VBUS (bnc#1012628).
- usb: gadget: udc: core: update usb_ep_queue() documentation
  (bnc#1012628).
- ARM64: dts: meson: reduce odroid-c2 eMMC maximum rate
  (bnc#1012628).
- KVM: arm/arm64: vgic-its: Fix potential overrun in
  vgic_copy_lpi_list (bnc#1012628).
- ARM: EXYNOS: Fix coupled CPU idle freeze on Exynos4210
  (bnc#1012628).
- arm: dts: mt7623: fix USB initialization fails on bananapi-r2
  (bnc#1012628).
- ARM: dts: at91: at91sam9g25: fix mux-mask pinctrl property
  (bnc#1012628).
- ARM: dts: exynos: Fix IOMMU support for GScaler devices on
  Exynos5250 (bnc#1012628).
- ARM: dts: at91: sama5d4: fix pinctrl compatible string
  (bnc#1012628).
- spi: atmel: init FIFOs before spi enable (bnc#1012628).
- spi: Fix scatterlist elements size in spi_map_buf (bnc#1012628).
- spi: Fix unregistration of controller with fixed SPI bus number
  (bnc#1012628).
- media: rc: oops in ir_timer_keyup after device unplug
  (bnc#1012628).
- media: atomisp_fops.c: disable atomisp_compat_ioctl32
  (bnc#1012628).
- media: vivid: check if the cec_adapter is valid (bnc#1012628).
- media: vb2: core: Finish buffers at the end of the stream
  (bnc#1012628).
- media: vsp1: Fix BRx conditional path in WPF (bnc#1012628).
- x86/xen: Delay get_cpu_cap until stack canary is established
  (bnc#1012628).
- regmap: Fix reversed bounds check in regmap_raw_write()
  (bnc#1012628).
- ACPI / video: Add quirk to force acpi-video backlight on
  Samsung 670Z5E (bnc#1012628).
- ACPI / hotplug / PCI: Check presence of slot itself in
  get_slot_status() (bnc#1012628).
- acpi, nfit: rework NVDIMM leaf method detection (bnc#1012628).
- USB: gadget: f_midi: fixing a possible double-free in f_midi
  (bnc#1012628).
- USB:fix USB3 devices behind USB3 hubs not resuming at hibernate
  thaw (bnc#1012628).
- usb: dwc3: prevent setting PRTCAP to OTG from debugfs
  (bnc#1012628).
- usb: dwc3: pci: Properly cleanup resource (bnc#1012628).
- usb: dwc3: gadget: never call ->complete() from ->ep_queue()
  (bnc#1012628).
- cifs: fix memory leak in SMB2_open() (bnc#1012628).
- fix smb3-encryption breakage when CONFIG_DEBUG_SG=y
  (bnc#1012628).
- Tree connect for SMB3.1.1 must be signed for non-encrypted
  shares (bnc#1012628).
- cifs: smbd: avoid reconnect lockup (bnc#1012628).
- cifs: smbd: disconnect transport on RDMA errors (bnc#1012628).
- smb3: Fix root directory when server returns inode number of
  zero (bnc#1012628).
- HID: i2c-hid: fix size check and type usage (bnc#1012628).
- i2c: i801: Save register SMBSLVCMD value only once
  (bnc#1012628).
- i2c: i801: Restore configuration at shutdown (bnc#1012628).
- CIFS: refactor crypto shash/sdesc allocation&free (bnc#1012628).
- CIFS: add sha512 secmech (bnc#1012628).
- CIFS: implement v3.11 preauth integrity (bnc#1012628).
- CIFS: fix sha512 check in cifs_crypto_secmech_release
  (bnc#1012628).
- powerpc/64s: Fix pkey support in dt_cpu_ftrs, add CPU_FTR_PKEY
  bit (bnc#1012628).
- powerpc/powernv: Handle unknown OPAL errors in
  opal_nvram_write() (bnc#1012628).
- powerpc/eeh: Fix race with driver un/bind (bnc#1012628).
- powerpc/64s: Fix dt_cpu_ftrs to have restore_cpu clear unwanted
  LPCR bits (bnc#1012628).
- powerpc/64: Call H_REGISTER_PROC_TBL when running as a HPT
  guest on POWER9 (bnc#1012628).
- powerpc/64: Fix smp_wmb barrier definition use use lwsync
  consistently (bnc#1012628).
- powerpc/kprobes: Fix call trace due to incorrect preempt count
  (bnc#1012628).
- powerpc/kexec_file: Fix error code when trying to load kdump
  kernel (bnc#1012628).
- powerpc/powernv: define a standard delay for OPAL_BUSY type
  retry loops (bnc#1012628).
- powerpc/powernv: Fix OPAL NVRAM driver OPAL_BUSY loops
  (bnc#1012628).
- powerpc/mm/radix: Fix checkstops caused by invalid tlbiel
  (bnc#1012628).
- ceph: always update atime/mtime/ctime for new inode
  (bnc#1012628).
- HID: Fix hid_report_len usage (bnc#1012628).
- HID: core: Fix size as type u32 (bnc#1012628).
- soc: mediatek: fix the mistaken pointer accessed when subdomains
  are added (bnc#1012628).
- ASoC: ssm2602: Replace reg_default_raw with reg_default
  (bnc#1012628).
- ASoC: topology: Fix kcontrol name string handling (bnc#1012628).
- thunderbolt: Wait a bit longer for ICM to authenticate the
  active NVM (bnc#1012628).
- thunderbolt: Serialize PCIe tunnel creation with PCI rescan
  (bnc#1012628).
- thunderbolt: Resume control channel after hibernation image
  is created (bnc#1012628).
- thunderbolt: Handle connecting device in place of host properly
  (bnc#1012628).
- thunderbolt: Prevent crash when ICM firmware is not running
  (bnc#1012628).
- irqchip/gic: Take lock when updating irq type (bnc#1012628).
- random: use a tighter cap in credit_entropy_bits_safe()
  (bnc#1012628).
- extcon: intel-cht-wc: Set direction and drv flags for V5 boost
  GPIO (bnc#1012628).
- block: use 32-bit blk_status_t on Alpha (bnc#1012628).
- jbd2: if the journal is aborted then don't allow update of
  the log tail (bnc#1012628).
- ext4: shutdown should not prevent get_write_access
  (bnc#1012628).
- ext4: eliminate sleep from shutdown ioctl (bnc#1012628).
- ext4: pass -ESHUTDOWN code to jbd2 layer (bnc#1012628).
- ext4: don't update checksum of new initialized bitmaps
  (bnc#1012628).
- ext4: protect i_disksize update by i_data_sem in direct write
  path (bnc#1012628).
- ext4: fix offset overflow on 32-bit archs in ext4_iomap_begin()
  (bnc#1012628 bsc#1079747).
- ext4: limit xattr size to INT_MAX (bnc#1012628).
- ext4: fail ext4_iget for root directory if unallocated
  (bnc#1012628).
- ext4: always initialize the crc32c checksum driver
  (bnc#1012628).
- ext4: don't allow r/w mounts if metadata blocks overlap the
  superblock (bnc#1012628).
- ext4: move call to ext4_error() into ext4_xattr_check_block()
  (bnc#1012628).
- ext4: add bounds checking to ext4_xattr_find_entry()
  (bnc#1012628).
- ext4: add extra checks to ext4_xattr_block_get() (bnc#1012628).
- ext4: force revalidation of directory pointer after seekdir(2)
  (bnc#1012628).
- dm: backfill abnormal IO support to non-splitting IO submission
  (bnc#1012628).
- dm crypt: limit the number of allocated pages (bnc#1012628).
- RDMA/ucma: Don't allow setting RDMA_OPTION_IB_PATH without an
  RDMA device (bnc#1012628).
- RDMA/mlx5: Protect from NULL pointer derefence (bnc#1012628).
- RDMA/rxe: Fix an out-of-bounds read (bnc#1012628).
- RDMA/core: Avoid that ib_drain_qp() triggers an out-of-bounds
  stack access (bnc#1012628).
- xprtrdma: Fix latency regression on NUMA NFS/RDMA clients
  (bnc#1012628).
- xprtrdma: Fix corner cases when handling device removal
  (bnc#1012628).
- ALSA: pcm: Avoid potential races between OSS ioctls and
  read/write (bnc#1012628).
- ALSA: pcm: Return -EBUSY for OSS ioctls changing busy streams
  (bnc#1012628).
- ALSA: pcm: Fix mutex unbalance in OSS emulation ioctls
  (bnc#1012628).
- ALSA: pcm: Fix UAF at PCM release via PCM timer access
  (bnc#1012628).
- ALSA: pcm: Fix endless loop for XRUN recovery in OSS emulation
  (bnc#1012628).
- IB/srp: Fix srp_abort() (bnc#1012628).
- IB/srp: Fix completion vector assignment algorithm
  (bnc#1012628).
- IB/srpt: Fix an out-of-bounds stack access in
  srpt_zerolength_write() (bnc#1012628).
- drivers/infiniband/core/verbs.c: fix build with gcc-4.4.4
  (bnc#1012628).
- drivers/infiniband/ulp/srpt/ib_srpt.c: fix build with gcc-4.4.4
  (bnc#1012628).
- dm raid: fix nosync status (bnc#1012628).
- dmaengine: at_xdmac: fix rare residue corruption (bnc#1012628).
- cxl: Fix possible deadlock when processing page faults from
  cxllib (bnc#1012628).
- tpm: self test failure should not cause suspend to fail
  (bnc#1012628).
- libnvdimm, dimm: fix dpa reservation vs uninitialized label area
  (bnc#1012628).
- libnvdimm, namespace: use a safe lookup for dimm device name
  (bnc#1012628).
- vsprintf: Do not preprocess non-dereferenced pointers for
  bprintf (%%px and %%pK) (bnc#1012628).
- nfit, address-range-scrub: fix scrub in-progress reporting
  (bnc#1012628).
- nfit: skip region registration for incomplete control regions
  (bnc#1012628).
- ring-buffer: Check if memory is available before allocation
  (bnc#1012628).
- um: Compile with modern headers (bnc#1012628).
- um: Use POSIX ucontext_t instead of struct ucontext
  (bnc#1012628).
- iommu/vt-d: Fix a potential memory leak (bnc#1012628).
- mmc: core: Prevent bus reference leak in mmc_blk_init()
  (bnc#1012628).
- mmc: jz4740: Fix race condition in IRQ mask update
  (bnc#1012628).
- mmc: tmio: Fix error handling when issuing CMD23 (bnc#1012628).
- Revert "drm/amd/display: fix dereferencing possible ERR_PTR()"
  (bnc#1012628).
- drm/amd/display: HDMI has no sound after Panel power off/on
  (bnc#1012628).
- trace_uprobe: Use %%lx to display offset (bnc#1012628).
- PCI: Mark Broadcom HT1100 and HT2000 Root Port Extended Tags
  as broken (bnc#1012628).
- clk: mvebu: armada-38x: add support for missing clocks
  (bnc#1012628).
- clk: fix false-positive Wmaybe-uninitialized warning
  (bnc#1012628).
- clk: mediatek: fix PWM clock source by adding a fixed-factor
  clock (bnc#1012628).
- clk: bcm2835: De-assert/assert PLL reset signal when appropriate
  (bnc#1012628).
- clk: tegra: Mark HCLK, SCLK and EMC as critical (bnc#1012628).
- pwm: rcar: Fix a condition to prevent mismatch value setting
  to duty (bnc#1012628).
- pwm: mediatek: Fix up PWM4 and PWM5 malfunction on MT7623
  (bnc#1012628).
- pwm: mediatek: Improve precision in rate calculation
  (bnc#1012628).
- thermal: imx: Fix race condition in imx_thermal_probe()
  (bnc#1012628).
- dt-bindings: clock: mediatek: add binding for fixed-factor
  clock axisel_d4 (bnc#1012628).
- watchdog: f71808e_wdt: Fix WD_EN register read (bnc#1012628).
- drm/amdgpu: Add an ATPX quirk for hybrid laptop (bnc#1012628).
- drm/amdgpu: Fix always_valid bos multiple LRU insertions
  (bnc#1012628).
- drm/amdgpu/sdma: fix mask in emit_pipeline_sync (bnc#1012628).
- drm/amdgpu: Fix PCIe lane width calculation (bnc#1012628).
- drm/amdgpu/si: implement get/set pcie_lanes asic callback
  (bnc#1012628).
- drm/rockchip: Clear all interrupts before requesting the IRQ
  (bnc#1012628).
- drm/radeon: add PX quirk for Asus K73TK (bnc#1012628).
- drm/radeon: Fix PCIe lane width calculation (bnc#1012628).
- ALSA: line6: Use correct endpoint type for midi output
  (bnc#1012628).
- ALSA: rawmidi: Fix missing input substream checks in compat
  ioctls (bnc#1012628).
- ALSA: hda - New VIA controller suppor no-snoop path
  (bnc#1012628).
- ALSA: hda/realtek - set PINCFG_HEADSET_MIC to parse_flags
  (bnc#1012628).
- ALSA: hda/realtek - adjust the location of one mic
  (bnc#1012628).
- random: fix crng_ready() test (bnc#1012628).
- random: use a different mixing algorithm for
  add_device_randomness() (bnc#1012628).
- random: crng_reseed() should lock the crng instance that it
  is modifying (bnc#1012628).
- random: add new ioctl RNDRESEEDCRNG (bnc#1012628).
- HID: i2c-hid: Fix resume issue on Raydium touchscreen device
  (bnc#1012628).
- HID: input: fix battery level reporting on BT mice
  (bnc#1012628).
- HID: hidraw: Fix crash on HIDIOCGFEATURE with a destroyed device
  (bnc#1012628).
- HID: wacom: bluetooth: send exit report for recent Bluetooth
  devices (bnc#1012628).
- s390: add support for IBM z14 Model ZR1 (bnc#1012628).
- MIPS: uaccess: Add micromips clobbers to bzero invocation
  (bnc#1012628).
- MIPS: memset.S: EVA & fault support for small_memset
  (bnc#1012628).
- MIPS: memset.S: Fix return of __clear_user from Lpartial_fixup
  (bnc#1012628).
- MIPS: memset.S: Fix clobber of v1 in last_fixup (bnc#1012628).
- powerpc/eeh: Fix enabling bridge MMIO windows (bnc#1012628).
- powerpc/xive: Fix trying to "push" an already active pool VP
  (bnc#1012628).
- powerpc/lib: Fix off-by-one in alternate feature patching
  (bnc#1012628).
- udf: Fix leak of UTF-16 surrogates into encoded strings
  (bnc#1012628).
- fanotify: fix logic of events on child (bnc#1012628).
- mmc: sdhci-pci: Only do AMD tuning for HS200 (bnc#1012628).
- drm/i915: Fix hibernation with ACPI S0 target state
  (bnc#1012628).
- drm/i915: Correctly handle limited range YCbCr data on VLV/CHV
  (bnc#1012628).
- jffs2_kill_sb(): deal with failed allocations (bnc#1012628).
- hypfs_kill_super(): deal with failed allocations (bnc#1012628).
- orangefs_kill_sb(): deal with allocation failures (bnc#1012628).
- rpc_pipefs: fix double-dput() (bnc#1012628).
- Don't leak MNT_INTERNAL away from internal mounts (bnc#1012628).
- libnvdimm, dimm: handle EACCES failures from label reads
  (bnc#1012628).
- device-dax: allow MAP_SYNC to succeed (bnc#1012628).
- autofs: mount point create should honour passed in mode
  (bnc#1012628).
- mm/filemap.c: fix NULL pointer in page_cache_tree_insert()
  (bnc#1012628).
- drm/i915/gvt: init mmio by lri command in vgpu inhibit context
  (bnc#1012628).
- HID: i2c-hid: fix inverted return value from i2c_hid_command()
  (bnc#1012628).
- writeback: safer lock nesting (bnc#1012628).
- Delete
  patches.suse/ext4-llseek-do-not-crop-offset-on-32bit.patch.
- commit 2ebc2ec
* Tue Apr 24 2018 mkubecek@suse.cz
- Documentation: typec.rst: Use literal-block element with
  ascii art.
- commit 1aebada
* Mon Apr 23 2018 jeffm@suse.com
- README.BRANCH: Added Michal Kubecek as co-maintainer.
- commit 53ecad7
* Mon Apr 23 2018 mkubecek@suse.cz
- Update to 4.17-rc2
- Eliminated 2 patches
- Config changes:
  - s390x:
  - KEXEC_FILE=y
- commit 8aad964
* Fri Apr 20 2018 mkubecek@suse.cz
- Update to 4.17-rc1.
- Eliminated 55 patches (51 stable 4.16.x)
- ARM configs need updating.
- Config changes:
  - x86:
  - ACPI_TAD=m
  - s390:
  - EXPOLINE_FULL=y
  - VT=y
  - CONSOLE_TRANSLATIONS=y
  - VT_CONSOLE=y
  - VT_HW_CONSOLE_BINDING=n
  - DUMMY_CONSOLE_COLUMNS=80
  - DUMMY_CONSOLE_ROWS=25
  - SPEAKUP=n
  - Network:
  - NF_TABLES_INET=y
  - NF_TABLES_NETDEV=y
  - NF_TABLES_ARP=y
  - NF_TABLES_BRIDGE=y
  - NET_EMATCH_IPT=m
  - ICE=m
  - RSI_COEX=y
  - IEEE802154_MCR20A=m
  - INFINIBAND_EXP_LEGACY_VERBS_NEW_UAPI=n
  - Filesystems:
  - OVERLAY_FS_XINO_AUTO=n
  - PSTORE_DEFLATE_COMPRESS=m
  - PSTORE_LZ4HC_COMPRESS=m
  - PSTORE_842_COMPRESS=n
  - PSTORE_DEFLATE_COMPRESS_DEFAULT=deflate
  - Crypto:
  - CRYPTO_CFB=m
  - CRYPTO_SM4=m
  - CRYPTO_SPECK=m
  - CRYPTO_DEV_CHELSIO_TLS=m
  - Input:
  - JOYSTICK_PXRC=m
  - HID_ELAN=m
  - HID_GOOGLE_HAMMER=m
  - Sound:
  - SND_SOC_INTEL_CHT_BSW_NAU8824_MACH=m
  - SND_SOC_INTEL_KBL_DA7219_MAX98357A_MACH=m
  - SND_SOC_AK4458=n
  - SND_SOC_AK5558=n
  - SND_SOC_BD28623=n
  - SND_SOC_MAX9867=n
  - SND_SOC_PCM1789_I2C=n
  - SND_SOC_TDA7419=m
  - SND_SOC_MAX9759=n
  - USB:
  - TYPEC_MUX_PI3USB30532=m
  - USB_ROLES_INTEL_XHCI=m
  - GPIO:
  - GPIO_104_DIO_48E=m
  - GPIO_104_IDIO_16=m
  - GPIO_104_IDI_48=m
  - GPIO_GPIO_MM=m
  - GPIO_WINBOND=m
  - GPIO_WS16C48=m
  - Media:
  - CEC_PIN_ERROR_INJ=n
  - CXD2880_SPI_DRV=m
  - MTK_MMC=n
  - IIO:
  - 104_QUAD_8=m
  - CIO_DAC=n
  - AD5272=m
  - MCP4018=m
  - MLX90632=m
  - Other:
  - THERMAL_STATISTICS=y
  - EBC_C384_WDT=m
  - LEDS_MLXREG=m
  - COMMON_CLK_SI544=n
  - STX104=n
  - LV0104CS=n
  - Remote controlers:
  - IR_IMON_DECODER=m
  - IR_IMON_RAW=m
  - INTEL_TH_ACPI=m
  - Debugging:
  - DEBUG_RWSEMS=n
- commit 4e61ecf
* Fri Apr 20 2018 mkubecek@suse.cz
- config: enable TCP_MD5SIG (bsc#1090162)
- commit 1cfc938
* Fri Apr 20 2018 mkubecek@suse.cz
- x86/power/64: Fix page-table setup for temporary text mapping
  (https://patchwork.kernel.org/patch/10342491/).
- x86/ldt: Fix support_pte_mask filtering in map_ldt_struct()
  (https://patchwork.kernel.org/patch/10342491/).
- commit 3c56473
* Thu Apr 19 2018 msuchanek@suse.de
- HID: redragon: Fix modifier keys for Redragon Asura Keyboard
  (https://build.opensuse.org/request/show/597583).
  Update config files.
- commit e9bd8ea
* Thu Apr 19 2018 jslaby@suse.cz
- Linux 4.16.3 (bnc#1012628).
- cdc_ether: flag the Cinterion AHS8 modem by gemalto as WWAN
  (bnc#1012628).
- rds: MP-RDS may use an invalid c_path (bnc#1012628).
- slip: Check if rstate is initialized before uncompressing
  (bnc#1012628).
- vhost: fix vhost_vq_access_ok() log check (bnc#1012628).
- l2tp: fix races in tunnel creation (bnc#1012628).
- l2tp: fix race in duplicate tunnel detection (bnc#1012628).
- ip_gre: clear feature flags when incompatible o_flags are set
  (bnc#1012628).
- vhost: Fix vhost_copy_to_user() (bnc#1012628).
- lan78xx: Correctly indicate invalid OTP (bnc#1012628).
- sparc64: Properly range check DAX completion index
  (bnc#1012628).
- media: v4l2-compat-ioctl32: don't oops on overlay (bnc#1012628).
- media: v4l: vsp1: Fix header display list status check in
  continuous mode (bnc#1012628).
- ipmi: Fix some error cleanup issues (bnc#1012628).
- parisc: Fix out of array access in match_pci_device()
  (bnc#1012628).
- parisc: Fix HPMC handler by increasing size to multiple of 16
  bytes (bnc#1012628).
- iwlwifi: add a bunch of new 9000 PCI IDs (bnc#1012628).
- Drivers: hv: vmbus: do not mark HV_PCIE as perf_device
  (bnc#1012628).
- PCI: hv: Serialize the present and eject work items
  (bnc#1012628).
- PCI: hv: Fix 2 hang issues in hv_compose_msi_msg()
  (bnc#1012628).
- KVM: PPC: Book3S HV: trace_tlbie must not be called in realmode
  (bnc#1012628).
- perf intel-pt: Fix overlap detection to identify consecutive
  buffers correctly (bnc#1012628).
- perf intel-pt: Fix sync_switch (bnc#1012628).
- perf intel-pt: Fix error recovery from missing TIP packet
  (bnc#1012628).
- perf intel-pt: Fix timestamp following overflow (bnc#1012628).
- perf/core: Fix use-after-free in uprobe_perf_close()
  (bnc#1012628).
- radeon: hide pointless #warning when compile testing
  (bnc#1012628).
- x86/mce/AMD: Pass the bank number to smca_get_bank_type()
  (bnc#1012628).
- x86/mce/AMD, EDAC/mce_amd: Enumerate Reserved SMCA bank type
  (bnc#1012628).
- x86/mce/AMD: Get address from already initialized block
  (bnc#1012628).
- ath9k: Protect queue draining by rcu_read_lock() (bnc#1012628).
- x86/uapi: Fix asm/bootparam.h userspace compilation errors
  (bnc#1012628).
- x86/apic: Fix signedness bug in APIC ID validity checks
  (bnc#1012628).
- sunrpc: remove incorrect HMAC request initialization
  (bnc#1012628).
- f2fs: fix heap mode to reset it back (bnc#1012628).
- block: Change a rcu_read_{lock,unlock}_sched() pair into
  rcu_read_{lock,unlock}() (bnc#1012628).
- nvme: Skip checking heads without namespaces (bnc#1012628).
- lib: fix stall in __bitmap_parselist() (bnc#1012628).
- zboot: fix stack protector in compressed boot phase
  (bnc#1012628).
- blk-mq: Directly schedule q->timeout_work when aborting a
  request (bnc#1012628).
- blk-mq: order getting budget and driver tag (bnc#1012628).
- blk-mq: make sure that correct hctx->next_cpu is set
  (bnc#1012628).
- blk-mq: don't keep offline CPUs mapped to hctx 0 (bnc#1012628).
- ovl: Set d->last properly during lookup (bnc#1012628).
- ovl: fix lookup with middle layer opaque dir and absolute path
  redirects (bnc#1012628).
- ovl: set i_ino to the value of st_ino for NFS export
  (bnc#1012628).
- ovl: set lower layer st_dev only if setting lower st_ino
  (bnc#1012628).
- xen: xenbus_dev_frontend: Fix XS_TRANSACTION_END handling
  (bnc#1012628).
- hugetlbfs: fix bug in pgoff overflow checking (bnc#1012628).
- nfsd: fix incorrect umasks (bnc#1012628).
- scsi: scsi_dh: Don't look for NULL devices handlers by name
  (bnc#1012628).
- scsi: qla2xxx: Fix small memory leak in qla2x00_probe_one on
  probe failure (bnc#1012628).
- Revert "scsi: core: return BLK_STS_OK for DID_OK in
  __scsi_error_from_host_byte()" (bnc#1012628).
- apparmor: fix logging of the existence test for signals
  (bnc#1012628).
- apparmor: fix display of .ns_name for containers (bnc#1012628).
- apparmor: fix resource audit messages when auditing peer
  (bnc#1012628).
- block/loop: fix deadlock after loop_set_status (bnc#1012628).
- nfit: fix region registration vs block-data-window ranges
  (bnc#1012628).
- s390/qdio: don't retry EQBS after CCQ 96 (bnc#1012628).
- s390/qdio: don't merge ERROR output buffers (bnc#1012628).
- s390/ipl: ensure loadparm valid flag is set (bnc#1012628).
- s390/compat: fix setup_frame32 (bnc#1012628).
- get_user_pages_fast(): return -EFAULT on access_ok failure
  (bnc#1012628).
- mm/gup_benchmark: handle gup failures (bnc#1012628).
- getname_kernel() needs to make sure that ->name != ->iname in
  long case (bnc#1012628).
- Bluetooth: Fix connection if directed advertising and privacy
  is used (bnc#1012628).
- Bluetooth: hci_bcm: Treat Interrupt ACPI resources as always
  being active-low (bnc#1012628).
- rtl8187: Fix NULL pointer dereference in priv->conf_mutex
  (bnc#1012628).
- Refresh patches.suse/0001-AppArmor-basic-networking-rules.patch.
- commit 771261a
* Thu Apr 19 2018 tiwai@suse.de
- resource: fix integer overflow at reallocation (bsc#1086739).
- commit 4cf2593
* Thu Apr 19 2018 tiwai@suse.de
- Update tags of upstreamed patches
  Refresh
  patches.suse/Revert-drm-amd-display-disable-CRTCs-with-NULL-FB.patch
  patches.suse/media-v4l2-core-fix-size-of-devnode_nums-bitarray.patch
  patches.suse/swiotlb-Fix-unexpected-swiotlb_alloc_coherent-failur.patch
- commit e2aa76d
* Thu Apr 19 2018 msuchanek@suse.de
- objtool, perf: Fix GCC 8 -Wrestrict error (bsc#1084620).
- commit 0c6114f
* Wed Apr 18 2018 msuchanek@suse.de
- supported.conf: update from openSUSE-15.0
- commit 4ef3f17
* Mon Apr 16 2018 tiwai@suse.de
- Revert "drm/amd/display: disable CRTCs with NULL FB on their
  primary plane (V2)" (bsc#1089615, bsc#1088902).
- commit e881e16
* Mon Apr 16 2018 mbrugger@suse.com
- arm64: Update config files. (bsc#1089764)
  Increase NR_CPUS to 384
- commit 6f06d9e
* Thu Apr 12 2018 jslaby@suse.cz
- Linux 4.16.2 (bnc#1012628).
- nfp: use full 40 bits of the NSP buffer address (bnc#1012628).
- net_sched: fix a missing idr_remove() in u32_delete_key()
  (bnc#1012628).
- vti6: better validate user provided tunnel names (bnc#1012628).
- ip6_tunnel: better validate user provided tunnel names
  (bnc#1012628).
- ip6_gre: better validate user provided tunnel names
  (bnc#1012628).
- ipv6: sit: better validate user provided tunnel names
  (bnc#1012628).
- ip_tunnel: better validate user provided tunnel names
  (bnc#1012628).
- net: fool proof dev_valid_name() (bnc#1012628).
- vlan: also check phy_driver ts_info for vlan's real device
  (bnc#1012628).
- sky2: Increase D3 delay to sky2 stops working after suspend
  (bnc#1012628).
- sctp: sctp_sockaddr_af must check minimal addr length for
  AF_INET6 (bnc#1012628).
- sctp: do not leak kernel memory to user space (bnc#1012628).
- pptp: remove a buggy dst release in pptp_connect()
  (bnc#1012628).
- net/sched: fix NULL dereference in the error path of
  tcf_bpf_init() (bnc#1012628).
- net/ipv6: Increment OUTxxx counters after netfilter hook
  (bnc#1012628).
- net: dsa: Discard frames from unused ports (bnc#1012628).
- arp: fix arp_filter on l3slave devices (bnc#1012628).
- sparc64: Oracle DAX driver depends on SPARC64 (bnc#1012628).
- commit 8ea896b
* Wed Apr 11 2018 jslaby@suse.cz
- Update config files.
  s390x/vanilla fails to build without this.
- commit e8d83e8
* Tue Apr 10 2018 tiwai@suse.de
- swiotlb: Fix unexpected swiotlb_alloc_coherent() failures
  (bsc#1088658, bsc#1088902).
- commit 096b538
* Tue Apr 10 2018 msuchanek@suse.de
- Add azure kernel description.
- commit 044dbe8
* Mon Apr  9 2018 tiwai@suse.de
- media: v4l2-core: fix size of devnode_nums[] bitarray
  (bsc#1088640).
- commit 6fcb3b5
* Mon Apr  9 2018 jslaby@suse.cz
- Linux 4.16.1 (bnc#1012628).
- signal: Correct the offset of si_pkey and si_lower in struct
  siginfo on m68k (bnc#1012628).
- Fix slab name "biovec-(1<<(21-12))" (bnc#1012628).
- vt: change SGR 21 to follow the standards (bnc#1012628).
- Input: i8042 - enable MUX on Sony VAIO VGN-CS series to fix
  touchpad (bnc#1012628).
- Input: i8042 - add Lenovo ThinkPad L460 to i8042 reset list
  (bnc#1012628).
- Input: ALPS - fix TrackStick detection on Thinkpad L570 and
  Latitude 7370 (bnc#1012628).
- Revert "base: arch_topology: fix section mismatch build
  warnings" (bnc#1012628).
- staging: comedi: ni_mio_common: ack ai fifo error interrupts
  (bnc#1012628).
- siox: fix possible buffer overflow in device_add_store
  (bnc#1012628).
- Btrfs: fix unexpected cow in run_delalloc_nocow (bnc#1012628).
- Bluetooth: hci_bcm: Add 6 new ACPI HIDs (bnc#1012628).
- crypto: x86/cast5-avx - fix ECB encryption when long sg follows
  short one (bnc#1012628).
- crypto: arm,arm64 - Fix random regeneration of S_shipped
  (bnc#1012628).
- crypto: ccp - return an actual key size from RSA max_size
  callback (bnc#1012628).
- crypto: caam - Fix null dereference at error path (bnc#1012628).
- crypto: ahash - Fix early termination in hash walk
  (bnc#1012628).
- crypto: talitos - fix IPsec cipher in length (bnc#1012628).
- crypto: testmgr - Fix incorrect values in PKCS#1 test vector
  (bnc#1012628).
- crypto: inside-secure - fix clock management (bnc#1012628).
- crypto: talitos - don't persistently map req_ctx->hw_context
  and req_ctx->buf (bnc#1012628).
- crypto: ccp - Fill the result buffer only on digest, finup,
  and final ops (bnc#1012628).
- crypto: lrw - Free rctx->ext with kzfree (bnc#1012628).
- parport_pc: Add support for WCH CH382L PCI-E single parallel
  port card (bnc#1012628).
- media: usbtv: prevent double free in error case (bnc#1012628).
- /dev/mem: Avoid overwriting "err" in read_mem() (bnc#1012628).
- mei: remove dev_err message on an unsupported ioctl
  (bnc#1012628).
- serial: 8250: Add Nuvoton NPCM UART (bnc#1012628).
- USB: serial: cp210x: add ELDAT Easywave RX09 id (bnc#1012628).
- USB: serial: ftdi_sio: add support for Harman
  FirmwareHubEmulator (bnc#1012628).
- USB: serial: ftdi_sio: add RT Systems VX-8 cable (bnc#1012628).
- bitmap: fix memset optimization on big-endian systems
  (bnc#1012628).
- commit 4bf9d1e
* Fri Apr  6 2018 agraf@suse.de
- armv6hl: Disable uacces with memcpy (boo#1080435)
- commit 2592f12
* Wed Apr  4 2018 rgoldwyn@suse.com
- apparmor: Check all profiles attached to the label (bsc#1085996).
- commit b249c9e
* Wed Apr  4 2018 jslaby@suse.cz
- Revert "tools: fix cross-compile var clobbering" (build fix).
- commit 590ff92
* Mon Apr  2 2018 jeffm@suse.com
- Update to 4.16-final.
- commit 1b10c5b
* Sat Mar 31 2018 jslaby@suse.cz
- Linux 4.15.15 (bnc#1012628).
- team: Fix double free in error path (bnc#1012628).
- skbuff: Fix not waking applications when errors are enqueued
  (bnc#1012628).
- qede: Fix qedr link update (bnc#1012628).
- net: systemport: Rewrite __bcm_sysport_tx_reclaim()
  (bnc#1012628).
- net: Only honor ifindex in IP_PKTINFO if non-0 (bnc#1012628).
- netlink: avoid a double skb free in genlmsg_mcast()
  (bnc#1012628).
- net/iucv: Free memory obtained by kzalloc (bnc#1012628).
- net: fec: Fix unbalanced PM runtime calls (bnc#1012628).
- net: ethernet: ti: cpsw: add check for in-band mode setting
  with RGMII PHY interface (bnc#1012628).
- commit 4904fc3
* Sat Mar 31 2018 jslaby@suse.cz
- net: ethernet: arc: Fix a potential memory leak if an optional
  regulator is deferred (bnc#1012628).
- l2tp: do not accept arbitrary sockets (bnc#1012628).
- ipv6: fix access to non-linear packet in
  ndisc_fill_redirect_hdr_option() (bnc#1012628).
- dccp: check sk for closed state in dccp_sendmsg() (bnc#1012628).
- dpaa_eth: remove duplicate increment of the tx_errors counter
  (bnc#1012628).
- dpaa_eth: increment the RX dropped counter when needed
  (bnc#1012628).
- dpaa_eth: remove duplicate initialization (bnc#1012628).
- dpaa_eth: fix error in dpaa_remove() (bnc#1012628).
- soc/fsl/qbman: fix issue in qman_delete_cgr_safe()
  (bnc#1012628).
- s390/qeth: on channel error, reject further cmd requests
  (bnc#1012628).
- s390/qeth: lock read device while queueing next buffer
  (bnc#1012628).
- s390/qeth: when thread completes, wake up all waiters
  (bnc#1012628).
- s390/qeth: free netdevice when removing a card (bnc#1012628).
- net: Fix hlist corruptions in inet_evict_bucket() (bnc#1012628).
- net: use skb_to_full_sk() in skb_update_prio() (bnc#1012628).
- ieee802154: 6lowpan: fix possible NULL deref in
  lowpan_device_event() (bnc#1012628).
- sch_netem: fix skb leak in netem_enqueue() (bnc#1012628).
- kcm: lock lower socket in kcm_attach (bnc#1012628).
- test_rhashtable: add test case for rhltable with duplicate
  objects (bnc#1012628).
- rhashtable: Fix rhlist duplicates insertion (bnc#1012628).
- ppp: avoid loop in xmit recursion detection code (bnc#1012628).
- net sched actions: return explicit error when tunnel_key mode
  is not specified (bnc#1012628).
- ipv6: Reflect MTU changes on PMTU of exceptions for MTU-less
  routes (bnc#1012628).
- net: phy: Tell caller result of phy_change() (bnc#1012628).
- mlxsw: spectrum_buffers: Set a minimum quota for CPU port
  traffic (bnc#1012628).
- ipv6: sr: fix scheduling in RCU when creating seg6 lwtunnel
  state (bnc#1012628).
- ipv6: sr: fix NULL pointer dereference when setting encap
  source address (bnc#1012628).
- ipv6: old_dport should be a __be16 in __ip6_datagram_connect()
  (bnc#1012628).
- net: ipv6: keep sk status consistent after datagram connect
  failure (bnc#1012628).
- macvlan: filter out unsupported feature flags (bnc#1012628).
- devlink: Remove redundant free on error path (bnc#1012628).
- net: phy: relax error checking when creating sysfs link
  netdev->phydev (bnc#1012628).
- sysfs: symlink: export sysfs_create_link_nowarn() (bnc#1012628).
- qed: Fix non TCP packets should be dropped on iWARP ll2
  connection (bnc#1012628).
- tcp: purge write queue upon aborting the connection
  (bnc#1012628).
- qed: Fix MPA unalign flow in case header is split across two
  packets (bnc#1012628).
- openvswitch: meter: fix the incorrect calculation of max delta_t
  (bnc#1012628).
- net: dsa: Fix dsa_is_user_port() test inversion (bnc#1012628).
- commit 0e7b541
* Thu Mar 29 2018 jslaby@suse.cz
- Linux 4.15.14 (bnc#1012628).
- MIPS: ralink: Remove ralink_halt() (bnc#1012628).
- MIPS: ralink: Fix booting on MT7621 (bnc#1012628).
- MIPS: lantiq: Fix Danube USB clock (bnc#1012628).
- MIPS: lantiq: Enable AHB Bus for USB (bnc#1012628).
- MIPS: lantiq: ase: Enable MFD_SYSCON (bnc#1012628).
- iio: chemical: ccs811: Corrected firmware boot/application
  mode transition (bnc#1012628).
- iio: st_pressure: st_accel: pass correct platform data to init
  (bnc#1012628).
- iio: adc: meson-saradc: unlock on error in meson_sar_adc_lock()
  (bnc#1012628).
- ALSA: usb-audio: Fix parsing descriptor of UAC2 processing unit
  (bnc#1012628).
- ALSA: aloop: Sync stale timer before release (bnc#1012628).
- ALSA: aloop: Fix access to not-yet-ready substream via cable
  (bnc#1012628).
- ALSA: hda - Force polling mode on CFL for fixing codec
  communication (bnc#1012628).
- ALSA: hda/realtek - Fix speaker no sound after system resume
  (bnc#1012628).
- ALSA: hda/realtek - Fix Dell headset Mic can't record
  (bnc#1012628).
- ALSA: hda/realtek - Always immediately update mute LED with
  pin VREF (bnc#1012628).
- mmc: core: Fix tracepoint print of blk_addr and blksz
  (bnc#1012628).
- mmc: core: Disable HPI for certain Micron (Numonyx) eMMC cards
  (bnc#1012628).
- mmc: block: fix updating ext_csd caches on ioctl call
  (bnc#1012628).
- mmc: dw_mmc: Fix the DTO/CTO timeout overflow calculation for
  32-bit systems (bnc#1012628).
- mmc: dw_mmc: exynos: fix the suspend/resume issue for exynos5433
  (bnc#1012628).
- mmc: dw_mmc: fix falling from idmac to PIO mode when
  dw_mci_reset occurs (bnc#1012628).
- PCI: Add function 1 DMA alias quirk for Highpoint RocketRAID
  644L (bnc#1012628).
- ahci: Add PCI-id for the Highpoint Rocketraid 644L card
  (bnc#1012628).
- lockdep: fix fs_reclaim warning (bnc#1012628).
- clk: bcm2835: Fix ana->maskX definitions (bnc#1012628).
- clk: bcm2835: Protect sections updating shared registers
  (bnc#1012628).
- clk: sunxi-ng: a31: Fix CLK_OUT_* clock ops (bnc#1012628).
- RDMA/mlx5: Fix crash while accessing garbage pointer and freed
  memory (bnc#1012628).
- Drivers: hv: vmbus: Fix ring buffer signaling (bnc#1012628).
- pinctrl: samsung: Validate alias coming from DT (bnc#1012628).
- Bluetooth: btusb: Remove Yoga 920 from the
  btusb_needs_reset_resume_table (bnc#1012628).
- Bluetooth: btusb: Add Dell OptiPlex 3060 to
  btusb_needs_reset_resume_table (bnc#1012628).
- libata: fix length validation of ATAPI-relayed SCSI commands
  (bnc#1012628).
- libata: remove WARN() for DMA or PIO command without data
  (bnc#1012628).
- libata: don't try to pass through NCQ commands to non-NCQ
  devices (bnc#1012628).
- libata: Apply NOLPM quirk to Crucial MX100 512GB SSDs
  (bnc#1012628).
- libata: disable LPM for Crucial BX100 SSD 500GB drive
  (bnc#1012628).
- libata: Enable queued TRIM for Samsung SSD 860 (bnc#1012628).
- libata: Apply NOLPM quirk to Crucial M500 480 and 960GB SSDs
  (bnc#1012628).
- libata: Make Crucial BX100 500GB LPM quirk apply to all firmware
  versions (bnc#1012628).
- libata: Modify quirks for MX100 to limit NCQ_TRIM quirk to
  MU01 version (bnc#1012628).
- sched, cgroup: Don't reject lower cpu.max on ancestors
  (bnc#1012628).
- cgroup: fix rule checking for threaded mode switching
  (bnc#1012628).
- nfsd: remove blocked locks on client teardown (bnc#1012628).
- media: tegra-cec: reset rx_buf_cnt when start bit detected
  (bnc#1012628).
- hugetlbfs: check for pgoff value overflow (bnc#1012628).
- h8300: remove extraneous __BIG_ENDIAN definition (bnc#1012628).
- mm/vmalloc: add interfaces to free unmapped page table
  (bnc#1012628).
- x86/mm: implement free pmd/pte page interfaces (bnc#1012628).
- mm/khugepaged.c: convert VM_BUG_ON() to collapse fail
  (bnc#1012628).
- mm/thp: do not wait for lock_page() in deferred_split_scan()
  (bnc#1012628).
- mm/shmem: do not wait for lock_page() in
  shmem_unused_huge_shrink() (bnc#1012628).
- Revert "mm: page_alloc: skip over regions of invalid pfns
  where possible" (bnc#1012628).
- drm/vmwgfx: Fix black screen and device errors when running
  without fbdev (bnc#1012628).
- drm/vmwgfx: Fix a destoy-while-held mutex problem (bnc#1012628).
- drm/radeon: Don't turn off DP sink when disconnected
  (bnc#1012628).
- drm/amd/display: We shouldn't set format_default on plane as
  atomic driver (bnc#1012628).
- drm/amd/display: Add one to EDID's audio channel count when
  passing to DC (bnc#1012628).
- drm: Reject getfb for multi-plane framebuffers (bnc#1012628).
- drm: udl: Properly check framebuffer mmap offsets (bnc#1012628).
- mm/vmscan: wake up flushers for legacy cgroups too
  (bnc#1012628).
- module: propagate error in modules_open() (bnc#1012628).
- acpi, numa: fix pxm to online numa node associations
  (bnc#1012628).
- ACPI / watchdog: Fix off-by-one error at resource assignment
  (bnc#1012628).
- libnvdimm, {btt, blk}: do integrity setup before add_disk()
  (bnc#1012628).
- brcmfmac: fix P2P_DEVICE ethernet address generation
  (bnc#1012628).
- rtlwifi: rtl8723be: Fix loss of signal (bnc#1012628).
- tracing: probeevent: Fix to support minus offset from symbol
  (bnc#1012628).
- mtdchar: fix usage of mtd_ooblayout_ecc() (bnc#1012628).
- mtd: nand: fsl_ifc: Fix nand waitfunc return value
  (bnc#1012628).
- mtd: nand: fsl_ifc: Fix eccstat array overflow for IFC ver >=
  2.0.0 (bnc#1012628).
- mtd: nand: fsl_ifc: Read ECCSTAT0 and ECCSTAT1 registers for
  IFC 2.0 (bnc#1012628).
- can: peak/pcie_fd: fix echo_skb is occupied! bug (bnc#1012628).
- can: peak/pcie_fd: remove useless code when interface starts
  (bnc#1012628).
- can: ifi: Repair the error handling (bnc#1012628).
- can: ifi: Check core revision upon probe (bnc#1012628).
- can: cc770: Fix stalls on rt-linux, remove redundant IRQ ack
  (bnc#1012628).
- can: cc770: Fix queue stall & dropped RTR reply (bnc#1012628).
- can: cc770: Fix use after free in cc770_tx_interrupt()
  (bnc#1012628).
- tty: vt: fix up tabstops properly (bnc#1012628).
- selftests/x86/ptrace_syscall: Fix for yet more glibc
  interference (bnc#1012628).
- x86/vsyscall/64: Use proper accessor to update P4D entry
  (bnc#1012628).
- x86/efi: Free efi_pgd with free_pages() (bnc#1012628).
- posix-timers: Protect posix clock array access against
  speculation (bnc#1012628).
- kvm/x86: fix icebp instruction handling (bnc#1012628).
- x86/build/64: Force the linker to use 2MB page size
  (bnc#1012628).
- x86/boot/64: Verify alignment of the LOAD segment (bnc#1012628).
- hwmon: (k10temp) Only apply temperature offset if result is
  positive (bnc#1012628).
- hwmon: (k10temp) Add temperature offset for Ryzen 1900X
  (bnc#1012628).
- perf/x86/intel/uncore: Fix Skylake UPI event format
  (bnc#1012628).
- perf stat: Fix CVS output format for non-supported counters
  (bnc#1012628).
- perf/core: Fix ctx_event_type in ctx_resched() (bnc#1012628).
- trace/bpf: remove helper bpf_perf_prog_read_value from
  tracepoint type programs (bnc#1012628).
- perf/x86/intel: Don't accidentally clear high bits in
  bdw_limit_period() (bnc#1012628).
- perf/x86/intel/uncore: Fix multi-domain PCI CHA enumeration
  bug on Skylake servers (bnc#1012628).
- iio: ABI: Fix name of timestamp sysfs file (bnc#1012628).
- iio: imu: st_lsm6dsx: fix endianness in
  st_lsm6dsx_read_oneshot() (bnc#1012628).
- iio: imu: st_lsm6dsx: introduce conf_lock mutex (bnc#1012628).
- staging: android: ion: Zero CMA allocated memory (bnc#1012628).
- kbuild: disable clang's default use of -fmerge-all-constants
  (bnc#1012628).
- bpf: skip unnecessary capability check (bnc#1012628).
- bpf, x64: increase number of passes (bnc#1012628).
- commit def7e44
* Wed Mar 28 2018 neilb@suse.com
- staging: ncpfs: memory corruption in ncp_read_kernel()
  (bsc#1086162, CVE-2018-8822).
- commit a967c04
* Tue Mar 27 2018 bp@suse.de
- x86/entry/64: Don't use IST entry for #BP stack (bsc#1087088).
- commit 67a9975
* Mon Mar 26 2018 tiwai@suse.de
- brcmsmac: allocate ucode with GFP_KERNEL (bsc#1085174).
- commit 580a38a
* Mon Mar 26 2018 jslaby@suse.cz
- Update vanilla config files.
- commit 9beaab6
* Mon Mar 26 2018 bpoirier@suse.com
- net: phy: mdio-bcm-unimac: fix potential NULL dereference in
  unimac_mdio_probe() (bsc#1084829 CVE-2018-8043).
- commit 7b5f96b
* Mon Mar 26 2018 jeffm@suse.com
- Update to 4.16-rc7.
- Eliminated 1 patch.
- commit 7a36f2f
* Sun Mar 25 2018 jslaby@suse.cz
- Linux 4.15.13 (bnc#1012628).
- RDMA/ucma: Don't allow join attempts for unsupported AF family
  (bnc#1012628).
- RDMA/ucma: Fix access to non-initialized CM_ID object
  (bnc#1012628).
- clk: migrate the count of orphaned clocks at init (bnc#1012628).
- RDMA/core: Do not use invalid destination in determining port
  reuse (bnc#1012628).
- serial: 8250_pci: Don't fail on multiport card class
  (bnc#1012628).
- RDMA/vmw_pvrdma: Fix usage of user response structures in ABI
  file (bnc#1012628).
- IB/mlx5: Fix out-of-bounds read in create_raw_packet_qp_rq
  (bnc#1012628).
- IB/mlx5: Fix integer overflows in mlx5_ib_create_srq
  (bnc#1012628).
- dmaengine: ti-dma-crossbar: Fix event mapping for
  TPCC_EVT_MUX_60_63 (bnc#1012628).
- hwrng: core - Clean up RNG list when last hwrng is unregistered
  (bnc#1012628).
- crypto: artpec6 - set correct iv size for gcm(aes)
  (bnc#1012628).
- clk: si5351: Rename internal plls to avoid name collisions
  (bnc#1012628).
- clk: axi-clkgen: Correctly handle nocount bit in recalc_rate()
  (bnc#1012628).
- clk: Don't touch hardware when reparenting during registration
  (bnc#1012628).
- clk: at91: pmc: Wait for clocks when resuming (bnc#1012628).
- nfsd4: permit layoutget of executable-only files (bnc#1012628).
- ARM: dts: aspeed-evb: Add unit name to memory node
  (bnc#1012628).
- RDMA/ocrdma: Fix permissions for OCRDMA_RESET_STATS
  (bnc#1012628).
- scsi: lpfc: Fix issues connecting with nvme initiator
  (bnc#1012628).
- scsi: lpfc: Fix SCSI LUN discovery when SCSI and NVME enabled
  (bnc#1012628).
- soc: qcom: smsm: fix child-node lookup (bnc#1012628).
- ip_gre: fix potential memory leak in erspan_rcv (bnc#1012628).
- ip_gre: fix error path when erspan_rcv failed (bnc#1012628).
- ip6_vti: adjust vti mtu according to mtu of lower device
  (bnc#1012628).
- iommu/vt-d: clean up pr_irq if request_threaded_irq fails
  (bnc#1012628).
- pinctrl: rockchip: enable clock when reading pin direction
  register (bnc#1012628).
- pinctrl: Really force states during suspend/resume
  (bnc#1012628).
- clk: use round rate to bail out early in set_rate (bnc#1012628).
- dt-bindings: display: panel: Fix compatible string for Toshiba
  LT089AC29000 (bnc#1012628).
- clk: check ops pointer on clock register (bnc#1012628).
- media: davinci: fix a debug printk (bnc#1012628).
- PCI: rcar: Handle rcar_pcie_parse_request_of_pci_ranges()
  failures (bnc#1012628).
- PCI: endpoint: Fix find_first_zero_bit() usage (bnc#1012628).
- PCI: designware-ep: Fix ->get_msi() to check MSI_EN bit
  (bnc#1012628).
- coresight: Fix disabling of CoreSight TPIU (bnc#1012628).
- pty: cancel pty slave port buf's work in tty_release
  (bnc#1012628).
- drm/omap: DMM: Check for DMM readiness after successful
  transaction commit (bnc#1012628).
- mmc: sdhci-xenon: wait 5ms after set 1.8V signal enable
  (bnc#1012628).
- omapdrm: panel: fix compatible vendor string for td028ttec1
  (bnc#1012628).
- vgacon: Set VGA struct resource types (bnc#1012628).
- PCI/ASPM: Calculate LTR_L1.2_THRESHOLD from device
  characteristics (bnc#1012628).
- bpf/cgroup: fix a verification error for a CGROUP_DEVICE type
  prog (bnc#1012628).
- iser-target: avoid reinitializing rdma contexts for isert
  commands (bnc#1012628).
- IB/umem: Fix use of npages/nmap fields (bnc#1012628).
- RDMA/cma: Use correct size when writing netlink stats
  (bnc#1012628).
- IB/ipoib: Avoid memory leak if the SA returns a different DGID
  (bnc#1012628).
- rtc: ac100: Fix multiple race conditions (bnc#1012628).
- media: s5p-mfc: Fix lock contention - request_firmware() once
  (bnc#1012628).
- sfp: fix non-detection of PHY (bnc#1012628).
- sfp: fix EEPROM reading in the case of non-SFF8472 SFPs
  (bnc#1012628).
- net: phy: meson-gxl: check phy_write return value (bnc#1012628).
- /dev/mem: Add bounce buffer for copy-out (bnc#1012628).
- mmc: block: fix logical error to avoid memory leak
  (bnc#1012628).
- mmc: avoid removing non-removable hosts during suspend
  (bnc#1012628).
- drm/tilcdc: ensure nonatomic iowrite64 is not used
  (bnc#1012628).
- dmaengine: zynqmp_dma: Fix race condition in the probe
  (bnc#1012628).
- platform/chrome: Use proper protocol transfer function
  (bnc#1012628).
- watchdog: Fix kref imbalance seen if handle_boot_enabled=0
  (bnc#1012628).
- watchdog: Fix potential kref imbalance when opening watchdog
  (bnc#1012628).
- cros_ec: fix nul-termination for firmware build info
  (bnc#1012628).
- serial: 8250_dw: Disable clock on error (bnc#1012628).
- tty: goldfish: Enable 'earlycon' only if built-in (bnc#1012628).
- qmi_wwan: set FLAG_SEND_ZLP to avoid network initiated
  disconnect (bnc#1012628).
- media: [RESEND] media: dvb-frontends: Add delay to Si2168
  restart (bnc#1012628).
- ath10k: handling qos at STA side based on AP WMM enable/disable
  (bnc#1012628).
- media: bt8xx: Fix err 'bt878_probe()' (bnc#1012628).
- rtlwifi: always initialize variables given to RT_TRACE()
  (bnc#1012628).
- rtlwifi: rtl_pci: Fix the bug when inactiveps is enabled
  (bnc#1012628).
- libbpf: prefer global symbols as bpf program name source
  (bnc#1012628).
- spi: sh-msiof: Avoid writing to registers from
  spi_master.setup() (bnc#1012628).
- tcp: allow TLP in ECN CWR (bnc#1012628).
- hv_netvsc: Fix the TX/RX buffer default sizes (bnc#1012628).
- hv_netvsc: Fix the receive buffer size limit (bnc#1012628).
- RDMA/iwpm: Fix uninitialized error code in iwpm_send_mapinfo()
  (bnc#1012628).
- IB/ipoib: Warn when one port fails to initialize (bnc#1012628).
- drm/msm: fix leak in failed get_pages (bnc#1012628).
- media: c8sectpfe: fix potential NULL pointer dereference in
  c8sectpfe_timer_interrupt (bnc#1012628).
- cpufreq: longhaul: Revert transition_delay_us to 200 ms
  (bnc#1012628).
- Bluetooth: btqcomsmd: Fix skb double free corruption
  (bnc#1012628).
- Bluetooth: hci_qca: Avoid setup failure on missing rampatch
  (bnc#1012628).
- drm/amdgpu: use polling mem to set SDMA3 wptr for VF
  (bnc#1012628).
- staging: android: ashmem: Fix possible deadlock in ashmem_ioctl
  (bnc#1012628).
- scsi: megaraid_sas: Do not use 32-bit atomic request descriptor
  for Ventura controllers (bnc#1012628).
- commit 950fc49
* Fri Mar 23 2018 agraf@suse.de
- armv7hl: Disable uacces with memcpy (boo#1080435)
- commit a3fb408
* Wed Mar 21 2018 jslaby@suse.cz
- Linux 4.15.12 (bnc#1012628).
- phy: phy-brcm-usb-init: Power down USB 3.0 PHY when XHCI
  disabled (bnc#1012628).
- phy: phy-brcm-usb-init: DRD mode can cause crash on startup
  (bnc#1012628).
- phy: phy-brcm-usb-init: Some Low Speed keyboards fail on 7271
  (bnc#1012628).
- phy: phy-brcm-usb: Fix two DT properties to match bindings doc
  (bnc#1012628).
- usb: gadget: udc: renesas_usb3: fix oops in
  renesas_usb3_remove() (bnc#1012628).
- usb: dwc3: of-simple: fix oops by unbalanced clk disable call
  (bnc#1012628).
- usb: dwc3: core: Power-off core/PHYs on system_suspend in host
  mode (bnc#1012628).
- usb: dwc3: Fix GDBGFIFOSPACE_TYPE values (bnc#1012628).
- USB: gadget: udc: Add missing platform_device_put() on error
  in bdc_pci_probe() (bnc#1012628).
- dt-bindings: usb: fix the STM32F7 DWC2 OTG HS core binding
  (bnc#1012628).
- usb: dwc2: fix STM32F7 USB OTG HS compatible (bnc#1012628).
- scsi: qla2xxx: Fix crashes in qla2x00_probe_one on probe failure
  (bnc#1012628).
- scsi: qla2xxx: Fix logo flag for qlt_free_session_done()
  (bnc#1012628).
- scsi: qla2xxx: Fix NULL pointer access for fcport structure
  (bnc#1012628).
- scsi: qla2xxx: Fix smatch warning in
  qla25xx_delete_{rsp|req}_que (bnc#1012628).
- btrfs: Fix memory barriers usage with device stats counters
  (bnc#1012628).
- btrfs: remove spurious WARN_ON(ref->count < 0) in
  find_parent_nodes (bnc#1012628).
- btrfs: Fix use-after-free when cleaning up fs_devs with a
  single stale device (bnc#1012628).
- btrfs: alloc_chunk: fix DUP stripe size handling (bnc#1012628).
- btrfs: add missing initialization in btrfs_check_shared
  (bnc#1012628).
- btrfs: Fix NULL pointer exception in find_bio_stripe
  (bnc#1012628).
- xfs: preserve i_rdev when recycling a reclaimable inode
  (bnc#1012628).
- nvme: fix subsystem multiple controllers support check
  (bnc#1012628).
- irqchip/gic-v3-its: Ensure nr_ites >= nr_lpis (bnc#1012628).
- RDMAVT: Fix synchronization around percpu_ref (bnc#1012628).
- fs/aio: Use RCU accessors for kioctx_table->table[]
  (bnc#1012628).
- fs/aio: Add explicit RCU grace period when freeing kioctx
  (bnc#1012628).
- lock_parent() needs to recheck if dentry got __dentry_kill'ed
  under it (bnc#1012628).
- KVM: arm/arm64: vgic: Don't populate multiple LRs with the
  same vintid (bnc#1012628).
- kvm: arm/arm64: vgic-v3: Tighten synchronization for guests
  using v2 on v3 (bnc#1012628).
- KVM: arm/arm64: Reset mapped IRQs on VM reset (bnc#1012628).
- KVM: arm/arm64: Reduce verbosity of KVM init log (bnc#1012628).
- fs: Teach path_connected to handle nfs filesystems with multiple
  roots (bnc#1012628).
- drm/amdgpu/dce: Don't turn off DP sink when disconnected
  (bnc#1012628).
- drm/radeon: fix prime teardown order (bnc#1012628).
- drm/amdgpu: fix prime teardown order (bnc#1012628).
- drm/nouveau/mmu: ALIGN_DOWN correct variable (bnc#1012628).
- drm/nouveau/bl: Fix oops on driver unbind (bnc#1012628).
- ALSA: seq: Clear client entry before deleting else at closing
  (bnc#1012628).
- ALSA: seq: Fix possible UAF in snd_seq_check_queue()
  (bnc#1012628).
- ALSA: hda - Revert power_save option default value
  (bnc#1012628).
- ALSA: pcm: Fix UAF in snd_pcm_oss_get_formats() (bnc#1012628).
- parisc: Handle case where flush_cache_range is called with no
  context (bnc#1012628).
- x86/mm: Fix vmalloc_fault to use pXd_large (bnc#1012628).
- KVM: x86: Fix device passthrough when SME is active
  (bnc#1012628).
- x86/speculation: Remove Skylake C2 from Speculation Control
  microcode blacklist (bnc#1012628).
- x86/speculation, objtool: Annotate indirect calls/jumps for
  objtool on 32-bit kernels (bnc#1012628).
- x86/vm86/32: Fix POPF emulation (bnc#1012628).
- selftests/x86/entry_from_vm86: Add test cases for POPF
  (bnc#1012628).
- selftests/x86/entry_from_vm86: Exit with 1 if we fail
  (bnc#1012628).
- x86/cpufeatures: Add Intel PCONFIG cpufeature (bnc#1012628).
- x86/cpufeatures: Add Intel Total Memory Encryption cpufeature
  (bnc#1012628).
- commit 9f942ce
* Mon Mar 19 2018 jslaby@suse.cz
- Update config files (4.15.11).
- commit a1db525
* Mon Mar 19 2018 jslaby@suse.cz
- Linux 4.15.11 (bnc#1012628).
- drm/i915/glk: Disable Guc and HuC on GLK (bnc#1012628).
- dmaengine: qcom_hidma: check pending interrupts (bnc#1012628).
- IB/mlx5: revisit -Wmaybe-uninitialized warning (bnc#1012628).
- ima: relax requiring a file signature for new files with zero
  length (bnc#1012628).
- locking/locktorture: Fix num reader/writer corner cases
  (bnc#1012628).
- rcutorture/configinit: Fix build directory error message
  (bnc#1012628).
- ipvlan: add L2 check for packets arriving via virtual devices
  (bnc#1012628).
- Fix misannotated out-of-line _copy_to_user() (bnc#1012628).
- mmc: mmc_test: Ensure command queue is disabled for testing
  (bnc#1012628).
- ASoC: nuc900: Fix a loop timeout test (bnc#1012628).
- crypto: caam/qi - use correct print specifier for size_t
  (bnc#1012628).
- mac80211: remove BUG() when interface type is invalid
  (bnc#1012628).
- mac80211_hwsim: enforce PS_MANUAL_POLL to be set after
  PS_ENABLED (bnc#1012628).
- agp/intel: Flush all chipset writes after updating the GGTT
  (bnc#1012628).
- arm64: dts: renesas: salvator-common: Add EthernetAVB PHY reset
  (bnc#1012628).
- powerpc/64: Don't trace irqs-off at interrupt return to
  soft-disabled context (bnc#1012628).
- powerpc/modules: Don't try to restore r2 after a sibling call
  (bnc#1012628).
- drm/amdkfd: Fix memory leaks in kfd topology (bnc#1012628).
- veth: set peer GSO values (bnc#1012628).
- net: sched: drop qdisc_reset from dev_graft_qdisc (bnc#1012628).
- virtio_net: Disable interrupts if napi_complete_done rescheduled
  napi (bnc#1012628).
- media: davinci: vpif_capture: add NULL check on devm_kzalloc
  return value (bnc#1012628).
- media: cpia2: Fix a couple off by one bugs (bnc#1012628).
- dm raid: fix raid set size revalidation (bnc#1012628).
- media: vsp1: Prevent suspending and resuming DRM pipelines
  (bnc#1012628).
- staging: fsl-dpaa2/eth: Fix access to FAS field (bnc#1012628).
- clk: renesas: r8a77970: Add LVDS clock (bnc#1012628).
- scsi: dh: add new rdac devices (bnc#1012628).
- scsi: devinfo: apply to HP XP the same flags as Hitachi VSP
  (bnc#1012628).
- scsi: core: scsi_get_device_flags_keyed(): Always return device
  flags (bnc#1012628).
- bnxt_en: Don't print "Link speed -1 no longer supported"
  messages (bnc#1012628).
- spi: sun6i: disable/unprepare clocks on remove (bnc#1012628).
- tools/usbip: fixes build with musl libc toolchain (bnc#1012628).
- ath10k: fix invalid STS_CAP_OFFSET_MASK (bnc#1012628).
- mwifiex: cfg80211: do not change virtual interface during scan
  processing (bnc#1012628).
- clk: qcom: msm8916: fix mnd_width for codec_digcodec
  (bnc#1012628).
- bnxt_en: Uninitialized variable in bnxt_tc_parse_actions()
  (bnc#1012628).
- drm/amdgpu: fix amdgpu_sync_resv v2 (bnc#1012628).
- drm/amdgpu:fix virtual dce bug (bnc#1012628).
- iwlwifi: mvm: avoid dumping assert log when device is stopped
  (bnc#1012628).
- perf annotate: Fix objdump comment parsing for Intel mov
  dissassembly (bnc#1012628).
- perf annotate: Fix unnecessary memory allocation for s390x
  (bnc#1012628).
- pinctrl: sh-pfc: r8a7795-es1: Fix MOD_SEL1 bit[25:24] to 0x3
  when using STP_ISEN_1_D (bnc#1012628).
- pinctrl: sh-pfc: r8a7791: Add can_clk function (bnc#1012628).
- drm/sun4i: Fix format mask in DE2 driver (bnc#1012628).
- pwm: stmpe: Fix wrong register offset for hwpwm=2 case
  (bnc#1012628).
- scsi: ses: don't ask for diagnostic pages repeatedly during
  probe (bnc#1012628).
- scsi: lpfc: Fix crash during driver unload with running nvme
  traffic (bnc#1012628).
- drm/amdgpu:fix random missing of FLR NOTIFY (bnc#1012628).
- KVM: X86: Restart the guest when insn_len is zero and SEV is
  enabled (bnc#1012628).
- cpufreq: Fix governor module removal race (bnc#1012628).
- ath10k: update tdls teardown state to target (bnc#1012628).
- iio: health: max30102: Add power enable parameter to get_temp
  function (bnc#1012628).
- iio: adc: ina2xx: Shift bus voltage register to mask flag bits
  (bnc#1012628).
- drm/etnaviv: make THERMAL selectable (bnc#1012628).
- power: supply: ab8500_charger: Bail out in case of error in
  'ab8500_charger_init_hw_registers()' (bnc#1012628).
- power: supply: ab8500_charger: Fix an error handling path
  (bnc#1012628).
- power: supply: sbs-message: double left shift bug in
  sbsm_select() (bnc#1012628).
- bpf: fix stack state printing in verifier log (bnc#1012628).
- leds: pm8058: Silence pointer to integer size warning
  (bnc#1012628).
- xfrm: Fix xfrm_replay_overflow_offload_esn (bnc#1012628).
- userns: Don't fail follow_automount based on s_user_ns
  (bnc#1012628).
- mtd: nand: ifc: update bufnum mask for ver >= 2.0.0
  (bnc#1012628).
- ARM: dts: omap3-n900: Fix the audio CODEC's reset pin
  (bnc#1012628).
- ARM: dts: am335x-pepper: Fix the audio CODEC's reset pin
  (bnc#1012628).
- net: thunderx: Set max queue count taking XDP_TX into account
  (bnc#1012628).
- mtd: nand: fix interpretation of NAND_CMD_NONE in
  nand_command[_lp]() (bnc#1012628).
- gpiolib: don't allow OPEN_DRAIN & OPEN_SOURCE flags
  simultaneously (bnc#1012628).
- net: xfrm: allow clearing socket xfrm policies (bnc#1012628).
- perf report: Fix -D output for user metadata events
  (bnc#1012628).
- rtc: brcmstb-waketimer: fix error handling in
  brcmstb_waketmr_probe() (bnc#1012628).
- net: ieee802154: adf7242: Fix bug if defined DEBUG
  (bnc#1012628).
- drm/vblank: Fix vblank timestamp debugs (bnc#1012628).
- test_firmware: fix setting old custom fw path back on exit
  (bnc#1012628).
- crypto: cavium - fix memory leak on info (bnc#1012628).
- crypto: keywrap - Add missing ULL suffixes for 64-bit constants
  (bnc#1012628).
- crypto: ecc - Fix NULL pointer deref. on no default_rng
  (bnc#1012628).
- crypto: chelsio - Fix an error code in chcr_hash_dma_map()
  (bnc#1012628).
- sched: Stop resched_cpu() from sending IPIs to offline CPUs
  (bnc#1012628).
- sched: Stop switched_to_rt() from sending IPIs to offline CPUs
  (bnc#1012628).
- dt-bindings: serial: Add common rs485 binding for RTS polarity
  (bnc#1012628).
- USB: ledtrig-usbport: fix of-node leak (bnc#1012628).
- typec: tcpm: fusb302: Resolve out of order messaging events
  (bnc#1012628).
- staging: rtl8822be: fix missing null check on dev_alloc_skb
  return (bnc#1012628).
- drm/amdgpu: fix get_max_engine_clock_in_mhz (bnc#1012628).
- ARM: dts: exynos: Correct Trats2 panel reset line (bnc#1012628).
- clk: meson: gxbb: fix wrong clock for SARADC/SANA (bnc#1012628).
- ARM: dts: koelsch: Move cec_clock to root node (bnc#1012628).
- iwlwifi: mvm: rs: don't override the rate history in the search
  cycle (bnc#1012628).
- HID: elo: clear BTN_LEFT mapping (bnc#1012628).
- KVM: PPC: Book3S HV: Fix typo in kvmppc_hv_get_dirty_log_radix()
  (bnc#1012628).
- video/hdmi: Allow "empty" HDMI infoframes (bnc#1012628).
- dma-buf/fence: Fix lock inversion within dma-fence-array
  (bnc#1012628).
- drm/edid: set ELD connector type in drm_edid_to_eld()
  (bnc#1012628).
- KVM: PPC: Book3S HV: Avoid shifts by negative amounts
  (bnc#1012628).
- HID: multitouch: Only look at non touch fields in first packet
  of a frame (bnc#1012628).
- spi: imx: Fix failure path leak on GPIO request error correctly
  (bnc#1012628).
- drm/panel: rpi-touchscreen: propagate errors in
  rpi_touchscreen_i2c_read() (bnc#1012628).
- gfs2: Fixes to "Implement iomap for block_map" (2)
  (bnc#1012628).
- gfs2: Clean up {lookup,fillup}_metapath (bnc#1012628).
- Revert "btrfs: use proper endianness accessors for super_copy"
  (bnc#1012628).
- dm mpath: fix passing integrity data (bnc#1012628).
- earlycon: add reg-offset to physical address before mapping
  (bnc#1012628).
- serial: core: mark port as initialized in autoconfig
  (bnc#1012628).
- serial: 8250_pci: Add Brainboxes UC-260 4 port serial device
  (bnc#1012628).
- usb: dwc3: Fix lock-up on ID change during system suspend/resume
  (bnc#1012628).
- usb: gadget: f_fs: Fix use-after-free in ffs_fs_kill_sb()
  (bnc#1012628).
- usb: usbmon: Read text within supplied buffer size
  (bnc#1012628).
- usb: quirks: add control message delay for 1b1c:1b20
  (bnc#1012628).
- usbip: vudc: fix null pointer dereference on udc->lock
  (bnc#1012628).
- USB: storage: Add JMicron bridge 152d:2567 to unusual_devs.h
  (bnc#1012628).
- scsi: sd_zbc: Fix potential memory leak (bnc#1012628).
- staging: android: ashmem: Fix lockdep issue during llseek
  (bnc#1012628).
- staging: comedi: fix comedi_nsamples_left (bnc#1012628).
- uas: fix comparison for error code (bnc#1012628).
- tty/serial: atmel: add new version check for usart
  (bnc#1012628).
- serial: sh-sci: prevent lockup on full TTY buffers
  (bnc#1012628).
- xhci: fix endpoint context tracer output (bnc#1012628).
- xhci: Fix front USB ports on ASUS PRIME B350M-A (bnc#1012628).
- usb: host: xhci-rcar: add support for r8a77965 (bnc#1012628).
- ASoC: rt5651: Fix regcache sync errors on resume (bnc#1012628).
- ASoC: wm_adsp: For TLV controls only register TLV get/set
  (bnc#1012628).
- ASoC: sgtl5000: Fix suspend/resume (bnc#1012628).
- ASoC: sun4i-i2s: Fix RX slot number of SUN8I (bnc#1012628).
- x86: Treat R_X86_64_PLT32 as R_X86_64_PC32 (bnc#1012628).
- commit 5c89418
* Mon Mar 19 2018 mkubecek@suse.cz
- Update
  patches.kernel.org/4.15.10-113-netfilter-ebtables-CONFIG_COMPAT-don-t-trust-.patch
  references (add CVE-2018-1068).
- Update
  patches.suse/netfilter-ebtables-fix-erroneous-reject-of-last-rule.patch
  references (add CVE-2018-1068).
- commit 3127e9f
* Mon Mar 19 2018 msuchanek@suse.de
- kernel-*.spec: remove remaining occurences of %%release from dependencies
  There is a mix of %%release and %%source_rel in manually added
  dependencies and the %%release dependencies tend to fail due to rebuild
  sync issues. So get rid of them.
- commit b4ec514
* Mon Mar 19 2018 jeffm@suse.com
- Update to 4.16-rc6.
- commit a98eb00
* Mon Mar 19 2018 jeffm@suse.com
- Refresh patches.suse/kernel-add-release-status-to-kernel-build.patch.
- commit cf5ff13
* Thu Mar 15 2018 jslaby@suse.cz
- Linux 4.15.10 (bnc#1012628).
- RDMA/ucma: Limit possible option size (bnc#1012628).
- RDMA/ucma: Check that user doesn't overflow QP state
  (bnc#1012628).
- RDMA/mlx5: Fix integer overflow while resizing CQ (bnc#1012628).
- IB/uverbs: Improve lockdep_check (bnc#1012628).
- mac80211_hwsim: don't use WQ_MEM_RECLAIM (bnc#1012628).
- net/smc: fix NULL pointer dereference on sock_create_kern()
  error path (bnc#1012628).
- regulator: stm32-vrefbuf: fix check on ready flag (bnc#1012628).
- drm/i915: Check for fused or unused pipes (bnc#1012628).
- drm/i915/audio: fix check for av_enc_map overflow (bnc#1012628).
- drm/i915: Fix rsvd2 mask when out-fence is returned
  (bnc#1012628).
- drm/i915: Clear the in-use marker on execbuf failure
  (bnc#1012628).
- drm/i915: Disable DC states around GMBUS on GLK (bnc#1012628).
- drm/i915: Update watermark state correctly in
  sanitize_watermarks (bnc#1012628).
- drm/i915: Try EDID bitbanging on HDMI after failed read
  (bnc#1012628).
- drm/i915/perf: fix perf stream opening lock (bnc#1012628).
- scsi: core: Avoid that ATA error handling can trigger a kernel
  hang or oops (bnc#1012628).
- scsi: qla2xxx: Fix NULL pointer crash due to active timer for
  ABTS (bnc#1012628).
- drm/i915: Always call to intel_display_set_init_power() in
  resume_early (bnc#1012628).
- workqueue: Allow retrieval of current task's work struct
  (bnc#1012628).
- drm: Allow determining if current task is output poll worker
  (bnc#1012628).
- drm/nouveau: Fix deadlock on runtime suspend (bnc#1012628).
- drm/radeon: Fix deadlock on runtime suspend (bnc#1012628).
- drm/amdgpu: Fix deadlock on runtime suspend (bnc#1012628).
- drm/nouveau: prefer XBGR2101010 for addfb ioctl (bnc#1012628).
- drm/amd/powerplay/smu7: allow mclk switching with no displays
  (bnc#1012628).
- drm/amd/powerplay/vega10: allow mclk switching with no displays
  (bnc#1012628).
- Revert "drm/radeon/pm: autoswitch power state when in balanced
  mode" (bnc#1012628).
- drm/amd/display: check for ipp before calling cursor operations
  (bnc#1012628).
- drm/radeon: insist on 32-bit DMA for Cedar on PPC64/PPC64LE
  (bnc#1012628).
- drm/amd/powerplay: fix power over limit on Fiji (bnc#1012628).
- drm/amd/display: Default HDMI6G support to true. Log VBIOS
  table error (bnc#1012628).
- drm/amdgpu: used cached pcie gen info for SI (v2) (bnc#1012628).
- drm/amdgpu: Notify sbios device ready before send request
  (bnc#1012628).
- drm/radeon: fix KV harvesting (bnc#1012628).
- drm/amdgpu: fix KV harvesting (bnc#1012628).
- drm/amdgpu:Correct max uvd handles (bnc#1012628).
- drm/amdgpu:Always save uvd vcpu_bo in VM Mode (bnc#1012628).
- ovl: redirect_dir=nofollow should not follow redirect for
  opaque lower (bnc#1012628).
- MIPS: BMIPS: Do not mask IPIs during suspend (bnc#1012628).
- MIPS: ath25: Check for kzalloc allocation failure (bnc#1012628).
- MIPS: OCTEON: irq: Check for null return on kzalloc allocation
  (bnc#1012628).
- PCI: dwc: Fix enumeration end when reaching root subordinate
  (bnc#1012628).
- Input: matrix_keypad - fix race when disabling interrupts
  (bnc#1012628).
- Revert "Input: synaptics - Lenovo Thinkpad T460p devices should
  use RMI" (bnc#1012628).
- bug: use %%pB in BUG and stack protector failure (bnc#1012628).
- lib/bug.c: exclude non-BUG/WARN exceptions from report_bug()
  (bnc#1012628).
- mm/memblock.c: hardcode the end_pfn being -1 (bnc#1012628).
- loop: Fix lost writes caused by missing flag (bnc#1012628).
- virtio_ring: fix num_free handling in error case (bnc#1012628).
- KVM: s390: fix memory overwrites when not using SCA entries
  (bnc#1012628).
- arm64: mm: fix thinko in non-global page table attribute check
  (bnc#1012628).
- IB/core: Fix missing RDMA cgroups release in case of failure
  to register device (bnc#1012628).
- Revert "nvme: create 'slaves' and 'holders' entries for hidden
  controllers" (bnc#1012628).
- kbuild: Handle builtin dtb file names containing hyphens
  (bnc#1012628).
- dm bufio: avoid false-positive Wmaybe-uninitialized warning
  (bnc#1012628).
- IB/mlx5: Fix incorrect size of klms in the memory region
  (bnc#1012628).
- bcache: fix crashes in duplicate cache device register
  (bnc#1012628).
- bcache: don't attach backing with duplicate UUID (bnc#1012628).
- x86/MCE: Save microcode revision in machine check records
  (bnc#1012628).
- x86/MCE: Serialize sysfs changes (bnc#1012628).
- perf tools: Fix trigger class trigger_on() (bnc#1012628).
- x86/spectre_v2: Don't check microcode versions when running
  under hypervisors (bnc#1012628).
- ALSA: hda/realtek - Add support headset mode for DELL WYSE
  (bnc#1012628).
- ALSA: hda/realtek - Add headset mode support for Dell laptop
  (bnc#1012628).
- ALSA: hda/realtek: Limit mic boost on T480 (bnc#1012628).
- ALSA: hda/realtek - Fix dock line-out volume on Dell Precision
  7520 (bnc#1012628).
- ALSA: hda/realtek - Make dock sound work on ThinkPad L570
  (bnc#1012628).
- ALSA: seq: Don't allow resizing pool in use (bnc#1012628).
- ALSA: seq: More protection for concurrent write and ioctl races
  (bnc#1012628).
- ALSA: hda - Fix a wrong FIXUP for alc289 on Dell machines
  (bnc#1012628).
- ALSA: hda: add dock and led support for HP EliteBook 820 G3
  (bnc#1012628).
- ALSA: hda: add dock and led support for HP ProBook 640 G2
  (bnc#1012628).
- scsi: qla2xxx: Fix NULL pointer crash due to probe failure
  (bnc#1012628).
- scsi: qla2xxx: Fix recursion while sending terminate exchange
  (bnc#1012628).
- dt-bindings: Document mti,mips-cpc binding (bnc#1012628).
- MIPS: CPC: Map registers using DT in
  mips_cpc_default_phys_base() (bnc#1012628).
- nospec: Kill array_index_nospec_mask_check() (bnc#1012628).
- nospec: Include <asm/barrier.h> dependency (bnc#1012628).
- x86/entry: Reduce the code footprint of the 'idtentry' macro
  (bnc#1012628).
- x86/entry/64: Use 'xorl' for faster register clearing
  (bnc#1012628).
- x86/mm: Remove stale comment about KMEMCHECK (bnc#1012628).
- x86/asm: Improve how GEN_*_SUFFIXED_RMWcc() specify clobbers
  (bnc#1012628).
- x86/IO-APIC: Avoid warning in 32-bit builds (bnc#1012628).
- x86/LDT: Avoid warning in 32-bit builds with older gcc
  (bnc#1012628).
- x86-64/realmode: Add instruction suffix (bnc#1012628).
- Revert "x86/retpoline: Simplify vmexit_fill_RSB()"
  (bnc#1012628).
- x86/speculation: Use IBRS if available before calling into
  firmware (bnc#1012628).
- x86/retpoline: Support retpoline builds with Clang
  (bnc#1012628).
- x86/speculation, objtool: Annotate indirect calls/jumps for
  objtool (bnc#1012628).
- x86/speculation: Move firmware_restrict_branch_speculation_*()
  from C to CPP (bnc#1012628).
- x86/paravirt, objtool: Annotate indirect calls (bnc#1012628).
- x86/boot, objtool: Annotate indirect jump in
  secondary_startup_64() (bnc#1012628).
- x86/mm/sme, objtool: Annotate indirect call in
  sme_encrypt_execute() (bnc#1012628).
- objtool: Use existing global variables for options
  (bnc#1012628).
- objtool: Add retpoline validation (bnc#1012628).
- objtool: Add module specific retpoline rules (bnc#1012628).
- objtool, retpolines: Integrate objtool with retpoline support
  more closely (bnc#1012628).
- objtool: Fix another switch table detection issue (bnc#1012628).
- objtool: Fix 32-bit build (bnc#1012628).
- x86/kprobes: Fix kernel crash when probing .entry_trampoline
  code (bnc#1012628).
- watchdog: hpwdt: SMBIOS check (bnc#1012628).
- watchdog: hpwdt: Check source of NMI (bnc#1012628).
- watchdog: hpwdt: fix unused variable warning (bnc#1012628).
- watchdog: hpwdt: Remove legacy NMI sourcing (bnc#1012628).
- netfilter: add back stackpointer size checks (bnc#1012628).
- netfilter: ipt_CLUSTERIP: fix a race condition of proc file
  creation (bnc#1012628).
- netfilter: xt_hashlimit: fix lock imbalance (bnc#1012628).
- netfilter: x_tables: fix missing timer initialization in xt_LED
  (bnc#1012628).
- netfilter: nat: cope with negative port range (bnc#1012628).
- netfilter: IDLETIMER: be syzkaller friendly (bnc#1012628).
- netfilter: bridge: ebt_among: add missing match size checks
  (bnc#1012628).
- netfilter: ipv6: fix use-after-free Write in
  nf_nat_ipv6_manip_pkt (bnc#1012628).
- netfilter: use skb_to_full_sk in ip6_route_me_harder
  (bnc#1012628).
- tpm_tis: Move ilb_base_addr to tpm_tis_data (bnc#1012628).
- tpm: Keep CLKRUN enabled throughout the duration of
  transmit_cmd() (bnc#1012628).
- tpm: delete the TPM_TIS_CLK_ENABLE flag (bnc#1012628).
- tpm: remove unused variables (bnc#1012628).
- tpm: only attempt to disable the LPC CLKRUN if is already
  enabled (bnc#1012628).
- x86/xen: Calculate __max_logical_packages on PV domains
  (bnc#1012628).
- scsi: qla2xxx: Fix system crash for Notify ack timeout handling
  (bnc#1012628).
- scsi: qla2xxx: Fix gpnid error processing (bnc#1012628).
- scsi: qla2xxx: Move session delete to driver work queue
  (bnc#1012628).
- scsi: qla2xxx: Skip IRQ affinity for Target QPairs
  (bnc#1012628).
- scsi: qla2xxx: Fix re-login for Nport Handle in use
  (bnc#1012628).
- scsi: qla2xxx: Retry switch command on time out (bnc#1012628).
- scsi: qla2xxx: Serialize GPNID for multiple RSCN (bnc#1012628).
- scsi: qla2xxx: Fix login state machine stuck at GPDB
  (bnc#1012628).
- scsi: qla2xxx: Fix NPIV host cleanup in target mode
  (bnc#1012628).
- scsi: qla2xxx: Relogin to target port on a cable swap
  (bnc#1012628).
- scsi: qla2xxx: Fix Relogin being triggered too fast
  (bnc#1012628).
- scsi: qla2xxx: Fix PRLI state check (bnc#1012628).
- scsi: qla2xxx: Fix abort command deadlock due to spinlock
  (bnc#1012628).
- scsi: qla2xxx: Replace fcport alloc with qla2x00_alloc_fcport
  (bnc#1012628).
- scsi: qla2xxx: Fix scan state field for fcport (bnc#1012628).
- scsi: qla2xxx: Clear loop id after delete (bnc#1012628).
- scsi: qla2xxx: Defer processing of GS IOCB calls (bnc#1012628).
- scsi: qla2xxx: Remove aborting ELS IOCB call issued as part
  of timeout (bnc#1012628).
- scsi: qla2xxx: Fix system crash in qlt_plogi_ack_unref
  (bnc#1012628).
- scsi: qla2xxx: Fix memory leak in dual/target mode
  (bnc#1012628).
- NFS: Fix an incorrect type in struct nfs_direct_req
  (bnc#1012628).
- pNFS: Prevent the layout header refcount going to zero in
  pnfs_roc() (bnc#1012628).
- NFS: Fix unstable write completion (bnc#1012628).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Refresh
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- Refresh
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- commit 5e4329c
* Thu Mar 15 2018 tiwai@suse.de
- Bluebooth: btusb: Fix quirk for Atheros 1525/QCA6174
  (bsc#1082504).
- commit 8413b00
* Thu Mar 15 2018 tiwai@suse.de
- Bluebooth: btusb: Fix quirk for Atheros 1525/QCA6174
  (bsc#1082504).
- commit e8a80ec
* Thu Mar 15 2018 mkubecek@suse.cz
- netfilter: ebtables: fix erroneous reject of last rule
  (bsc#1085107).
- netfilter: ebtables: CONFIG_COMPAT: don't trust userland offsets
  (bsc#1085107).
- commit bfb5701
* Wed Mar 14 2018 jeffm@suse.com
- config: sync i386/default
  Some options had been removed completely.
- commit 95f48d7
* Wed Mar 14 2018 jeffm@suse.com
- rpm/kernel-source.spec.in: Add check-module-license to Sources
  The package builds in the build service but the script won't make it
  into the SRPM if it's not in the Sources list.
- commit 031ed9e
* Wed Mar 14 2018 tiwai@suse.de
- brcmsmac: allocate ucode with GFP_KERNEL (bsc#1085174).
- commit 8e06b20
* Wed Mar 14 2018 tiwai@suse.de
- mac80211_hwsim: fix possible memory leak in hwsim_new_radio_nl()
  (CVE-2018-8087,bsc#1085053).
- commit cddf6d5
* Tue Mar 13 2018 msuchanek@suse.de
- mkspec: fix perl warning
- commit f15670f
* Mon Mar 12 2018 jeffm@suse.com
- Update to 4.16-rc5.
- Eliminated 1 patch.
- commit 0dfffad
* Sun Mar 11 2018 jslaby@suse.cz
- Linux 4.15.9 (bnc#1012628).
- bpf: fix mlock precharge on arraymaps (bnc#1012628).
- bpf: fix memory leak in lpm_trie map_free callback function
  (bnc#1012628).
- bpf: fix rcu lockdep warning for lpm_trie map_free callback
  (bnc#1012628).
- bpf, x64: implement retpoline for tail call (bnc#1012628).
- bpf, arm64: fix out of bounds access in tail call (bnc#1012628).
- bpf: add schedule points in percpu arrays management
  (bnc#1012628).
- bpf: allow xadd only on aligned memory (bnc#1012628).
- bpf, ppc64: fix out of bounds access in tail call (bnc#1012628).
- scsi: mpt3sas: fix oops in error handlers after shutdown/unload
  (bnc#1012628).
- scsi: mpt3sas: wait for and flush running commands on
  shutdown/unload (bnc#1012628).
- KVM: x86: fix backward migration with async_PF (bnc#1012628).
- Refresh
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- commit 23fae4b
* Sun Mar 11 2018 afaerber@suse.de
- config: armv7hl: Update to 4.16-rc4
- commit ad451a4
* Sun Mar 11 2018 afaerber@suse.de
- config: armv6hl: Update to 4.16-rc4
- commit 6c846e1
* Sat Mar 10 2018 tiwai@suse.de
- Refresh to upstream patch (bsc#1083694)
  patches.suse/Documentation-sphinx-Fix-Directive-import-error.patch
- commit 2d62679
* Sat Mar 10 2018 jeffm@suse.com
- kernel: add release status to kernel build (bsc#FATE#325281).
- commit c51605f
* Fri Mar  9 2018 jeffm@suse.com
- rpm: use %%_sourcedir prefix for release-projects
- rpm: set SUSE_KERNEL_RELEASED based on project name
  Set SUSE_KERNEL_RELEASED in the config only if the project name matches
  a list of projects that are part of official release channels.  This
  list of projects is maintained per-branch.
- commit a391a5b
* Fri Mar  9 2018 jeffm@suse.com
- config: added new 'kvmsmall' flavor
  This flavor is an unreleased internal configuration intended for kernel
  developers to use in simple virtual machines.  It contains only the
  device drivers necessary to use a KVM virtual machine *without* device
  passthrough enabled.  Common local and network file systems are enabled.
  All device mapper targets are enabled.  Only the network and graphics
  drivers for devices that qemu emulates are enabled.  Many subsystems
  enabled in the default kernel are entirely disabled.  This kernel is
  meant to be small and to build very quickly.  There will be no kABI
  stability and its configuration may be changed arbitrarily.
- commit 088f1da
* Fri Mar  9 2018 jeffm@suse.com
- config: convert kvmsmall to fragment config
- commit 7a5941a
* Fri Mar  9 2018 jeffm@suse.com
- config: disabled some more options for kvmsmall
  Disable CAN, BT, rare partition types, unused mouse protocols, UIO,
  STM, and others.
- commit 4707d44
* Fri Mar  9 2018 jeffm@suse.com
- config: added new 'kvmsmall' flavor
  This flavor is intended for kernel developers to use in simple virtual
  machines.  It contains only the device drivers necessary to use a
  KVM virtual machine *without* device passthrough enabled.  Common
  local and network file systems are enabled.  All device mapper targets
  are enabled.  Only the network and graphics drivers for devices that qemu
  emulates are enabled.  Many subsystems enabled in the default kernel
  are entirely disabled.  This kernel is meant to be small and to build
  very quickly.
- commit 3c99d1f
* Fri Mar  9 2018 jslaby@suse.cz
- Linux 4.15.8 (bnc#1012628).
- platform/x86: dell-laptop: fix kbd_get_state's request value
  (bnc#1012628).
- md: only allow remove_and_add_spares when no sync_thread running
  (bnc#1012628).
- powerpc/64s/radix: Boot-time NULL pointer protection using a
  guard-PID (bnc#1012628).
- ARM: dts: LogicPD Torpedo: Fix I2C1 pinmux (bnc#1012628).
- ARM: dts: LogicPD SOM-LV: Fix I2C1 pinmux (bnc#1012628).
- ACPI / bus: Parse tables as term_list for Dell XPS 9570 and
  Precision M5530 (bnc#1012628).
- KVM/x86: remove WARN_ON() for when vm_munmap() fails
  (bnc#1012628).
- KVM: x86: fix vcpu initialization with userspace lapic
  (bnc#1012628).
- KVM/VMX: Optimize vmx_vcpu_run() and svm_vcpu_run() by marking
  the RDMSR path as unlikely() (bnc#1012628).
- KVM: x86: move LAPIC initialization after VMCS creation
  (bnc#1012628).
- KVM/x86: Remove indirect MSR op calls from SPEC_CTRL
  (bnc#1012628).
- KVM: mmu: Fix overlap between public and private memslots
  (bnc#1012628).
- KVM: X86: Fix SMRAM accessing even if VM is shutdown
  (bnc#1012628).
- ARM: kvm: fix building with gcc-8 (bnc#1012628).
- ARM: mvebu: Fix broken PL310_ERRATA_753970 selects
  (bnc#1012628).
- ARM: dts: rockchip: Remove 1.8 GHz operation point from phycore
  som (bnc#1012628).
- ARM: orion: fix orion_ge00_switch_board_info initialization
  (bnc#1012628).
- x86/mm: Fix {pmd,pud}_{set,clear}_flags() (bnc#1012628).
- nospec: Allow index argument to have const-qualified type
  (bnc#1012628).
- KVM: s390: consider epoch index on TOD clock syncs
  (bnc#1012628).
- KVM: s390: consider epoch index on hotplugged CPUs
  (bnc#1012628).
- KVM: s390: provide only a single function for setting the tod
  (fix SCK) (bnc#1012628).
- KVM: s390: take care of clock-comparator sign control
  (bnc#1012628).
- EDAC, sb_edac: Fix out of bound writes during DIMM configuration
  on KNL (bnc#1012628).
- media: m88ds3103: don't call a non-initalized function
  (bnc#1012628).
- blk-mq: don't call io sched's .requeue_request when requeueing
  rq to ->dispatch (bnc#1012628).
- tcp: revert F-RTO extension to detect more spurious timeouts
  (bnc#1012628).
- tcp: revert F-RTO middle-box workaround (bnc#1012628).
- s390/qeth: fix IPA command submission race (bnc#1012628).
- s390/qeth: fix IP address lookup for L3 devices (bnc#1012628).
- Revert "s390/qeth: fix using of ref counter for rxip addresses"
  (bnc#1012628).
- s390/qeth: fix double-free on IP add/remove race (bnc#1012628).
- s390/qeth: fix IP removal on offline cards (bnc#1012628).
- s390/qeth: fix overestimated count of buffer elements
  (bnc#1012628).
- s390/qeth: fix SETIP command handling (bnc#1012628).
- s390/qeth: fix underestimated count of buffer elements
  (bnc#1012628).
- l2tp: fix tunnel lookup use-after-free race (bnc#1012628).
- l2tp: fix race in pppol2tp_release with session object destroy
  (bnc#1012628).
- l2tp: fix races with tunnel socket close (bnc#1012628).
- l2tp: don't use inet_shutdown on ppp session destroy
  (bnc#1012628).
- l2tp: don't use inet_shutdown on tunnel destroy (bnc#1012628).
- tcp: tracepoint: only call trace_tcp_send_reset with full socket
  (bnc#1012628).
- net: phy: Restore phy_resume() locking assumption (bnc#1012628).
- net/mlx5: Fix error handling when adding flow rules
  (bnc#1012628).
- cxgb4: fix trailing zero in CIM LA dump (bnc#1012628).
- virtio-net: disable NAPI only when enabled during XDP set
  (bnc#1012628).
- tuntap: disable preemption during XDP processing (bnc#1012628).
- tuntap: correctly add the missing XDP flush (bnc#1012628).
- tcp: purge write queue upon RST (bnc#1012628).
- netlink: put module reference if dump start fails (bnc#1012628).
- mlxsw: spectrum_router: Do not unconditionally clear route
  offload indication (bnc#1012628).
- cls_u32: fix use after free in u32_destroy_key() (bnc#1012628).
- amd-xgbe: Restore PCI interrupt enablement setting on resume
  (bnc#1012628).
- tls: Use correct sk->sk_prot for IPV6 (bnc#1012628).
- net/mlx5e: Verify inline header size do not exceed SKB linear
  size (bnc#1012628).
- bridge: Fix VLAN reference count problem (bnc#1012628).
- sctp: fix dst refcnt leak in sctp_v6_get_dst() (bnc#1012628).
- net: ipv4: Set addr_type in hash_keys for forwarded case
  (bnc#1012628).
- mlxsw: spectrum_router: Fix error path in mlxsw_sp_vr_create
  (bnc#1012628).
- sctp: do not pr_err for the duplicated node in transport rhlist
  (bnc#1012628).
- net/sched: cls_u32: fix cls_u32 on filter replace (bnc#1012628).
- net_sched: gen_estimator: fix broken estimators based on percpu
  stats (bnc#1012628).
- net/mlx5e: Fix loopback self test when GRO is off (bnc#1012628).
- doc: Change the min default value of tcp_wmem/tcp_rmem
  (bnc#1012628).
- tcp_bbr: better deal with suboptimal GSO (bnc#1012628).
- rxrpc: Fix send in rxrpc_send_data_packet() (bnc#1012628).
- tcp: Honor the eor bit in tcp_mtu_probe (bnc#1012628).
- net: phy: fix phy_start to consider PHY_IGNORE_INTERRUPT
  (bnc#1012628).
- net/mlx5e: Specify numa node when allocating drop rq
  (bnc#1012628).
- mlxsw: spectrum_switchdev: Check success of FDB add operation
  (bnc#1012628).
- sctp: fix dst refcnt leak in sctp_v4_get_dst (bnc#1012628).
- net/mlx5e: Fix TCP checksum in LRO buffers (bnc#1012628).
- udplite: fix partial checksum initialization (bnc#1012628).
- sctp: verify size of a new chunk in _sctp_make_chunk()
  (bnc#1012628).
- ppp: prevent unregistered channels from connecting to PPP units
  (bnc#1012628).
- net: sched: report if filter is too large to dump (bnc#1012628).
- netlink: ensure to loop over all netns in
  genlmsg_multicast_allns() (bnc#1012628).
- net: ipv4: don't allow setting net.ipv4.route.min_pmtu below 68
  (bnc#1012628).
- net: fix race on decreasing number of TX queues (bnc#1012628).
- net: ethernet: ti: cpsw: fix net watchdog timeout (bnc#1012628).
- net: amd-xgbe: fix comparison to bitshift when dealing with
  a mask (bnc#1012628).
- ipv6 sit: work around bogus gcc-8 -Wrestrict warning
  (bnc#1012628).
- hdlc_ppp: carrier detect ok, don't turn off negotiation
  (bnc#1012628).
- fib_semantics: Don't match route with mismatching tclassid
  (bnc#1012628).
- bridge: check brport attr show in brport_show (bnc#1012628).
- x86/cpu_entry_area: Sync cpu_entry_area to initial_page_table
  (bnc#1012628).
- x86/platform/intel-mid: Handle Intel Edison reboot correctly
  (bnc#1012628).
- x86/xen: Zero MSR_IA32_SPEC_CTRL before suspend (bnc#1012628).
- direct-io: Fix sleep in atomic due to sync AIO (bnc#1012628).
- dax: fix vma_is_fsdax() helper (bnc#1012628).
- cpufreq: s3c24xx: Fix broken s3c_cpufreq_init() (bnc#1012628).
- vfio: disable filesystem-dax page pinning (bnc#1012628).
- block: pass inclusive 'lend' parameter to
  truncate_inode_pages_range (bnc#1012628).
- block: kyber: fix domain token leak during requeue
  (bnc#1012628).
- block: fix the count of PGPGOUT for WRITE_SAME (bnc#1012628).
- btrfs: use proper endianness accessors for super_copy
  (bnc#1012628).
- parisc: Hide virtual kernel memory layout (bnc#1012628).
- parisc: Fix ordering of cache and TLB flushes (bnc#1012628).
- parisc: Reduce irq overhead when run in qemu (bnc#1012628).
- parisc: Use cr16 interval timers unconditionally on qemu
  (bnc#1012628).
- timers: Forward timer base before migrating timers
  (bnc#1012628).
- mmc: dw_mmc: Fix out-of-bounds access for slot's caps
  (bnc#1012628).
- mmc: dw_mmc: Factor out dw_mci_init_slot_caps (bnc#1012628).
- mmc: dw_mmc: Avoid accessing registers in runtime suspended
  state (bnc#1012628).
- mmc: dw_mmc-k3: Fix out-of-bounds access through DT alias
  (bnc#1012628).
- mmc: sdhci-pci: Fix S0i3 for Intel BYT-based controllers
  (bnc#1012628).
- ALSA: hda - Fix pincfg at resume on Lenovo T470 dock
  (bnc#1012628).
- ALSA: hda: Add a power_save blacklist (bnc#1012628).
- ALSA: x86: Fix missing spinlock and mutex initializations
  (bnc#1012628).
- ALSA: control: Fix memory corruption risk in snd_ctl_elem_read
  (bnc#1012628).
- ALSA: usb-audio: Add a quirck for B&W PX headphones
  (bnc#1012628).
- tpm_tis: fix potential buffer overruns caused by bit glitches
  on the bus (bnc#1012628).
- tpm_i2c_nuvoton: fix potential buffer overruns caused by bit
  glitches on the bus (bnc#1012628).
- tpm_i2c_infineon: fix potential buffer overruns caused by bit
  glitches on the bus (bnc#1012628).
- tpm: fix potential buffer overruns caused by bit glitches on
  the bus (bnc#1012628).
- tpm: st33zp24: fix potential buffer overruns caused by bit
  glitches on the bus (bnc#1012628).
- ixgbe: fix crash in build_skb Rx code path (bnc#1012628).
- Bluetooth: btusb: Use DMI matching for QCA reset_resume quirking
  (bnc#1012628).
- powerpc/pseries: Enable RAS hotplug events later (bnc#1012628).
- platform/x86: dell-laptop: Allocate buffer on heap rather than
  globally (bnc#1012628).
- ipmi_si: Fix error handling of platform device (bnc#1012628).
- hrtimer: Ensure POSIX compliance (relative CLOCK_REALTIME
  hrtimers) (bnc#1012628).
- vsprintf: avoid misleading "(null)" for %%px (bnc#1012628).
- commit 67f0889
* Thu Mar  8 2018 msuchanek@suse.de
- mkspec: do not build dtbs for architectures with no kernel.
- commit 8394abf
* Thu Mar  8 2018 jeffm@suse.com
- kconfig: move SUSE options from init/Kconfig to init/Kconfig.suse
- commit b7f69ff
* Wed Mar  7 2018 afaerber@suse.de
- config: arm64: Update to 4.16-rc4
- commit 0bb9ed4
* Wed Mar  7 2018 tiwai@suse.de
- rpm/kernel-binary.spec.in: Check module licenses (bsc#1083215,bsc#1083527)
- commit e41de0c
* Wed Mar  7 2018 tiwai@suse.de
- x86/kvm/vmx: do not use vm-exit instruction length for fast
  MMIO when running nested (bsc#1081431).
- commit 4e5b14d
* Tue Mar  6 2018 jslaby@suse.cz
- Update config files.
  Enable module signing (bnc#1082905):
  * CONFIG_MODULE_SIG=y
  * # CONFIG_MODULE_SIG_FORCE is not set
  * # CONFIG_MODULE_SIG_ALL is not set
  * # CONFIG_MODULE_SIG_SHA1 is not set
  * # CONFIG_MODULE_SIG_SHA224 is not set
  * CONFIG_MODULE_SIG_SHA256=y
  * # CONFIG_MODULE_SIG_SHA384 is not set
  * # CONFIG_MODULE_SIG_SHA512 is not set
  * CONFIG_MODULE_SIG_HASH="sha256"
  * CONFIG_MODULE_SIG_KEY="certs/signing_key.pem"
  * CONFIG_SECONDARY_TRUSTED_KEYRING=y
  * CONFIG_SYSTEM_BLACKLIST_KEYRING=y
  * CONFIG_SYSTEM_BLACKLIST_HASH_LIST=""
  This commit synchronizes these options with SLE15.
  We do not add patches for loading keys from the shim layer (as in
  SLE15) for the time being. They were rejected multiple times in
  upstream and we do not want to forward-port them infinitely. This only
  means that loading KMPs with none/invalid signatures generates this:
  <module_name>: loading out-of-tree module taints kernel.
  <module_name>: module verification failed: signature and/or required key missing - tainting kernel
  But the modules load fine after that as we have MODULE_SIG_FORCE set
  to 'n'.
  Tested in qemu+OVMF and bare metal and everything looks fine.
- commit 12abbef
* Mon Mar  5 2018 msuchanek@suse.de
- rpm: provide %%name%%-srchash = <kernel-source commit hash> (FATE#325312).
  - Also use for kernel-obs-build dependency.
- commit b6fccdf
* Mon Mar  5 2018 jeffm@suse.com
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Refresh
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- Refresh
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- commit 1ba5305
* Mon Mar  5 2018 jeffm@suse.com
- Update to 4.16-rc4.
- IBRS patches need review.
- commit 061459a
* Sun Mar  4 2018 msuchanek@suse.de
- arch-symbols: use bash as interpreter since the script uses bashism.
- commit 4cdfb23
* Fri Mar  2 2018 msuchanek@suse.de
- kernel-binary: do not BuildIgnore m4.
  It is actually needed for regenerating zconf when it is not up-to-date
  due to merge.
- commit 967b28b
* Fri Mar  2 2018 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: add build requirement for flex
  In addition to bison, we also need flex for "make oldconfig".
- commit 83d831c
* Fri Mar  2 2018 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: remove m4 from BuildIgnore list
  As bison depends on m4, we cannot set !BuildIgnore for it any more.
- commit d7695e1
* Fri Mar  2 2018 tiwai@suse.de
- Documentation/sphinx: Fix Directive import error (bsc#1083694).
- commit 7f94eb1
* Wed Feb 28 2018 msuchanek@suse.de
- bs-upload-kernel: do not set %%opensuse_bs
  Since SLE15 it is not set in the distribution project so do not set it
  for kernel projects either.
- commit d696aa0
* Wed Feb 28 2018 jslaby@suse.cz
- Linux 4.15.7 (bnc#1012628).
- microblaze: fix endian handling (bnc#1012628).
- drm/i915/breadcrumbs: Ignore unsubmitted signalers
  (bnc#1012628).
- arm64: __show_regs: Only resolve kernel symbols when running
  at EL1 (bnc#1012628).
- drm/amdgpu: add new device to use atpx quirk (bnc#1012628).
- drm/amdgpu: Avoid leaking PM domain on driver unbind (v2)
  (bnc#1012628).
- drm/amdgpu: add atpx quirk handling (v2) (bnc#1012628).
- drm/amdgpu: only check mmBIF_IOV_FUNC_IDENTIFIER on tonga/fiji
  (bnc#1012628).
- drm/amdgpu: Add dpm quirk for Jet PRO (v2) (bnc#1012628).
- drm/amdgpu: fix VA hole handling on Vega10 v3 (bnc#1012628).
- drm/amdgpu: disable MMHUB power gating on raven (bnc#1012628).
- drm: Handle unexpected holes in color-eviction (bnc#1012628).
- drm/atomic: Fix memleak on ERESTARTSYS during non-blocking
  commits (bnc#1012628).
- drm/cirrus: Load lut in crtc_commit (bnc#1012628).
- usb: renesas_usbhs: missed the "running" flag in usb_dmac with
  rx path (bnc#1012628).
- usb: gadget: f_fs: Use config_ep_by_speed() (bnc#1012628).
- usb: gadget: f_fs: Process all descriptors during bind
  (bnc#1012628).
- Revert "usb: musb: host: don't start next rx urb if current
  one failed" (bnc#1012628).
- usb: ldusb: add PIDs for new CASSY devices supported by this
  driver (bnc#1012628).
- usb: phy: mxs: Fix NULL pointer dereference on i.MX23/28
  (bnc#1012628).
- usb: dwc3: ep0: Reset TRB counter for ep0 IN (bnc#1012628).
- usb: dwc3: gadget: Set maxpacket size for ep0 IN (bnc#1012628).
- usb: host: ehci: use correct device pointer for dma ops
  (bnc#1012628).
- drm/edid: Add 6 bpc quirk for CPT panel in Asus UX303LA
  (bnc#1012628).
- Add delay-init quirk for Corsair K70 RGB keyboards
  (bnc#1012628).
- arm64: cpufeature: Fix CTR_EL0 field definitions (bnc#1012628).
- arm64: Disable unhandled signal log messages by default
  (bnc#1012628).
- arm64: Remove unimplemented syscall log message (bnc#1012628).
- usb: ohci: Proper handling of ed_rm_list to handle race
  condition between usb_kill_urb() and finish_unlinks()
  (bnc#1012628).
- ohci-hcd: Fix race condition caused by ohci_urb_enqueue()
  and io_watchdog_func() (bnc#1012628).
- net: thunderbolt: Run disconnect flow asynchronously when
  logout is received (bnc#1012628).
- net: thunderbolt: Tear down connection properly on suspend
  (bnc#1012628).
- PCI/cxgb4: Extend T3 PCI quirk to T4+ devices (bnc#1012628).
- irqchip/mips-gic: Avoid spuriously handling masked interrupts
  (bnc#1012628).
- irqchip/gic-v3: Use wmb() instead of smb_wmb() in
  gic_raise_softirq() (bnc#1012628).
- uapi/if_ether.h: move __UAPI_DEF_ETHHDR libc define
  (bnc#1012628).
- mm: don't defer struct page initialization for Xen pv guests
  (bnc#1012628).
- mm, swap, frontswap: fix THP swap if frontswap enabled
  (bnc#1012628).
- x86/oprofile: Fix bogus GCC-8 warning in nmi_setup()
  (bnc#1012628).
- x86/apic/vector: Handle vector release on CPU unplug correctly
  (bnc#1012628).
- Kbuild: always define endianess in kconfig.h (bnc#1012628).
- iio: adis_lib: Initialize trigger before requesting interrupt
  (bnc#1012628).
- iio: buffer: check if a buffer has been set up when poll is
  called (bnc#1012628).
- iio: srf08: fix link error "devm_iio_triggered_buffer_setup"
  undefined (bnc#1012628).
- iio: adc: stm32: fix stm32h7_adc_enable error handling
  (bnc#1012628).
- RDMA/uverbs: Sanitize user entered port numbers prior to access
  it (bnc#1012628).
- RDMA/uverbs: Fix circular locking dependency (bnc#1012628).
- RDMA/uverbs: Fix bad unlock balance in ib_uverbs_close_xrcd
  (bnc#1012628).
- RDMA/uverbs: Protect from command mask overflow (bnc#1012628).
- RDMA/uverbs: Protect from races between lookup and destroy of
  uobjects (bnc#1012628).
- genirq/matrix: Handle CPU offlining proper (bnc#1012628).
- extcon: int3496: process id-pin first so that we start with
  the right status (bnc#1012628).
- PKCS#7: fix certificate blacklisting (bnc#1012628).
- PKCS#7: fix certificate chain verification (bnc#1012628).
- X.509: fix NULL dereference when restricting key with
  unsupported_sig (bnc#1012628).
- X.509: fix BUG_ON() when hash algorithm is unsupported
  (bnc#1012628).
- i2c: bcm2835: Set up the rising/falling edge delays
  (bnc#1012628).
- i2c: designware: must wait for enable (bnc#1012628).
- cfg80211: fix cfg80211_beacon_dup (bnc#1012628).
- MIPS: Drop spurious __unused in struct compat_flock
  (bnc#1012628).
- scsi: ibmvfc: fix misdefined reserved field in
  ibmvfc_fcp_rsp_info (bnc#1012628).
- xtensa: fix high memory/reserved memory collision (bnc#1012628).
- MIPS: boot: Define __ASSEMBLY__ for its.S build (bnc#1012628).
- kconfig.h: Include compiler types to avoid missed struct
  attributes (bnc#1012628).
- arm64: mm: don't write garbage into TTBR1_EL1 register
  (bnc#1012628).
- netfilter: drop outermost socket lock in getsockopt()
  (bnc#1012628).
- commit 48cfb35
* Wed Feb 28 2018 jeffm@suse.com
- kernel: add product-identifying information to kernel build (FATE#325281).
- commit 450b8db
* Tue Feb 27 2018 msuchanek@suse.de
- Revert "rpm/kernel-binary.spec.in: Also require m4 for build."
  This reverts commit 0d7b4b3f948c2efb67b7d1b95b5e1dcae225991c.
- commit f5686d2
* Tue Feb 27 2018 tiwai@suse.de
- kernel-binary: do not package extract-cert when not signing modules
  (boo#1080250).
- commit 10a8bc4
* Mon Feb 26 2018 jeffm@suse.com
- Update to 4.16-rc3.
- Eliminated 2 patches.
- commit a1d0a5c
* Mon Feb 26 2018 jeffm@suse.com
- Update to 4.16-rc2.
- Eliminated 1 patch.
- Config changes:
  - i386:
  - X86_MINIMUM_CPU_FAMILY (set automatically by oldconfig).
- commit 70f217f
* Mon Feb 26 2018 jeffm@suse.com
- Update to 4.16-rc1.
- Eliminated 624 patches (mostly 4.15.x).
- ARM configs need updating.
- Config changes:
  - General:
  - CC_STACKPROTECTOR_REGULAR=y
  - x86:
  - ACPI_SPCR_TABLE=y
  - ACER_WIRELESS=m
  - GPD_POCKET_FAN=m
  - INTEL_CHTDC_TI_PWRBTN=m
  - MELLANOX_PLATFORM=y
  - MLXREG_HOTPLUG=m
  - JAILHOUSE_GUEST=y
  - i386:
  - MLX_PLATFORM=m
  - DEFERRED_STRUCT_PAGE_INIT=y
  - powerpc:
  - PPC_MEM_KEYS=y
  - OCXL=m
  - PPC_IRQ_SOFT_MASK_DEBUG=n
  - s390:
  - KERNEL_NOBP=y
  - EXPOLINE=y
  - EXPOLINE_FULL=y
  - PCI:
  - PCIE_CADENCE_HOST=y
  - PCIE_CADENCE_EP=y
  - Network:
  - NF_FLOW_TABLE=m
  - NF_FLOW_TABLE_IPV4=m
  - NF_FLOW_TABLE_IPV6=m
  - IP6_NF_MATCH_SRH=m
  - BT_HCIBTUSB_AUTOSUSPEND=y
  - NET_VENDOR_CORTINA=y
  - GEMINI_ETHERNET=m
  - NET_VENDOR_SOCIONEXT=y
  - NETDEVSIM=n
  - NFT_FLOW_OFFLOAD=m
  - NF_FLOW_TABLE_INET=m
  - Block:
  - BLK_DEV_NULL_BLK_FAULT_INJECTION=n
  - SATA_MOBILE_LPM_POLICY=0
  - DM_UNSTRIPED=m
  - MMC_SDHCI_F_SDH30=n
  - Misc:
  - MISC_RTSX_PCI=m
  - MISC_RTSX_USB=m
  - HW_RANDOM_TPM=y (from m)
  - I2C_GPIO_FAULT_INJECTOR=n
  - PINCTRL_AXP209=m
  - GPIO_WINBOND=m
  - GPIO_PCIE_IDIO_24=m
  - SENSORS_W83773G=m
  - MFD_CROS_EC_CHARDEV=n
  - RAVE_SP_CORE=n
  CAVIUM_PTP=m
  - Graphics:
  - DRM_PANEL_ILITEK_IL9322=n
  - TINYDRM_ILI9225=n
  - TINYDRM_ST7735R=n
  - Sound:
  - SND_SOC_INTEL_SST_TOPLEVEL=y
  - SND_SST_ATOM_HIFI2_PLATFORM_PCI=m
  - SND_SOC_INTEL_BYT_MAX98090_MACH=m
  - SND_SOC_INTEL_BYT_RT5640_MACH=m
  - SND_SOC_MAX98373=n
  - SND_SOC_PCM186X_I2C=n
  - SND_SOC_PCM186X_SPI=n
  - SND_SOC_TAS6424=n
  - SND_SOC_TLV320AIC32X4_I2C=n
  - SND_SOC_TLV320AIC32X4_SPI=n
  - SND_SOC_TSCS42XX=n
  - SOUNDWIRE=y
  - SOUNDWIRE_INTEL=m
  - Input:
  - HID_JABRA=n
  - USB:
  - USB_XHCI_DBGCAP=n
  - LEDS:
  - LEDS_LM3692X=n
  - LEDS_TRIGGER_NETDEV=m
  - LEDS_LP8860=n
  - RTC:
  - RTC_DRV_CROS_EC=n
  - VIRT:
  - VBOXGUEST=m
  - VIRTIO_MENU=y
  - KVM_AMD_SEV=y
  - Filesystems:
  - CIFS_SMB_DIRECT=n (still experimental)
  - Other:
  - UNISYSSPAR=n
  - XILINX_VCU=n
  - IIO_BUFFER_HW_CONSUMER=n
  - SD_ADC_MODULATOR=n
  - OF_FPGA_REGION=n
  - SIOX=n
  - SLIMBUS=n
  - BPF_KPROBE_OVERRIDE=n
  - FPGA_BRIDGE=n
  - Sensors:
  - ST_UVIS25=n
  - ZOPT2201=n
  - Media:
  - MT76x2E=m
  - LIRC=y
  - DVB_MMAP=n (still experimental)
  - DVB_ULE_DEBUG=n
  - Testing:
  - FAIL_FUNCTION=n
  - RUNTIME_TESTING_MENU=y
  - FIND_BIT_BENCHMARK=n
  - Crypto:
  - CHELSIO_IPSEC_INLINE=n
  - CRYPTO_DEV_SP_PSP=y
- commit 955d7ce
* Sun Feb 25 2018 jslaby@suse.cz
- bpf: cpumap: use GFP_KERNEL instead of GFP_ATOMIC in
  __cpu_map_entry_alloc() (git-fixes).
- commit b050949
* Sun Feb 25 2018 jslaby@suse.cz
- ptr_ring: prevent integer overflow when calculating size
  (git-fixes).
- commit f95a8d4
* Sun Feb 25 2018 jslaby@suse.cz
- Linux 4.15.6 (bnc#1012628).
- vmalloc: fix __GFP_HIGHMEM usage for vmalloc_32 on 32b systems
  (bnc#1012628).
- mei: me: add cannon point device ids for 4th device
  (bnc#1012628).
- mei: me: add cannon point device ids (bnc#1012628).
- crypto: s5p-sss - Fix kernel Oops in AES-ECB mode (bnc#1012628).
- usbip: keep usbip_device sockfd state in sync with tcp_socket
  (bnc#1012628).
- xhci: fix xhci debugfs errors in xhci_stop (bnc#1012628).
- xhci: xhci debugfs device nodes weren't removed after device
  plugged out (bnc#1012628).
- xhci: Fix xhci debugfs devices node disappearance after
  hibernation (bnc#1012628).
- xhci: Fix NULL pointer in xhci debugfs (bnc#1012628).
- staging: iio: ad5933: switch buffer mode to software
  (bnc#1012628).
- staging: iio: adc: ad7192: fix external frequency setting
  (bnc#1012628).
- staging: fsl-mc: fix build testing on x86 (bnc#1012628).
- binder: replace "%%p" with "%%pK" (bnc#1012628).
- binder: check for binder_thread allocation failure in
  binder_poll() (bnc#1012628).
- staging: android: ashmem: Fix a race condition in pin ioctls
  (bnc#1012628).
- ANDROID: binder: synchronize_rcu() when using POLLFREE
  (bnc#1012628).
- ANDROID: binder: remove WARN() for redundant txn error
  (bnc#1012628).
- dn_getsockoptdecnet: move nf_{get/set}sockopt outside sock lock
  (bnc#1012628).
- arm64: dts: add #cooling-cells to CPU nodes (bnc#1012628).
- ARM: 8743/1: bL_switcher: add MODULE_LICENSE tag (bnc#1012628).
- video: fbdev/mmp: add MODULE_LICENSE (bnc#1012628).
- ASoC: ux500: add MODULE_LICENSE tag (bnc#1012628).
- soc: qcom: rmtfs_mem: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- net_sched: gen_estimator: fix lockdep splat (bnc#1012628).
- net: avoid skb_warn_bad_offload on IS_ERR (bnc#1012628).
- rds: tcp: atomically purge entries from rds_tcp_conn_list
  during netns delete (bnc#1012628).
- rds: tcp: correctly sequence cleanup on netns deletion
  (bnc#1012628).
- netfilter: xt_RATEEST: acquire xt_rateest_mutex for hash insert
  (bnc#1012628).
- netfilter: xt_cgroup: initialize info->priv in
  cgroup_mt_check_v1() (bnc#1012628).
- netfilter: on sockopt() acquire sock lock only in the required
  scope (bnc#1012628).
- netfilter: ipt_CLUSTERIP: fix out-of-bounds accesses in
  clusterip_tg_check() (bnc#1012628).
- netfilter: x_tables: avoid out-of-bounds reads in
  xt_request_find_{match|target} (bnc#1012628).
- netfilter: x_tables: fix int overflow in xt_alloc_table_info()
  (bnc#1012628).
- kcov: detect double association with a single task
  (bnc#1012628).
- KVM: x86: fix escape of guest dr6 to the host (bnc#1012628).
- blk_rq_map_user_iov: fix error override (bnc#1012628).
- staging: android: ion: Switch from WARN to pr_warn
  (bnc#1012628).
- staging: android: ion: Add __GFP_NOWARN for system contig heap
  (bnc#1012628).
- crypto: x86/twofish-3way - Fix %%rbp usage (bnc#1012628).
- media: pvrusb2: properly check endpoint types (bnc#1012628).
- selinux: skip bounded transition processing if the policy
  isn't loaded (bnc#1012628).
- selinux: ensure the context is NUL terminated in
  security_context_to_sid_core() (bnc#1012628).
- ptr_ring: try vmalloc() when kmalloc() fails (bnc#1012628).
- ptr_ring: fail early if queue occupies more than
  KMALLOC_MAX_SIZE (bnc#1012628).
- tun: fix tun_napi_alloc_frags() frag allocator (bnc#1012628).
- commit 71fd692
* Thu Feb 22 2018 jslaby@suse.cz
- powerpc/pseries: Add empty update_numa_cpu_lookup_table()
  for NUMA=n (git-fixes).
- commit 4a82466
* Thu Feb 22 2018 jslaby@suse.cz
- Linux 4.15.5 (bnc#1012628).
- scsi: smartpqi: allow static build ("built-in") (bnc#1012628).
- IB/umad: Fix use of unprotected device pointer (bnc#1012628).
- IB/qib: Fix comparison error with qperf compare/swap test
  (bnc#1012628).
- IB/mlx4: Fix incorrectly releasing steerable UD QPs when have
  only ETH ports (bnc#1012628).
- IB/core: Fix two kernel warnings triggered by rxe registration
  (bnc#1012628).
- IB/core: Fix ib_wc structure size to remain in 64 bytes boundary
  (bnc#1012628).
- IB/core: Avoid a potential OOPs for an unused optional parameter
  (bnc#1012628).
- selftests: seccomp: fix compile error seccomp_bpf (bnc#1012628).
- kselftest: fix OOM in memory compaction test (bnc#1012628).
- RDMA/rxe: Fix a race condition related to the QP error state
  (bnc#1012628).
- RDMA/rxe: Fix a race condition in rxe_requester() (bnc#1012628).
- RDMA/rxe: Fix rxe_qp_cleanup() (bnc#1012628).
- cpufreq: powernv: Dont assume distinct pstate values for
  nominal and pmin (bnc#1012628).
- swiotlb: suppress warning when __GFP_NOWARN is set
  (bnc#1012628).
- PM / devfreq: Propagate error from devfreq_add_device()
  (bnc#1012628).
- mwifiex: resolve reset vs. remove()/shutdown() deadlocks
  (bnc#1012628).
- ocfs2: try a blocking lock before return AOP_TRUNCATED_PAGE
  (bnc#1012628).
- trace_uprobe: Display correct offset in uprobe_events
  (bnc#1012628).
- powerpc/radix: Remove trace_tlbie call from radix__flush_tlb_all
  (bnc#1012628).
- powerpc/kernel: Block interrupts when updating TIDR
  (bnc#1012628).
- powerpc/vas: Don't set uses_vas for kernel windows
  (bnc#1012628).
- powerpc/numa: Invalidate numa_cpu_lookup_table on cpu remove
  (bnc#1012628).
- powerpc/mm: Flush radix process translations when setting MMU
  type (bnc#1012628).
- powerpc/xive: Use hw CPU ids when configuring the CPU queues
  (bnc#1012628).
- dma-buf: fix reservation_object_wait_timeout_rcu once more v2
  (bnc#1012628).
- s390: fix handling of -1 in set{,fs}[gu]id16 syscalls
  (bnc#1012628).
- arm64: dts: msm8916: Correct ipc references for smsm
  (bnc#1012628).
- ARM: lpc3250: fix uda1380 gpio numbers (bnc#1012628).
- ARM: dts: STi: Add gpio polarity for "hdmi,hpd-gpio" property
  (bnc#1012628).
- ARM: dts: nomadik: add interrupt-parent for clcd (bnc#1012628).
- arm: dts: mt7623: fix card detection issue on bananapi-r2
  (bnc#1012628).
- arm: spear600: Add missing interrupt-parent of rtc
  (bnc#1012628).
- arm: spear13xx: Fix dmas cells (bnc#1012628).
- arm: spear13xx: Fix spics gpio controller's warning
  (bnc#1012628).
- x86/gpu: add CFL to early quirks (bnc#1012628).
- x86/kexec: Make kexec (mostly) work in 5-level paging mode
  (bnc#1012628).
- x86/xen: init %%gs very early to avoid page faults with stack
  protector (bnc#1012628).
- x86: PM: Make APM idle driver initialize polling state
  (bnc#1012628).
- mm, memory_hotplug: fix memmap initialization (bnc#1012628).
- x86/entry/64: Clear extra registers beyond syscall arguments,
  to reduce speculation attack surface (bnc#1012628).
- x86/entry/64/compat: Clear registers for compat syscalls,
  to reduce speculation attack surface (bnc#1012628).
- compiler-gcc.h: Introduce __optimize function attribute
  (bnc#1012628).
- compiler-gcc.h: __nostackprotector needs gcc-4.4 and up
  (bnc#1012628).
- crypto: sun4i_ss_prng - fix return value of
  sun4i_ss_prng_generate (bnc#1012628).
- crypto: sun4i_ss_prng - convert lock to _bh in
  sun4i_ss_prng_generate (bnc#1012628).
- powerpc/mm/radix: Split linear mapping on hot-unplug
  (bnc#1012628).
- x86/mm/pti: Fix PTI comment in entry_SYSCALL_64() (bnc#1012628).
- x86/speculation: Update Speculation Control microcode blacklist
  (bnc#1012628).
- x86/speculation: Correct Speculation Control microcode blacklist
  again (bnc#1012628).
- Revert "x86/speculation: Simplify
  indirect_branch_prediction_barrier()" (bnc#1012628).
- KVM/x86: Reduce retpoline performance impact in
  slot_handle_level_range(), by always inlining iterator helper
  methods (bnc#1012628).
- X86/nVMX: Properly set spec_ctrl and pred_cmd before merging
  MSRs (bnc#1012628).
- KVM/nVMX: Set the CPU_BASED_USE_MSR_BITMAPS if we have a valid
  L02 MSR bitmap (bnc#1012628).
- x86/speculation: Clean up various Spectre related details
  (bnc#1012628).
- PM / runtime: Update links_count also if !CONFIG_SRCU
  (bnc#1012628).
- PM: cpuidle: Fix cpuidle_poll_state_init() prototype
  (bnc#1012628).
- platform/x86: wmi: fix off-by-one write in wmi_dev_probe()
  (bnc#1012628).
- x86/entry/64: Clear registers for exceptions/interrupts,
  to reduce speculation attack surface (bnc#1012628).
- x86/entry/64: Merge SAVE_C_REGS and SAVE_EXTRA_REGS, remove
  unused extensions (bnc#1012628).
- x86/entry/64: Merge the POP_C_REGS and POP_EXTRA_REGS macros
  into a single POP_REGS macro (bnc#1012628).
- x86/entry/64: Interleave XOR register clearing with PUSH
  instructions (bnc#1012628).
- x86/entry/64: Introduce the PUSH_AND_CLEAN_REGS macro
  (bnc#1012628).
- x86/entry/64: Use PUSH_AND_CLEAN_REGS in more cases
  (bnc#1012628).
- x86/entry/64: Get rid of the ALLOC_PT_GPREGS_ON_STACK and
  SAVE_AND_CLEAR_REGS macros (bnc#1012628).
- x86/entry/64: Indent PUSH_AND_CLEAR_REGS and POP_REGS properly
  (bnc#1012628).
- x86/entry/64: Fix paranoid_entry() frame pointer warning
  (bnc#1012628).
- x86/entry/64: Remove the unused 'icebp' macro (bnc#1012628).
- selftests/x86: Fix vDSO selftest segfault for vsyscall=none
  (bnc#1012628).
- selftests/x86: Clean up and document sscanf() usage
  (bnc#1012628).
- selftests/x86/pkeys: Remove unused functions (bnc#1012628).
- selftests/x86: Fix build bug caused by the 5lvl test which
  has been moved to the VM directory (bnc#1012628).
- selftests/x86: Do not rely on "int $0x80" in test_mremap_vdso.c
  (bnc#1012628).
- gfs2: Fixes to "Implement iomap for block_map" (bnc#1012628).
- selftests/x86: Do not rely on "int $0x80" in
  single_step_syscall.c (bnc#1012628).
- selftests/x86: Disable tests requiring 32-bit support on pure
  64-bit systems (bnc#1012628).
- objtool: Fix segfault in ignore_unreachable_insn()
  (bnc#1012628).
- x86/debug, objtool: Annotate WARN()-related UD2 as reachable
  (bnc#1012628).
- x86/debug: Use UD2 for WARN() (bnc#1012628).
- x86/speculation: Fix up array_index_nospec_mask() asm constraint
  (bnc#1012628).
- nospec: Move array_index_nospec() parameter checking into
  separate macro (bnc#1012628).
- x86/speculation: Add <asm/msr-index.h> dependency (bnc#1012628).
- x86/mm: Rename flush_tlb_single() and flush_tlb_one() to
  __flush_tlb_one_[user|kernel]() (bnc#1012628).
- selftests/x86/mpx: Fix incorrect bounds with old _sigfault
  (bnc#1012628).
- x86/cpu: Rename cpu_data.x86_mask to cpu_data.x86_stepping
  (bnc#1012628).
- x86/spectre: Fix an error message (bnc#1012628).
- x86/cpu: Change type of x86_cache_size variable to unsigned int
  (bnc#1012628).
- x86/entry/64: Fix CR3 restore in paranoid_exit() (bnc#1012628).
- drm/ttm: Don't add swapped BOs to swap-LRU list (bnc#1012628).
- drm/ttm: Fix 'buf' pointer update in ttm_bo_vm_access_kmap()
  (v2) (bnc#1012628).
- drm/qxl: unref cursor bo when finished with it (bnc#1012628).
- drm/qxl: reapply cursor after resetting primary (bnc#1012628).
- drm/amd/powerplay: Fix smu_table_entry.handle type
  (bnc#1012628).
- drm/ast: Load lut in crtc_commit (bnc#1012628).
- drm: Check for lessee in DROP_MASTER ioctl (bnc#1012628).
- arm64: Add missing Falkor part number for branch predictor
  hardening (bnc#1012628).
- drm/radeon: Add dpm quirk for Jet PRO (v2) (bnc#1012628).
- drm/radeon: adjust tested variable (bnc#1012628).
- x86/smpboot: Fix uncore_pci_remove() indexing bug when
  hot-removing a physical CPU (bnc#1012628).
- rtc-opal: Fix handling of firmware error codes, prevent busy
  loops (bnc#1012628).
- mbcache: initialize entry->e_referenced in
  mb_cache_entry_create() (bnc#1012628).
- mmc: sdhci: Implement an SDHCI-specific bounce buffer
  (bnc#1012628).
- mmc: bcm2835: Don't overwrite max frequency unconditionally
  (bnc#1012628).
- Revert "mmc: meson-gx: include tx phase in the tuning process"
  (bnc#1012628).
- mlx5: fix mlx5_get_vector_affinity to start from completion
  vector 0 (bnc#1012628).
- Revert "apple-gmux: lock iGP IO to protect from vgaarb changes"
  (bnc#1012628).
- jbd2: fix sphinx kernel-doc build warnings (bnc#1012628).
- ext4: fix a race in the ext4 shutdown path (bnc#1012628).
- ext4: save error to disk in __ext4_grp_locked_error()
  (bnc#1012628).
- ext4: correct documentation for grpid mount option
  (bnc#1012628).
- mm: hide a #warning for COMPILE_TEST (bnc#1012628).
- mm: Fix memory size alignment in devm_memremap_pages_release()
  (bnc#1012628).
- MIPS: Fix typo BIG_ENDIAN to CPU_BIG_ENDIAN (bnc#1012628).
- MIPS: CPS: Fix MIPS_ISA_LEVEL_RAW fallout (bnc#1012628).
- MIPS: Fix incorrect mem=X@Y handling (bnc#1012628).
- PCI: Disable MSI for HiSilicon Hip06/Hip07 only in Root Port
  mode (bnc#1012628).
- PCI: iproc: Fix NULL pointer dereference for BCMA (bnc#1012628).
- PCI: pciehp: Assume NoCompl+ for Thunderbolt ports
  (bnc#1012628).
- PCI: keystone: Fix interrupt-controller-node lookup
  (bnc#1012628).
- video: fbdev: atmel_lcdfb: fix display-timings lookup
  (bnc#1012628).
- console/dummy: leave .con_font_get set to NULL (bnc#1012628).
- rbd: whitelist RBD_FEATURE_OPERATIONS feature bit (bnc#1012628).
- xen: Fix {set,clear}_foreign_p2m_mapping on autotranslating
  guests (bnc#1012628).
- xenbus: track caller request id (bnc#1012628).
- seq_file: fix incomplete reset on read from zero offset
  (bnc#1012628).
- tracing: Fix parsing of globs with a wildcard at the beginning
  (bnc#1012628).
- mpls, nospec: Sanitize array index in mpls_label_ok()
  (bnc#1012628).
- rtlwifi: rtl8821ae: Fix connection lost problem correctly
  (bnc#1012628).
- arm64: proc: Set PTE_NG for table entries to avoid traversing
  them twice (bnc#1012628).
- xprtrdma: Fix calculation of ri_max_send_sges (bnc#1012628).
- xprtrdma: Fix BUG after a device removal (bnc#1012628).
- blk-wbt: account flush requests correctly (bnc#1012628).
- target/iscsi: avoid NULL dereference in CHAP auth error path
  (bnc#1012628).
- iscsi-target: make sure to wake up sleeping login worker
  (bnc#1012628).
- dm: correctly handle chained bios in dec_pending()
  (bnc#1012628).
- Btrfs: fix deadlock in run_delalloc_nocow (bnc#1012628).
- Btrfs: fix crash due to not cleaning up tree log block's dirty
  bits (bnc#1012628).
- Btrfs: fix extent state leak from tree log (bnc#1012628).
- Btrfs: fix use-after-free on root->orphan_block_rsv
  (bnc#1012628).
- Btrfs: fix unexpected -EEXIST when creating new inode
  (bnc#1012628).
- 9p/trans_virtio: discard zero-length reply (bnc#1012628).
- mtd: nand: vf610: set correct ooblayout (bnc#1012628).
- ALSA: hda - Fix headset mic detection problem for two Dell
  machines (bnc#1012628).
- ALSA: usb-audio: Fix UAC2 get_ctl request with a RANGE attribute
  (bnc#1012628).
- ALSA: hda/realtek - Add headset mode support for Dell laptop
  (bnc#1012628).
- ALSA: hda/realtek - Enable Thinkpad Dock device for ALC298
  platform (bnc#1012628).
- ALSA: hda/realtek: PCI quirk for Fujitsu U7x7 (bnc#1012628).
- ALSA: usb-audio: add implicit fb quirk for Behringer UFX1204
  (bnc#1012628).
- ALSA: usb: add more device quirks for USB DSD devices
  (bnc#1012628).
- ALSA: seq: Fix racy pool initializations (bnc#1012628).
- mvpp2: fix multicast address filter (bnc#1012628).
- usb: Move USB_UHCI_BIG_ENDIAN_* out of USB_SUPPORT
  (bnc#1012628).
- x86/mm, mm/hwpoison: Don't unconditionally unmap kernel 1:1
  pages (bnc#1012628).
- ARM: dts: exynos: fix RTC interrupt for exynos5410
  (bnc#1012628).
- ARM: pxa/tosa-bt: add MODULE_LICENSE tag (bnc#1012628).
- arm64: dts: msm8916: Add missing #phy-cells (bnc#1012628).
- ARM: dts: s5pv210: add interrupt-parent for ohci (bnc#1012628).
- arm: dts: mt7623: Update ethsys binding (bnc#1012628).
- arm: dts: mt2701: Add reset-cells (bnc#1012628).
- ARM: dts: Delete bogus reference to the charlcd (bnc#1012628).
- media: r820t: fix r820t_write_reg for KASAN (bnc#1012628).
- mmc: sdhci-of-esdhc: fix eMMC couldn't work after kexec
  (bnc#1012628).
- mmc: sdhci-of-esdhc: fix the mmc error after sleep on ls1046ardb
  (bnc#1012628).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Refresh
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- Refresh
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- commit 078aac5
* Thu Feb 22 2018 lpechacek@suse.com
- rpm/kernel-spec-macros: Try harder to detect Build Service environment (bsc#1078788)
- commit a5f1a4a
* Wed Feb 21 2018 msuchanek@suse.de
- kernel-binary undefine unique_debug_names
  Some tools do not understand names like
  usr/lib/debug/boot/vmlinux-4.12.14-11.10-default-4.12.14-11.10.ppc64le.debug
- commit 2b90c1e
* Tue Feb 20 2018 jeffm@suse.com
- config: enable IMA and EVM
- commit 8c97198
* Sun Feb 18 2018 afaerber@suse.de
- config: arm64: Enable MAX77620 for Nvidia Jetson TX1 (boo#1081473)
- commit 5cbffaf
* Sat Feb 17 2018 jslaby@suse.cz
- Linux 4.15.4 (bnc#1012628).
- watchdog: indydog: Add dependency on SGI_HAS_INDYDOG
  (bnc#1012628).
- cifs: Fix missing put_xid in cifs_file_strict_mmap
  (bnc#1012628).
- cifs: Fix autonegotiate security settings mismatch
  (bnc#1012628).
- CIFS: zero sensitive data when freeing (bnc#1012628).
- cpufreq: mediatek: add mediatek related projects into blacklist
  (bnc#1012628).
- dmaengine: dmatest: fix container_of member in dmatest_callback
  (bnc#1012628).
- ssb: Do not disable PCI host on non-Mips (bnc#1012628).
- watchdog: gpio_wdt: set WDOG_HW_RUNNING in gpio_wdt_stop
  (bnc#1012628).
- Revert "drm/i915: mark all device info struct with __initconst"
  (bnc#1012628).
- sched/rt: Use container_of() to get root domain in
  rto_push_irq_work_func() (bnc#1012628).
- sched/rt: Up the root domain ref count when passing it around
  via IPIs (bnc#1012628).
- media: dvb-usb-v2: lmedm04: Improve logic checking of warm start
  (bnc#1012628).
- media: dvb-usb-v2: lmedm04: move ts2020 attach to
  dm04_lme2510_tuner (bnc#1012628).
- media: hdpvr: Fix an error handling path in hdpvr_probe()
  (bnc#1012628).
- arm64: cpu_errata: Add Kryo to Falkor 1003 errata (bnc#1012628).
- arm64: kpti: Make use of nG dependent on
  arm64_kernel_unmapped_at_el0() (bnc#1012628).
- arm64: mm: Permit transitioning from Global to Non-Global
  without BBM (bnc#1012628).
- arm64: kpti: Add ->enable callback to remap swapper using nG
  mappings (bnc#1012628).
- arm64: Force KPTI to be disabled on Cavium ThunderX
  (bnc#1012628).
- arm64: entry: Reword comment about post_ttbr_update_workaround
  (bnc#1012628).
- arm64: idmap: Use "awx" flags for .idmap.text .pushsection
  directives (bnc#1012628).
- arm64: barrier: Add CSDB macros to control data-value prediction
  (bnc#1012628).
- arm64: Implement array_index_mask_nospec() (bnc#1012628).
- arm64: Make USER_DS an inclusive limit (bnc#1012628).
- arm64: Use pointer masking to limit uaccess speculation
  (bnc#1012628).
- arm64: entry: Ensure branch through syscall table is bounded
  under speculation (bnc#1012628).
- arm64: uaccess: Prevent speculative use of the current
  addr_limit (bnc#1012628).
- arm64: uaccess: Don't bother eliding access_ok checks in __{get,
  put}_user (bnc#1012628).
- arm64: uaccess: Mask __user pointers for __arch_{clear,
  copy_*}_user (bnc#1012628).
- arm64: futex: Mask __user pointers prior to dereference
  (bnc#1012628).
- arm64: cpufeature: __this_cpu_has_cap() shouldn't stop early
  (bnc#1012628).
- arm64: entry: Apply BP hardening for high-priority synchronous
  exceptions (bnc#1012628).
- arm64: entry: Apply BP hardening for suspicious interrupts
  from EL0 (bnc#1012628).
- arm64: KVM: Increment PC after handling an SMC trap
  (bnc#1012628).
- arm/arm64: KVM: Consolidate the PSCI include files
  (bnc#1012628).
- arm/arm64: KVM: Add PSCI_VERSION helper (bnc#1012628).
- arm/arm64: KVM: Add smccc accessors to PSCI code (bnc#1012628).
- arm/arm64: KVM: Implement PSCI 1.0 support (bnc#1012628).
- arm/arm64: KVM: Advertise SMCCC v1.1 (bnc#1012628).
- arm/arm64: KVM: Turn kvm_psci_version into a static inline
  (bnc#1012628).
- arm64: KVM: Report SMCCC_ARCH_WORKAROUND_1 BP hardening support
  (bnc#1012628).
- arm64: KVM: Add SMCCC_ARCH_WORKAROUND_1 fast handling
  (bnc#1012628).
- firmware/psci: Expose PSCI conduit (bnc#1012628).
- firmware/psci: Expose SMCCC version through psci_ops
  (bnc#1012628).
- arm/arm64: smccc: Make function identifiers an unsigned quantity
  (bnc#1012628).
- arm/arm64: smccc: Implement SMCCC v1.1 inline primitive
  (bnc#1012628).
- arm64: Add ARM_SMCCC_ARCH_WORKAROUND_1 BP hardening support
  (bnc#1012628).
- arm64: Kill PSCI_GET_VERSION as a variant-2 workaround
  (bnc#1012628).
- mtd: cfi: convert inline functions to macros (bnc#1012628).
- mtd: nand: brcmnand: Disable prefetch by default (bnc#1012628).
- mtd: nand: Fix nand_do_read_oob() return value (bnc#1012628).
- mtd: nand: sunxi: Fix ECC strength choice (bnc#1012628).
- ubi: Fix race condition between ubi volume creation and udev
  (bnc#1012628).
- ubi: fastmap: Erase outdated anchor PEBs during attach
  (bnc#1012628).
- ubi: block: Fix locking for idr_alloc/idr_remove (bnc#1012628).
- ubifs: free the encrypted symlink target (bnc#1012628).
- nfs/pnfs: fix nfs_direct_req ref leak when i/o falls back to
  the mds (bnc#1012628).
- nfs41: do not return ENOMEM on LAYOUTUNAVAILABLE (bnc#1012628).
- NFS: Add a cond_resched() to nfs_commit_release_pages()
  (bnc#1012628).
- NFS: Fix nfsstat breakage due to LOOKUPP (bnc#1012628).
- NFS: commit direct writes even if they fail partially
  (bnc#1012628).
- NFS: reject request for id_legacy key without auxdata
  (bnc#1012628).
- NFS: Fix a race between mmap() and O_DIRECT (bnc#1012628).
- nfsd: Detect unhashed stids in nfsd4_verify_open_stid()
  (bnc#1012628).
- kernfs: fix regression in kernfs_fop_write caused by wrong type
  (bnc#1012628).
- ahci: Annotate PCI ids for mobile Intel chipsets as such
  (bnc#1012628).
- ahci: Add PCI ids for Intel Bay Trail, Cherry Trail and Apollo
  Lake AHCI (bnc#1012628).
- ahci: Add Intel Cannon Lake PCH-H PCI ID (bnc#1012628).
- crypto: hash - introduce crypto_hash_alg_has_setkey()
  (bnc#1012628).
- crypto: cryptd - pass through absence of ->setkey()
  (bnc#1012628).
- crypto: mcryptd - pass through absence of ->setkey()
  (bnc#1012628).
- crypto: poly1305 - remove ->setkey() method (bnc#1012628).
- crypto: hash - annotate algorithms taking optional key
  (bnc#1012628).
- crypto: hash - prevent using keyed hashes without setting key
  (bnc#1012628).
- media: v4l2-ioctl.c: use check_fmt for enum/g/s/try_fmt
  (bnc#1012628).
- media: v4l2-ioctl.c: don't copy back the result for -ENOTTY
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: add missing VIDIOC_PREPARE_BUF
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: fix the indentation (bnc#1012628).
- media: v4l2-compat-ioctl32.c: move 'helper' functions to
  __get/put_v4l2_format32 (bnc#1012628).
- media: v4l2-compat-ioctl32.c: avoid sizeof(type) (bnc#1012628).
- media: v4l2-compat-ioctl32.c: copy m.userptr in put_v4l2_plane32
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: fix ctrl_is_pointer (bnc#1012628).
- media: v4l2-compat-ioctl32.c: copy clip list in
  put_v4l2_window32 (bnc#1012628).
- media: v4l2-compat-ioctl32.c: drop pr_info for unknown buffer
  type (bnc#1012628).
- media: v4l2-compat-ioctl32.c: don't copy back the result for
  certain errors (bnc#1012628).
- media: v4l2-compat-ioctl32.c: refactor compat ioctl32 logic
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: make ctrl_is_pointer work for
  subdevs (bnc#1012628).
- crypto: caam - fix endless loop when DECO acquire fails
  (bnc#1012628).
- crypto: sha512-mb - initialize pending lengths correctly
  (bnc#1012628).
- crypto: talitos - fix Kernel Oops on hashing an empty file
  (bnc#1012628).
- arm: KVM: Fix SMCCC handling of unimplemented SMC/HVC calls
  (bnc#1012628).
- KVM: nVMX: Fix races when sending nested PI while dest
  enters/leaves L2 (bnc#1012628).
- KVM: nVMX: Fix bug of injecting L2 exception into L1
  (bnc#1012628).
- KVM: PPC: Book3S HV: Make sure we don't re-enter guest without
  XIVE loaded (bnc#1012628).
- KVM: PPC: Book3S HV: Drop locks before reading guest memory
  (bnc#1012628).
- KVM: arm/arm64: Handle CPU_PM_ENTER_FAILED (bnc#1012628).
- KVM: PPC: Book3S PR: Fix broken select due to misspelling
  (bnc#1012628).
- ASoC: acpi: fix machine driver selection based on quirk
  (bnc#1012628).
- ASoC: rockchip: i2s: fix playback after runtime resume
  (bnc#1012628).
- ASoC: skl: Fix kernel warning due to zero NHTL entry
  (bnc#1012628).
- ASoC: compress: Correct handling of copy callback (bnc#1012628).
- watchdog: imx2_wdt: restore previous timeout after
  suspend+resume (bnc#1012628).
- afs: Add missing afs_put_cell() (bnc#1012628).
- afs: Need to clear responded flag in addr cursor (bnc#1012628).
- afs: Fix missing cursor clearance (bnc#1012628).
- afs: Fix server list handling (bnc#1012628).
- btrfs: Handle btrfs_set_extent_delalloc failure in fixup worker
  (bnc#1012628).
- Btrfs: raid56: iterate raid56 internal bio with
  bio_for_each_segment_all (bnc#1012628).
- kasan: don't emit builtin calls when sanitization is off
  (bnc#1012628).
- kasan: rework Kconfig settings (bnc#1012628).
- media: dvb_frontend: be sure to init dvb_frontend_handle_ioctl()
  return code (bnc#1012628).
- media: dvb-frontends: fix i2c access helpers for KASAN
  (bnc#1012628).
- media: dt-bindings/media/cec-gpio.txt: mention the CEC/HPD
  max voltages (bnc#1012628).
- media: ts2020: avoid integer overflows on 32 bit machines
  (bnc#1012628).
- media: vivid: fix module load error when enabling fb and
  no_error_inj=1 (bnc#1012628).
- media: cxusb, dib0700: ignore XC2028_I2C_FLUSH (bnc#1012628).
- fs/proc/kcore.c: use probe_kernel_read() instead of memcpy()
  (bnc#1012628).
- kernel/async.c: revert "async: simplify lowest_in_progress()"
  (bnc#1012628).
- kernel/relay.c: revert "kernel/relay.c: fix potential memory
  leak" (bnc#1012628).
- pipe: actually allow root to exceed the pipe buffer limits
  (bnc#1012628).
- pipe: fix off-by-one error when checking buffer limits
  (bnc#1012628).
- HID: quirks: Fix keyboard + touchpad on Toshiba Click Mini
  not working (bnc#1012628).
- Bluetooth: btsdio: Do not bind to non-removable BCM43341
  (bnc#1012628).
- Revert "Bluetooth: btusb: fix QCA Rome suspend/resume"
  (bnc#1012628).
- Bluetooth: btusb: Restore QCA Rome suspend/resume fix with a
  "rewritten" version (bnc#1012628).
- ipmi: use dynamic memory for DMI driver override (bnc#1012628).
- signal/openrisc: Fix do_unaligned_access to send the proper
  signal (bnc#1012628).
- signal/sh: Ensure si_signo is initialized in do_divide_error
  (bnc#1012628).
- alpha: fix crash if pthread_create races with signal delivery
  (bnc#1012628).
- alpha: osf_sys.c: fix put_tv32 regression (bnc#1012628).
- alpha: Fix mixed up args in EXC macro in futex operations
  (bnc#1012628).
- alpha: fix reboot on Avanti platform (bnc#1012628).
- alpha: fix formating of stack content (bnc#1012628).
- xtensa: fix futex_atomic_cmpxchg_inatomic (bnc#1012628).
- EDAC, octeon: Fix an uninitialized variable warning
  (bnc#1012628).
- genirq: Make legacy autoprobing work again (bnc#1012628).
- pinctrl: intel: Initialize GPIO properly when used through
  irqchip (bnc#1012628).
- pinctrl: mcp23s08: fix irq setup order (bnc#1012628).
- pinctrl: sx150x: Unregister the pinctrl on release
  (bnc#1012628).
- pinctrl: sx150x: Register pinctrl before adding the gpiochip
  (bnc#1012628).
- pinctrl: sx150x: Add a static gpio/pinctrl pin range mapping
  (bnc#1012628).
- pktcdvd: Fix pkt_setup_dev() error path (bnc#1012628).
- pktcdvd: Fix a recently introduced NULL pointer dereference
  (bnc#1012628).
- blk-mq: quiesce queue before freeing queue (bnc#1012628).
- clocksource/drivers/stm32: Fix kernel panic with multiple timers
  (bnc#1012628).
- lib/ubsan.c: s/missaligned/misaligned/ (bnc#1012628).
- lib/ubsan: add type mismatch handler for new GCC/Clang
  (bnc#1012628).
- objtool: Fix switch-table detection (bnc#1012628).
- arm64: dts: marvell: add Ethernet aliases (bnc#1012628).
- drm/i915: Avoid PPS HW/SW state mismatch due to rounding
  (bnc#1012628).
- ACPI: sbshc: remove raw pointer from printk() message
  (bnc#1012628).
- acpi, nfit: fix register dimm error handling (bnc#1012628).
- ovl: force r/o mount when index dir creation fails
  (bnc#1012628).
- ovl: fix failure to fsync lower dir (bnc#1012628).
- ovl: take mnt_want_write() for work/index dir setup
  (bnc#1012628).
- ovl: take mnt_want_write() for removing impure xattr
  (bnc#1012628).
- ovl: hash directory inodes for fsnotify (bnc#1012628).
- mn10300/misalignment: Use SIGSEGV SEGV_MAPERR to report a
  failed user copy (bnc#1012628).
- devpts: fix error handling in devpts_mntget() (bnc#1012628).
- ftrace: Remove incorrect setting of glob search field
  (bnc#1012628).
- scsi: core: Ensure that the SCSI error handler gets woken up
  (bnc#1012628).
- scsi: lpfc: Fix crash after bad bar setup on driver attachment
  (bnc#1012628).
- scsi: cxlflash: Reset command ioasc (bnc#1012628).
- rcu: Export init_rcu_head() and destroy_rcu_head() to GPL
  modules (bnc#1012628).
- media: dvb_frontend: fix return error code (git-fixes).
- mtd: ubi: wl: Fix error return code in ubi_wl_init()
  (git-fixes).
- Update config files.
- Linux 4.15.4 (bnc#1012628).
- watchdog: indydog: Add dependency on SGI_HAS_INDYDOG
  (bnc#1012628).
- cifs: Fix missing put_xid in cifs_file_strict_mmap
  (bnc#1012628).
- cifs: Fix autonegotiate security settings mismatch
  (bnc#1012628).
- CIFS: zero sensitive data when freeing (bnc#1012628).
- cpufreq: mediatek: add mediatek related projects into blacklist
  (bnc#1012628).
- dmaengine: dmatest: fix container_of member in dmatest_callback
  (bnc#1012628).
- ssb: Do not disable PCI host on non-Mips (bnc#1012628).
- watchdog: gpio_wdt: set WDOG_HW_RUNNING in gpio_wdt_stop
  (bnc#1012628).
- Revert "drm/i915: mark all device info struct with __initconst"
  (bnc#1012628).
- sched/rt: Use container_of() to get root domain in
  rto_push_irq_work_func() (bnc#1012628).
- sched/rt: Up the root domain ref count when passing it around
  via IPIs (bnc#1012628).
- media: dvb-usb-v2: lmedm04: Improve logic checking of warm start
  (bnc#1012628).
- media: dvb-usb-v2: lmedm04: move ts2020 attach to
  dm04_lme2510_tuner (bnc#1012628).
- media: hdpvr: Fix an error handling path in hdpvr_probe()
  (bnc#1012628).
- arm64: cpu_errata: Add Kryo to Falkor 1003 errata (bnc#1012628).
- arm64: kpti: Make use of nG dependent on
  arm64_kernel_unmapped_at_el0() (bnc#1012628).
- arm64: mm: Permit transitioning from Global to Non-Global
  without BBM (bnc#1012628).
- arm64: kpti: Add ->enable callback to remap swapper using nG
  mappings (bnc#1012628).
- arm64: Force KPTI to be disabled on Cavium ThunderX
  (bnc#1012628).
- arm64: entry: Reword comment about post_ttbr_update_workaround
  (bnc#1012628).
- arm64: idmap: Use "awx" flags for .idmap.text .pushsection
  directives (bnc#1012628).
- arm64: barrier: Add CSDB macros to control data-value prediction
  (bnc#1012628).
- arm64: Implement array_index_mask_nospec() (bnc#1012628).
- arm64: Make USER_DS an inclusive limit (bnc#1012628).
- arm64: Use pointer masking to limit uaccess speculation
  (bnc#1012628).
- arm64: entry: Ensure branch through syscall table is bounded
  under speculation (bnc#1012628).
- arm64: uaccess: Prevent speculative use of the current
  addr_limit (bnc#1012628).
- arm64: uaccess: Don't bother eliding access_ok checks in __{get,
  put}_user (bnc#1012628).
- arm64: uaccess: Mask __user pointers for __arch_{clear,
  copy_*}_user (bnc#1012628).
- arm64: futex: Mask __user pointers prior to dereference
  (bnc#1012628).
- arm64: cpufeature: __this_cpu_has_cap() shouldn't stop early
  (bnc#1012628).
- arm64: entry: Apply BP hardening for high-priority synchronous
  exceptions (bnc#1012628).
- arm64: entry: Apply BP hardening for suspicious interrupts
  from EL0 (bnc#1012628).
- arm64: KVM: Increment PC after handling an SMC trap
  (bnc#1012628).
- arm/arm64: KVM: Consolidate the PSCI include files
  (bnc#1012628).
- arm/arm64: KVM: Add PSCI_VERSION helper (bnc#1012628).
- arm/arm64: KVM: Add smccc accessors to PSCI code (bnc#1012628).
- arm/arm64: KVM: Implement PSCI 1.0 support (bnc#1012628).
- arm/arm64: KVM: Advertise SMCCC v1.1 (bnc#1012628).
- arm/arm64: KVM: Turn kvm_psci_version into a static inline
  (bnc#1012628).
- arm64: KVM: Report SMCCC_ARCH_WORKAROUND_1 BP hardening support
  (bnc#1012628).
- arm64: KVM: Add SMCCC_ARCH_WORKAROUND_1 fast handling
  (bnc#1012628).
- firmware/psci: Expose PSCI conduit (bnc#1012628).
- firmware/psci: Expose SMCCC version through psci_ops
  (bnc#1012628).
- arm/arm64: smccc: Make function identifiers an unsigned quantity
  (bnc#1012628).
- arm/arm64: smccc: Implement SMCCC v1.1 inline primitive
  (bnc#1012628).
- arm64: Add ARM_SMCCC_ARCH_WORKAROUND_1 BP hardening support
  (bnc#1012628).
- arm64: Kill PSCI_GET_VERSION as a variant-2 workaround
  (bnc#1012628).
- mtd: cfi: convert inline functions to macros (bnc#1012628).
- mtd: nand: brcmnand: Disable prefetch by default (bnc#1012628).
- mtd: nand: Fix nand_do_read_oob() return value (bnc#1012628).
- mtd: nand: sunxi: Fix ECC strength choice (bnc#1012628).
- ubi: Fix race condition between ubi volume creation and udev
  (bnc#1012628).
- ubi: fastmap: Erase outdated anchor PEBs during attach
  (bnc#1012628).
- ubi: block: Fix locking for idr_alloc/idr_remove (bnc#1012628).
- ubifs: free the encrypted symlink target (bnc#1012628).
- nfs/pnfs: fix nfs_direct_req ref leak when i/o falls back to
  the mds (bnc#1012628).
- nfs41: do not return ENOMEM on LAYOUTUNAVAILABLE (bnc#1012628).
- NFS: Add a cond_resched() to nfs_commit_release_pages()
  (bnc#1012628).
- NFS: Fix nfsstat breakage due to LOOKUPP (bnc#1012628).
- NFS: commit direct writes even if they fail partially
  (bnc#1012628).
- NFS: reject request for id_legacy key without auxdata
  (bnc#1012628).
- NFS: Fix a race between mmap() and O_DIRECT (bnc#1012628).
- nfsd: Detect unhashed stids in nfsd4_verify_open_stid()
  (bnc#1012628).
- kernfs: fix regression in kernfs_fop_write caused by wrong type
  (bnc#1012628).
- ahci: Annotate PCI ids for mobile Intel chipsets as such
  (bnc#1012628).
- ahci: Add PCI ids for Intel Bay Trail, Cherry Trail and Apollo
  Lake AHCI (bnc#1012628).
- ahci: Add Intel Cannon Lake PCH-H PCI ID (bnc#1012628).
- crypto: hash - introduce crypto_hash_alg_has_setkey()
  (bnc#1012628).
- crypto: cryptd - pass through absence of ->setkey()
  (bnc#1012628).
- crypto: mcryptd - pass through absence of ->setkey()
  (bnc#1012628).
- crypto: poly1305 - remove ->setkey() method (bnc#1012628).
- crypto: hash - annotate algorithms taking optional key
  (bnc#1012628).
- crypto: hash - prevent using keyed hashes without setting key
  (bnc#1012628).
- media: v4l2-ioctl.c: use check_fmt for enum/g/s/try_fmt
  (bnc#1012628).
- media: v4l2-ioctl.c: don't copy back the result for -ENOTTY
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: add missing VIDIOC_PREPARE_BUF
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: fix the indentation (bnc#1012628).
- media: v4l2-compat-ioctl32.c: move 'helper' functions to
  __get/put_v4l2_format32 (bnc#1012628).
- media: v4l2-compat-ioctl32.c: avoid sizeof(type) (bnc#1012628).
- media: v4l2-compat-ioctl32.c: copy m.userptr in put_v4l2_plane32
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: fix ctrl_is_pointer (bnc#1012628).
- media: v4l2-compat-ioctl32.c: copy clip list in
  put_v4l2_window32 (bnc#1012628).
- media: v4l2-compat-ioctl32.c: drop pr_info for unknown buffer
  type (bnc#1012628).
- media: v4l2-compat-ioctl32.c: don't copy back the result for
  certain errors (bnc#1012628).
- media: v4l2-compat-ioctl32.c: refactor compat ioctl32 logic
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: make ctrl_is_pointer work for
  subdevs (bnc#1012628).
- crypto: caam - fix endless loop when DECO acquire fails
  (bnc#1012628).
- crypto: sha512-mb - initialize pending lengths correctly
  (bnc#1012628).
- crypto: talitos - fix Kernel Oops on hashing an empty file
  (bnc#1012628).
- arm: KVM: Fix SMCCC handling of unimplemented SMC/HVC calls
  (bnc#1012628).
- KVM: nVMX: Fix races when sending nested PI while dest
  enters/leaves L2 (bnc#1012628).
- KVM: nVMX: Fix bug of injecting L2 exception into L1
  (bnc#1012628).
- KVM: PPC: Book3S HV: Make sure we don't re-enter guest without
  XIVE loaded (bnc#1012628).
- KVM: PPC: Book3S HV: Drop locks before reading guest memory
  (bnc#1012628).
- KVM: arm/arm64: Handle CPU_PM_ENTER_FAILED (bnc#1012628).
- KVM: PPC: Book3S PR: Fix broken select due to misspelling
  (bnc#1012628).
- ASoC: acpi: fix machine driver selection based on quirk
  (bnc#1012628).
- ASoC: rockchip: i2s: fix playback after runtime resume
  (bnc#1012628).
- ASoC: skl: Fix kernel warning due to zero NHTL entry
  (bnc#1012628).
- ASoC: compress: Correct handling of copy callback (bnc#1012628).
- watchdog: imx2_wdt: restore previous timeout after
  suspend+resume (bnc#1012628).
- afs: Add missing afs_put_cell() (bnc#1012628).
- afs: Need to clear responded flag in addr cursor (bnc#1012628).
- afs: Fix missing cursor clearance (bnc#1012628).
- afs: Fix server list handling (bnc#1012628).
- btrfs: Handle btrfs_set_extent_delalloc failure in fixup worker
  (bnc#1012628).
- Btrfs: raid56: iterate raid56 internal bio with
  bio_for_each_segment_all (bnc#1012628).
- kasan: don't emit builtin calls when sanitization is off
  (bnc#1012628).
- kasan: rework Kconfig settings (bnc#1012628).
- media: dvb_frontend: be sure to init dvb_frontend_handle_ioctl()
  return code (bnc#1012628).
- media: dvb-frontends: fix i2c access helpers for KASAN
  (bnc#1012628).
- media: dt-bindings/media/cec-gpio.txt: mention the CEC/HPD
  max voltages (bnc#1012628).
- media: ts2020: avoid integer overflows on 32 bit machines
  (bnc#1012628).
- media: vivid: fix module load error when enabling fb and
  no_error_inj=1 (bnc#1012628).
- media: cxusb, dib0700: ignore XC2028_I2C_FLUSH (bnc#1012628).
- fs/proc/kcore.c: use probe_kernel_read() instead of memcpy()
  (bnc#1012628).
- kernel/async.c: revert "async: simplify lowest_in_progress()"
  (bnc#1012628).
- kernel/relay.c: revert "kernel/relay.c: fix potential memory
  leak" (bnc#1012628).
- pipe: actually allow root to exceed the pipe buffer limits
  (bnc#1012628).
- pipe: fix off-by-one error when checking buffer limits
  (bnc#1012628).
- HID: quirks: Fix keyboard + touchpad on Toshiba Click Mini
  not working (bnc#1012628).
- Bluetooth: btsdio: Do not bind to non-removable BCM43341
  (bnc#1012628).
- Revert "Bluetooth: btusb: fix QCA Rome suspend/resume"
  (bnc#1012628).
- Bluetooth: btusb: Restore QCA Rome suspend/resume fix with a
  "rewritten" version (bnc#1012628).
- ipmi: use dynamic memory for DMI driver override (bnc#1012628).
- signal/openrisc: Fix do_unaligned_access to send the proper
  signal (bnc#1012628).
- signal/sh: Ensure si_signo is initialized in do_divide_error
  (bnc#1012628).
- alpha: fix crash if pthread_create races with signal delivery
  (bnc#1012628).
- alpha: osf_sys.c: fix put_tv32 regression (bnc#1012628).
- alpha: Fix mixed up args in EXC macro in futex operations
  (bnc#1012628).
- alpha: fix reboot on Avanti platform (bnc#1012628).
- alpha: fix formating of stack content (bnc#1012628).
- xtensa: fix futex_atomic_cmpxchg_inatomic (bnc#1012628).
- EDAC, octeon: Fix an uninitialized variable warning
  (bnc#1012628).
- genirq: Make legacy autoprobing work again (bnc#1012628).
- pinctrl: intel: Initialize GPIO properly when used through
  irqchip (bnc#1012628).
- pinctrl: mcp23s08: fix irq setup order (bnc#1012628).
- pinctrl: sx150x: Unregister the pinctrl on release
  (bnc#1012628).
- pinctrl: sx150x: Register pinctrl before adding the gpiochip
  (bnc#1012628).
- pinctrl: sx150x: Add a static gpio/pinctrl pin range mapping
  (bnc#1012628).
- pktcdvd: Fix pkt_setup_dev() error path (bnc#1012628).
- pktcdvd: Fix a recently introduced NULL pointer dereference
  (bnc#1012628).
- blk-mq: quiesce queue before freeing queue (bnc#1012628).
- clocksource/drivers/stm32: Fix kernel panic with multiple timers
  (bnc#1012628).
- lib/ubsan.c: s/missaligned/misaligned/ (bnc#1012628).
- lib/ubsan: add type mismatch handler for new GCC/Clang
  (bnc#1012628).
- objtool: Fix switch-table detection (bnc#1012628).
- arm64: dts: marvell: add Ethernet aliases (bnc#1012628).
- drm/i915: Avoid PPS HW/SW state mismatch due to rounding
  (bnc#1012628).
- ACPI: sbshc: remove raw pointer from printk() message
  (bnc#1012628).
- acpi, nfit: fix register dimm error handling (bnc#1012628).
- ovl: force r/o mount when index dir creation fails
  (bnc#1012628).
- ovl: fix failure to fsync lower dir (bnc#1012628).
- ovl: take mnt_want_write() for work/index dir setup
  (bnc#1012628).
- ovl: take mnt_want_write() for removing impure xattr
  (bnc#1012628).
- ovl: hash directory inodes for fsnotify (bnc#1012628).
- mn10300/misalignment: Use SIGSEGV SEGV_MAPERR to report a
  failed user copy (bnc#1012628).
- devpts: fix error handling in devpts_mntget() (bnc#1012628).
- ftrace: Remove incorrect setting of glob search field
  (bnc#1012628).
- scsi: core: Ensure that the SCSI error handler gets woken up
  (bnc#1012628).
- scsi: lpfc: Fix crash after bad bar setup on driver attachment
  (bnc#1012628).
- scsi: cxlflash: Reset command ioasc (bnc#1012628).
- rcu: Export init_rcu_head() and destroy_rcu_head() to GPL
  modules (bnc#1012628).
- Update config files.
- commit 4d42c34
* Thu Feb 15 2018 jmoreira@suse.de
- Add kernel livepatch-devel package
  Resolving non-exported static symbols in kernel livepatches cannot
  be done implicitly. For such, the relocations of these symbols must
  follow a specially crafted format in the respective elf file. Willing
  to make the task of converting the elf into the right format, a tool
  named klp-convert was proposed. Through a file that maps all kernel
  symbols into their respective kernel object, this tool infers which
  non-exported symbol is relative to a livepatch relocation and
  automatically formats the final elf file.
  Add support to the generation of a map file right after the kernel
  compilation.
  Add the package kernel-<flavour>-livepatch-devel that brings
  the map file.
- commit 0b1b4d3
* Tue Feb 13 2018 jslaby@suse.cz
- Linux 4.15.3 (bnc#1012628).
- crypto: tcrypt - fix S/G table for test_aead_speed()
  (bnc#1012628).
- gpio: uniphier: fix mismatch between license text and
  MODULE_LICENSE (bnc#1012628).
- media: tegra-cec: add missing MODULE_DESCRIPTION/AUTHOR/LICENSE
  (bnc#1012628).
- media: soc_camera: soc_scale_crop: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- media: mtk-vcodec: add missing MODULE_LICENSE/DESCRIPTION
  (bnc#1012628).
- net: sched: fix use-after-free in tcf_block_put_ext
  (bnc#1012628).
- net_sched: get rid of rcu_barrier() in tcf_block_put_ext()
  (bnc#1012628).
- soreuseport: fix mem leak in reuseport_add_sock() (bnc#1012628).
- ipv6: Fix SO_REUSEPORT UDP socket with implicit sk_ipv6only
  (bnc#1012628).
- cls_u32: add missing RCU annotation (bnc#1012628).
- tcp_bbr: fix pacing_gain to always be unity when using lt_bw
  (bnc#1012628).
- rocker: fix possible null pointer dereference in
  rocker_router_fib_event_work (bnc#1012628).
- net: ipv6: send unsolicited NA after DAD (bnc#1012628).
- Revert "defer call to mem_cgroup_sk_alloc()" (bnc#1012628).
- ipv6: change route cache aging logic (bnc#1012628).
- ipv6: addrconf: break critical section in addrconf_verify_rtnl()
  (bnc#1012628).
- vhost_net: stop device during reset owner (bnc#1012628).
- tcp: release sk_frag.page in tcp_disconnect (bnc#1012628).
- r8169: fix RTL8168EP take too long to complete driver
  initialization (bnc#1012628).
- qmi_wwan: Add support for Quectel EP06 (bnc#1012628).
- qlcnic: fix deadlock bug (bnc#1012628).
- net: igmp: add a missing rcu locking section (bnc#1012628).
- ip6mr: fix stale iterator (bnc#1012628).
- commit e7bb737
* Tue Feb 13 2018 jslaby@suse.cz
- ext4: llseek, do not crop offset on 32bit (bsc#1079747).
- commit c6ab9c6
* Sun Feb 11 2018 afaerber@suse.de
- config: arm64: Enable Hi6421 PMU (bsc#1080449)
- commit 77a784c
* Fri Feb  9 2018 jslaby@suse.cz
- Update i386 config files.
  Switch from almost unusable UNWINDER_GUESS to UNWINDER_FRAME_POINTER
  (which enables FRAME_POINTERs). It will slow down the kernel a bit,
  but improves the stack traces by the order of magnitude. Sad is that
  we have no ORCs on i386...
- commit 1d39996
* Fri Feb  9 2018 jslaby@suse.cz
- Update config files.
  Sync vanilla configs to 4.15.
- commit 85c7881
* Thu Feb  8 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Also require m4 for build.
- commit 0d7b4b3
* Thu Feb  8 2018 jslaby@suse.cz
- Linux 4.15.2 (bnc#1012628).
- KVM: x86: Make indirect calls in emulator speculation safe
  (bnc#1012628).
- KVM: VMX: Make indirect call speculation safe (bnc#1012628).
- x86/alternative: Print unadorned pointers (bnc#1012628).
- auxdisplay: img-ascii-lcd: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- iio: adc/accel: Fix up module licenses (bnc#1012628).
- pinctrl: pxa: pxa2xx: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- ASoC: pcm512x: add missing MODULE_DESCRIPTION/AUTHOR/LICENSE
  (bnc#1012628).
- KVM: nVMX: Eliminate vmcs02 pool (bnc#1012628).
- KVM: VMX: introduce alloc_loaded_vmcs (bnc#1012628).
- objtool: Improve retpoline alternative handling (bnc#1012628).
- objtool: Add support for alternatives at the end of a section
  (bnc#1012628).
- objtool: Warn on stripped section symbol (bnc#1012628).
- x86/mm: Fix overlap of i386 CPU_ENTRY_AREA with FIX_BTMAP
  (bnc#1012628).
- x86/entry/64: Remove the SYSCALL64 fast path (bnc#1012628).
- x86/entry/64: Push extra regs right away (bnc#1012628).
- x86/asm: Move 'status' from thread_struct to thread_info
  (bnc#1012628).
- x86/spectre: Fix spelling mistake: "vunerable"-> "vulnerable"
  (bnc#1012628).
- x86/paravirt: Remove 'noreplace-paravirt' cmdline option
  (bnc#1012628).
- KVM: VMX: make MSR bitmaps per-VCPU (bnc#1012628).
- x86/kvm: Update spectre-v1 mitigation (bnc#1012628).
- x86/retpoline: Avoid retpolines for built-in __init functions
  (bnc#1012628).
- x86/speculation: Fix typo IBRS_ATT, which should be IBRS_ALL
  (bnc#1012628).
- KVM/x86: Update the reverse_cpuid list to include CPUID_7_EDX
  (bnc#1012628).
- KVM/x86: Add IBPB support (bnc#1012628).
- KVM/VMX: Emulate MSR_IA32_ARCH_CAPABILITIES (bnc#1012628).
- KVM/VMX: Allow direct access to MSR_IA32_SPEC_CTRL
  (bnc#1012628).
- KVM/SVM: Allow direct access to MSR_IA32_SPEC_CTRL
  (bnc#1012628).
- serial: core: mark port as initialized after successful IRQ
  change (bnc#1012628).
- fpga: region: release of_parse_phandle nodes after use
  (bnc#1012628).
- commit 54903ae
* Wed Feb  7 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: install ksym-provides tool (bsc#1077692).
- commit 679f5c5
* Wed Feb  7 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: require bison for build.
  linux-next tends to have outdated generated files so it needs bison to
  regenerate them.
- commit 4ad1ede
* Wed Feb  7 2018 msuchanek@suse.de
- Add ksym-provides tool (bsc#1077692).
- commit 9cd1e1e
* Mon Feb  5 2018 jslaby@suse.cz
- x86/pti: Mark constant arrays as __initconst (bsc#1068032
  CVE-2017-5753).
- x86/cpuid: Fix up "virtual" IBRS/IBPB/STIBP feature bits on
  Intel (bsc#1068032 CVE-2017-5753).
- commit 7d4f257
* Mon Feb  5 2018 jslaby@suse.cz
- x86/speculation: Add basic IBRS support infrastructure
  (bsc#1068032 CVE-2017-5753).
- x86/pti: Do not enable PTI on CPUs which are not vulnerable
  to Meltdown (bsc#1068032 CVE-2017-5753).
- x86/cpufeature: Blacklist SPEC_CTRL/PRED_CMD on early Spectre
  v2 microcodes (bsc#1068032 CVE-2017-5753).
- x86/nospec: Fix header guards names (bsc#1068032 CVE-2017-5753).
- x86/bugs: Drop one "mitigation" from dmesg (bsc#1068032
  CVE-2017-5753).
- x86/cpu/bugs: Make retpoline module warning conditional
  (bsc#1068032 CVE-2017-5753).
- x86/cpufeatures: Clean up Spectre v2 related CPUID flags
  (bsc#1068032 CVE-2017-5753).
- x86/retpoline: Simplify vmexit_fill_RSB() (bsc#1068032
  CVE-2017-5753).
- x86/speculation: Simplify indirect_branch_prediction_barrier()
  (bsc#1068032 CVE-2017-5753).
- module/retpoline: Warn about missing retpoline in module
  (bsc#1068032 CVE-2017-5753).
- x86/spectre: Check CONFIG_RETPOLINE in command line parser
  (bsc#1068032 CVE-2017-5753).
- x86/speculation: Use Indirect Branch Prediction Barrier in
  context switch (bsc#1068032 CVE-2017-5753).
- Refresh
  patches.suse/0001-x86-cpufeatures-Add-CPUID_7_EDX-CPUID-leaf.patch.
- Refresh
  patches.suse/0002-x86-cpufeatures-Add-Intel-feature-bits-for-Speculati.patch.
- Refresh
  patches.suse/0003-x86-cpufeatures-Add-AMD-feature-bits-for-Speculation.patch.
- Refresh
  patches.suse/0004-x86-msr-Add-definitions-for-new-speculation-control-.patch.
- Refresh
  patches.suse/0007-x86-speculation-Add-basic-IBPB-Indirect-Branch-Predi.patch.
- Refresh patches.suse/supported-flag.
- Delete
  patches.suse/0005-x86-pti-Do-not-enable-PTI-on-processors-which-are-no.patch.
- Delete
  patches.suse/0006-x86-cpufeature-Blacklist-SPEC_CTRL-on-early-Spectre-.patch.
- Delete patches.suse/0008-x86-kvm-Add-IBPB-support.patch.
- Delete
  patches.suse/0009-x86-speculation-Use-Indirect-Branch-Prediction-Barri.patch.
- Delete
  patches.suse/0010-x86-mm-Only-flush-indirect-branches-when-switching-i.patch.
- Delete
  patches.suse/0011-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Delete
  patches.suse/0017-x86-ibrs-Add-new-helper-macros-to-save-restore-MSR_I-fix.patch.
- Delete
  patches.suse/0017-x86-ibrs-Add-new-helper-macros-to-save-restore-MSR_I.patch.
- Delete
  patches.suse/0018-x86-vmx-Direct-access-to-MSR_IA32_SPEC_CTRL.patch.
  Update to the patches from 4.16-rc1 and the updated IBRS patches from
  the dwmw's repo.
- commit cd20d46
* Mon Feb  5 2018 jslaby@suse.cz
- Documentation: Document array_index_nospec (bsc#1068032
  CVE-2017-5715).
- array_index_nospec: Sanitize speculative array de-references
  (bsc#1068032 CVE-2017-5715).
- x86: Implement array_index_mask_nospec (bsc#1068032
  CVE-2017-5715).
- x86: Introduce barrier_nospec (bsc#1068032 CVE-2017-5715).
- x86: Introduce __uaccess_begin_nospec() and uaccess_try_nospec
  (bsc#1068032 CVE-2017-5715).
- x86/usercopy: Replace open coded stac/clac with
  __uaccess_{begin, end} (bsc#1068032 CVE-2017-5715).
- x86/syscall: Sanitize syscall table de-references under
  speculation (bsc#1068032 CVE-2017-5715).
- nl80211: Sanitize array index in parse_txq_params (bsc#1068032
  CVE-2017-5715).
- x86/spectre: Report get_user mitigation for spectre_v1
  (bsc#1068032 CVE-2017-5715).
- Delete patches.suse/0001-Documentation-document-array_ptr.patch.
- Delete
  patches.suse/0002-asm-nospec-array_ptr-sanitize-speculative-array-de-r.patch.
- Delete patches.suse/0003-x86-implement-array_ptr_mask.patch.
- Delete
  patches.suse/0004-x86-introduce-__uaccess_begin_nospec-and-ifence.patch.
- Delete
  patches.suse/0007-x86-narrow-out-of-bounds-syscalls-to-sys_read-under-.patch.
- Delete
  patches.suse/0009-kvm-x86-update-spectre-v1-mitigation.patch.
- Delete
  patches.suse/0010-nl80211-sanitize-array-index-in-parse_txq_params.patch.
  Replace by the patches from 4.16-rc1.
- commit 8343cab
* Mon Feb  5 2018 jslaby@suse.cz
- scsi: aacraid: remove redundant setting of variable c
  (git-fixes).
- commit 143e25c
* Sun Feb  4 2018 jslaby@suse.cz
- Linux 4.15.1 (bnc#1012628).
- x86/efi: Clarify that reset attack mitigation needs appropriate
  userspace (bnc#1012628).
- Input: synaptics-rmi4 - do not delete interrupt memory too early
  (bnc#1012628).
- Input: synaptics-rmi4 - unmask F03 interrupts when port is
  opened (bnc#1012628).
- test_firmware: fix missing unlock on error in
  config_num_requests_store() (bnc#1012628).
- iio: chemical: ccs811: Fix output of IIO_CONCENTRATION channels
  (bnc#1012628).
- iio: adc: stm32: fix scan of multiple channels with DMA
  (bnc#1012628).
- spi: imx: do not access registers while clocks disabled
  (bnc#1012628).
- serial: imx: Only wakeup via RTSDEN bit if the system has
  RTS/CTS (bnc#1012628).
- serial: 8250_dw: Revert "Improve clock rate setting"
  (bnc#1012628).
- serial: 8250_uniphier: fix error return code in
  uniphier_uart_probe() (bnc#1012628).
- serial: 8250_of: fix return code when probe function fails to
  get reset (bnc#1012628).
- mei: me: allow runtime pm for platform with D0i3 (bnc#1012628).
- android: binder: use VM_ALLOC to get vm area (bnc#1012628).
- ANDROID: binder: remove waitqueue when thread exits
  (bnc#1012628).
- usb/gadget: Fix "high bandwidth" check in
  usb_gadget_ep_match_desc() (bnc#1012628).
- usb: uas: unconditionally bring back host after reset
  (bnc#1012628).
- usb: f_fs: Prevent gadget unbind if it is already unbound
  (bnc#1012628).
- USB: serial: simple: add Motorola Tetra driver (bnc#1012628).
- usbip: list: don't list devices attached to vhci_hcd
  (bnc#1012628).
- usbip: prevent bind loops on devices attached to vhci_hcd
  (bnc#1012628).
- USB: serial: io_edgeport: fix possible sleep-in-atomic
  (bnc#1012628).
- CDC-ACM: apply quirk for card reader (bnc#1012628).
- USB: cdc-acm: Do not log urb submission errors on disconnect
  (bnc#1012628).
- USB: serial: pl2303: new device id for Chilitag (bnc#1012628).
- usb: option: Add support for FS040U modem (bnc#1012628).
- tty: fix data race between tty_init_dev and flush of buf
  (bnc#1012628).
- staging: ccree: fix fips event irq handling build (bnc#1012628).
- staging: ccree: NULLify backup_info when unused (bnc#1012628).
- staging: lustre: separate a connection destroy from free struct
  kib_conn (bnc#1012628).
- scsi: storvsc: missing error code in storvsc_probe()
  (bnc#1012628).
- scsi: aacraid: Fix hang in kdump (bnc#1012628).
- scsi: aacraid: Fix udev inquiry race condition (bnc#1012628).
- ima/policy: fix parsing of fsuuid (bnc#1012628).
- igb: Free IRQs when device is hotplugged (bnc#1012628).
- mtd: nand: denali_pci: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- gpio: ath79: add missing MODULE_DESCRIPTION/LICENSE
  (bnc#1012628).
- gpio: iop: add missing MODULE_DESCRIPTION/AUTHOR/LICENSE
  (bnc#1012628).
- power: reset: zx-reboot: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- HID: wacom: Fix reporting of touch toggle
  (WACOM_HID_WD_MUTE_DEVICE) events (bnc#1012628).
- HID: wacom: EKR: ensure devres groups at higher indexes are
  released (bnc#1012628).
- crypto: af_alg - whitelist mask and type (bnc#1012628).
- crypto: sha3-generic - fixes for alignment and big endian
  operation (bnc#1012628).
- crypto: inside-secure - avoid unmapping DMA memory that was
  not mapped (bnc#1012628).
- crypto: inside-secure - fix hash when length is a multiple of
  a block (bnc#1012628).
- crypto: aesni - Fix out-of-bounds access of the AAD buffer in
  generic-gcm-aesni (bnc#1012628).
- crypto: aesni - Fix out-of-bounds access of the data buffer
  in generic-gcm-aesni (bnc#1012628).
- crypto: aesni - add wrapper for generic gcm(aes) (bnc#1012628).
- crypto: aesni - fix typo in generic_gcmaes_decrypt
  (bnc#1012628).
- crypto: aesni - handle zero length dst buffer (bnc#1012628).
- crypto: ecdh - fix typo in KPP dependency of CRYPTO_ECDH
  (bnc#1012628).
- ALSA: hda - Reduce the suspend time consumption for ALC256
  (bnc#1012628).
- gpio: Fix kernel stack leak to userspace (bnc#1012628).
- gpio: stmpe: i2c transfer are forbiden in atomic context
  (bnc#1012628).
- tools/gpio: Fix build error with musl libc (bnc#1012628).
- Bluetooth: hci_serdev: Init hci_uart proto_lock to avoid oops
  (bnc#1012628).
- Linux 4.15.1 (bnc#1012628).
- x86/efi: Clarify that reset attack mitigation needs appropriate
  userspace (bnc#1012628).
- Input: synaptics-rmi4 - do not delete interrupt memory too early
  (bnc#1012628).
- Input: synaptics-rmi4 - unmask F03 interrupts when port is
  opened (bnc#1012628).
- test_firmware: fix missing unlock on error in
  config_num_requests_store() (bnc#1012628).
- iio: chemical: ccs811: Fix output of IIO_CONCENTRATION channels
  (bnc#1012628).
- iio: adc: stm32: fix scan of multiple channels with DMA
  (bnc#1012628).
- spi: imx: do not access registers while clocks disabled
  (bnc#1012628).
- serial: imx: Only wakeup via RTSDEN bit if the system has
  RTS/CTS (bnc#1012628).
- serial: 8250_dw: Revert "Improve clock rate setting"
  (bnc#1012628).
- serial: 8250_uniphier: fix error return code in
  uniphier_uart_probe() (bnc#1012628).
- serial: 8250_of: fix return code when probe function fails to
  get reset (bnc#1012628).
- mei: me: allow runtime pm for platform with D0i3 (bnc#1012628).
- android: binder: use VM_ALLOC to get vm area (bnc#1012628).
- ANDROID: binder: remove waitqueue when thread exits
  (bnc#1012628).
- usb/gadget: Fix "high bandwidth" check in
  usb_gadget_ep_match_desc() (bnc#1012628).
- usb: uas: unconditionally bring back host after reset
  (bnc#1012628).
- usb: f_fs: Prevent gadget unbind if it is already unbound
  (bnc#1012628).
- USB: serial: simple: add Motorola Tetra driver (bnc#1012628).
- usbip: list: don't list devices attached to vhci_hcd
  (bnc#1012628).
- usbip: prevent bind loops on devices attached to vhci_hcd
  (bnc#1012628).
- USB: serial: io_edgeport: fix possible sleep-in-atomic
  (bnc#1012628).
- CDC-ACM: apply quirk for card reader (bnc#1012628).
- USB: cdc-acm: Do not log urb submission errors on disconnect
  (bnc#1012628).
- USB: serial: pl2303: new device id for Chilitag (bnc#1012628).
- usb: option: Add support for FS040U modem (bnc#1012628).
- tty: fix data race between tty_init_dev and flush of buf
  (bnc#1012628).
- staging: ccree: fix fips event irq handling build (bnc#1012628).
- staging: ccree: NULLify backup_info when unused (bnc#1012628).
- staging: lustre: separate a connection destroy from free struct
  kib_conn (bnc#1012628).
- scsi: storvsc: missing error code in storvsc_probe()
  (bnc#1012628).
- scsi: aacraid: Fix hang in kdump (bnc#1012628).
- scsi: aacraid: Fix udev inquiry race condition (bnc#1012628).
- ima/policy: fix parsing of fsuuid (bnc#1012628).
- igb: Free IRQs when device is hotplugged (bnc#1012628).
- mtd: nand: denali_pci: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- gpio: ath79: add missing MODULE_DESCRIPTION/LICENSE
  (bnc#1012628).
- gpio: iop: add missing MODULE_DESCRIPTION/AUTHOR/LICENSE
  (bnc#1012628).
- power: reset: zx-reboot: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- HID: wacom: Fix reporting of touch toggle
  (WACOM_HID_WD_MUTE_DEVICE) events (bnc#1012628).
- HID: wacom: EKR: ensure devres groups at higher indexes are
  released (bnc#1012628).
- crypto: af_alg - whitelist mask and type (bnc#1012628).
- crypto: sha3-generic - fixes for alignment and big endian
  operation (bnc#1012628).
- crypto: inside-secure - avoid unmapping DMA memory that was
  not mapped (bnc#1012628).
- crypto: inside-secure - fix hash when length is a multiple of
  a block (bnc#1012628).
- crypto: aesni - Fix out-of-bounds access of the AAD buffer in
  generic-gcm-aesni (bnc#1012628).
- crypto: aesni - Fix out-of-bounds access of the data buffer
  in generic-gcm-aesni (bnc#1012628).
- crypto: aesni - add wrapper for generic gcm(aes) (bnc#1012628).
- crypto: aesni - fix typo in generic_gcmaes_decrypt
  (bnc#1012628).
- crypto: aesni - handle zero length dst buffer (bnc#1012628).
- crypto: ecdh - fix typo in KPP dependency of CRYPTO_ECDH
  (bnc#1012628).
- ALSA: hda - Reduce the suspend time consumption for ALC256
  (bnc#1012628).
- gpio: Fix kernel stack leak to userspace (bnc#1012628).
- gpio: stmpe: i2c transfer are forbiden in atomic context
  (bnc#1012628).
- tools/gpio: Fix build error with musl libc (bnc#1012628).
- Bluetooth: hci_serdev: Init hci_uart proto_lock to avoid oops
  (bnc#1012628).
- commit 671bf29
* Thu Feb  1 2018 matwey.kornilov@gmail.com
- config: arm64: Enable RockChip 8xx
  We need RockChip RK-808 support to run openSUSE on Rock64 board (RK3328).
  Currently, even voltage regulator is missed.
- commit a348749
* Wed Jan 31 2018 jslaby@suse.cz
- Update to 4.15-final.
- Eliminated 5 patches.
- Config changes:
  - Security:
  - GENERIC_CPU_VULNERABILITIES=y
- commit 978c9b0
* Tue Jan 30 2018 mkubecek@suse.cz
- Update
  patches.kernel.org/4.14.14-036-RDS-Heap-OOB-write-in-rds_message_alloc_sgs.patch
  upstream references (add CVE-2018-5332 bsc#1075621).
- commit 510de01
* Tue Jan 30 2018 mkubecek@suse.cz
- Update
  patches.kernel.org/4.14.14-037-RDS-null-pointer-dereference-in-rds_atomic_fr.patch
  upstream references (add CVE-2018-5333 bsc#1075617).
- commit e6cf845
* Mon Jan 29 2018 jeffm@suse.com
- Update to 4.15-final.
- Eliminated 5 patches.
- commit 36830f7
* Mon Jan 29 2018 jeffm@suse.com
- btrfs: fix btrfs_evict_inode to handle abnormal inodes correctly (bsc#1078019).
- commit d3f1d2c
* Mon Jan 29 2018 jslaby@suse.cz
- Revert "module: Add retpoline tag to VERMAGIC" (fix loading
  of KMPs).
- commit 9a6fca5
* Fri Jan 26 2018 yousaf.kaukab@suse.com
- config: arm64: enable UNMAP_KERNEL_AT_EL0 and HARDEN_BRANCH_PREDICTOR
- commit c41900c
* Fri Jan 26 2018 yousaf.kaukab@suse.com
- arm64: Turn on KPTI only on CPUs that need it (bsc#1068032).
- arm64: Branch predictor hardening for Cavium ThunderX2
  (bsc#1068032).
- arm64: Run enable method for errata work arounds on late CPUs
  (bsc#1068032).
- arm64: Move BP hardening to check_and_switch_context
  (bsc#1068032).
- arm: KVM: Invalidate icache on guest exit for Cortex-A15
  (bsc#1068032).
- arm: Invalidate icache on prefetch abort outside of user
  mapping on Cortex-A15 (bsc#1068032).
- arm: Add icache invalidation on switch_mm for Cortex-A15
  (bsc#1068032).
- arm: KVM: Invalidate BTB on guest exit (bsc#1068032).
- arm: Invalidate BTB on prefetch abort outside of user mapping
  on Cortex A8, A9, A12 and A17 (bsc#1068032).
- arm: Add BTB invalidation on switch_mm for Cortex-A9, A12 and
  A17 (bsc#1068032).
- arm64: cputype: Add MIDR values for Cavium ThunderX2 CPUs
  (bsc#1068032).
- arm64: Implement branch predictor hardening for Falkor
  (bsc#1068032).
- arm64: Implement branch predictor hardening for affected
  Cortex-A CPUs (bsc#1068032).
- arm64: cputype: Add missing MIDR values for Cortex-A72 and
  Cortex-A75 (bsc#1068032).
- arm64: KVM: Make PSCI_VERSION a fast path (bsc#1068032).
- arm64: KVM: Use per-CPU vector when BP hardening is enabled
  (bsc#1068032).
- arm64: Add skeleton to harden the branch predictor against
  aliasing attacks (bsc#1068032).
- arm64: Move post_ttbr_update_workaround to C code (bsc#1068032).
- drivers/firmware: Expose psci_get_version through psci_ops
  structure (bsc#1068032).
- arm64: Take into account ID_AA64PFR0_EL1.CSV3 (bsc#1068032).
- arm64: Kconfig: Reword UNMAP_KERNEL_AT_EL0 kconfig entry
  (bsc#1068032).
- arm64: use RET instruction for exiting the trampoline
  (bsc#1068032).
- arm64: capabilities: Handle duplicate entries for a capability
  (bsc#1068032).
- arm64: cpufeature: Pass capability structure to ->enable
  callback (bsc#1068032).
- arm64: kpti: Fix the interaction between ASID switching and
  software PAN (bsc#1068032).
- arm64: kaslr: Put kernel vectors address in separate data page
  (bsc#1068032).
- arm64: mm: Introduce TTBR_ASID_MASK for getting at the ASID
  in the TTBR (bsc#1068032).
- perf: arm_spe: Fail device probe when
  arm64_kernel_unmapped_at_el0() (bsc#1068032).
- arm64: Kconfig: Add CONFIG_UNMAP_KERNEL_AT_EL0 (bsc#1068032).
- arm64: entry: Add fake CPU feature for unmapping the kernel
  at EL0 (bsc#1068032).
- arm64: tls: Avoid unconditional zeroing of tpidrro_el0 for
  native tasks (bsc#1068032).
- arm64: erratum: Work around Falkor erratum #E1003 in trampoline
  code (bsc#1068032).
- arm64: entry: Hook up entry trampoline to exception vectors
  (bsc#1068032).
- arm64: entry: Explicitly pass exception level to kernel_ventry
  macro (bsc#1068032).
- arm64: mm: Map entry trampoline into trampoline and kernel
  page tables (bsc#1068032).
- arm64: entry: Add exception trampoline page for exceptions
  from EL0 (bsc#1068032).
- arm64: mm: Invalidate both kernel and user ASIDs when performing
  TLBI (bsc#1068032).
- arm64: mm: Add arm64_kernel_unmapped_at_el0 helper
  (bsc#1068032).
- arm64: mm: Allocate ASIDs in pairs (bsc#1068032).
- arm64: mm: Fix and re-enable ARM64_SW_TTBR0_PAN (bsc#1068032).
- arm64: mm: Rename post_ttbr0_update_workaround (bsc#1068032).
- arm64: mm: Remove pre_ttbr0_update_workaround for Falkor
  erratum #E1003 (bsc#1068032).
- arm64: mm: Move ASID from TTBR0 to TTBR1 (bsc#1068032).
- arm64: mm: Temporarily disable ARM64_SW_TTBR0_PAN (bsc#1068032).
- arm64: mm: Use non-global mappings for kernel space
  (bsc#1068032).
- commit cdf2ded
* Fri Jan 26 2018 yousaf.kaukab@suse.com
- config: arm64: enable rk3399 missing drivers
  These drivers are required for Rockchip RK3399 Sapphire board
- commit 94b8551
* Fri Jan 26 2018 jslaby@suse.cz
- Refresh
  patches.suse/netfilter-nfnetlink_cthelper-Add-missing-permission-.patch.
- Refresh
  patches.suse/netfilter-xt_osf-Add-missing-permission-checks.patch.
- Refresh patches.suse/scsi-libfc-fix-ELS-request-handling.patch.
  Update upstream status.
- commit 12e5c10
* Fri Jan 26 2018 jslaby@suse.cz
- x86/ibrs: Add new helper macros to save/restore
  MSR_IA32_SPEC_CTRL fix (bsc#1068032 CVE-2017-5753).
- commit 13295d4
* Thu Jan 25 2018 jslaby@suse.cz
- Delete patches.suse/orc-fix-retpolines-segfaults.patch.
  No longer needed.
- commit 9e84548
* Thu Jan 25 2018 jslaby@suse.cz
- x86/cpufeatures: Add Intel feature bits for Speculation Control
  (bsc#1068032 CVE-2017-5715).
- x86/cpufeatures: Add AMD feature bits for Speculation Control
  (bsc#1068032 CVE-2017-5715).
- x86/pti: Do not enable PTI on processors which are not
  vulnerable to Meltdown (bsc#1068032 CVE-2017-5715).
- x86/cpufeature: Blacklist SPEC_CTRL on early Spectre v2
  microcodes (bsc#1068032 CVE-2017-5715).
- x86/speculation: Add basic IBPB (Indirect Branch Prediction
  Barrier) support (bsc#1068032 CVE-2017-5715).
- x86/kvm: Add IBPB support (bsc#1068032 CVE-2017-5715).
- x86/speculation: Use Indirect Branch Prediction Barrier in
  context switch (bsc#1068032 CVE-2017-5715).
- x86/mm: Only flush indirect branches when switching into non
  dumpable process (bsc#1068032 CVE-2017-5715).
- x86/speculation: Add basic IBRS support infrastructure
  (bsc#1068032 CVE-2017-5715).
- x86/speculation: Add inlines to control Indirect Branch
  Speculation (bsc#1068032 CVE-2017-5715).
- x86: Simplify spectre_v2 command line parsing (bsc#1068032
  CVE-2017-5715).
- x86/idle: Control Indirect Branch Speculation in idle
  (bsc#1068032 CVE-2017-5715).
- x86/enter: Create macros to restrict/unrestrict Indirect Branch
  Speculation (bsc#1068032 CVE-2017-5715).
- x86/enter: Use IBRS on syscall and interrupts (bsc#1068032
  CVE-2017-5715).
- x86/ibrs: Add new helper macros to save/restore
  MSR_IA32_SPEC_CTRL (bsc#1068032 CVE-2017-5715).
- x86/vmx: Direct access to MSR_IA32_SPEC_CTRL (bsc#1068032
  CVE-2017-5715).
- Delete
  patches.suse/0002-x86-cpufeatures-Add-AMD-feature-bits-for-Prediction-.patch.
- Delete
  patches.suse/0004-x86-feature-Report-presence-of-IBPB-and-IBRS-control.patch.
- Delete
  patches.suse/0005-x86-enter-MACROS-to-set-clear-IBRS-and-set-IBPB.patch.
- Delete
  patches.suse/0006-x86-Add-macro-that-does-not-save-rax-rcx-rdx-on-stac.patch.
- Delete
  patches.suse/0007-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- Delete
  patches.suse/0008-x86-spec_ctrl-save-IBRS-MSR-value-in-paranoid_entry.patch.
- Delete
  patches.suse/0009-x86-idle-Disable-IBRS-entering-idle-and-enable-it-on.patch.
- Delete
  patches.suse/0010-x86-idle-Disable-IBRS-when-offlining-cpu-and-re-enab.patch.
- Delete
  patches.suse/0011-x86-mm-Set-IBPB-upon-context-switch.patch.
- Delete
  patches.suse/0012-x86-mm-Only-set-IBPB-when-the-new-thread-cannot-ptra.patch.
- Delete
  patches.suse/0013-x86-entry-Stuff-RSB-for-entry-to-kernel-for-non-SMEP.patch.
- Delete
  patches.suse/0014-x86-syscall-Clear-unused-extra-registers-on-syscall-.patch.
- Delete
  patches.suse/0015-x86-syscall-Clear-unused-extra-registers-on-32-bit-c.patch.
- Delete
  patches.suse/0016-x86-kvm-add-MSR_IA32_SPEC_CTRL-and-MSR_IA32_PRED_CMD.patch.
- Delete
  patches.suse/0017-x86-kvm-Set-IBPB-when-switching-VM.patch.
- Delete
  patches.suse/0018-x86-kvm-Toggle-IBRS-on-VM-entry-and-exit.patch.
- Delete
  patches.suse/0021-x86-spec_ctrl-Add-sysctl-knobs-to-enable-disable-SPE.patch.
- Delete
  patches.suse/0022-x86-spec_ctrl-Add-lock-to-serialize-changes-to-ibrs-.patch.
- Delete
  patches.suse/0023-x86-Move-IBRS-IBPB-feature-detection-to-scattered.c.patch.
- Delete
  patches.suse/0024-x86-microcode-Recheck-IBRS-and-IBPB-feature-on-micro.patch.
- Delete
  patches.suse/0025-x86-cpu-AMD-Add-speculative-control-support-for-AMD.patch.
- Delete
  patches.suse/0028-x86-svm-Set-IBPB-when-running-a-different-VCPU.patch.
- Delete
  patches.suse/0029-kvm-svm-add-MSR_IA32_SPEC_CTRL-and-MSR_IA32_PRED_CMD.patch.
- Delete patches.suse/0030-Use-the-ibrs_inuse-variable.patch.
- Delete
  patches.suse/0031-Reverting-the-commit-e5247c4f209530-to-replace.patch.
- Delete
  patches.suse/0032-kvm-vmx-add-MSR_IA32_SPEC_CTRL-and-MSR_IA32_PRED_CMD.patch.
- Delete
  patches.suse/0033-KVM-x86-add-SPEC_CTRL-to-MSR-and-CPUID-lists.patch.
- Delete
  patches.suse/0034-Remove-the-code-that-uses-MSR-save-restore-list.patch.
- Delete patches.suse/0035-Use-the-ibpb_inuse-variable.patch.
- Delete
  patches.suse/0037-Set-IBPB-when-running-a-different-VCPU.patch.
  Update spectre_v1 to the upstream patches.
- commit 67b0a37
* Thu Jan 25 2018 jslaby@suse.cz
- Revert "futex: Prevent overflow by strengthen input validation"
  (4.14.15-fix).
- commit 5b3d0ce
* Thu Jan 25 2018 jslaby@suse.cz
- x86/cpufeature: Move processor tracing out of scattered features
  (bsc#1068032 CVE-2017-5753).
- Refresh
  patches.suse/0001-x86-cpufeatures-Add-CPUID_7_EDX-CPUID-leaf.patch.
- Refresh
  patches.suse/0007-x86-speculation-Add-basic-IBPB-Indirect-Branch-Predi.patch.
- commit 8d8b718
* Wed Jan 24 2018 jslaby@suse.cz
- x86/retpoline: Add LFENCE to the retpoline/RSB filling RSB
  macros (bsc#1068032 CVE-2017-5753).
- commit 8dc7c71
* Wed Jan 24 2018 jslaby@suse.cz
- x86/vmx: Direct access to MSR_IA32_SPEC_CTRL (bsc#1068032
  CVE-2017-5753).
- x86/ibrs: Add new helper macros to save/restore
  MSR_IA32_SPEC_CTRL (bsc#1068032 CVE-2017-5753).
- x86/enter: Use IBRS on syscall and interrupts (bsc#1068032
  CVE-2017-5753).
- x86/enter: Create macros to restrict/unrestrict Indirect Branch
  Speculation (bsc#1068032 CVE-2017-5753).
- x86/idle: Control Indirect Branch Speculation in idle
  (bsc#1068032 CVE-2017-5753).
- x86: Simplify spectre_v2 command line parsing (bsc#1068032
  CVE-2017-5753).
- x86/speculation: Add inlines to control Indirect Branch
  Speculation (bsc#1068032 CVE-2017-5753).
- x86/speculation: Add basic IBRS support infrastructure
  (bsc#1068032 CVE-2017-5753).
- x86/mm: Only flush indirect branches when switching into non
  dumpable process (bsc#1068032 CVE-2017-5753).
- x86/speculation: Use Indirect Branch Prediction Barrier in
  context switch (bsc#1068032 CVE-2017-5753).
- x86/kvm: Add IBPB support (bsc#1068032 CVE-2017-5753).
- x86/speculation: Add basic IBPB (Indirect Branch Prediction
  Barrier) support (bsc#1068032 CVE-2017-5753).
- x86/cpufeature: Blacklist SPEC_CTRL on early Spectre v2
  microcodes (bsc#1068032 CVE-2017-5753).
- x86/pti: Do not enable PTI on processors which are not
  vulnerable to Meltdown (bsc#1068032 CVE-2017-5753).
- x86/msr: Add definitions for new speculation control MSRs
  (bsc#1068032 CVE-2017-5753).
- x86/cpufeatures: Add AMD feature bits for Speculation Control
  (bsc#1068032 CVE-2017-5753).
- x86/cpufeatures: Add Intel feature bits for Speculation Control
  (bsc#1068032 CVE-2017-5753).
- x86/cpufeatures: Add CPUID_7_EDX CPUID leaf (bsc#1068032
  CVE-2017-5753).
- x86/retpoline: Optimize inline assembler for vmexit_fill_RSB
  (bsc#1068032 CVE-2017-5753).
- x86/retpoline: Fill RSB on context switch for affected CPUs
  (bsc#1068032 CVE-2017-5753).
- commit e36ab4f
* Wed Jan 24 2018 jslaby@suse.cz
- Documentation: document array_ptr (bsc#1068032 CVE-2017-5715).
- asm/nospec, array_ptr: sanitize speculative array de-references
  (bsc#1068032 CVE-2017-5715).
- x86: implement array_ptr_mask() (bsc#1068032 CVE-2017-5715).
- x86: introduce __uaccess_begin_nospec and ifence (bsc#1068032
  CVE-2017-5715).
- x86, __get_user: use __uaccess_begin_nospec (bsc#1068032
  CVE-2017-5715).
- x86, get_user: use pointer masking to limit speculation
  (bsc#1068032 CVE-2017-5715).
- x86: narrow out of bounds syscalls to sys_read under speculation
  (bsc#1068032 CVE-2017-5715).
- vfs, fdtable: prevent bounds-check bypass via speculative
  execution (bsc#1068032 CVE-2017-5715).
- kvm, x86: update spectre-v1 mitigation (bsc#1068032
  CVE-2017-5715).
- nl80211: sanitize array index in parse_txq_params (bsc#1068032
  CVE-2017-5715).
- Delete
  patches.suse/0003-locking-barriers-introduce-new-observable-speculatio.patch.
- Delete
  patches.suse/0004-bpf-prevent-speculative-execution-in-eBPF-interprete.patch.
- Delete
  patches.suse/0005-x86-bpf-jit-prevent-speculative-execution-when-JIT-i.patch.
- Delete
  patches.suse/0006-uvcvideo-prevent-speculative-execution.patch.
- Delete
  patches.suse/0007-carl9170-prevent-speculative-execution.patch.
- Delete
  patches.suse/0008-p54-prevent-speculative-execution.patch.
- Delete
  patches.suse/0009-qla2xxx-prevent-speculative-execution.patch.
- Delete
  patches.suse/0010-cw1200-prevent-speculative-execution.patch.
- Delete
  patches.suse/0011-Thermal-int340x-prevent-speculative-execution.patch.
- Delete
  patches.suse/0012-ipv4-prevent-speculative-execution.patch.
- Delete
  patches.suse/0013-ipv6-prevent-speculative-execution.patch.
- Delete patches.suse/0014-fs-prevent-speculative-execution.patch.
- Delete
  patches.suse/0015-net-mpls-prevent-speculative-execution.patch.
- Delete
  patches.suse/0016-udf-prevent-speculative-execution.patch.
- Delete
  patches.suse/0017-userns-prevent-speculative-execution.patch.
  Replace by the potential upstream solution.
- commit 804f8a1
* Wed Jan 24 2018 jslaby@suse.cz
- Documentation: document array_ptr (bsc#1068032 CVE-2017-5715).
- asm/nospec, array_ptr: sanitize speculative array de-references
  (bsc#1068032 CVE-2017-5715).
- x86: implement array_ptr_mask() (bsc#1068032 CVE-2017-5715).
- x86: introduce __uaccess_begin_nospec and ifence (bsc#1068032
  CVE-2017-5715).
- x86, __get_user: use __uaccess_begin_nospec (bsc#1068032
  CVE-2017-5715).
- x86, get_user: use pointer masking to limit speculation
  (bsc#1068032 CVE-2017-5715).
- x86: narrow out of bounds syscalls to sys_read under speculation
  (bsc#1068032 CVE-2017-5715).
- vfs, fdtable: prevent bounds-check bypass via speculative
  execution (bsc#1068032 CVE-2017-5715).
- kvm, x86: update spectre-v1 mitigation (bsc#1068032
  CVE-2017-5715).
- nl80211: sanitize array index in parse_txq_params (bsc#1068032
  CVE-2017-5715).
- Delete
  patches.suse/0003-locking-barriers-introduce-new-observable-speculatio.patch.
- Delete
  patches.suse/0005-x86-bpf-jit-prevent-speculative-execution-when-JIT-i.patch.
- Delete
  patches.suse/0006-uvcvideo-prevent-speculative-execution.patch.
- Delete
  patches.suse/0007-carl9170-prevent-speculative-execution.patch.
- Delete
  patches.suse/0008-p54-prevent-speculative-execution.patch.
- Delete
  patches.suse/0009-qla2xxx-prevent-speculative-execution.patch.
- Delete
  patches.suse/0010-cw1200-prevent-speculative-execution.patch.
- Delete
  patches.suse/0011-Thermal-int340x-prevent-speculative-execution.patch.
- Delete
  patches.suse/0012-ipv4-prevent-speculative-execution.patch.
- Delete
  patches.suse/0013-ipv6-prevent-speculative-execution.patch.
- Delete patches.suse/0014-fs-prevent-speculative-execution.patch.
- Delete
  patches.suse/0015-net-mpls-prevent-speculative-execution.patch.
- Delete
  patches.suse/0016-udf-prevent-speculative-execution.patch.
- Delete
  patches.suse/0017-userns-prevent-speculative-execution.patch.
  Replace intel's shit by the potential upstream solution for spectre_v1.
- commit 6fdb1df
* Tue Jan 23 2018 jslaby@suse.cz
- Linux 4.14.15 (bnc#1012628).
- tools/objtool/Makefile: don't assume sync-check.sh is executable
  (bnc#1012628).
- objtool: Fix seg fault with clang-compiled objects
  (bnc#1012628).
- objtool: Fix Clang enum conversion warning (bnc#1012628).
- objtool: Fix seg fault caused by missing parameter
  (bnc#1012628).
- powerpc/pseries: Add H_GET_CPU_CHARACTERISTICS flags & wrapper
  (bnc#1012628).
- powerpc/64: Add macros for annotating the destination of
  rfid/hrfid (bnc#1012628).
- powerpc/64s: Simple RFI macro conversions (bnc#1012628).
- powerpc/64: Convert the syscall exit path to use
  RFI_TO_USER/KERNEL (bnc#1012628).
- powerpc/64: Convert fast_exception_return to use
  RFI_TO_USER/KERNEL (bnc#1012628).
- powerpc/64s: Convert slb_miss_common to use RFI_TO_USER/KERNEL
  (bnc#1012628).
- powerpc/64s: Add support for RFI flush of L1-D cache
  (bnc#1012628).
- powerpc/64s: Support disabling RFI flush with no_rfi_flush
  and nopti (bnc#1012628).
- powerpc/pseries: Query hypervisor for RFI flush settings
  (bnc#1012628).
- powerpc/powernv: Check device-tree for RFI flush settings
  (bnc#1012628).
- futex: Avoid violating the 10th rule of futex (bnc#1012628).
- futex: Prevent overflow by strengthen input validation
  (bnc#1012628).
- ALSA: pcm: Remove yet superfluous WARN_ON() (bnc#1012628).
- ALSA: hda - Apply headphone noise quirk for another Dell XPS
  13 variant (bnc#1012628).
- ALSA: hda - Apply the existing quirk to iMac 14,1 (bnc#1012628).
- IB/hfi1: Prevent a NULL dereference (bnc#1012628).
- RDMA/mlx5: Fix out-of-bound access while querying AH
  (bnc#1012628).
- timers: Unconditionally check deferrable base (bnc#1012628).
- af_key: fix buffer overread in verify_address_len()
  (bnc#1012628).
- af_key: fix buffer overread in parse_exthdrs() (bnc#1012628).
- iser-target: Fix possible use-after-free in connection
  establishment error (bnc#1012628).
- delayacct: Account blkio completion on the correct task
  (bnc#1012628).
- objtool: Fix seg fault with gold linker (bnc#1012628).
- mmc: sdhci-esdhc-imx: Fix i.MX53 eSDHCv3 clock (bnc#1012628).
- x86/kasan: Panic if there is not enough memory to boot
  (bnc#1012628).
- objtool: Improve error message for bad file argument
  (bnc#1012628).
- x86/cpufeature: Move processor tracing out of scattered features
  (bnc#1012628).
- x86/intel_rdt/cqm: Prevent use after free (bnc#1012628).
- x86/mm/pkeys: Fix fill_sig_info_pkey (bnc#1012628).
- x86/idt: Mark IDT tables __initconst (bnc#1012628).
- x86/tsc: Future-proof native_calibrate_tsc() (bnc#1012628).
- x86/tsc: Fix erroneous TSC rate on Skylake Xeon (bnc#1012628).
- pipe: avoid round_pipe_size() nr_pages overflow on 32-bit
  (bnc#1012628).
- x86/apic/vector: Fix off by one in error path (bnc#1012628).
- x86/mm: Clean up register saving in the __enc_copy() assembly
  code (bnc#1012628).
- x86/mm: Use a struct to reduce parameters for SME PGD mapping
  (bnc#1012628).
- x86/mm: Centralize PMD flags in sme_encrypt_kernel()
  (bnc#1012628).
- x86/mm: Prepare sme_encrypt_kernel() for PAGE aligned encryption
  (bnc#1012628).
- ARM: OMAP3: hwmod_data: add missing module_offs for MMC3
  (bnc#1012628).
- x86/mm: Encrypt the initrd earlier for BSP microcode update
  (bnc#1012628).
- Input: ALPS - fix multi-touch decoding on SS4 plus touchpads
  (bnc#1012628).
- Input: synaptics-rmi4 - prevent UAF reported by KASAN
  (bnc#1012628).
- Input: 88pm860x-ts - fix child-node lookup (bnc#1012628).
- Input: twl6040-vibra - fix child-node lookup (bnc#1012628).
- Input: twl4030-vibra - fix sibling-node lookup (bnc#1012628).
- tracing: Fix converting enum's from the map in
  trace_event_eval_update() (bnc#1012628).
- phy: work around 'phys' references to usb-nop-xceiv devices
  (bnc#1012628).
- ARM64: dts: marvell: armada-cp110: Fix clock resources for
  various node (bnc#1012628).
- ARM: sunxi_defconfig: Enable CMA (bnc#1012628).
- ARM: dts: kirkwood: fix pin-muxing of MPP7 on OpenBlocks A7
  (bnc#1012628).
- can: peak: fix potential bug in packet fragmentation
  (bnc#1012628).
- can: af_can: can_rcv(): replace WARN_ONCE by pr_warn_once
  (bnc#1012628).
- can: af_can: canfd_rcv(): replace WARN_ONCE by pr_warn_once
  (bnc#1012628).
- i2c: core-smbus: prevent stack corruption on read I2C_BLOCK_DATA
  (bnc#1012628).
- scripts/gdb/linux/tasks.py: fix get_thread_info (bnc#1012628).
- proc: fix coredump vs read /proc/*/stat race (bnc#1012628).
- libata: apply MAX_SEC_1024 to all LITEON EP1 series devices
  (bnc#1012628).
- scsi: libsas: Disable asynchronous aborts for SATA devices
  (bnc#1012628).
- workqueue: avoid hard lockups in show_workqueue_state()
  (bnc#1012628).
- drm/vmwgfx: fix memory corruption with legacy/sou connectors
  (bnc#1012628).
- dm btree: fix serious bug in btree_split_beneath()
  (bnc#1012628).
- dm thin metadata: THIN_MAX_CONCURRENT_LOCKS should be 6
  (bnc#1012628).
- dm integrity: don't store cipher request on the stack
  (bnc#1012628).
- dm crypt: fix crash by adding missing check for auth key size
  (bnc#1012628).
- dm crypt: wipe kernel key copy after IV initialization
  (bnc#1012628).
- dm crypt: fix error return code in crypt_ctr() (bnc#1012628).
- x86: Use __nostackprotect for sme_encrypt_kernel (bnc#1012628).
- alpha/PCI: Fix noname IRQ level detection (bnc#1012628).
- MIPS: CM: Drop WARN_ON(vp != 0) (bnc#1012628).
- KVM: arm/arm64: Check pagesize when allocating a hugepage at
  Stage 2 (bnc#1012628).
- arm64: KVM: Fix SMCCC handling of unimplemented SMC/HVC calls
  (bnc#1012628).
- x86/mce: Make machine check speculation protected (bnc#1012628).
- retpoline: Introduce start/end markers of indirect thunk
  (bnc#1012628).
- kprobes/x86: Blacklist indirect thunk functions for kprobes
  (bnc#1012628).
- kprobes/x86: Disable optimizing on the function jumps to
  indirect thunk (bnc#1012628).
- x86/pti: Document fix wrong index (bnc#1012628).
- x86/retpoline: Optimize inline assembler for vmexit_fill_RSB
  (bnc#1012628).
- x86/mm: Rework wbinvd, hlt operation in stop_this_cpu()
  (bnc#1012628).
- mm, page_vma_mapped: Drop faulty pointer arithmetics in
  check_pte() (bnc#1012628).
- net: mvpp2: do not disable GMAC padding (bnc#1012628).
- MIPS: AR7: ensure the port type's FCR value is used
  (bnc#1012628).
- Refresh
  patches.kernel.org/4.14.10-003-objtool-Move-kernel-headers-code-sync-check-t.patch.
- Refresh
  patches.suse/0001-x86-cpufeatures-Add-Intel-feature-bits-for-Speculati.patch.
- Refresh
  patches.suse/0002-x86-cpufeatures-Add-AMD-feature-bits-for-Prediction-.patch.
- commit fe1d712
* Mon Jan 22 2018 msuchanek@suse.de
- rpm/mkspec-dtb: Remove COPYING file (bsc#1076905).
  It conflicts between different versions of dtb package.
- commit 0e5fcf9
* Sun Jan 21 2018 jslaby@suse.cz
- x86/cpufeatures: Add Intel feature bits for Speculation Control
  (bsc#1068032 CVE-2017-5715).
- x86/cpufeatures: Add AMD feature bits for Prediction Command
  (bsc#1068032 CVE-2017-5715).
- x86/msr: Add definitions for new speculation control MSRs
  (bsc#1068032 CVE-2017-5715).
- module: Add retpoline tag to VERMAGIC (bsc#1068032
  CVE-2017-5715).
- x86/retpoline: Add LFENCE to the retpoline/RSB filling RSB
  macros (bsc#1068032 CVE-2017-5715).
- x86/retpoline: Fill RSB on context switch for affected CPUs
  (bsc#1068032 CVE-2017-5715).
- Refresh
  patches.suse/0005-x86-enter-MACROS-to-set-clear-IBRS-and-set-IBPB.patch.
- Refresh
  patches.suse/0008-x86-spec_ctrl-save-IBRS-MSR-value-in-paranoid_entry.patch.
- Refresh
  patches.suse/0009-x86-idle-Disable-IBRS-entering-idle-and-enable-it-on.patch.
- Refresh
  patches.suse/0010-x86-idle-Disable-IBRS-when-offlining-cpu-and-re-enab.patch.
- Refresh
  patches.suse/0011-x86-mm-Set-IBPB-upon-context-switch.patch.
- Refresh
  patches.suse/0012-x86-mm-Only-set-IBPB-when-the-new-thread-cannot-ptra.patch.
- Refresh
  patches.suse/0017-x86-kvm-Set-IBPB-when-switching-VM.patch.
- Refresh
  patches.suse/0018-x86-kvm-Toggle-IBRS-on-VM-entry-and-exit.patch.
- Refresh
  patches.suse/0021-x86-spec_ctrl-Add-sysctl-knobs-to-enable-disable-SPE.patch.
- Refresh
  patches.suse/0023-x86-Move-IBRS-IBPB-feature-detection-to-scattered.c.patch.
- Refresh
  patches.suse/0028-x86-svm-Set-IBPB-when-running-a-different-VCPU.patch.
- Refresh
  patches.suse/0029-kvm-svm-add-MSR_IA32_SPEC_CTRL-and-MSR_IA32_PRED_CMD.patch.
- Refresh patches.suse/0030-Use-the-ibrs_inuse-variable.patch.
- Refresh
  patches.suse/0032-kvm-vmx-add-MSR_IA32_SPEC_CTRL-and-MSR_IA32_PRED_CMD.patch.
- Refresh
  patches.suse/0034-Remove-the-code-that-uses-MSR-save-restore-list.patch.
- Refresh patches.suse/0035-Use-the-ibpb_inuse-variable.patch.
- Refresh
  patches.suse/0037-Set-IBPB-when-running-a-different-VCPU.patch.
- Delete
  patches.suse/0001-x86-feature-Enable-the-x86-feature-to-control-Specul.patch.
- Delete
  patches.suse/0002-x86-cpufeature-Add-X86_FEATURE_IA32_ARCH_CAPS-and-X8.patch.
- Delete
  patches.suse/0003-x86-Add-STIBP-feature-enumeration.patch.
- commit 5790c9a
* Thu Jan 18 2018 jslaby@suse.cz
- Update config files (bsc#1068032 CVE-2017-5715).
  Enable RETPOLINE -- the compiler is capable of them already.
- commit 5d5345e
* Wed Jan 17 2018 rjschwei@suse.com
- kernel-obs-build.spec.in: enable xfs module
  This allows the public cloud team to build images with XFS
  as root filesystem
- commit 95a2d6f
* Wed Jan 17 2018 msuchanek@suse.de
- macros.kernel-source: pass -f properly in module subpackage (boo#1076393).
- commit 66bd9b8
* Wed Jan 17 2018 jslaby@suse.cz
- Linux 4.14.14 (bnc#1012628).
- Delete
  patches.kernel.org/4.14.14-053-Revert-Revert-xfrm-Fix-stack-out-of-bounds-re.patch.
- commit eef6178
* Tue Jan 16 2018 tiwai@suse.de
- ALSA: seq: Make ioctls race-free (CVE-2018-1000004,bsc#1076017).
- commit 2134862
* Tue Jan 16 2018 jslaby@suse.cz
- ORC: fix retpolines segfaults (bnc#1068032 CVE-2017-5715).
- commit 470cac2
* Tue Jan 16 2018 jslaby@suse.cz
- dm bufio: fix shrinker scans when (nr_to_scan < retain_target)
  (bnc#1012628).
- KVM: Fix stack-out-of-bounds read in write_mmio (bnc#1012628).
- can: vxcan: improve handling of missing peer name attribute
  (bnc#1012628).
- can: gs_usb: fix return value of the "set_bittiming" callback
  (bnc#1012628).
- IB/srpt: Disable RDMA access by the initiator (bnc#1012628).
- IB/srpt: Fix ACL lookup during login (bnc#1012628).
- MIPS: Validate PR_SET_FP_MODE prctl(2) requests against the
  ABI of the task (bnc#1012628).
- MIPS: Factor out NT_PRFPREG regset access helpers (bnc#1012628).
- MIPS: Guard against any partial write attempt with
  PTRACE_SETREGSET (bnc#1012628).
- MIPS: Consistently handle buffer counter with PTRACE_SETREGSET
  (bnc#1012628).
- MIPS: Fix an FCSR access API regression with NT_PRFPREG and MSA
  (bnc#1012628).
- MIPS: Also verify sizeof `elf_fpreg_t' with PTRACE_SETREGSET
  (bnc#1012628).
- MIPS: Disallow outsized PTRACE_SETREGSET NT_PRFPREG regset
  accesses (bnc#1012628).
- cgroup: fix css_task_iter crash on CSS_TASK_ITER_PROC
  (bnc#1012628).
- kvm: vmx: Scrub hardware GPRs at VM-exit (bnc#1012628
  bnc#1068032 CVE-2017-5715).
- platform/x86: wmi: Call acpi_wmi_init() later (bnc#1012628).
- iw_cxgb4: only call the cq comp_handler when the cq is armed
  (bnc#1012628).
- iw_cxgb4: atomically flush the qp (bnc#1012628).
- iw_cxgb4: only clear the ARMED bit if a notification is needed
  (bnc#1012628).
- iw_cxgb4: reflect the original WR opcode in drain cqes
  (bnc#1012628).
- iw_cxgb4: when flushing, complete all wrs in a chain
  (bnc#1012628).
- x86/acpi: Handle SCI interrupts above legacy space gracefully
  (bnc#1012628).
- ALSA: pcm: Remove incorrect snd_BUG_ON() usages (bnc#1012628).
- ALSA: pcm: Workaround for weird PulseAudio behavior on rewind
  error (bnc#1012628).
- ALSA: pcm: Add missing error checks in OSS emulation plugin
  builder (bnc#1012628).
- ALSA: pcm: Abort properly at pending signal in OSS read/write
  loops (bnc#1012628).
- ALSA: pcm: Allow aborting mutex lock at OSS read/write loops
  (bnc#1012628).
- ALSA: aloop: Release cable upon open error path (bnc#1012628).
- ALSA: aloop: Fix inconsistent format due to incomplete rule
  (bnc#1012628).
- ALSA: aloop: Fix racy hw constraints adjustment (bnc#1012628).
- x86/acpi: Reduce code duplication in mp_override_legacy_irq()
  (bnc#1012628).
- 8021q: fix a memory leak for VLAN 0 device (bnc#1012628).
- ip6_tunnel: disable dst caching if tunnel is dual-stack
  (bnc#1012628).
- net: core: fix module type in sock_diag_bind (bnc#1012628).
- phylink: ensure we report link down when LOS asserted
  (bnc#1012628).
- RDS: Heap OOB write in rds_message_alloc_sgs() (bnc#1012628).
- RDS: null pointer dereference in rds_atomic_free_op
  (bnc#1012628).
- net: fec: restore dev_id in the cases of probe error
  (bnc#1012628).
- net: fec: defer probe if regulator is not ready (bnc#1012628).
- net: fec: free/restore resource in related probe error pathes
  (bnc#1012628).
- sctp: do not retransmit upon FragNeeded if PMTU discovery is
  disabled (bnc#1012628).
- sctp: fix the handling of ICMP Frag Needed for too small MTUs
  (bnc#1012628).
- sh_eth: fix TSU resource handling (bnc#1012628).
- net: stmmac: enable EEE in MII, GMII or RGMII only
  (bnc#1012628).
- sh_eth: fix SH7757 GEther initialization (bnc#1012628).
- ipv6: fix possible mem leaks in ipv6_make_skb() (bnc#1012628).
- ethtool: do not print warning for applications using legacy API
  (bnc#1012628).
- mlxsw: spectrum_router: Fix NULL pointer deref (bnc#1012628).
- net/sched: Fix update of lastuse in act modules implementing
  stats_update (bnc#1012628).
- ipv6: sr: fix TLVs not being copied using setsockopt
  (bnc#1012628).
- mlxsw: spectrum: Relax sanity checks during enslavement
  (bnc#1012628).
- sfp: fix sfp-bus oops when removing socket/upstream
  (bnc#1012628).
- Revert "Revert "xfrm: Fix stack-out-of-bounds read in
  xfrm_state_find."" (bnc#1012628).
- membarrier: Disable preemption when calling
  smp_call_function_many() (bnc#1012628).
- crypto: algapi - fix NULL dereference in crypto_remove_spawns()
  (bnc#1012628).
- mmc: renesas_sdhi: Add MODULE_LICENSE (bnc#1012628).
- rbd: reacquire lock should update lock owner client id
  (bnc#1012628).
- rbd: set max_segments to USHRT_MAX (bnc#1012628).
- iwlwifi: pcie: fix DMA memory mapping / unmapping (bnc#1012628).
- x86/microcode/intel: Extend BDW late-loading with a revision
  check (bnc#1012628).
- KVM: x86: Add memory barrier on vmcs field lookup (bnc#1012628).
- KVM: PPC: Book3S PR: Fix WIMG handling under pHyp (bnc#1012628).
- KVM: PPC: Book3S HV: Drop prepare_done from struct
  kvm_resize_hpt (bnc#1012628).
- KVM: PPC: Book3S HV: Fix use after free in case of multiple
  resize requests (bnc#1012628).
- KVM: PPC: Book3S HV: Always flush TLB in
  kvmppc_alloc_reset_hpt() (bnc#1012628).
- drm/vmwgfx: Don't cache framebuffer maps (bnc#1012628).
- drm/vmwgfx: Potential off by one in vmw_view_add()
  (bnc#1012628).
- drm/i915/gvt: Clear the shadow page table entry after post-sync
  (bnc#1012628).
- drm/i915: Whitelist SLICE_COMMON_ECO_CHICKEN1 on Geminilake
  (bnc#1012628).
- drm/i915: Move init_clock_gating() back to where it was
  (bnc#1012628).
- drm/i915: Fix init_clock_gating for resume (bnc#1012628).
- bpf: arsh is not supported in 32 bit alu thus reject it
  (bnc#1012628).
- USB: serial: cp210x: add IDs for LifeScan OneTouch Verio IQ
  (bnc#1012628).
- USB: serial: cp210x: add new device ID ELV ALC 8xxx
  (bnc#1012628).
- usb: misc: usb3503: make sure reset is low for at least 100us
  (bnc#1012628).
- USB: fix usbmon BUG trigger (bnc#1012628).
- USB: UDC core: fix double-free in usb_add_gadget_udc_release
  (bnc#1012628).
- usbip: remove kernel addresses from usb device and urb debug
  msgs (bnc#1012628).
- usbip: fix vudc_rx: harden CMD_SUBMIT path to handle malicious
  input (bnc#1012628).
- usbip: vudc_tx: fix v_send_ret_submit() vulnerability to null
  xfer buffer (bnc#1012628).
- staging: android: ashmem: fix a race condition in
  ASHMEM_SET_SIZE ioctl (bnc#1012628).
- Bluetooth: Prevent stack info leak from the EFS element
  (bnc#1012628).
- uas: ignore UAS for Norelsys NS1068(X) chips (bnc#1012628).
- mux: core: fix double get_device() (bnc#1012628).
- kdump: write correct address of mem_section into vmcoreinfo
  (bnc#1012628).
- apparmor: fix ptrace label match when matching stacked labels
  (bnc#1012628).
- e1000e: Fix e1000_check_for_copper_link_ich8lan return value
  (bnc#1012628).
- x86/pti: Unbreak EFI old_memmap (bnc#1012628).
- x86/Documentation: Add PTI description (bnc#1012628).
- x86/cpufeatures: Add X86_BUG_SPECTRE_V[12] (bnc#1012628).
- sysfs/cpu: Add vulnerability folder (bnc#1012628).
- x86/cpu: Implement CPU vulnerabilites sysfs functions
  (bnc#1012628).
- x86/tboot: Unbreak tboot with PTI enabled (bnc#1012628).
- x86/mm/pti: Remove dead logic in pti_user_pagetable_walk*()
  (bnc#1012628).
- sysfs/cpu: Fix typos in vulnerability documentation
  (bnc#1012628).
- x86/alternatives: Fix optimize_nops() checking (bnc#1012628).
- x86/pti: Make unpoison of pgd for trusted boot work for real
  (bnc#1012628).
- objtool: Detect jumps to retpoline thunks (bnc#1012628).
- objtool: Allow alternatives to be ignored (bnc#1012628).
- x86/retpoline: Add initial retpoline support (bnc#1012628
  bnc#1068032 CVE-2017-5715).
- x86/spectre: Add boot time option to select Spectre v2
  mitigation (bnc#1012628).
- x86/retpoline/crypto: Convert crypto assembler indirect jumps
  (bnc#1012628).
- x86/retpoline/entry: Convert entry assembler indirect jumps
  (bnc#1012628).
- x86/retpoline/ftrace: Convert ftrace assembler indirect jumps
  (bnc#1012628).
- x86/retpoline/hyperv: Convert assembler indirect jumps
  (bnc#1012628).
- x86/retpoline/xen: Convert Xen hypercall indirect jumps
  (bnc#1012628).
- x86/retpoline/checksum32: Convert assembler indirect jumps
  (bnc#1012628).
- x86/retpoline/irq32: Convert assembler indirect jumps
  (bnc#1012628).
- x86/retpoline: Fill return stack buffer on vmexit (bnc#1012628
  bnc#1068032 CVE-2017-5715).
- selftests/x86: Add test_vsyscall (bnc#1012628).
- x86/pti: Fix !PCID and sanitize defines (bnc#1012628).
- security/Kconfig: Correct the Documentation reference for PTI
  (bnc#1012628).
- x86,perf: Disable intel_bts when PTI (bnc#1012628).
- x86/retpoline: Remove compile time warning (bnc#1012628).
- Update config files.
- Refresh
  patches.suse/0007-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- Refresh
  patches.suse/0016-x86-kvm-add-MSR_IA32_SPEC_CTRL-and-MSR_IA32_PRED_CMD.patch.
- Refresh
  patches.suse/0029-kvm-svm-add-MSR_IA32_SPEC_CTRL-and-MSR_IA32_PRED_CMD.patch.
- Refresh
  patches.suse/0031-Reverting-the-commit-e5247c4f209530-to-replace.patch.
- Refresh
  patches.suse/0032-kvm-vmx-add-MSR_IA32_SPEC_CTRL-and-MSR_IA32_PRED_CMD.patch.
- Delete patches.suse/0019-x86-kvm-Pad-RSB-on-VM-transition.patch.
- Delete
  patches.suse/0020-x86-kvm-clear-registers-on-VM-exit.patch.
- Delete
  patches.suse/0026-Revert-x86-kvm-Pad-RSB-on-VM-transition.patch.
- Delete patches.suse/0027-x86-kvm-Pad-RSB-on-VM-transition.patch.
- Delete
  patches.suse/0036-Clear-the-host-registers-after-setbe.patch.
- commit edd3e75
* Mon Jan 15 2018 jeffm@suse.com
- Update to 4.15-rc8.
- Eliminated 3 patches.
- Config changes:
  - Security:
  - BPF_JIT_ALWAYS_ON=y
  - RETPOLINE=n (depends on gcc with -mindirect-branch=thunk-extern)
- commit 05e4405
* Fri Jan 12 2018 jslaby@suse.cz
- bpf, array: fix overflow in max_entries and undefined behavior
  in index_mask (bsc#1068032 CVE-2017-5753).
- commit 3283516
* Fri Jan 12 2018 jslaby@suse.cz
- Refresh
  patches.suse/bpf-prevent-out-of-bounds-speculation.patch.
- Delete
  patches.suse/0004-bpf-prevent-speculative-execution-in-eBPF-interprete.patch.
  Update the upstream status of the former.
  And removed the latter as it has been just replaced by the proper
  upstream solution.
- commit 20ac09f
* Fri Jan 12 2018 jslaby@suse.cz
- bpf: prevent out-of-bounds speculation (bsc#1068032
  CVE-2017-5753).
- commit 0eca303
* Thu Jan 11 2018 matwey.kornilov@gmail.com
- config: arm64: Enable Aardvark PCIe controller
  Aardvark PCIe controller is a part of Marvel Armada 3700 SoC.
  This option is required to support PCIe for JeOS-espressobin.
- commit b0bb655
* Thu Jan 11 2018 tiwai@suse.de
- drm/nouveau/disp/gf119: add missing drive vfunc ptr
  (bsc#1075613).
- commit 80f2eaf
* Thu Jan 11 2018 lpechacek@suse.com
- rpm/kernel-binary.spec.in: more specific kGraft Provides: (fate#323682)
  Follow openSUSE packaging practices described at
  https://en.opensuse.org/openSUSE:Package_dependencies#Renaming_a_package.
- commit 050081b
* Thu Jan 11 2018 mkubecek@suse.cz
- Update
  patches.kernel.org/4.14.9-161-bpf-fix-branch-pruning-logic.patch
  references (add CVE-2017-17862 CVE-2017-17864 bsc#1073928).
- Update
  patches.kernel.org/4.14.9-166-bpf-verifier-fix-bounds-calculation-on-BPF_RSH.patch
  references (add CVE-2017-17853 bsc#1073928).
- Update
  patches.kernel.org/4.14.9-167-bpf-fix-incorrect-sign-extension-in-check_alu_.patch
  references (add CVE-2017-16995 bsc#1073928).
- Update
  patches.kernel.org/4.14.9-168-bpf-fix-incorrect-tracking-of-register-size-tr.patch
  references (add CVE-2017-16996 bsc#1073928).
- Update
  patches.kernel.org/4.14.9-169-bpf-fix-32-bit-ALU-op-verification.patch
  references (add CVE-2017-17852 bsc#1073928).
- Update
  patches.kernel.org/4.14.9-170-bpf-fix-missing-error-return-in-check_stack_bo.patch
  references (add CVE-2017-17857 bsc#1073928).
- Update
  patches.kernel.org/4.14.9-171-bpf-force-strict-alignment-checks-for-stack-po.patch
  references (add CVE-2017-17856 bsc#1073928).
- Update
  patches.kernel.org/4.14.9-172-bpf-don-t-prune-branches-when-a-scalar-is-repl.patch
  references (add CVE-2017-17855 bsc#1073928).
- Update
  patches.kernel.org/4.14.9-173-bpf-fix-integer-overflows.patch
  references (add CVE-2017-17854 bsc#1073928).
- Update
  patches.kernel.org/4.14.9-174-selftests-bpf-add-tests-for-recent-bugfixes.patch
  references (add bsc#1073928).
- commit 4a4cd97
* Thu Jan 11 2018 mkubecek@suse.cz
- Fix mainline reference:
  patches.kernel.org/4.14.9-170-bpf-fix-missing-error-return-in-check_stack_bo.patch.
- commit 98662d2
* Thu Jan 11 2018 mkubecek@suse.cz
- Update
  patches.kernel.org/4.14.11-084-net-Fix-double-free-and-memory-corruption-in-.patch
  references (add CVE-2017-15129 bsc#1074839).
- commit 7acebb3
* Wed Jan 10 2018 jslaby@suse.cz
- x86/cpu/AMD: Make LFENCE a serializing instruction (bsc#1068032
  CVE-2017-5754).
- x86/cpu/AMD: Use LFENCE_RDTSC in preference to MFENCE_RDTSC
  (bsc#1068032 CVE-2017-5754).
- Delete
  patches.suse/0001-x86-cpu-AMD-Make-the-LFENCE-instruction-serialized.patch.
- Delete
  patches.suse/0002-x86-cpu-AMD-Remove-now-unused-definition-of-MFENCE_R.patch.
  Use the variants from upstream (tip tree).
- commit 33b16eb
* Wed Jan 10 2018 jslaby@suse.cz
- Linux 4.14.13 (bnc#1012628).
- x86/mm: Set MODULES_END to 0xffffffffff000000 (bnc#1012628).
- x86/mm: Map cpu_entry_area at the same place on 4/5 level
  (bnc#1012628).
- x86/kaslr: Fix the vaddr_end mess (bnc#1012628).
- x86/events/intel/ds: Use the proper cache flush method for
  mapping ds buffers (bnc#1012628).
- x86/tlb: Drop the _GPL from the cpu_tlbstate export
  (bnc#1012628).
- x86/alternatives: Add missing '\n' at end of ALTERNATIVE inline
  asm (bnc#1012628).
- x86/pti: Rename BUG_CPU_INSECURE to BUG_CPU_MELTDOWN
  (bnc#1012628).
- kernel/acct.c: fix the acct->needcheck check in
  check_free_space() (bnc#1012628).
- mm/mprotect: add a cond_resched() inside change_pmd_range()
  (bnc#1012628).
- mm/sparse.c: wrong allocation for mem_section (bnc#1012628).
- userfaultfd: clear the vma->vm_userfaultfd_ctx if
  UFFD_EVENT_FORK fails (bnc#1012628).
- btrfs: fix refcount_t usage when deleting btrfs_delayed_nodes
  (bnc#1012628).
- efi/capsule-loader: Reinstate virtual capsule mapping
  (bnc#1012628).
- crypto: n2 - cure use after free (bnc#1012628).
- crypto: chacha20poly1305 - validate the digest size
  (bnc#1012628).
- crypto: pcrypt - fix freeing pcrypt instances (bnc#1012628).
- crypto: chelsio - select CRYPTO_GF128MUL (bnc#1012628).
- drm/i915: Disable DC states around GMBUS on GLK (bnc#1012628).
- drm/i915: Apply Display WA #1183 on skl, kbl, and cfl
  (bnc#1012628).
- sunxi-rsb: Include OF based modalias in device uevent
  (bnc#1012628).
- fscache: Fix the default for fscache_maybe_release_page()
  (bnc#1012628).
- x86 / CPU: Avoid unnecessary IPIs in arch_freq_get_on_cpu()
  (bnc#1012628).
- x86 / CPU: Always show current CPU frequency in /proc/cpuinfo
  (bnc#1012628).
- kernel/signal.c: protect the traced SIGNAL_UNKILLABLE tasks
  from SIGKILL (bnc#1012628).
- kernel/signal.c: protect the SIGNAL_UNKILLABLE tasks from
  !sig_kernel_only() signals (bnc#1012628).
- kernel/signal.c: remove the no longer needed SIGNAL_UNKILLABLE
  check in complete_signal() (bnc#1012628).
- iommu/arm-smmu-v3: Don't free page table ops twice
  (bnc#1012628).
- iommu/arm-smmu-v3: Cope with duplicated Stream IDs
  (bnc#1012628).
- ARC: uaccess: dont use "l" gcc inline asm constraint modifier
  (bnc#1012628).
- powerpc/mm: Fix SEGV on mapped region to return SEGV_ACCERR
  (bnc#1012628).
- Input: elantech - add new icbody type 15 (bnc#1012628).
- apparmor: fix regression in mount mediation when feature set
  is pinned (bnc#1012628).
- parisc: Fix alignment of pa_tlb_lock in assembly on 32-bit
  SMP kernel (bnc#1012628).
- parisc: qemu idle sleep support (bnc#1012628).
- mtd: nand: pxa3xx: Fix READOOB implementation (bnc#1012628).
- KVM: s390: fix cmma migration for multiple memory slots
  (bnc#1012628).
- KVM: s390: prevent buffer overrun on memory hotplug during
  migration (bnc#1012628).
- commit bd444a0
* Tue Jan  9 2018 jslaby@suse.cz
- Refresh
  patches.suse/0007-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- Refresh
  patches.suse/0013-x86-entry-Stuff-RSB-for-entry-to-kernel-for-non-SMEP.patch.
- Refresh
  patches.suse/0015-x86-syscall-Clear-unused-extra-registers-on-32-bit-c.patch.
  Fix double fault in 32bit binaries (bnc#1074869, bnc#1074918,
  bnc#1074920, bnc#1074921, bnc#1075018, bnc#1075034)
- commit f4b3cf0
* Mon Jan  8 2018 msuchanek@suse.de
- kernel-obs-build.spec.in: add --no-hostonly-cmdline to dracut invocation (boo#1062303).
  call dracut with --no-hostonly-cmdline to avoid the random rootfs UUID
  being added into the initrd's /etc/cmdline.d/95root-dev.conf
- commit da5186f
* Mon Jan  8 2018 jeffm@suse.com
- Update to 4.15-rc7.
- Eliminated 1 patch.
- commit b07c570
* Sat Jan  6 2018 jslaby@suse.cz
- rpm/constraints.in: lower kernel-syzkaller's mem requirements
  OBS now reports that it needs only around 2G, so lower the limit to
  8G, so that more compliant workers can be used.
- commit a73399a
* Fri Jan  5 2018 jslaby@suse.cz
- Linux 4.14.12 (bnc#1012628).
- exec: Weaken dumpability for secureexec (bnc#1012628).
- capabilities: fix buffer overread on very short xattr
  (bnc#1012628).
- x86/cpu, x86/pti: Do not enable PTI on AMD processors
  (bnc#1012628).
- x86/pti: Make sure the user/kernel PTEs match (bnc#1012628).
- x86/dumpstack: Fix partial register dumps (bnc#1012628).
- x86/dumpstack: Print registers for first stack frame
  (bnc#1012628).
- x86/pti: Switch to kernel CR3 at early in entry_SYSCALL_compat()
  (bnc#1012628).
- x86/process: Define cpu_tss_rw in same section as declaration
  (bnc#1012628).
- Revert "xfrm: Fix stack-out-of-bounds read in
  xfrm_state_find." (bnc#1012628).
- rtc: m41t80: m41t80_sqw_set_rate should return 0 on success
  (bnc#1012628).
- rtc: m41t80: fix m41t80_sqw_round_rate return value
  (bnc#1012628).
- rtc: m41t80: avoid i2c read in m41t80_sqw_recalc_rate
  (bnc#1012628).
- rtc: m41t80: avoid i2c read in m41t80_sqw_is_prepared
  (bnc#1012628).
- rtc: m41t80: remove unneeded checks from m41t80_sqw_set_rate
  (bnc#1012628).
- Refresh
  patches.suse/0002-x86-stacktrace-make-clear-the-success-paths.patch.
- Refresh
  patches.suse/0007-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- Refresh
  patches.suse/0013-x86-entry-Stuff-RSB-for-entry-to-kernel-for-non-SMEP.patch.
- Refresh
  patches.suse/0015-x86-syscall-Clear-unused-extra-registers-on-32-bit-c.patch.
- commit 3cf399e
* Thu Jan  4 2018 jslaby@suse.cz
- Refresh
  patches.suse/0027-x86-kvm-Pad-RSB-on-VM-transition.patch.
- Refresh
  patches.suse/0031-Reverting-the-commit-e5247c4f209530-to-replace.patch.
  Fix i386 build.
- commit c36893f
* Wed Jan  3 2018 jslaby@suse.cz
- Set IBPB when running a different VCPU (bnc#1068032
  CVE-2017-5715).
- Clear the host registers after setbe (bnc#1068032
  CVE-2017-5715).
- Use the ibpb_inuse variable (bnc#1068032 CVE-2017-5715).
- Remove the code that uses MSR save/restore list (bnc#1068032
  CVE-2017-5715).
- KVM: x86: add SPEC_CTRL to MSR and CPUID lists (bnc#1068032
  CVE-2017-5715).
- kvm: vmx: add MSR_IA32_SPEC_CTRL and MSR_IA32_PRED_CMD
  (bnc#1068032 CVE-2017-5715).
- Reverting the commit e5247c4f209530 to replace (bnc#1068032
  CVE-2017-5715).
- Use the "ibrs_inuse" variable (bnc#1068032 CVE-2017-5715).
- kvm: svm: add MSR_IA32_SPEC_CTRL and MSR_IA32_PRED_CMD
  (bnc#1068032 CVE-2017-5715).
- x86/svm: Set IBPB when running a different VCPU (bnc#1068032
  CVE-2017-5715).
- x86/kvm: Pad RSB on VM transition (bnc#1068032 CVE-2017-5715).
- Revert x86/kvm: Pad RSB on VM transition (bnc#1068032
  CVE-2017-5715).
- x86/cpu/AMD: Add speculative control support for AMD
  (bnc#1068032 CVE-2017-5715).
- x86/microcode: Recheck IBRS and IBPB feature on microcode reload
  (bnc#1068032 CVE-2017-5715).
- x86: Move IBRS/IBPB feature detection to scattered.c
  (bnc#1068032 CVE-2017-5715).
- x86/spec_ctrl: Add lock to serialize changes to ibrs and ibpb
  control (bnc#1068032 CVE-2017-5715).
- x86/spec_ctrl: Add sysctl knobs to enable/disable SPEC_CTRL
  feature (bnc#1068032 CVE-2017-5715).
- x86/kvm: clear registers on VM exit (bnc#1068032 CVE-2017-5715).
- x86/kvm: Pad RSB on VM transition (bnc#1068032 CVE-2017-5715).
- x86/kvm: Toggle IBRS on VM entry and exit (bnc#1068032
  CVE-2017-5715).
- x86/kvm: Set IBPB when switching VM (bnc#1068032 CVE-2017-5715).
- x86/kvm: add MSR_IA32_SPEC_CTRL and MSR_IA32_PRED_CMD to kvm
  (bnc#1068032 CVE-2017-5715).
- x86/syscall: Clear unused extra registers on 32-bit compatible
  syscall entrance (bnc#1068032 CVE-2017-5715).
- x86/syscall: Clear unused extra registers on syscall entrance
  (bnc#1068032 CVE-2017-5715).
- x86/entry: Stuff RSB for entry to kernel for non-SMEP platform
  (bnc#1068032 CVE-2017-5715).
- x86/mm: Only set IBPB when the new thread cannot ptrace current
  thread (bnc#1068032 CVE-2017-5715).
- x86/mm: Set IBPB upon context switch (bnc#1068032
  CVE-2017-5715).
- x86/idle: Disable IBRS when offlining cpu and re-enable on
  wakeup (bnc#1068032 CVE-2017-5715).
- x86/idle: Disable IBRS entering idle and enable it on wakeup
  (bnc#1068032 CVE-2017-5715).
- x86/spec_ctrl: save IBRS MSR value in paranoid_entry
  (bnc#1068032 CVE-2017-5715).
- x86/enter: Use IBRS on syscall and interrupts (bnc#1068032
  CVE-2017-5715).
- x86: Add macro that does not save rax, rcx, rdx on stack to
  disable IBRS (bnc#1068032 CVE-2017-5715).
- x86/enter: MACROS to set/clear IBRS and set IBPB (bnc#1068032
  CVE-2017-5715).
- x86/feature: Report presence of IBPB and IBRS control
  (bnc#1068032 CVE-2017-5715).
- x86: Add STIBP feature enumeration (bnc#1068032 CVE-2017-5715).
- x86/cpufeature: Add X86_FEATURE_IA32_ARCH_CAPS and
  X86_FEATURE_IBRS_ATT (bnc#1068032 CVE-2017-5715).
- x86/feature: Enable the x86 feature to control Speculation
  (bnc#1068032 CVE-2017-5715).
- commit 816f713
* Wed Jan  3 2018 jslaby@suse.cz
- userns: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- udf: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- net: mpls: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- fs: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- ipv6: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- ipv4: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- Thermal/int340x: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- cw1200: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- qla2xxx: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- p54: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- carl9170: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- uvcvideo: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- x86, bpf, jit: prevent speculative execution when JIT is enabled
  (bnc#1068032 CVE-2017-5753).
- bpf: prevent speculative execution in eBPF interpreter
  (bnc#1068032 CVE-2017-5753).
- locking/barriers: introduce new observable speculation barrier
  (bnc#1068032 CVE-2017-5753).
- x86/cpu/AMD: Remove now unused definition of MFENCE_RDTSC
  feature (bnc#1068032 CVE-2017-5753).
- x86/cpu/AMD: Make the LFENCE instruction serialized (bnc#1068032
  CVE-2017-5753).
- commit cf46932
* Wed Jan  3 2018 jslaby@suse.cz
- Linux 4.14.11 (bnc#1012628).
- tracing: Remove extra zeroing out of the ring buffer page
  (bnc#1012628).
- tracing: Fix possible double free on failure of allocating
  trace buffer (bnc#1012628).
- tracing: Fix crash when it fails to alloc ring buffer
  (bnc#1012628).
- x86/cpufeatures: Add X86_BUG_CPU_INSECURE (bnc#1012628).
- x86/mm/pti: Disable global pages if PAGE_TABLE_ISOLATION=y
  (bnc#1012628).
- x86/mm/pti: Prepare the x86/entry assembly code for entry/exit
  CR3 switching (bnc#1012628).
- x86/mm/pti: Add infrastructure for page table isolation
  (bnc#1012628).
- x86/pti: Add the pti= cmdline option and documentation
  (bnc#1012628).
- x86/mm/pti: Add mapping helper functions (bnc#1012628).
- x86/mm/pti: Allow NX poison to be set in p4d/pgd (bnc#1012628).
- x86/mm/pti: Allocate a separate user PGD (bnc#1012628).
- x86/mm/pti: Populate user PGD (bnc#1012628).
- x86/mm/pti: Add functions to clone kernel PMDs (bnc#1012628).
- x86/mm/pti: Force entry through trampoline when PTI active
  (bnc#1012628).
- x86/mm/pti: Share cpu_entry_area with user space page tables
  (bnc#1012628).
- x86/entry: Align entry text section to PMD boundary
  (bnc#1012628).
- x86/mm/pti: Share entry text PMD (bnc#1012628).
- x86/mm/pti: Map ESPFIX into user space (bnc#1012628).
- x86/cpu_entry_area: Add debugstore entries to cpu_entry_area
  (bnc#1012628).
- x86/events/intel/ds: Map debug buffers in cpu_entry_area
  (bnc#1012628).
- x86/mm/64: Make a full PGD-entry size hole in the memory map
  (bnc#1012628).
- x86/pti: Put the LDT in its own PGD if PTI is on (bnc#1012628).
- x86/pti: Map the vsyscall page if needed (bnc#1012628).
- x86/mm: Allow flushing for future ASID switches (bnc#1012628).
- x86/mm: Abstract switching CR3 (bnc#1012628).
- x86/mm: Use/Fix PCID to optimize user/kernel switches
  (bnc#1012628).
- x86/mm: Optimize RESTORE_CR3 (bnc#1012628).
- x86/mm: Use INVPCID for __native_flush_tlb_single()
  (bnc#1012628).
- x86/mm: Clarify the whole ASID/kernel PCID/user PCID naming
  (bnc#1012628).
- x86/dumpstack: Indicate in Oops whether PTI is configured and
  enabled (bnc#1012628).
- x86/mm/pti: Add Kconfig (bnc#1012628).
- x86/mm/dump_pagetables: Add page table directory to the debugfs
  VFS hierarchy (bnc#1012628).
- x86/mm/dump_pagetables: Check user space page table for WX pages
  (bnc#1012628).
- x86/mm/dump_pagetables: Allow dumping current pagetables
  (bnc#1012628).
- x86/ldt: Make the LDT mapping RO (bnc#1012628).
- ring-buffer: Mask out the info bits when returning buffer page
  length (bnc#1012628).
- ring-buffer: Do no reuse reader page if still in use
  (bnc#1012628).
- iw_cxgb4: Only validate the MSN for successful completions
  (bnc#1012628).
- ASoC: codecs: msm8916-wcd: Fix supported formats (bnc#1012628).
- ASoC: wm_adsp: Fix validation of firmware and coeff lengths
  (bnc#1012628).
- ASoC: da7218: fix fix child-node lookup (bnc#1012628).
- ASoC: fsl_ssi: AC'97 ops need regmap, clock and cleaning up
  on failure (bnc#1012628).
- ASoC: twl4030: fix child-node lookup (bnc#1012628).
- ASoC: tlv320aic31xx: Fix GPIO1 register definition
  (bnc#1012628).
- gpio: fix "gpio-line-names" property retrieval (bnc#1012628).
- IB/hfi: Only read capability registers if the capability exists
  (bnc#1012628).
- IB/mlx5: Serialize access to the VMA list (bnc#1012628).
- IB/uverbs: Fix command checking as part of
  ib_uverbs_ex_modify_qp() (bnc#1012628).
- IB/core: Verify that QP is security enabled in create and
  destroy (bnc#1012628).
- ALSA: hda: Drop useless WARN_ON() (bnc#1012628).
- ALSA: hda - Add MIC_NO_PRESENCE fixup for 2 HP machines
  (bnc#1012628).
- ALSA: hda - change the location for one mic on a Lenovo machine
  (bnc#1012628).
- ALSA: hda - fix headset mic detection issue on a Dell machine
  (bnc#1012628).
- ALSA: hda - Fix missing COEF init for ALC225/295/299
  (bnc#1012628).
- cpufreq: schedutil: Use idle_calls counter of the remote CPU
  (bnc#1012628).
- block: fix blk_rq_append_bio (bnc#1012628).
- block: don't let passthrough IO go into .make_request_fn()
  (bnc#1012628).
- kbuild: add '-fno-stack-check' to kernel build options
  (bnc#1012628).
- ipv4: igmp: guard against silly MTU values (bnc#1012628).
- ipv6: mcast: better catch silly mtu values (bnc#1012628).
- net: fec: unmap the xmit buffer that are not transferred by DMA
  (bnc#1012628).
- net: igmp: Use correct source address on IGMPv3 reports
  (bnc#1012628).
- net: qmi_wwan: add Sierra EM7565 1199:9091 (bnc#1012628).
- net: reevalulate autoflowlabel setting after sysctl setting
  (bnc#1012628).
- ptr_ring: add barriers (bnc#1012628).
- RDS: Check cmsg_len before dereferencing CMSG_DATA
  (bnc#1012628).
- tcp_bbr: record "full bw reached" decision in new
  full_bw_reached bit (bnc#1012628).
- tcp md5sig: Use skb's saddr when replying to an incoming segment
  (bnc#1012628).
- tg3: Fix rx hang on MTU change with 5717/5719 (bnc#1012628).
- tcp_bbr: reset full pipe detection on loss recovery undo
  (bnc#1012628).
- tcp_bbr: reset long-term bandwidth sampling on loss recovery
  undo (bnc#1012628).
- s390/qeth: apply takeover changes when mode is toggled
  (bnc#1012628).
- s390/qeth: don't apply takeover changes to RXIP (bnc#1012628).
- s390/qeth: lock IP table while applying takeover changes
  (bnc#1012628).
- s390/qeth: update takeover IPs after configuration change
  (bnc#1012628).
- net: ipv4: fix for a race condition in raw_sendmsg
  (bnc#1012628).
- net: mvmdio: disable/unprepare clocks in EPROBE_DEFER case
  (bnc#1012628).
- sctp: Replace use of sockets_allocated with specified macro
  (bnc#1012628).
- adding missing rcu_read_unlock in ipxip6_rcv (bnc#1012628).
- ip6_gre: fix device features for ioctl setup (bnc#1012628).
- ipv4: Fix use-after-free when flushing FIB tables (bnc#1012628).
- net: bridge: fix early call to br_stp_change_bridge_id and
  plug newlink leaks (bnc#1012628).
- net: Fix double free and memory corruption in get_net_ns_by_id()
  (bnc#1012628).
- net: phy: micrel: ksz9031: reconfigure autoneg after phy
  autoneg workaround (bnc#1012628).
- sock: free skb in skb_complete_tx_timestamp on error
  (bnc#1012628).
- tcp: invalidate rate samples during SACK reneging (bnc#1012628).
- net/mlx5: Fix rate limit packet pacing naming and struct
  (bnc#1012628).
- net/mlx5e: Fix possible deadlock of VXLAN lock (bnc#1012628).
- net/mlx5e: Fix features check of IPv6 traffic (bnc#1012628).
- net/mlx5e: Add refcount to VXLAN structure (bnc#1012628).
- net/mlx5e: Prevent possible races in VXLAN control flow
  (bnc#1012628).
- net/mlx5: Fix error flow in CREATE_QP command (bnc#1012628).
- openvswitch: Fix pop_vlan action for double tagged frames
  (bnc#1012628).
- sfc: pass valid pointers from efx_enqueue_unwind (bnc#1012628).
- net: dsa: bcm_sf2: Clear IDDQ_GLOBAL_PWR bit for PHY
  (bnc#1012628).
- s390/qeth: fix error handling in checksum cmd callback
  (bnc#1012628).
- sctp: make sure stream nums can match optlen in
  sctp_setsockopt_reset_streams (bnc#1012628).
- tipc: fix hanging poll() for stream sockets (bnc#1012628).
- mlxsw: spectrum: Disable MAC learning for ovs port
  (bnc#1012628).
- tcp: fix potential underestimation on rcv_rtt (bnc#1012628).
- net: phy: marvell: Limit 88m1101 autoneg errata to 88E1145 as
  well (bnc#1012628).
- ipv6: Honor specified parameters in fibmatch lookup
  (bnc#1012628).
- tcp: refresh tcp_mstamp from timers callbacks (bnc#1012628).
- net/mlx5: FPGA, return -EINVAL if size is zero (bnc#1012628).
- vxlan: restore dev->mtu setting based on lower device
  (bnc#1012628).
- net: sched: fix static key imbalance in case of
  ingress/clsact_init error (bnc#1012628).
- bnxt_en: Fix sources of spurious netpoll warnings (bnc#1012628).
- phylink: ensure the PHY interface mode is appropriately set
  (bnc#1012628).
- phylink: ensure AN is enabled (bnc#1012628).
- ipv4: fib: Fix metrics match when deleting a route
  (bnc#1012628).
- ipv6: set all.accept_dad to 0 by default (bnc#1012628).
- Revert "mlx5: move affinity hints assignments to generic code"
  (bnc#1012628).
- skbuff: orphan frags before zerocopy clone (bnc#1012628).
- skbuff: skb_copy_ubufs must release uarg even without user frags
  (bnc#1012628).
- skbuff: in skb_copy_ubufs unclone before releasing zerocopy
  (bnc#1012628).
- sparc64: repair calling incorrect hweight function from stubs
  (bnc#1012628).
- usbip: fix usbip bind writing random string after command in
  match_busid (bnc#1012628).
- usbip: prevent leaking socket pointer address in messages
  (bnc#1012628).
- usbip: stub: stop printing kernel pointer addresses in messages
  (bnc#1012628).
- usbip: vhci: stop printing kernel pointer addresses in messages
  (bnc#1012628).
- USB: chipidea: msm: fix ulpi-node lookup (bnc#1012628).
- USB: serial: ftdi_sio: add id for Airbus DS P8GR (bnc#1012628).
- USB: serial: qcserial: add Sierra Wireless EM7565 (bnc#1012628).
- USB: serial: option: add support for Telit ME910 PID 0x1101
  (bnc#1012628).
- USB: serial: option: adding support for YUGA CLM920-NC5
  (bnc#1012628).
- usb: Add device quirk for Logitech HD Pro Webcam C925e
  (bnc#1012628).
- usb: add RESET_RESUME for ELSA MicroLink 56K (bnc#1012628).
- USB: Fix off by one in type-specific length check of BOS SSP
  capability (bnc#1012628).
- usb: xhci: Add XHCI_TRUST_TX_LENGTH for Renesas uPD720201
  (bnc#1012628).
- timers: Use deferrable base independent of base::nohz_active
  (bnc#1012628).
- timers: Invoke timer_start_debug() where it makes sense
  (bnc#1012628).
- timers: Reinitialize per cpu bases on hotplug (bnc#1012628).
- binder: fix proc->files use-after-free (bnc#1012628).
- phy: tegra: fix device-tree node lookups (bnc#1012628).
- drivers: base: cacheinfo: fix cache type for non-architected
  system cache (bnc#1012628).
- staging: android: ion: Fix dma direction for
  dma_sync_sg_for_cpu/device (bnc#1012628).
- nohz: Prevent a timer interrupt storm in
  tick_nohz_stop_sched_tick() (bnc#1012628).
- x86/smpboot: Remove stale TLB flush invocations (bnc#1012628).
- x86/mm: Remove preempt_disable/enable() from
  __native_flush_tlb() (bnc#1012628).
- x86-32: Fix kexec with stack canary (CONFIG_CC_STACKPROTECTOR)
  (bnc#1012628).
- x86/espfix/64: Fix espfix double-fault handling on 5-level
  systems (bnc#1012628).
- x86/ldt: Plug memory leak in error path (bnc#1012628).
- x86/ldt: Make LDT pgtable free conditional (bnc#1012628).
- n_tty: fix EXTPROC vs ICANON interaction with TIOCINQ (aka
  FIONREAD) (bnc#1012628).
- tty: fix tty_ldisc_receive_buf() documentation (bnc#1012628).
- Update config files.
- commit 58fec0f
* Wed Jan  3 2018 jeffm@suse.com
- config: x86, PAGE_TABLE_ISOLATION=y (bsc#1068032).
- commit 4343d87
* Tue Jan  2 2018 jslaby@suse.cz
- userns: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- udf: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- net: mpls: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- fs: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- ipv6: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- ipv4: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- Thermal/int340x: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- cw1200: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- qla2xxx: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- p54: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- carl9170: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- uvcvideo: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- x86, bpf, jit: prevent speculative execution when JIT is enabled
  (bnc#1068032 CVE-2017-5753).
- bpf: prevent speculative execution in eBPF interpreter
  (bnc#1068032 CVE-2017-5753).
- locking/barriers: introduce new observable speculation barrier
  (bnc#1068032 CVE-2017-5753).
- x86/cpu/AMD: Remove now unused definition of MFENCE_RDTSC
  feature (bnc#1068032 CVE-2017-5753).
- x86/cpu/AMD: Make the LFENCE instruction serialized (bnc#1068032
  CVE-2017-5753).
- commit ee4aa62
* Tue Jan  2 2018 jeffm@suse.com
- Update to 4.15-rc6.
- Config changes:
  - x86: PAGE_TABLE_ISOLATION=n (default, performance)
- commit cd70bd8
* Mon Jan  1 2018 jslaby@suse.cz
- Update config files.
- i386: NR_CPUS 128->64
  - 7bbcbd3d1cd (x86/Kconfig: Limit NR_CPUS on 32-bit to a sane
    amount)
- commit 69201cf
* Fri Dec 29 2017 jslaby@suse.cz
- Linux 4.14.10 (bnc#1012628).
- Revert "ipmi_si: fix memory leak on new_smi" (bnc#1012628).
- net: mvneta: eliminate wrong call to handle rx descriptor error
  (bnc#1012628).
- net: mvneta: use proper rxq_number in loop on rx queues
  (bnc#1012628).
- net: mvneta: clear interface link status on port disable
  (bnc#1012628).
- libnvdimm, pfn: fix start_pad handling for aligned namespaces
  (bnc#1012628).
- libnvdimm, btt: Fix an incompatibility in the log layout
  (bnc#1012628).
- libnvdimm, dax: fix 1GB-aligned namespaces vs physical
  misalignment (bnc#1012628).
- drm/sun4i: Fix error path handling (bnc#1012628).
- drm/i915: Flush pending GTT writes before unbinding
  (bnc#1012628).
- powerpc/perf: Dereference BHRB entries safely (bnc#1012628).
- clk: sunxi: sun9i-mmc: Implement reset callback for reset
  controls (bnc#1012628).
- kvm: x86: fix RSM when PCID is non-zero (bnc#1012628).
- KVM: X86: Fix load RFLAGS w/o the fixed bit (bnc#1012628).
- KVM: MMU: Fix infinite loop when there is no available mmu page
  (bnc#1012628).
- KVM: PPC: Book3S HV: Fix pending_pri value in
  kvmppc_xive_get_icp() (bnc#1012628).
- KVM: PPC: Book3S: fix XIVE migration of pending interrupts
  (bnc#1012628).
- KVM: arm/arm64: Fix HYP unmapping going off limits
  (bnc#1012628).
- arm64: kvm: Prevent restoring stale PMSCR_EL1 for vcpu
  (bnc#1012628).
- pinctrl: cherryview: Mask all interrupts on Intel_Strago based
  systems (bnc#1012628).
- spi: a3700: Fix clk prescaling for coefficient over 15
  (bnc#1012628).
- spi: xilinx: Detect stall with Unknown commands (bnc#1012628).
- Revert "parisc: Re-enable interrupts early" (bnc#1012628).
- parisc: Hide Diva-built-in serial aux and graphics card
  (bnc#1012628).
- parisc: Fix indenting in puts() (bnc#1012628).
- parisc: Align os_hpmc_size on word boundary (bnc#1012628).
- block-throttle: avoid double charge (bnc#1012628).
- block: unalign call_single_data in struct request (bnc#1012628).
- PCI / PM: Force devices to D0 in pci_pm_thaw_noirq()
  (bnc#1012628).
- ALSA: usb-audio: Fix the missing ctl name suffix at parsing SU
  (bnc#1012628).
- ALSA: usb-audio: Add native DSD support for Esoteric D-05X
  (bnc#1012628).
- ALSA: hda - Add vendor id for Cannonlake HDMI codec
  (bnc#1012628).
- ALSA: hda/realtek - Fix Dell AIO LineOut issue (bnc#1012628).
- ALSA: rawmidi: Avoid racy info ioctl via ctl device
  (bnc#1012628).
- mfd: twl6040: Fix child-node lookup (bnc#1012628).
- mfd: twl4030-audio: Fix sibling-node lookup (bnc#1012628).
- mfd: cros ec: spi: Don't send first message too soon
  (bnc#1012628).
- crypto: af_alg - fix race accessing cipher request
  (bnc#1012628).
- crypto: af_alg - wait for data at beginning of recvmsg
  (bnc#1012628).
- crypto: mcryptd - protect the per-CPU queue with a lock
  (bnc#1012628).
- crypto: skcipher - set walk.iv for zero-length inputs
  (bnc#1012628).
- acpi, nfit: fix health event notification (bnc#1012628).
- ACPI: APEI / ERST: Fix missing error handling in erst_reader()
  (bnc#1012628).
- x86/cpu_entry_area: Prevent wraparound in
  setup_cpu_entry_area_ptes() on 32bit (bnc#1012628).
- init: Invoke init_espfix_bsp() from mm_init() (bnc#1012628).
- x86/cpu_entry_area: Move it out of the fixmap (bnc#1012628).
- x86/cpu_entry_area: Move it to a separate unit (bnc#1012628).
- x86/mm: Create asm/invpcid.h (bnc#1012628).
- x86/mm: Put MMU to hardware ASID translation in one place
  (bnc#1012628).
- x86/mm: Remove hard-coded ASID limit checks (bnc#1012628).
- x86/mm: Move the CR3 construction functions to tlbflush.h
  (bnc#1012628).
- x86/mm: Add comments to clarify which TLB-flush functions are
  supposed to flush what (bnc#1012628).
- x86/mm: Remove superfluous barriers (bnc#1012628).
- x86/mm: Use __flush_tlb_one() for kernel memory (bnc#1012628).
- x86/microcode: Dont abuse the TLB-flush interface (bnc#1012628).
- x86/uv: Use the right TLB-flush API (bnc#1012628).
- x86/entry: Rename SYSENTER_stack to CPU_ENTRY_AREA_entry_stack
  (bnc#1012628).
- x86/doc: Remove obvious weirdnesses from the x86 MM layout
  documentation (bnc#1012628).
- x86/mm/64: Improve the memory map documentation (bnc#1012628).
- x86/ldt: Prevent LDT inheritance on exec (bnc#1012628).
- x86/ldt: Rework locking (bnc#1012628).
- arch, mm: Allow arch_dup_mmap() to fail (bnc#1012628).
- x86/vsyscall/64: Warn and fail vsyscall emulation in NATIVE mode
  (bnc#1012628).
- x86/vsyscall/64: Explicitly set _PAGE_USER in the pagetable
  hierarchy (bnc#1012628).
- x86/mm/dump_pagetables: Make the address hints correct and
  readable (bnc#1012628).
- x86/mm/dump_pagetables: Check PAGE_PRESENT for real
  (bnc#1012628).
- x86/Kconfig: Limit NR_CPUS on 32-bit to a sane amount
  (bnc#1012628).
- x86/insn-eval: Add utility functions to get segment selector
  (bnc#1012628).
- x86/decoder: Fix and update the opcodes map (bnc#1012628).
- objtool: Fix 64-bit build on 32-bit host (bnc#1012628).
- tools/headers: Sync objtool UAPI header (bnc#1012628).
- objtool: Fix cross-build (bnc#1012628).
- objtool: Move kernel headers/code sync check to a script
  (bnc#1012628).
- objtool: Move synced files to their original relative locations
  (bnc#1012628).
- Revert "ipv6: grab rt->rt6i_ref before allocating pcpu rt"
  (bnc#1012628).
- commit a9b9f85
* Mon Dec 25 2017 jslaby@suse.cz
- Linux 4.14.9 (bnc#1012628).
- x86/asm: Remove unnecessary \n\t in front of CC_SET() from
  asm templates (bnc#1012628).
- ACPI / APEI: adjust a local variable type in
  ghes_ioremap_pfn_irq() (bnc#1012628).
- x86/fpu/debug: Remove unused 'x86_fpu_state' and
  'x86_fpu_deactivate_state' tracepoints (bnc#1012628).
- bitops: Add clear/set_bit32() to linux/bitops.h (bnc#1012628).
- x86/cpuid: Add generic table for CPUID dependencies
  (bnc#1012628).
- x86/fpu: Parse clearcpuid= as early XSAVE argument
  (bnc#1012628).
- x86/fpu: Make XSAVE check the base CPUID features before
  enabling (bnc#1012628).
- x86/fpu: Remove the explicit clearing of XSAVE dependent
  features (bnc#1012628).
- x86/platform/UV: Convert timers to use timer_setup()
  (bnc#1012628).
- x86/cpuid: Prevent out of bound access in do_clear_cpu_cap()
  (bnc#1012628).
- mm/sparsemem: Allocate mem_section at runtime for
  CONFIG_SPARSEMEM_EXTREME=y (bnc#1012628).
- x86/kasan: Use the same shadow offset for 4- and 5-level paging
  (bnc#1012628).
- x86/xen: Provide pre-built page tables only for CONFIG_XEN_PV=y
  and CONFIG_XEN_PVH=y (bnc#1012628).
- x86/xen: Drop 5-level paging support code from the XEN_PV code
  (bnc#1012628).
- ACPI / APEI: remove the unused dead-code for SEA/NMI
  notification type (bnc#1012628).
- x86/asm: Don't use the confusing '.ifeq' directive
  (bnc#1012628).
- x86/build: Beautify build log of syscall headers (bnc#1012628).
- x86/mm/64: Rename the register_page_bootmem_memmap() 'size'
  parameter to 'nr_pages' (bnc#1012628).
- x86/cpufeatures: Enable new SSE/AVX/AVX512 CPU features
  (bnc#1012628).
- x86/mm: Relocate page fault error codes to traps.h
  (bnc#1012628).
- x86/boot: Relocate definition of the initial state of CR0
  (bnc#1012628).
- ptrace,x86: Make user_64bit_mode() available to 32-bit builds
  (bnc#1012628).
- x86/entry/64: Remove the restore_c_regs_and_iret label
  (bnc#1012628).
- x86/entry/64: Split the IRET-to-user and IRET-to-kernel paths
  (bnc#1012628).
- x86/entry/64: Move SWAPGS into the common IRET-to-usermode path
  (bnc#1012628).
- x86/entry/64: Simplify reg restore code in the standard IRET
  paths (bnc#1012628).
- x86/entry/64: Shrink paranoid_exit_restore and make labels local
  (bnc#1012628).
- x86/entry/64: Use pop instead of movq in
  syscall_return_via_sysret (bnc#1012628).
- x86/entry/64: Merge the fast and slow SYSRET paths
  (bnc#1012628).
- x86/entry/64: Use POP instead of MOV to restore regs on NMI
  return (bnc#1012628).
- x86/entry/64: Remove the RESTORE_..._REGS infrastructure
  (bnc#1012628).
- xen, x86/entry/64: Add xen NMI trap entry (bnc#1012628).
- x86/entry/64: De-Xen-ify our NMI code (bnc#1012628).
- x86/entry/32: Pull the MSR_IA32_SYSENTER_CS update code out
  of native_load_sp0() (bnc#1012628).
- x86/entry/64: Pass SP0 directly to load_sp0() (bnc#1012628).
- x86/entry: Add task_top_of_stack() to find the top of a task's
  stack (bnc#1012628).
- x86/xen/64, x86/entry/64: Clean up SP code in
  cpu_initialize_context() (bnc#1012628).
- x86/entry/64: Stop initializing TSS.sp0 at boot (bnc#1012628).
- x86/entry/64: Remove all remaining direct thread_struct::sp0
  reads (bnc#1012628).
- x86/entry/32: Fix cpu_current_top_of_stack initialization at
  boot (bnc#1012628).
- x86/entry/64: Remove thread_struct::sp0 (bnc#1012628).
- x86/traps: Use a new on_thread_stack() helper to clean up an
  assertion (bnc#1012628).
- x86/entry/64: Shorten TEST instructions (bnc#1012628).
- x86/cpuid: Replace set/clear_bit32() (bnc#1012628).
- bitops: Revert cbe96375025e ("bitops: Add clear/set_bit32()
  to linux/bitops.h") (bnc#1012628).
- x86/mm: Define _PAGE_TABLE using _KERNPG_TABLE (bnc#1012628).
- x86/cpufeatures: Re-tabulate the X86_FEATURE definitions
  (bnc#1012628).
- x86/cpufeatures: Fix various details in the feature definitions
  (bnc#1012628).
- selftests/x86/ldt_gdt: Add infrastructure to test
  set_thread_area() (bnc#1012628).
- selftests/x86/ldt_gdt: Run most existing LDT test cases against
  the GDT as well (bnc#1012628).
- ACPI / APEI: Replace ioremap_page_range() with fixmap
  (bnc#1012628).
- x86/virt, x86/platform: Merge 'struct x86_hyper' into 'struct
  x86_platform' and 'struct x86_init' (bnc#1012628).
- x86/virt: Add enum for hypervisors to replace x86_hyper
  (bnc#1012628).
- drivers/misc/intel/pti: Rename the header file to free up the
  namespace (bnc#1012628).
- x86/cpufeature: Add User-Mode Instruction Prevention definitions
  (bnc#1012628).
- x86: Make X86_BUG_FXSAVE_LEAK detectable in CPUID on AMD
  (bnc#1012628).
- perf/x86: Enable free running PEBS for REGS_USER/INTR
  (bnc#1012628).
- bpf: fix build issues on um due to mising bpf_perf_event.h
  (bnc#1012628).
- locking/barriers: Add implicit smp_read_barrier_depends()
  to READ_ONCE() (bnc#1012628).
- locking/barriers: Convert users of lockless_dereference()
  to READ_ONCE() (bnc#1012628).
- x86/mm/kasan: Don't use vmemmap_populate() to initialize shadow
  (bnc#1012628).
- x86/entry/64/paravirt: Use paravirt-safe macro to access eflags
  (bnc#1012628).
- x86/unwinder/orc: Dont bail on stack overflow (bnc#1012628).
- x86/unwinder: Handle stack overflows more gracefully
  (bnc#1012628).
- x86/irq: Remove an old outdated comment about context tracking
  races (bnc#1012628).
- x86/irq/64: Print the offending IP in the stack overflow warning
  (bnc#1012628).
- x86/entry/64: Allocate and enable the SYSENTER stack
  (bnc#1012628).
- x86/dumpstack: Add get_stack_info() support for the SYSENTER
  stack (bnc#1012628).
- x86/entry/gdt: Put per-CPU GDT remaps in ascending order
  (bnc#1012628).
- x86/mm/fixmap: Generalize the GDT fixmap mechanism, introduce
  struct cpu_entry_area (bnc#1012628).
- x86/kasan/64: Teach KASAN about the cpu_entry_area
  (bnc#1012628).
- x86/entry: Fix assumptions that the HW TSS is at the beginning
  of cpu_tss (bnc#1012628).
- x86/dumpstack: Handle stack overflow on all stacks
  (bnc#1012628).
- x86/entry: Move SYSENTER_stack to the beginning of struct
  tss_struct (bnc#1012628).
- x86/entry: Remap the TSS into the CPU entry area (bnc#1012628).
- x86/entry/64: Separate cpu_current_top_of_stack from TSS.sp0
  (bnc#1012628).
- x86/espfix/64: Stop assuming that pt_regs is on the entry stack
  (bnc#1012628).
- x86/entry/64: Use a per-CPU trampoline stack for IDT entries
  (bnc#1012628).
- x86/entry/64: Return to userspace from the trampoline stack
  (bnc#1012628).
- x86/entry/64: Create a per-CPU SYSCALL entry trampoline
  (bnc#1012628).
- x86/entry/64: Move the IST stacks into struct cpu_entry_area
  (bnc#1012628).
- x86/entry/64: Remove the SYSENTER stack canary (bnc#1012628).
- x86/entry: Clean up the SYSENTER_stack code (bnc#1012628).
- x86/entry/64: Make cpu_entry_area.tss read-only (bnc#1012628).
- x86/paravirt: Dont patch flush_tlb_single (bnc#1012628).
- x86/paravirt: Provide a way to check for hypervisors
  (bnc#1012628).
- x86/cpufeatures: Make CPU bugs sticky (bnc#1012628).
- optee: fix invalid of_node_put() in optee_driver_init()
  (bnc#1012628).
- backlight: pwm_bl: Fix overflow condition (bnc#1012628).
- drm: Add retries for lspcon mode detection (bnc#1012628).
- clk: sunxi-ng: nm: Check if requested rate is supported by
  fractional clock (bnc#1012628).
- clk: sunxi-ng: sun5i: Fix bit offset of audio PLL post-divider
  (bnc#1012628).
- crypto: crypto4xx - increase context and scatter ring buffer
  elements (bnc#1012628).
- crypto: lrw - Fix an error handling path in 'create()'
  (bnc#1012628).
- rtc: pl031: make interrupt optional (bnc#1012628).
- kvm, mm: account kvm related kmem slabs to kmemcg (bnc#1012628).
- net: phy: at803x: Change error to EINVAL for invalid MAC
  (bnc#1012628).
- PCI: Avoid bus reset if bridge itself is broken (bnc#1012628).
- scsi: cxgb4i: fix Tx skb leak (bnc#1012628).
- scsi: mpt3sas: Fix IO error occurs on pulling out a drive from
  RAID1 volume created on two SATA drive (bnc#1012628).
- PCI: Create SR-IOV virtfn/physfn links before attaching driver
  (bnc#1012628).
- PM / OPP: Move error message to debug level (bnc#1012628).
- igb: check memory allocation failure (bnc#1012628).
- i40e: use the safe hash table iterator when deleting mac filters
  (bnc#1012628).
- iio: st_sensors: add register mask for status register
  (bnc#1012628).
- ixgbe: fix use of uninitialized padding (bnc#1012628).
- IB/rxe: check for allocation failure on elem (bnc#1012628).
- block,bfq: Disable writeback throttling (bnc#1012628).
- md: always set THREAD_WAKEUP and wake up wqueue if thread
  existed (bnc#1012628).
- ip_gre: check packet length and mtu correctly in erspan tx
  (bnc#1012628).
- ipv6: grab rt->rt6i_ref before allocating pcpu rt (bnc#1012628).
- leds: pca955x: Don't invert requested value in
  pca955x_gpio_set_value() (bnc#1012628).
- Bluetooth: hci_uart_set_flow_control: Fix NULL deref when
  using serdev (bnc#1012628).
- Bluetooth: hci_bcm: Fix setting of irq trigger type
  (bnc#1012628).
- i40e/i40evf: spread CPU affinity hints across online CPUs only
  (bnc#1012628).
- PCI/AER: Report non-fatal errors only to the affected endpoint
  (bnc#1012628).
- tracing: Exclude 'generic fields' from histograms (bnc#1012628).
- ASoC: codecs: msm8916-wcd-analog: fix micbias level
  (bnc#1012628).
- ASoC: img-parallel-out: Add pm_runtime_get/put to set_fmt
  callback (bnc#1012628).
- powerpc/xmon: Avoid tripping SMP hardlockup watchdog
  (bnc#1012628).
- powerpc/watchdog: Do not trigger SMP crash from
  touch_nmi_watchdog (bnc#1012628).
- sctp: silence warns on sctp_stream_init allocations
  (bnc#1012628).
- ASoC: codecs: msm8916-wcd-analog: fix module autoload
  (bnc#1012628).
- fm10k: fix mis-ordered parameters in declaration for
  .ndo_set_vf_bw (bnc#1012628).
- scsi: lpfc: Fix secure firmware updates (bnc#1012628).
- scsi: lpfc: PLOGI failures during NPIV testing (bnc#1012628).
- scsi: lpfc: Fix warning messages when NVME_TARGET_FC not defined
  (bnc#1012628).
- i40e: fix client notify of VF reset (bnc#1012628).
- vfio/pci: Virtualize Maximum Payload Size (bnc#1012628).
- ARM: exynos_defconfig: Enable UAS support for Odroid HC1 board
  (bnc#1012628).
- fm10k: ensure we process SM mbx when processing VF mbx
  (bnc#1012628).
- ibmvnic: Set state UP (bnc#1012628).
- net: ipv6: send NS for DAD when link operationally up
  (bnc#1012628).
- RDMA/hns: Avoid NULL pointer exception (bnc#1012628).
- staging: greybus: light: Release memory obtained by kasprintf
  (bnc#1012628).
- clk: sunxi-ng: sun6i: Rename HDMI DDC clock to avoid name
  collision (bnc#1012628).
- tcp: fix under-evaluated ssthresh in TCP Vegas (bnc#1012628).
- rtc: set the alarm to the next expiring timer (bnc#1012628).
- cpuidle: fix broadcast control when broadcast can not be entered
  (bnc#1012628).
- drm/vc4: Avoid using vrefresh==0 mode in DSI htotal math
  (bnc#1012628).
- IB/opa_vnic: Properly clear Mac Table Digest (bnc#1012628).
- IB/opa_vnic: Properly return the total MACs in UC MAC list
  (bnc#1012628).
- thermal/drivers/hisi: Fix missing interrupt enablement
  (bnc#1012628).
- thermal/drivers/hisi: Fix kernel panic on alarm interrupt
  (bnc#1012628).
- thermal/drivers/hisi: Simplify the temperature/step computation
  (bnc#1012628).
- thermal/drivers/hisi: Fix multiple alarm interrupts firing
  (bnc#1012628).
- platform/x86: asus-wireless: send an EV_SYN/SYN_REPORT between
  state changes (bnc#1012628).
- mm/sparsemem: Fix ARM64 boot crash when
  CONFIG_SPARSEMEM_EXTREME=y (bnc#1012628).
- bpf: fix branch pruning logic (bnc#1012628).
- bpf: fix corruption on concurrent perf_event_output calls
  (bnc#1012628).
- bpf, s390x: do not reload skb pointers in non-skb context
  (bnc#1012628).
- bpf, ppc64: do not reload skb pointers in non-skb context
  (bnc#1012628).
- bpf, sparc: fix usage of wrong reg for load_skb_regs after call
  (bnc#1012628).
- bpf/verifier: fix bounds calculation on BPF_RSH (bnc#1012628).
- bpf: fix incorrect sign extension in check_alu_op()
  (bnc#1012628).
- bpf: fix incorrect tracking of register size truncation
  (bnc#1012628).
- bpf: fix 32-bit ALU op verification (bnc#1012628).
- bpf: fix missing error return in check_stack_boundary()
  (bnc#1012628).
- bpf: force strict alignment checks for stack pointers
  (bnc#1012628).
- bpf: don't prune branches when a scalar is replaced with a
  pointer (bnc#1012628).
- bpf: fix integer overflows (bnc#1012628).
- selftests/bpf: add tests for recent bugfixes (bnc#1012628).
- linux/compiler.h: Split into compiler.h and compiler_types.h
  (bnc#1012628).
- Refresh patches.suse/dm-mpath-accept-failed-paths.
- Refresh patches.suse/suse-hv-guest-os-id.patch.
- commit 9423ca2
* Mon Dec 25 2017 jeffm@suse.com
- config: disable BUG_ON_DATA_CORRUPTION
  On its face this option makes sense but it brings along with it
  DEBUG_LIST, which is very expensive and obvious on benchmarks.
- commit 7bfff34
* Mon Dec 25 2017 jeffm@suse.com
- config: refresh i386/default
  Commit 4735d41aeeb added a disabled CONFIG_SPI_INTEL_SPI_PLATFORM option
  that doesn't exist on i386/default (at least in 4.15-rc5).
- commit 84167ae
* Sun Dec 24 2017 jeffm@suse.com
- Update to 4.15-rc5.
- Config changes:
  - i386: NR_CPUS 128->64
  - 7bbcbd3d1cd (x86/Kconfig: Limit NR_CPUS on 32-bit to a sane amount)
- commit 9e8deb3
* Thu Dec 21 2017 msuchanek@suse.de
- kernel-obs-build: use pae and lpae kernels where available
  (bsc#1073579).
- commit 1ac1946
* Thu Dec 21 2017 tiwai@suse.de
- Disable CONFIG_SPI_INTEL_SPI_PCI as well (bsc#1073836)
- commit ddb33b2
* Thu Dec 21 2017 tiwai@suse.de
- Disable CONFIG_SPI_INTEL_SPI_PLATFORM for BIOS breakge on Lenovo laptops
  (bsc#1073836)
- commit 4735d41
* Wed Dec 20 2017 jslaby@suse.cz
- Linux 4.14.8 (bnc#1012628).
- mfd: fsl-imx25: Clean up irq settings during removal
  (bnc#1012628).
- crypto: algif_aead - fix reference counting of null skcipher
  (bnc#1012628).
- crypto: rsa - fix buffer overread when stripping leading zeroes
  (bnc#1012628).
- crypto: hmac - require that the underlying hash algorithm is
  unkeyed (bnc#1012628).
- crypto: salsa20 - fix blkcipher_walk API usage (bnc#1012628).
- crypto: af_alg - fix NULL pointer dereference in (bnc#1012628).
- cifs: fix NULL deref in SMB2_read (bnc#1012628).
- string.h: workaround for increased stack usage (bnc#1012628).
- autofs: fix careless error in recent commit (bnc#1012628).
- kernel: make groups_sort calling a responsibility group_info
  allocators (bnc#1012628).
- mm, oom_reaper: fix memory corruption (bnc#1012628).
- tracing: Allocate mask_str buffer dynamically (bnc#1012628).
- USB: uas and storage: Add US_FL_BROKEN_FUA for another JMicron
  JMS567 ID (bnc#1012628).
- USB: core: prevent malicious bNumInterfaces overflow
  (bnc#1012628).
- ovl: Pass ovl_get_nlink() parameters in right order
  (bnc#1012628).
- ovl: update ctx->pos on impure dir iteration (bnc#1012628).
- usbip: fix stub_rx: get_pipe() to validate endpoint number
  (bnc#1012628).
- usbip: fix stub_rx: harden CMD_SUBMIT path to handle malicious
  input (bnc#1012628).
- usbip: prevent vhci_hcd driver from leaking a socket pointer
  address (bnc#1012628).
- usbip: fix stub_send_ret_submit() vulnerability to null
  transfer_buffer (bnc#1012628).
- mmc: core: apply NO_CMD23 quirk to some specific cards
  (bnc#1012628).
- ceph: drop negative child dentries before try pruning inode's
  alias (bnc#1012628).
- usb: xhci: fix TDS for MTK xHCI1.1 (bnc#1012628).
- xhci: Don't add a virt_dev to the devs array before it's fully
  allocated (bnc#1012628).
- IB/core: Bound check alternate path port number (bnc#1012628).
- IB/core: Don't enforce PKey security on SMI MADs (bnc#1012628).
- nfs: don't wait on commit in nfs_commit_inode() if there were
  no commit requests (bnc#1012628).
- arm64: mm: Fix pte_mkclean, pte_mkdirty semantics (bnc#1012628).
- arm64: Initialise high_memory global variable earlier
  (bnc#1012628).
- arm64: fix CONFIG_DEBUG_WX address reporting (bnc#1012628).
- scsi: core: Fix a scsi_show_rq() NULL pointer dereference
  (bnc#1012628).
- scsi: libsas: fix length error in sas_smp_handler()
  (bnc#1012628).
- sched/rt: Do not pull from current CPU if only one CPU to pull
  (bnc#1012628).
- dm: fix various targets to dm_register_target after module
  __init resources created (bnc#1012628).
- SUNRPC: Fix a race in the receive code path (bnc#1012628).
- iw_cxgb4: only insert drain cqes if wq is flushed (bnc#1012628).
- x86/boot/compressed/64: Detect and handle 5-level paging at
  boot-time (bnc#1012628).
- x86/boot/compressed/64: Print error if 5-level paging is not
  supported (bnc#1012628).
- eeprom: at24: change nvmem stride to 1 (bnc#1012628).
- posix-timer: Properly check sigevent->sigev_notify
  (bnc#1012628).
- dmaengine: dmatest: move callback wait queue to thread context
  (bnc#1012628).
- Revert "exec: avoid RLIMIT_STACK races with prlimit()"
  (bnc#1012628).
- ext4: support fast symlinks from ext3 file systems
  (bnc#1012628).
- ext4: fix fdatasync(2) after fallocate(2) operation
  (bnc#1012628).
- ext4: add missing error check in __ext4_new_inode()
  (bnc#1012628).
- ext4: fix crash when a directory's i_size is too small
  (bnc#1012628).
- IB/mlx4: Fix RSS's QPC attributes assignments (bnc#1012628).
- HID: cp2112: fix broken gpio_direction_input callback
  (bnc#1012628).
- sfc: don't warn on successful change of MAC (bnc#1012628).
- fbdev: controlfb: Add missing modes to fix out of bounds access
  (bnc#1012628).
- video: udlfb: Fix read EDID timeout (bnc#1012628).
- video: fbdev: au1200fb: Release some resources if a memory
  allocation fails (bnc#1012628).
- video: fbdev: au1200fb: Return an error code if a memory
  allocation fails (bnc#1012628).
- rtc: pcf8563: fix output clock rate (bnc#1012628).
- scsi: aacraid: use timespec64 instead of timeval (bnc#1012628).
- drm/amdgpu: bypass lru touch for KIQ ring submission
  (bnc#1012628).
- PM / s2idle: Clear the events_check_enabled flag (bnc#1012628).
- ASoC: Intel: Skylake: Fix uuid_module memory leak in failure
  case (bnc#1012628).
- dmaengine: ti-dma-crossbar: Correct am335x/am43xx mux value type
  (bnc#1012628).
- mlxsw: spectrum: Fix error return code in mlxsw_sp_port_create()
  (bnc#1012628).
- PCI/PME: Handle invalid data when reading Root Status
  (bnc#1012628).
- powerpc/powernv/cpufreq: Fix the frequency read by /proc/cpuinfo
  (bnc#1012628).
- PCI: Do not allocate more buses than available in parent
  (bnc#1012628).
- iommu/mediatek: Fix driver name (bnc#1012628).
- thunderbolt: tb: fix use after free in tb_activate_pcie_devices
  (bnc#1012628).
- netfilter: ipvs: Fix inappropriate output of procfs
  (bnc#1012628).
- powerpc/opal: Fix EBUSY bug in acquiring tokens (bnc#1012628).
- powerpc/ipic: Fix status get and status clear (bnc#1012628).
- powerpc/pseries/vio: Dispose of virq mapping on vdevice
  unregister (bnc#1012628).
- platform/x86: intel_punit_ipc: Fix resource ioremap warning
  (bnc#1012628).
- target/iscsi: Detect conn_cmd_list corruption early
  (bnc#1012628).
- target/iscsi: Fix a race condition in
  iscsit_add_reject_from_cmd() (bnc#1012628).
- iscsi-target: fix memory leak in lio_target_tiqn_addtpg()
  (bnc#1012628).
- target:fix condition return in core_pr_dump_initiator_port()
  (bnc#1012628).
- target/file: Do not return error for UNMAP if length is zero
  (bnc#1012628).
- badblocks: fix wrong return value in badblocks_set if badblocks
  are disabled (bnc#1012628).
- iommu/amd: Limit the IOVA page range to the specified addresses
  (bnc#1012628).
- xfs: truncate pagecache before writeback in xfs_setattr_size()
  (bnc#1012628).
- arm-ccn: perf: Prevent module unload while PMU is in use
  (bnc#1012628).
- crypto: tcrypt - fix buffer lengths in test_aead_speed()
  (bnc#1012628).
- mm: Handle 0 flags in _calc_vm_trans() macro (bnc#1012628).
- net: hns3: fix for getting advertised_caps in
  hns3_get_link_ksettings (bnc#1012628).
- net: hns3: Fix a misuse to devm_free_irq (bnc#1012628).
- staging: rtl8188eu: Revert part of "staging: rtl8188eu: fix
  comments with lines over 80 characters" (bnc#1012628).
- clk: mediatek: add the option for determining PLL source clock
  (bnc#1012628).
- clk: imx: imx7d: Fix parent clock for OCRAM_CLK (bnc#1012628).
- clk: imx6: refine hdmi_isfr's parent to make HDMI work on
  i.MX6 SoCs w/o VPU (bnc#1012628).
- media: camss-vfe: always initialize reg at vfe_set_xbar_cfg()
  (bnc#1012628).
- clk: hi6220: mark clock cs_atb_syspll as critical (bnc#1012628).
- blk-mq-sched: dispatch from scheduler IFF progress is made in
  - >dispatch (bnc#1012628).
- clk: tegra: Use readl_relaxed_poll_timeout_atomic() in
  tegra210_clock_init() (bnc#1012628).
- clk: tegra: Fix cclk_lp divisor register (bnc#1012628).
- ppp: Destroy the mutex when cleanup (bnc#1012628).
- ASoC: rsnd: rsnd_ssi_run_mods() needs to care ssi_parent_mod
  (bnc#1012628).
- thermal/drivers/step_wise: Fix temperature regulation
  misbehavior (bnc#1012628).
- misc: pci_endpoint_test: Fix failure path return values in probe
  (bnc#1012628).
- misc: pci_endpoint_test: Avoid triggering a BUG() (bnc#1012628).
- scsi: scsi_debug: write_same: fix error report (bnc#1012628).
- GFS2: Take inode off order_write list when setting jdata flag
  (bnc#1012628).
- media: usbtv: fix brightness and contrast controls
  (bnc#1012628).
- rpmsg: glink: Initialize the "intent_req_comp" completion
  variable (bnc#1012628).
- bcache: explicitly destroy mutex while exiting (bnc#1012628).
- bcache: fix wrong cache_misses statistics (bnc#1012628).
- Ib/hfi1: Return actual operational VLs in port info query
  (bnc#1012628).
- Bluetooth: hci_ldisc: Fix another race when closing the tty
  (bnc#1012628).
- arm64: prevent regressions in compressed kernel image size
  when upgrading to binutils 2.27 (bnc#1012628).
- btrfs: fix false EIO for missing device (bnc#1012628).
- btrfs: Explicitly handle btrfs_update_root failure
  (bnc#1012628).
- btrfs: undo writable superblocke when sprouting fails
  (bnc#1012628).
- btrfs: avoid null pointer dereference on fs_info when calling
  btrfs_crit (bnc#1012628).
- btrfs: tests: Fix a memory leak in error handling path in
  'run_test()' (bnc#1012628).
- qtnfmac: modify full Tx queue error reporting (bnc#1012628).
- mtd: spi-nor: stm32-quadspi: Fix uninitialized error return code
  (bnc#1012628).
- ARM64: dts: meson-gxbb-odroidc2: fix usb1 power supply
  (bnc#1012628).
- Bluetooth: btusb: Add new NFA344A entry (bnc#1012628).
- samples/bpf: adjust rlimit RLIMIT_MEMLOCK for xdp1
  (bnc#1012628).
- liquidio: fix kernel panic in VF driver (bnc#1012628).
- platform/x86: hp_accel: Add quirk for HP ProBook 440 G4
  (bnc#1012628).
- nvme: use kref_get_unless_zero in nvme_find_get_ns
  (bnc#1012628).
- l2tp: cleanup l2tp_tunnel_delete calls (bnc#1012628).
- xfs: fix log block underflow during recovery cycle verification
  (bnc#1012628).
- xfs: return a distinct error code value for IGET_INCORE cache
  misses (bnc#1012628).
- xfs: fix incorrect extent state in
  xfs_bmap_add_extent_unwritten_real (bnc#1012628).
- net: dsa: lan9303: Do not disable switch fabric port 0 at .probe
  (bnc#1012628).
- net: hns3: fix a bug in hclge_uninit_client_instance
  (bnc#1012628).
- net: hns3: add nic_client check when initialize roce base
  information (bnc#1012628).
- net: hns3: fix the bug of hns3_set_txbd_baseinfo (bnc#1012628).
- RDMA/cxgb4: Declare stag as __be32 (bnc#1012628).
- PCI: Detach driver before procfs & sysfs teardown on device
  remove (bnc#1012628).
- scsi: hisi_sas: fix the risk of freeing slot twice
  (bnc#1012628).
- scsi: hpsa: cleanup sas_phy structures in sysfs when unloading
  (bnc#1012628).
- scsi: hpsa: destroy sas transport properties before scsi_host
  (bnc#1012628).
- mfd: mxs-lradc: Fix error handling in mxs_lradc_probe()
  (bnc#1012628).
- net: hns3: fix the TX/RX ring.queue_index in hns3_ring_get_cfg
  (bnc#1012628).
- net: hns3: fix the bug when map buffer fail (bnc#1012628).
- net: hns3: fix a bug when alloc new buffer (bnc#1012628).
- serdev: ttyport: enforce tty-driver open() requirement
  (bnc#1012628).
- powerpc/perf/hv-24x7: Fix incorrect comparison in memord
  (bnc#1012628).
- powerpc/xmon: Check before calling xive functions (bnc#1012628).
- soc: mediatek: pwrap: fix compiler errors (bnc#1012628).
- ipv4: ipv4_default_advmss() should use route mtu (bnc#1012628).
- KVM: nVMX: Fix EPT switching advertising (bnc#1012628).
- tty fix oops when rmmod 8250 (bnc#1012628).
- dev/dax: fix uninitialized variable build warning (bnc#1012628).
- pinctrl: adi2: Fix Kconfig build problem (bnc#1012628).
- raid5: Set R5_Expanded on parity devices as well as data
  (bnc#1012628).
- IB/core: Fix use workqueue without WQ_MEM_RECLAIM (bnc#1012628).
- IB/core: Fix calculation of maximum RoCE MTU (bnc#1012628).
- vt6655: Fix a possible sleep-in-atomic bug in vt6655_suspend
  (bnc#1012628).
- IB/hfi1: Mask out A bit from psn trace (bnc#1012628).
- rtl8188eu: Fix a possible sleep-in-atomic bug in
  rtw_createbss_cmd (bnc#1012628).
- rtl8188eu: Fix a possible sleep-in-atomic bug in
  rtw_disassoc_cmd (bnc#1012628).
- nullb: fix error return code in null_init() (bnc#1012628).
- scsi: sd: change manage_start_stop to bool in sysfs interface
  (bnc#1012628).
- scsi: sd: change allow_restart to bool in sysfs interface
  (bnc#1012628).
- scsi: bfa: integer overflow in debugfs (bnc#1012628).
- raid5-ppl: check recovery_offset when performing ppl recovery
  (bnc#1012628).
- md-cluster: fix wrong condition check in raid1_write_request
  (bnc#1012628).
- xprtrdma: Don't defer fencing an async RPC's chunks
  (bnc#1012628).
- udf: Avoid overflow when session starts at large offset
  (bnc#1012628).
- macvlan: Only deliver one copy of the frame to the macvlan
  interface (bnc#1012628).
- IB/core: Fix endianness annotation in rdma_is_multicast_addr()
  (bnc#1012628).
- RDMA/cma: Avoid triggering undefined behavior (bnc#1012628).
- IB/ipoib: Grab rtnl lock on heavy flush when calling
  ndo_open/stop (bnc#1012628).
- icmp: don't fail on fragment reassembly time exceeded
  (bnc#1012628).
- lightnvm: pblk: prevent gc kicks when gc is not operational
  (bnc#1012628).
- lightnvm: pblk: fix changing GC group list for a line
  (bnc#1012628).
- lightnvm: pblk: use right flag for GC allocation (bnc#1012628).
- lightnvm: pblk: initialize debug stat counter (bnc#1012628).
- lightnvm: pblk: fix min size for page mempool (bnc#1012628).
- lightnvm: pblk: protect line bitmap while submitting meta io
  (bnc#1012628).
- ath9k: fix tx99 potential info leak (bnc#1012628).
- ath10k: fix core PCI suspend when WoWLAN is supported but
  disabled (bnc#1012628).
- ath10k: fix build errors with !CONFIG_PM (bnc#1012628).
- usb: musb: da8xx: fix babble condition handling (bnc#1012628).
- commit 674981b
* Tue Dec 19 2017 jeffm@suse.com
- Update to 4.15-rc4.
- Eliminated 1 patch.
- Config changes:
  - ARM:
  - QCOM_FALKOR_ERRATUM_E1041=y
  - Overlayfs:
  - OVERLAY_FS_REDIRECT_ALWAYS_FOLLOW=y (preserves existing behavior)
- commit ff8819c
* Sun Dec 17 2017 jslaby@suse.cz
- Linux 4.14.7 (bnc#1012628).
- net: qmi_wwan: add Quectel BG96 2c7c:0296 (bnc#1012628).
- net: thunderx: Fix TCP/UDP checksum offload for IPv6 pkts
  (bnc#1012628).
- net: thunderx: Fix TCP/UDP checksum offload for IPv4 pkts
  (bnc#1012628).
- net: realtek: r8169: implement set_link_ksettings()
  (bnc#1012628).
- s390/qeth: fix early exit from error path (bnc#1012628).
- tipc: fix memory leak in tipc_accept_from_sock() (bnc#1012628).
- vhost: fix skb leak in handle_rx() (bnc#1012628).
- rds: Fix NULL pointer dereference in __rds_rdma_map
  (bnc#1012628).
- sit: update frag_off info (bnc#1012628).
- tcp: add tcp_v4_fill_cb()/tcp_v4_restore_cb() (bnc#1012628).
- packet: fix crash in fanout_demux_rollover() (bnc#1012628).
- net/packet: fix a race in packet_bind() and packet_notifier()
  (bnc#1012628).
- tcp: remove buggy call to tcp_v6_restore_cb() (bnc#1012628).
- usbnet: fix alignment for frames with no ethernet header
  (bnc#1012628).
- net: remove hlist_nulls_add_tail_rcu() (bnc#1012628).
- stmmac: reset last TSO segment size after device open
  (bnc#1012628).
- tcp/dccp: block bh before arming time_wait timer (bnc#1012628).
- s390/qeth: build max size GSO skbs on L2 devices (bnc#1012628).
- s390/qeth: fix thinko in IPv4 multicast address tracking
  (bnc#1012628).
- s390/qeth: fix GSO throughput regression (bnc#1012628).
- tcp: use IPCB instead of TCP_SKB_CB in inet_exact_dif_match()
  (bnc#1012628).
- tipc: call tipc_rcv() only if bearer is up in tipc_udp_recv()
  (bnc#1012628).
- tcp: use current time in tcp_rcv_space_adjust() (bnc#1012628).
- net: sched: cbq: create block for q->link.block (bnc#1012628).
- tap: free skb if flags error (bnc#1012628).
- tcp: when scheduling TLP, time of RTO should account for
  current ACK (bnc#1012628).
- tun: free skb in early errors (bnc#1012628).
- net: ipv6: Fixup device for anycast routes during copy
  (bnc#1012628).
- tun: fix rcu_read_lock imbalance in tun_build_skb (bnc#1012628).
- net: accept UFO datagrams from tuntap and packet (bnc#1012628).
- net: openvswitch: datapath: fix data type in queue_gso_packets
  (bnc#1012628).
- cls_bpf: don't decrement net's refcount when offload fails
  (bnc#1012628).
- sctp: use right member as the param of list_for_each_entry
  (bnc#1012628).
- ipmi: Stop timers before cleaning up the module (bnc#1012628).
- usb: gadget: ffs: Forbid usb_ep_alloc_request from sleeping
  (bnc#1012628).
- fcntl: don't cap l_start and l_end values for F_GETLK64 in
  compat syscall (bnc#1012628).
- fix kcm_clone() (bnc#1012628).
- KVM: arm/arm64: vgic-its: Preserve the revious read from the
  pending table (bnc#1012628).
- kbuild: do not call cc-option before KBUILD_CFLAGS
  initialization (bnc#1012628).
- powerpc/powernv/idle: Round up latency and residency values
  (bnc#1012628).
- ipvlan: fix ipv6 outbound device (bnc#1012628).
- ide: ide-atapi: fix compile error with defining macro DEBUG
  (bnc#1012628).
- blk-mq: Avoid that request queue removal can trigger list
  corruption (bnc#1012628).
- nvmet-rdma: update queue list during ib_device removal
  (bnc#1012628).
- audit: Allow auditd to set pid to 0 to end auditing
  (bnc#1012628).
- audit: ensure that 'audit=1' actually enables audit for PID 1
  (bnc#1012628).
- dm raid: fix panic when attempting to force a raid to sync
  (bnc#1012628).
- md: free unused memory after bitmap resize (bnc#1012628).
- RDMA/cxgb4: Annotate r2 and stag as __be32 (bnc#1012628).
- x86/intel_rdt: Fix potential deadlock during resctrl unmount
  (bnc#1012628).
- Refresh patches.suse/supported-flag.
- commit 0598608
* Fri Dec 15 2017 jslaby@suse.cz
- x86/stacktrace: make clear the success paths (bnc#1058115).
- Refresh
  patches.suse/0003-x86-stacktrace-remove-STACKTRACE_DUMP_ONCE-from-__sa.patch.
- Refresh
  patches.suse/0004-x86-stacktrace-do-not-fail-for-ORC-with-regs-on-stac.patch.
- Delete
  patches.suse/0002-x86-stacktrace-remove-unwind_state-error.patch.
  Fix livepatch to succeed also for kthreads and idle tasks.
- commit 580e12c
* Thu Dec 14 2017 jslaby@suse.cz
- Linux 4.14.6 (bnc#1012628).
- usb: gadget: udc: renesas_usb3: fix number of the pipes
  (bnc#1012628).
- usb: gadget: core: Fix ->udc_set_speed() speed handling
  (bnc#1012628).
- serdev: ttyport: add missing receive_buf sanity checks
  (bnc#1012628).
- serdev: ttyport: fix NULL-deref on hangup (bnc#1012628).
- serdev: ttyport: fix tty locking in close (bnc#1012628).
- usb: f_fs: Force Reserved1=1 in OS_DESC_EXT_COMPAT
  (bnc#1012628).
- can: mcba_usb: fix device disconnect bug (bnc#1012628).
- can: peak/pci: fix potential bug when probe() fails
  (bnc#1012628).
- can: flexcan: fix VF610 state transition issue (bnc#1012628).
- can: ti_hecc: Fix napi poll return value for repoll
  (bnc#1012628).
- can: kvaser_usb: free buf in error paths (bnc#1012628).
- can: kvaser_usb: Fix comparison bug in
  kvaser_usb_read_bulk_callback() (bnc#1012628).
- can: kvaser_usb: ratelimit errors if incomplete messages are
  received (bnc#1012628).
- can: kvaser_usb: cancel urb on -EPIPE and -EPROTO (bnc#1012628).
- can: mcba_usb: cancel urb on -EPROTO (bnc#1012628).
- can: ems_usb: cancel urb on -EPIPE and -EPROTO (bnc#1012628).
- can: esd_usb2: cancel urb on -EPIPE and -EPROTO (bnc#1012628).
- can: usb_8dev: cancel urb on -EPIPE and -EPROTO (bnc#1012628).
- can: peak/pcie_fd: fix potential bug in restarting tx queue
  (bnc#1012628).
- virtio: release virtio index when fail to device_register
  (bnc#1012628).
- iio: stm32: fix adc/trigger link error (bnc#1012628).
- iio: health: max30102: Temperature should be in milli Celsius
  (bnc#1012628).
- iio: adc: cpcap: fix incorrect validation (bnc#1012628).
- iio: adc: meson-saradc: fix the bit_idx of the adc_en clock
  (bnc#1012628).
- iio: adc: meson-saradc: initialize the bandgap correctly on
  older SoCs (bnc#1012628).
- iio: adc: meson-saradc: Meson8 and Meson8b do not have REG11
  and REG13 (bnc#1012628).
- pinctrl: armada-37xx: Fix direction_output() callback behavior
  (bnc#1012628).
- Drivers: hv: vmbus: Fix a rescind issue (bnc#1012628).
- hv: kvp: Avoid reading past allocated blocks from KVP file
  (bnc#1012628).
- firmware: cleanup FIRMWARE_IN_KERNEL message (bnc#1012628).
- firmware: vpd: Destroy vpd sections in remove function
  (bnc#1012628).
- firmware: vpd: Tie firmware kobject to device lifetime
  (bnc#1012628).
- firmware: vpd: Fix platform driver and device
  registration/unregistration (bnc#1012628).
- isa: Prevent NULL dereference in isa_bus driver callbacks
  (bnc#1012628).
- scsi: dma-mapping: always provide dma_get_cache_alignment
  (bnc#1012628).
- scsi: use dma_get_cache_alignment() as minimum DMA alignment
  (bnc#1012628).
- scsi: libsas: align sata_device's rps_resp on a cacheline
  (bnc#1012628).
- efi: Move some sysfs files to be read-only by root
  (bnc#1012628).
- efi/esrt: Use memunmap() instead of kfree() to free the
  remapping (bnc#1012628).
- ASN.1: fix out-of-bounds read when parsing indefinite length
  item (bnc#1012628).
- ASN.1: check for error from ASN1_OP_END__ACT actions
  (bnc#1012628).
- KEYS: add missing permission check for request_key() destination
  (bnc#1012628).
- KEYS: reject NULL restriction string when type is specified
  (bnc#1012628).
- X.509: reject invalid BIT STRING for subjectPublicKey
  (bnc#1012628).
- X.509: fix comparisons of ->pkey_algo (bnc#1012628).
- x86/idt: Load idt early in start_secondary (bnc#1012628).
- x86/PCI: Make broadcom_postcore_init() check acpi_disabled
  (bnc#1012628).
- KVM: x86: fix APIC page invalidation (bnc#1012628).
- btrfs: fix missing error return in btrfs_drop_snapshot
  (bnc#1012628).
- btrfs: handle errors while updating refcounts in
  update_ref_for_cow (bnc#1012628).
- ALSA: hda/realtek - New codec support for ALC257 (bnc#1012628).
- ALSA: pcm: prevent UAF in snd_pcm_info (bnc#1012628).
- ALSA: seq: Remove spurious WARN_ON() at timer check
  (bnc#1012628).
- ALSA: usb-audio: Fix out-of-bound error (bnc#1012628).
- ALSA: usb-audio: Add check return value for usb_string()
  (bnc#1012628).
- iommu/vt-d: Fix scatterlist offset handling (bnc#1012628).
- smp/hotplug: Move step CPUHP_AP_SMPCFD_DYING to the correct
  place (bnc#1012628).
- s390: always save and restore all registers on context switch
  (bnc#1012628).
- s390/mm: fix off-by-one bug in 5-level page table handling
  (bnc#1012628).
- s390: fix compat system call table (bnc#1012628).
- KVM: s390: Fix skey emulation permission check (bnc#1012628).
- Revert "powerpc: Do not call ppc_md.panic in fadump panic
  notifier" (bnc#1012628).
- powerpc/64s: Initialize ISAv3 MMU registers before setting
  partition table (bnc#1012628).
- iwlwifi: mvm: mark MIC stripped MPDUs (bnc#1012628).
- iwlwifi: mvm: don't use transmit queue hang detection when it
  is not possible (bnc#1012628).
- iwlwifi: mvm: flush queue before deleting ROC (bnc#1012628).
- iwlwifi: add new cards for 9260 and 22000 series (bnc#1012628).
- iwlwifi: mvm: fix packet injection (bnc#1012628).
- iwlwifi: mvm: enable RX offloading with TKIP and WEP
  (bnc#1012628).
- brcmfmac: change driver unbind order of the sdio function
  devices (bnc#1012628).
- kdb: Fix handling of kallsyms_symbol_next() return value
  (bnc#1012628).
- md/r5cache: move mddev_lock() out of r5c_journal_mode_set()
  (bnc#1012628).
- drm/exynos: gem: Drop NONCONTIG flag for buffers allocated
  without IOMMU (bnc#1012628).
- drm/i915: Fix vblank timestamp/frame counter jumps on gen2
  (bnc#1012628).
- media: dvb: i2c transfers over usb cannot be done from stack
  (bnc#1012628).
- media: rc: sir_ir: detect presence of port (bnc#1012628).
- media: rc: partial revert of "media: rc: per-protocol repeat
  period" (bnc#1012628).
- arm64: KVM: fix VTTBR_BADDR_MASK BUG_ON off-by-one
  (bnc#1012628).
- arm: KVM: Fix VTTBR_BADDR_MASK BUG_ON off-by-one (bnc#1012628).
- KVM: VMX: remove I/O port 0x80 bypass on Intel hosts
  (bnc#1012628).
- KVM: arm/arm64: Fix broken GICH_ELRSR big endian conversion
  (bnc#1012628).
- KVM: arm/arm64: vgic-irqfd: Fix MSI entry allocation
  (bnc#1012628).
- KVM: arm/arm64: vgic: Preserve the revious read from the
  pending table (bnc#1012628).
- KVM: arm/arm64: vgic-its: Check result of allocation before use
  (bnc#1012628).
- arm64: fpsimd: Prevent registers leaking from dead tasks
  (bnc#1012628).
- arm64: SW PAN: Point saved ttbr0 at the zero page when switching
  to init_mm (bnc#1012628).
- arm64: SW PAN: Update saved ttbr0 value on enter_lazy_tlb
  (bnc#1012628).
- Revert "ARM: dts: imx53: add srtc node" (bnc#1012628).
- bus: arm-cci: Fix use of smp_processor_id() in preemptible
  context (bnc#1012628).
- bus: arm-ccn: Check memory allocation failure (bnc#1012628).
- bus: arm-ccn: Fix use of smp_processor_id() in preemptible
  context (bnc#1012628).
- bus: arm-ccn: fix module unloading Error: Removing state 147
  which has instances left (bnc#1012628).
- IB/core: Avoid unnecessary return value check (bnc#1012628).
- IB/core: Only enforce security for InfiniBand (bnc#1012628).
- crypto: talitos - fix AEAD test failures (bnc#1012628).
- crypto: talitos - fix memory corruption on SEC2 (bnc#1012628).
- crypto: talitos - fix setkey to check key weakness
  (bnc#1012628).
- crypto: talitos - fix AEAD for sha224 on non sha224 capable
  chips (bnc#1012628).
- crypto: talitos - fix use of sg_link_tbl_len (bnc#1012628).
- crypto: talitos - fix ctr-aes-talitos (bnc#1012628).
- ARM: BUG if jumping to usermode address in kernel mode
  (bnc#1012628).
- ARM: avoid faulting on qemu (bnc#1012628).
- irqchip/qcom: Fix u32 comparison with value less than zero
  (bnc#1012628).
- net/smc: use sk_rcvbuf as start for rmb creation (bnc#1012628).
- kbuild: pkg: use --transform option to prefix paths in tar
  (bnc#1012628).
- coccinelle: fix parallel build with CHECK=scripts/coccicheck
  (bnc#1012628).
- powerpc/perf: Fix pmu_count to count only nest imc pmus
  (bnc#1012628).
- apparmor: fix leak of null profile name if profile allocation
  fails (bnc#1012628).
- x86/mpx/selftests: Fix up weird arrays (bnc#1012628).
- mac80211_hwsim: Fix memory leak in hwsim_new_radio_nl()
  (bnc#1012628).
- gre6: use log_ecn_error module parameter in ip6_tnl_rcv()
  (bnc#1012628).
- route: also update fnhe_genid when updating a route cache
  (bnc#1012628).
- route: update fnhe_expires for redirect when the fnhe exists
  (bnc#1012628).
- rsi: fix memory leak on buf and usb_reg_buf (bnc#1012628).
- drivers/rapidio/devices/rio_mport_cdev.c: fix resource leak
  in error handling path in 'rio_dma_transfer()' (bnc#1012628).
- pipe: match pipe_max_size data type with procfs (bnc#1012628).
- lib/genalloc.c: make the avail variable an atomic_long_t
  (bnc#1012628).
- dynamic-debug-howto: fix optional/omitted ending line number
  to be LARGE instead of 0 (bnc#1012628).
- NFS: Fix a typo in nfs_rename() (bnc#1012628).
- sunrpc: Fix rpc_task_begin trace point (bnc#1012628).
- nfp: inherit the max_mtu from the PF netdev (bnc#1012628).
- nfp: fix flower offload metadata flag usage (bnc#1012628).
- xfs: fix forgotten rcu read unlock when skipping inode reclaim
  (bnc#1012628).
- dt-bindings: usb: fix reg-property port-number range
  (bnc#1012628).
- block: wake up all tasks blocked in get_request() (bnc#1012628).
- sparc64/mm: set fields in deferred pages (bnc#1012628).
- zsmalloc: calling zs_map_object() from irq is a bug
  (bnc#1012628).
- slub: fix sysfs duplicate filename creation when slub_debug=O
  (bnc#1012628).
- sctp: do not free asoc when it is already dead in sctp_sendmsg
  (bnc#1012628).
- sctp: use the right sk after waking up from wait_buf sleep
  (bnc#1012628).
- fcntl: don't leak fd reference when fixup_compat_flock fails
  (bnc#1012628).
- geneve: fix fill_info when link down (bnc#1012628).
- bpf: fix lockdep splat (bnc#1012628).
- clk: stm32h7: fix test of clock config (bnc#1012628).
- clk: sunxi-ng: a83t: Fix i2c buses bits (bnc#1012628).
- clk: qcom: common: fix legacy board-clock registration
  (bnc#1012628).
- clk: uniphier: fix DAPLL2 clock rate of Pro5 (bnc#1012628).
- clk: hi3660: fix incorrect uart3 clock freqency (bnc#1012628).
- mailbox: mailbox-test: don't rely on rx_buffer content to
  signal data ready (bnc#1012628).
- kbuild: rpm-pkg: fix jobserver unavailable warning
  (bnc#1012628).
- atm: horizon: Fix irq release error (bnc#1012628).
- jump_label: Invoke jump_label_test() via early_initcall()
  (bnc#1012628).
- tls: Use kzalloc for aead_request allocation (bnc#1012628).
- xfrm: Copy policy family in clone_policy (bnc#1012628).
- f2fs: fix to clear FI_NO_PREALLOC (bnc#1012628).
- bnxt_re: changing the ip address shouldn't affect new
  connections (bnc#1012628).
- IB/mlx4: Increase maximal message size under UD QP
  (bnc#1012628).
- IB/mlx5: Assign send CQ and recv CQ of UMR QP (bnc#1012628).
- afs: Fix total-length calculation for multiple-page send
  (bnc#1012628).
- afs: Connect up the CB.ProbeUuid (bnc#1012628).
- commit 45f120a
* Wed Dec 13 2017 msuchanek@suse.de
- s390/sclp: disable FORTIFY_SOURCE for early sclp code (-).
- commit 62412b6
* Tue Dec 12 2017 bp@suse.de
- x86/microcode/AMD: Add support for fam17h microcode loading
  (bsc#1068032).
- commit c1a1611
* Tue Dec 12 2017 mkubecek@suse.cz
- netfilter: xt_osf: Add missing permission checks (CVE-2017-17450
  bsc#1071695).
- commit a1ac243
* Tue Dec 12 2017 mkubecek@suse.cz
- netlink: Add netns check on taps (CVE-2017-17449 bsc#1071694).
- commit 9e5e383
* Tue Dec 12 2017 mkubecek@suse.cz
- netfilter: nfnetlink_cthelper: Add missing permission checks
  (CVE-2017-17448 bsc#1071693).
- commit a208c29
* Tue Dec 12 2017 mkubecek@suse.cz
- dccp: CVE-2017-8824: use-after-free in DCCP code (CVE-2017-8824
  bsc#1070771).
- commit bd1657a
* Mon Dec 11 2017 jslaby@suse.cz
- Linux 4.14.5 (bnc#1012628).
- Update config files.
- locking/refcounts: Do not force refcount_t usage as GPL-only
  export (bnc#1012628).
- usb: host: fix incorrect updating of offset (bnc#1012628).
- USB: usbfs: Filter flags passed in from user space
  (bnc#1012628).
- USB: core: Add type-specific length check of BOS descriptors
  (bnc#1012628).
- usb: xhci: fix panic in xhci_free_virt_devices_depth_first
  (bnc#1012628).
- xhci: Don't show incorrect WARN message about events for empty
  rings (bnc#1012628).
- USB: ulpi: fix bus-node lookup (bnc#1012628).
- usb: hub: Cycle HUB power when initialization fails
  (bnc#1012628).
- staging: ccree: fix leak of import() after init() (bnc#1012628).
- dma-buf/sw_sync: force signal all unsignaled fences on dying
  timeline (bnc#1012628).
- powerpc/kprobes: Disable preemption before invoking probe
  handler for optprobes (bnc#1012628).
- powerpc/jprobes: Disable preemption when triggered through
  ftrace (bnc#1012628).
- locking/refcounts, x86/asm: Enable CONFIG_ARCH_HAS_REFCOUNT
  (bnc#1012628).
- iio: multiplexer: add NULL check on devm_kzalloc() and
  devm_kmemdup() return values (bnc#1012628).
- iio: adc: ti-ads1015: add 10%% to conversion wait time
  (bnc#1012628).
- mm, x86/mm: Fix performance regression in get_user_pages_fast()
  (bnc#1012628).
- perf tools: Fix leaking rec_argv in error cases (bnc#1012628).
- tools include: Do not use poison with C++ (bnc#1012628).
- s390/ptrace: fix guarded storage regset handling (bnc#1012628).
- locking/refcounts, x86/asm: Use unique .text section for
  refcount exceptions (bnc#1012628).
- kprobes/x86: Disable preemption in ftrace-based jprobes
  (bnc#1012628).
- perf test attr: Fix python error on empty result (bnc#1012628).
- perf test attr: Fix ignored test case result (bnc#1012628).
- staging: fsl-mc/dpio: Fix incorrect comparison (bnc#1012628).
- serial: imx: Update cached mctrl value when changing RTS
  (bnc#1012628).
- usbip: tools: Install all headers needed for libusbip
  development (bnc#1012628).
- serial: sh-sci: suppress warning for ports without dma channels
  (bnc#1012628).
- sysrq : fix Show Regs call trace on ARM (bnc#1012628).
- usb: xhci: Return error when host is dead in xhci_disable_slot()
  (bnc#1012628).
- ARM: cpuidle: Correct driver unregistration if init fails
  (bnc#1012628).
- staging: rtl8822be: Keep array subscript no lower than zero
  (bnc#1012628).
- staging: fsl-dpaa2/eth: Account for Rx FD buffers on error path
  (bnc#1012628).
- usb: mtu3: fix error return code in ssusb_gadget_init()
  (bnc#1012628).
- EDAC, sb_edac: Fix missing break in switch (bnc#1012628).
- dt-bindings: timer: renesas, cmt: Fix SoC-specific compatible
  values (bnc#1012628).
- clocksource/drivers/arm_arch_timer: Validate CNTFRQ after
  enabling frame (bnc#1012628).
- x86/entry: Use SYSCALL_DEFINE() macros for sys_modify_ldt()
  (bnc#1012628).
- kprobes: Use synchronize_rcu_tasks() for optprobe with
  CONFIG_PREEMPT=y (bnc#1012628).
- serial: 8250: Preserve DLD[7:4] for PORT_XR17V35X (bnc#1012628).
- x86/intel_rdt: Fix potential deadlock during resctrl mount
  (bnc#1012628).
- x86/intel_rdt: Initialize bitmask of shareable resource if
  CDP enabled (bnc#1012628).
- PCI: dra7xx: Create functional dependency between PCIe and PHY
  (bnc#1012628).
- usb: phy: tahvo: fix error handling in tahvo_usb_probe()
  (bnc#1012628).
- perf/core: Fix __perf_read_group_add() locking (bnc#1012628).
- hwmon: (pmbus/core) Prevent unintentional setting of page to
  0xFF (bnc#1012628).
- mmc: sdhci-msm: fix issue with power irq (bnc#1012628).
- mmc: tmio: check mmc_regulator_get_supply return value
  (bnc#1012628).
- spi: spi-axi: fix potential use-after-free after deregistration
  (bnc#1012628).
- spi: sh-msiof: Fix DMA transfer size check (bnc#1012628).
- staging: rtl8188eu: avoid a null dereference on pmlmepriv
  (bnc#1012628).
- staging: rtl8822be: fix wrong dma unmap len (bnc#1012628).
- serial: 8250_fintek: Fix rs485 disablement on invalid ioctl()
  (bnc#1012628).
- m68k: fix ColdFire node shift size calculation (bnc#1012628).
- staging: greybus: loopback: Fix iteration count on async path
  (bnc#1012628).
- selftests/x86/ldt_gdt: Robustify against set_thread_area()
  and LAR oddities (bnc#1012628).
- selftests/x86/ldt_get: Add a few additional tests for limits
  (bnc#1012628).
- s390/pci: do not require AIS facility (bnc#1012628).
- PM / Domains: Fix genpd to deal with drivers returning 1 from
  - >prepare() (bnc#1012628).
- s390: vfio-ccw: Do not attempt to free no-op, test and tic cda
  (bnc#1012628).
- ima: fix hash algorithm initialization (bnc#1012628).
- MIPS: Add custom serial.h with BASE_BAUD override for generic
  kernel (bnc#1012628).
- serial: 8250_early: Only set divisor if valid clk & baud
  (bnc#1012628).
- USB: serial: usb_debug: add new USB device id (bnc#1012628).
- USB: serial: option: add Quectel BG96 id (bnc#1012628).
- ANDROID: binder: fix transaction leak (bnc#1012628).
- serial: 8250_pci: Add Amazon PCI serial device ID (bnc#1012628).
- usb: quirks: Add no-lpm quirk for KY-688 USB 3.1 Type-C Hub
  (bnc#1012628).
- uas: Always apply US_FL_NO_ATA_1X quirk to Seagate devices
  (bnc#1012628).
- usbip: Fix USB device hang due to wrong enabling of
  scatter-gather (bnc#1012628).
- usbip: fix usbip attach to find a port that matches the
  requested speed (bnc#1012628).
- s390/runtime instrumentation: simplify task exit handling
  (bnc#1012628).
- drm/amdgpu: Use unsigned ring indices in amdgpu_queue_mgr_map
  (bnc#1012628).
- drm/fsl-dcu: enable IRQ before drm_atomic_helper_resume()
  (bnc#1012628).
- drm/fsl-dcu: avoid disabling pixel clock twice on suspend
  (bnc#1012628).
- commit c4edabf
* Mon Dec 11 2017 jeffm@suse.com
- Update to 4.15-rc3.
- Eliminated 1 patch.
- commit 383d72f
* Sat Dec  9 2017 afaerber@suse.de
- config: armv7hl: Enable SUN4I_A10_CCU for Allwinner A20 (boo#1072032)
- commit 170d177
* Fri Dec  8 2017 msuchanek@suse.de
- Add undefine _unique_build_ids (bsc#964063)
- commit 47e91a1
* Tue Dec  5 2017 jslaby@suse.cz
- Linux 4.14.4 (bnc#1012628).
- platform/x86: hp-wmi: Fix tablet mode detection for convertibles
  (bnc#1012628).
- mm, memory_hotplug: do not back off draining pcp free pages
  from kworker context (bnc#1012628).
- mm, oom_reaper: gather each vma to prevent leaking TLB entry
  (bnc#1012628).
- mm, thp: Do not make page table dirty unconditionally in
  touch_p[mu]d() (bnc#1012628).
- mm/cma: fix alloc_contig_range ret code/potential leak
  (bnc#1012628).
- mm: fix device-dax pud write-faults triggered by
  get_user_pages() (bnc#1012628).
- mm, hugetlbfs: introduce ->split() to vm_operations_struct
  (bnc#1012628).
- device-dax: implement ->split() to catch invalid munmap attempts
  (bnc#1012628).
- mm: introduce get_user_pages_longterm (bnc#1012628).
- mm: fail get_vaddr_frames() for filesystem-dax mappings
  (bnc#1012628).
- v4l2: disable filesystem-dax mapping support (bnc#1012628).
- IB/core: disable memory registration of filesystem-dax vmas
  (bnc#1012628).
- exec: avoid RLIMIT_STACK races with prlimit() (bnc#1012628).
- mm/madvise.c: fix madvise() infinite loop under special
  circumstances (bnc#1012628).
- mm: migrate: fix an incorrect call of prep_transhuge_page()
  (bnc#1012628).
- mm, memcg: fix mem_cgroup_swapout() for THPs (bnc#1012628).
- fs/fat/inode.c: fix sb_rdonly() change (bnc#1012628).
- autofs: revert "autofs: take more care to not update last_used
  on path walk" (bnc#1012628).
- autofs: revert "autofs: fix AT_NO_AUTOMOUNT not being honored"
  (bnc#1012628).
- mm/hugetlb: fix NULL-pointer dereference on 5-level paging
  machine (bnc#1012628).
- btrfs: clear space cache inode generation always (bnc#1012628).
- nfsd: Fix stateid races between OPEN and CLOSE (bnc#1012628).
- nfsd: Fix another OPEN stateid race (bnc#1012628).
- nfsd: fix panic in posix_unblock_lock called from
  nfs4_laundromat (bnc#1012628).
- crypto: algif_aead - skip SGL entries with NULL page
  (bnc#1012628).
- crypto: af_alg - remove locking in async callback (bnc#1012628).
- crypto: skcipher - Fix skcipher_walk_aead_common (bnc#1012628).
- lockd: lost rollback of set_grace_period() in lockd_down_net()
  (bnc#1012628).
- s390: revert ELF_ET_DYN_BASE base changes (bnc#1012628).
- drm: omapdrm: Fix DPI on platforms using the DSI VDDS
  (bnc#1012628).
- omapdrm: hdmi4: Correct the SoC revision matching (bnc#1012628).
- arm64: module-plts: factor out PLT generation code for ftrace
  (bnc#1012628).
- arm64: ftrace: emit ftrace-mod.o contents through code
  (bnc#1012628).
- powerpc/powernv: Fix kexec crashes caused by tlbie tracing
  (bnc#1012628).
- powerpc/kexec: Fix kexec/kdump in P9 guest kernels
  (bnc#1012628).
- KVM: x86: pvclock: Handle first-time write to pvclock-page
  contains random junk (bnc#1012628).
- KVM: x86: Exit to user-mode on #UD intercept when emulator
  requires (bnc#1012628).
- KVM: x86: inject exceptions produced by x86_decode_insn
  (bnc#1012628).
- KVM: lapic: Split out x2apic ldr calculation (bnc#1012628).
- KVM: lapic: Fixup LDR on load in x2apic (bnc#1012628).
- mmc: block: Fix missing blk_put_request() (bnc#1012628).
- mmc: block: Check return value of blk_get_request()
  (bnc#1012628).
- mmc: core: Do not leave the block driver in a suspended state
  (bnc#1012628).
- mmc: block: Ensure that debugfs files are removed (bnc#1012628).
- mmc: core: prepend 0x to pre_eol_info entry in sysfs
  (bnc#1012628).
- mmc: core: prepend 0x to OCR entry in sysfs (bnc#1012628).
- ACPI / EC: Fix regression related to PM ops support in ECDT
  device (bnc#1012628).
- eeprom: at24: fix reading from 24MAC402/24MAC602 (bnc#1012628).
- eeprom: at24: correctly set the size for at24mac402
  (bnc#1012628).
- eeprom: at24: check at24_read/write arguments (bnc#1012628).
- i2c: i801: Fix Failed to allocate irq -2147483648 error
  (bnc#1012628).
- cxl: Check if vphb exists before iterating over AFU devices
  (bnc#1012628).
- bcache: Fix building error on MIPS (bnc#1012628).
- bcache: only permit to recovery read error when cache device
  is clean (bnc#1012628).
- bcache: recover data from backing when data is clean
  (bnc#1012628).
- hwmon: (jc42) optionally try to disable the SMBUS timeout
  (bnc#1012628).
- nvme-pci: add quirk for delay before CHK RDY for WDC SN200
  (bnc#1012628).
- Revert "drm/radeon: dont switch vt on suspend" (bnc#1012628).
- drm/amdgpu: potential uninitialized variable in
  amdgpu_vce_ring_parse_cs() (bnc#1012628).
- drm/amdgpu: Potential uninitialized variable in
  amdgpu_vm_update_directories() (bnc#1012628).
- drm/amdgpu: correct reference clock value on vega10
  (bnc#1012628).
- drm/amdgpu: fix error handling in amdgpu_bo_do_create
  (bnc#1012628).
- drm/amdgpu: Properly allocate VM invalidate eng v2
  (bnc#1012628).
- drm/amdgpu: Remove check which is not valid for certain VBIOS
  (bnc#1012628).
- drm/ttm: fix ttm_bo_cleanup_refs_or_queue once more
  (bnc#1012628).
- dma-buf: make reservation_object_copy_fences rcu save
  (bnc#1012628).
- drm/amdgpu: reserve root PD while releasing it (bnc#1012628).
- drm/ttm: Always and only destroy bo->ttm_resv in
  ttm_bo_release_list (bnc#1012628).
- drm/vblank: Fix flip event vblank count (bnc#1012628).
- drm/vblank: Tune drm_crtc_accurate_vblank_count() WARN down
  to a debug (bnc#1012628).
- drm/tilcdc: Precalculate total frametime in
  tilcdc_crtc_set_mode() (bnc#1012628).
- drm/radeon: fix atombios on big endian (bnc#1012628).
- drm/panel: simple: Add missing panel_simple_unprepare() calls
  (bnc#1012628).
- drm/hisilicon: Ensure LDI regs are properly configured
  (bnc#1012628).
- drm/ttm: once more fix ttm_buffer_object_transfer (bnc#1012628).
- drm/amd/pp: fix typecast error in powerplay (bnc#1012628).
- drm/fb_helper: Disable all crtc's when initial setup fails
  (bnc#1012628).
- drm/fsl-dcu: Don't set connector DPMS property (bnc#1012628).
- drm/edid: Don't send non-zero YQ in AVI infoframe for HDMI
  1.x sinks (bnc#1012628).
- drm/amdgpu: move UVD/VCE and VCN structure out from union
  (bnc#1012628).
- drm/amdgpu: Set adev->vcn.irq.num_types for VCN (bnc#1012628).
- include/linux/compiler-clang.h: handle randomizable anonymous
  structs (bnc#1012628).
- IB/core: Do not warn on lid conversions for OPA (bnc#1012628).
- IB/hfi1: Do not warn on lid conversions for OPA (bnc#1012628).
- e1000e: fix the use of magic numbers for buffer overrun issue
  (bnc#1012628).
- md: forbid a RAID5 from having both a bitmap and a journal
  (bnc#1012628).
- drm/i915: Fix false-positive assert_rpm_wakelock_held in
  i915_pmic_bus_access_notifier v2 (bnc#1012628).
- drm/i915: Re-register PMIC bus access notifier on runtime resume
  (bnc#1012628).
- drm/i915/fbdev: Serialise early hotplug events with async
  fbdev config (bnc#1012628).
- drm/i915/gvt: Correct ADDR_4K/2M/1G_MASK definition
  (bnc#1012628).
- drm/i915: Don't try indexed reads to alternate slave addresses
  (bnc#1012628).
- drm/i915: Prevent zero length "index" write (bnc#1012628).
- Revert "x86/entry/64: Add missing irqflags tracing to
  native_load_gs_index()" (bnc#1012628).
- commit b29439c
* Tue Dec  5 2017 jslaby@suse.cz
- x86/stacktrace: do now unwind after user regs (bnc#1058115).
- x86/stacktrace: remove unwind_state->error (bnc#1058115).
- x86/stacktrace: remove STACKTRACE_DUMP_ONCE from
  __save_stack_trace_reliable (bnc#1058115).
- x86/stacktrace: do not fail for ORC with regs on stack
  (bnc#1058115).
  More make-ORC-reliable patches.
- commit a6a5b05
* Mon Dec  4 2017 jeffm@suse.com
- Update to 4.15-rc2.
- Eliminated 2 patches.
- commit 68549b6
* Thu Nov 30 2017 jslaby@suse.cz
- Linux 4.14.3 (bnc#1012628).
- s390: fix transactional execution control register handling
  (bnc#1012628).
- s390/noexec: execute kexec datamover without DAT (bnc#1012628).
- s390/runtime instrumention: fix possible memory corruption
  (bnc#1012628).
- s390/guarded storage: fix possible memory corruption
  (bnc#1012628).
- s390/disassembler: add missing end marker for e7 table
  (bnc#1012628).
- s390/disassembler: increase show_code buffer size (bnc#1012628).
- ACPI / PM: Fix acpi_pm_notifier_lock vs flush_workqueue()
  deadlock (bnc#1012628).
- ACPI / EC: Fix regression related to triggering source of EC
  event handling (bnc#1012628).
- cpufreq: schedutil: Reset cached_raw_freq when not in sync
  with next_freq (bnc#1012628).
- serdev: fix registration of second slave (bnc#1012628).
- sched: Make resched_cpu() unconditional (bnc#1012628).
- lib/mpi: call cond_resched() from mpi_powm() loop (bnc#1012628).
- x86/boot: Fix boot failure when SMP MP-table is based at 0
  (bnc#1012628).
- x86/decoder: Add new TEST instruction pattern (bnc#1012628).
- x86/entry/64: Fix entry_SYSCALL_64_after_hwframe() IRQ tracing
  (bnc#1012628).
- x86/entry/64: Add missing irqflags tracing to
  native_load_gs_index() (bnc#1012628).
- perf/x86/intel: Hide TSX events when RTM is not supported
  (bnc#1012628).
- arm64: Implement arch-specific pte_access_permitted()
  (bnc#1012628).
- ARM: 8722/1: mm: make STRICT_KERNEL_RWX effective for LPAE
  (bnc#1012628).
- ARM: 8721/1: mm: dump: check hardware RO bit for LPAE
  (bnc#1012628).
- uapi: fix linux/tls.h userspace compilation error (bnc#1012628).
- uapi: fix linux/rxrpc.h userspace compilation errors
  (bnc#1012628).
- MIPS: cmpxchg64() and HAVE_VIRT_CPU_ACCOUNTING_GEN don't work
  for 32-bit SMP (bnc#1012628).
- MIPS: ralink: Fix MT7628 pinmux (bnc#1012628).
- MIPS: ralink: Fix typo in mt7628 pinmux function (bnc#1012628).
- net: mvneta: fix handling of the Tx descriptor counter
  (bnc#1012628).
- nbd: wait uninterruptible for the dead timeout (bnc#1012628).
- nbd: don't start req until after the dead connection logic
  (bnc#1012628).
- PM / OPP: Add missing of_node_put(np) (bnc#1012628).
- PCI/ASPM: Account for downstream device's Port
  Common_Mode_Restore_Time (bnc#1012628).
- PCI/ASPM: Use correct capability pointer to program
  LTR_L1.2_THRESHOLD (bnc#1012628).
- PCI: hv: Use effective affinity mask (bnc#1012628).
- PCI: Set Cavium ACS capability quirk flags to assert RR/CR/SV/UF
  (bnc#1012628).
- PCI: Apply Cavium ThunderX ACS quirk to more Root Ports
  (bnc#1012628).
- ALSA: hda: Add Raven PCI ID (bnc#1012628).
- dm integrity: allow unaligned bv_offset (bnc#1012628).
- dm cache: fix race condition in the writeback mode overwrite_bio
  optimisation (bnc#1012628).
- dm crypt: allow unaligned bv_offset (bnc#1012628).
- dm zoned: ignore last smaller runt zone (bnc#1012628).
- dm mpath: remove annoying message of 'blk_get_request()
  returned -11' (bnc#1012628).
- dm bufio: fix integer overflow when limiting maximum cache size
  (bnc#1012628).
- ovl: Put upperdentry if ovl_check_origin() fails (bnc#1012628).
- dm: allocate struct mapped_device with kvzalloc (bnc#1012628).
- sched/rt: Simplify the IPI based RT balancing logic
  (bnc#1012628).
- MIPS: pci: Remove KERN_WARN instance inside the mt7620 driver
  (bnc#1012628).
- dm: fix race between dm_get_from_kobject() and __dm_destroy()
  (bnc#1012628).
- dm: discard support requires all targets in a table support
  discards (bnc#1012628).
- MIPS: Fix odd fp register warnings with MIPS64r2 (bnc#1012628).
- MIPS: Fix MIPS64 FP save/restore on 32-bit kernels
  (bnc#1012628).
- MIPS: dts: remove bogus bcm96358nb4ser.dtb from dtb-y entry
  (bnc#1012628).
- MIPS: Fix an n32 core file generation regset support regression
  (bnc#1012628).
- MIPS: BCM47XX: Fix LED inversion for WRT54GSv1 (bnc#1012628).
- MIPS: math-emu: Fix final emulation phase for certain
  instructions (bnc#1012628).
- rt2x00usb: mark device removed when get ENOENT usb error
  (bnc#1012628).
- mm/z3fold.c: use kref to prevent page free/compact race
  (bnc#1012628).
- autofs: don't fail mount for transient error (bnc#1012628).
- nilfs2: fix race condition that causes file system corruption
  (bnc#1012628).
- fscrypt: lock mutex before checking for bounce page pool
  (bnc#1012628).
- eCryptfs: use after free in ecryptfs_release_messaging()
  (bnc#1012628).
- libceph: don't WARN() if user tries to add invalid key
  (bnc#1012628).
- bcache: check ca->alloc_thread initialized before wake up it
  (bnc#1012628).
- fs: guard_bio_eod() needs to consider partitions (bnc#1012628).
- fanotify: fix fsnotify_prepare_user_wait() failure
  (bnc#1012628).
- isofs: fix timestamps beyond 2027 (bnc#1012628).
- btrfs: change how we decide to commit transactions during
  flushing (bnc#1012628).
- f2fs: expose some sectors to user in inline data or dentry case
  (bnc#1012628).
- NFS: Fix typo in nomigration mount option (bnc#1012628).
- NFS: Revert "NFS: Move the flock open mode check into
  nfs_flock()" (bnc#1012628).
- nfs: Fix ugly referral attributes (bnc#1012628).
- NFS: Avoid RCU usage in tracepoints (bnc#1012628).
- NFS: revalidate "." etc correctly on "open" (bnc#1012628).
- nfsd: deal with revoked delegations appropriately (bnc#1012628).
- rtlwifi: rtl8192ee: Fix memory leak when loading firmware
  (bnc#1012628).
- rtlwifi: fix uninitialized rtlhal->last_suspend_sec time
  (bnc#1012628).
- iwlwifi: fix firmware names for 9000 and A000 series hw
  (bnc#1012628).
- md: fix deadlock error in recent patch (bnc#1012628).
- md: don't check MD_SB_CHANGE_CLEAN in md_allow_write
  (bnc#1012628).
- Bluetooth: btqcomsmd: Add support for BD address setup
  (bnc#1012628).
- md/bitmap: revert a patch (bnc#1012628 bsc#1062597).
- fsnotify: clean up fsnotify_prepare/finish_user_wait()
  (bnc#1012628).
- fsnotify: pin both inode and vfsmount mark (bnc#1012628).
- fsnotify: fix pinning group in fsnotify_prepare_user_wait()
  (bnc#1012628).
- ata: fixes kernel crash while tracing ata_eh_link_autopsy event
  (bnc#1012628).
- ext4: fix interaction between i_size, fallocate, and delalloc
  after a crash (bnc#1012628).
- ext4: prevent data corruption with inline data + DAX
  (bnc#1012628).
- ext4: prevent data corruption with journaling + DAX
  (bnc#1012628).
- ALSA: pcm: update tstamp only if audio_tstamp changed
  (bnc#1012628).
- ALSA: usb-audio: Add sanity checks to FE parser (bnc#1012628).
- ALSA: usb-audio: Fix potential out-of-bound access at parsing SU
  (bnc#1012628).
- ALSA: usb-audio: Add sanity checks in v2 clock parsers
  (bnc#1012628).
- ALSA: timer: Remove kernel warning at compat ioctl error paths
  (bnc#1012628).
- ALSA: hda/realtek - Fix ALC275 no sound issue (bnc#1012628).
- ALSA: hda: Fix too short HDMI/DP chmap reporting (bnc#1012628).
- ALSA: hda - Fix yet remaining issue with vmaster 0dB
  initialization (bnc#1012628).
- ALSA: hda/realtek - Fix ALC700 family no sound issue
  (bnc#1012628).
- ASoC: sun8i-codec: Invert Master / Slave condition
  (bnc#1012628).
- ASoC: sun8i-codec: Fix left and right channels inversion
  (bnc#1012628).
- ASoC: sun8i-codec: Set the BCLK divider (bnc#1012628).
- mfd: lpc_ich: Avoton/Rangeley uses SPI_BYT method (bnc#1012628).
- fix a page leak in vhost_scsi_iov_to_sgl() error recovery
  (bnc#1012628).
- 9p: Fix missing commas in mount options (bnc#1012628).
- fs/9p: Compare qid.path in v9fs_test_inode (bnc#1012628).
- net/9p: Switch to wait_event_killable() (bnc#1012628).
- scsi: qla2xxx: Suppress a kernel complaint in
  qla_init_base_qpair() (bnc#1012628).
- scsi: sd_zbc: Fix sd_zbc_read_zoned_characteristics()
  (bnc#1012628).
- scsi: lpfc: fix pci hot plug crash in timer management routines
  (bnc#1012628).
- scsi: lpfc: fix pci hot plug crash in list_add call
  (bnc#1012628).
- scsi: lpfc: Fix crash receiving ELS while detaching driver
  (bnc#1012628).
- scsi: lpfc: Fix FCP hba_wqidx assignment (bnc#1012628).
- scsi: lpfc: Fix oops if nvmet_fc_register_targetport fails
  (bnc#1012628).
- iscsi-target: Make TASK_REASSIGN use proper se_cmd->cmd_kref
  (bnc#1012628).
- iscsi-target: Fix non-immediate TMR reference leak
  (bnc#1012628).
- target: fix null pointer regression in core_tmr_drain_tmr_list
  (bnc#1012628).
- target: fix buffer offset in core_scsi3_pri_read_full_status
  (bnc#1012628).
- target: Fix QUEUE_FULL + SCSI task attribute handling
  (bnc#1012628).
- target: Fix caw_sem leak in transport_generic_request_failure
  (bnc#1012628).
- target: Fix quiese during transport_write_pending_qf endless
  loop (bnc#1012628).
- target: Avoid early CMD_T_PRE_EXECUTE failures during ABORT_TASK
  (bnc#1012628).
- mtd: Avoid probe failures when mtd->dbg.dfs_dir is invalid
  (bnc#1012628).
- mtd: nand: Export nand_reset() symbol (bnc#1012628).
- mtd: nand: atmel: Actually use the PM ops (bnc#1012628).
- mtd: nand: omap2: Fix subpage write (bnc#1012628).
- mtd: nand: Fix writing mtdoops to nand flash (bnc#1012628).
- mtd: nand: mtk: fix infinite ECC decode IRQ issue (bnc#1012628).
- mailbox: bcm-flexrm-mailbox: Fix FlexRM ring flush sequence
  (bnc#1012628).
- p54: don't unregister leds when they are not initialized
  (bnc#1012628).
- block: Fix a race between blk_cleanup_queue() and timeout
  handling (bnc#1012628).
- raid1: prevent freeze_array/wait_all_barriers deadlock
  (bnc#1012628).
- genirq: Track whether the trigger type has been set
  (bnc#1012628).
- irqchip/gic-v3: Fix ppi-partitions lookup (bnc#1012628).
- lockd: double unregister of inetaddr notifiers (bnc#1012628).
- KVM: PPC: Book3S HV: Don't call real-mode XICS hypercall
  handlers if not enabled (bnc#1012628).
- KVM: nVMX: set IDTR and GDTR limits when loading L1 host state
  (bnc#1012628).
- KVM: SVM: obey guest PAT (bnc#1012628).
- kvm: vmx: Reinstate support for CPUs without virtual NMI
  (bnc#1012628).
- dax: fix PMD faults on zero-length files (bnc#1012628).
- dax: fix general protection fault in dax_alloc_inode
  (bnc#1012628).
- SUNRPC: Fix tracepoint storage issues with svc_recv and
  svc_rqst_status (bnc#1012628).
- clk: ti: dra7-atl-clock: fix child-node lookups (bnc#1012628).
- libnvdimm, dimm: clear 'locked' status on successful DIMM enable
  (bnc#1012628).
- libnvdimm, pfn: make 'resource' attribute only readable by root
  (bnc#1012628).
- libnvdimm, namespace: fix label initialization to use valid
  seq numbers (bnc#1012628).
- libnvdimm, region : make 'resource' attribute only readable
  by root (bnc#1012628).
- libnvdimm, namespace: make 'resource' attribute only readable
  by root (bnc#1012628).
- svcrdma: Preserve CB send buffer across retransmits
  (bnc#1012628).
- IB/srpt: Do not accept invalid initiator port names
  (bnc#1012628).
- IB/cm: Fix memory corruption in handling CM request
  (bnc#1012628).
- IB/hfi1: Fix incorrect available receive user context count
  (bnc#1012628).
- IB/srp: Avoid that a cable pull can trigger a kernel crash
  (bnc#1012628).
- IB/core: Avoid crash on pkey enforcement failed in received MADs
  (bnc#1012628).
- IB/core: Only maintain real QPs in the security lists
  (bnc#1012628).
- NFC: fix device-allocation error return (bnc#1012628).
- spi-nor: intel-spi: Fix broken software sequencing codes
  (bnc#1012628).
- i40e: Use smp_rmb rather than read_barrier_depends
  (bnc#1012628).
- igb: Use smp_rmb rather than read_barrier_depends (bnc#1012628).
- igbvf: Use smp_rmb rather than read_barrier_depends
  (bnc#1012628).
- ixgbevf: Use smp_rmb rather than read_barrier_depends
  (bnc#1012628).
- i40evf: Use smp_rmb rather than read_barrier_depends
  (bnc#1012628).
- fm10k: Use smp_rmb rather than read_barrier_depends
  (bnc#1012628).
- ixgbe: Fix skb list corruption on Power systems (bnc#1012628).
- parisc: Fix validity check of pointer size argument in new
  CAS implementation (bnc#1012628).
- powerpc: Fix boot on BOOK3S_32 with CONFIG_STRICT_KERNEL_RWX
  (bnc#1012628).
- powerpc/mm/radix: Fix crashes on Power9 DD1 with radix MMU
  and STRICT_RWX (bnc#1012628).
- powerpc/perf/imc: Use cpu_to_node() not
  topology_physical_package_id() (bnc#1012628).
- powerpc/signal: Properly handle return value from
  uprobe_deny_signal() (bnc#1012628).
- powerpc/64s: Fix masking of SRR1 bits on instruction fault
  (bnc#1012628).
- powerpc/64s/radix: Fix 128TB-512TB virtual address boundary
  case allocation (bnc#1012628).
- powerpc/64s/hash: Fix 512T hint detection to use >= 128T
  (bnc#1012628).
- powerpc/64s/hash: Fix 128TB-512TB virtual address boundary
  case allocation (bnc#1012628).
- powerpc/64s/hash: Fix fork() with 512TB process address space
  (bnc#1012628).
- powerpc/64s/hash: Allow MAP_FIXED allocations to cross 128TB
  boundary (bnc#1012628).
- media: Don't do DMA on stack for firmware upload in the AS102
  driver (bnc#1012628).
- media: rc: check for integer overflow (bnc#1012628).
- media: rc: nec decoder should not send both repeat and keycode
  (bnc#1012628).
- media: v4l2-ctrl: Fix flags field on Control events
  (bnc#1012628).
- media: venus: fix wrong size on dma_free (bnc#1012628).
- media: venus: venc: fix bytesused v4l2_plane field
  (bnc#1012628).
- media: venus: reimplement decoder stop command (bnc#1012628).
- ARM64: dts: meson-gxl: Add alternate ARM Trusted Firmware
  reserved memory zone (bnc#1012628).
- iwlwifi: fix wrong struct for a000 device (bnc#1012628).
- iwlwifi: add a new a000 device (bnc#1012628).
- iwlwifi: pcie: sort IDs for the 9000 series for easier
  comparisons (bnc#1012628).
- iwlwifi: add new cards for a000 series (bnc#1012628).
- iwlwifi: add new cards for 8265 series (bnc#1012628).
- iwlwifi: add new cards for 8260 series (bnc#1012628).
- iwlwifi: fix PCI IDs and configuration mapping for 9000 series
  (bnc#1012628).
- e1000e: Fix error path in link detection (bnc#1012628).
- e1000e: Fix return value test (bnc#1012628).
- e1000e: Separate signaling for link check/link up (bnc#1012628).
- e1000e: Avoid receiver overrun interrupt bursts (bnc#1012628).
- e1000e: fix buffer overrun while the I219 is processing DMA
  transactions (bnc#1012628).
- Refresh patches.suse/dm-mpath-accept-failed-paths.
- Delete
  patches.suse/0002-md-bitmap-copy-correct-data-for-bitmap-super.patch.
- commit a731a45
* Thu Nov 30 2017 jslaby@suse.cz
- Refresh
  patches.suse/apparmor-fix-oops-in-audit_signal_cb-hook.patch.
  Update upstream status.
- commit 00f319b
* Thu Nov 30 2017 jslaby@suse.cz
- mmc: sdhci: Avoid swiotlb buffer being full (bnc#1068877).
- Delete
  patches.suse/revert-mmc-Delete-bounce-buffer-handling.patch.
- mmc: sdhci: Avoid swiotlb buffer being full (bnc#1068877).
- commit acb1236
* Wed Nov 29 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: fix incorrectly moved comment
  While moving # END COMMON DEPS moved following comment with it.
- commit 858b7e7
* Tue Nov 28 2017 afaerber@suse.de
- config: armv7hl: Update to 4.15-rc1
- commit b4c7f19
* Tue Nov 28 2017 afaerber@suse.de
- config: armv6hl: Update to 4.15-rc1
- commit edcdf48
* Tue Nov 28 2017 afaerber@suse.de
- config: arm64: Update to 4.15-rc1
- commit 3278861
* Mon Nov 27 2017 jeffm@suse.com
- Update to 4.15-rc1.
- Eliminated 74 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - CPU_ISOLATION=y
  - GUP_BENCHMARK=n
  - x86:
  - X86_INTEL_UMIP=y
  - PINCTRL_CEDARFORK=m
  - INTEL_SOC_PMIC_CHTDC_TI=m
  - INTEL_WMI_THUNDERBOLT=m
  - DELL_SMBIOS_WMI=m
  - DELL_SMBIOS_SMM=m
  - CHT_DC_TI_PMIC_OPREGION=y
  - RPMSG_CHAR=m
  - i386:
  - IR_SPI=m
  - IR_GPIO_CIR=m
  - IR_GPIO_TX=m
  - IR_PWM_TX=m
  - powerpc:
  - PPC_RADIX_MMU_DEFAULT=y (default)
  - MEM_SOFT_DIRTY=n (needs arch expert review)
  - PINCTRL=n
  - PPC_FAST_ENDIAN_SWITCH=n (default)
  - s390:
  - GCC_PLUGINS=n
  - MEM_SOFT_DIRTY=(needs arch expert review)
  - PINCTRL=n
  - FORTIFY_SOURCE=y
  - s390/zfcpdump:
  - BPF_STREAM_PARSER=n
  - MTD=n
  - Network:
  - NET_SCH_CBS=m
  - VSOCKETS_DIAG=m
  - DP83822_PHY=m
  - RENESAS_PHY=m
  - THUNDERBOLT_NET=m
  - Input:
  - TOUCHSCREEN_EXC3000=m
  - TOUCHSCREEN_HIDEEP=m
  - TOUCHSCREEN_S6SY761=m
  - DRM_I2C_ADV7511_CEC=y
  - Misc:
  - IPMI_PROC_INTERFACE=y
  - GPIO_MAX3191X=m
  - MANAGER_SBS=m
  - W1_SLAVE_DS28E17=m
  - SENSORS_MAX6621=m
  - SENSORS_MAX31785=m
  - CEC_GPIO=m
  - TYPEC_TPS6598X=m
  - RPMSG_VIRTIO=m
  - IIO_CROS_EC_ACCEL_LEGACY=m
  - RFD77402=m
  - NTB_SWITCHTEC=m
  - MMC_SDHCI_OMAP=m
  - Filesystems:
  - XFS_ONLINE_SCRUB=n (still experimental)
  - BTRFS_FS_REF_VERIFY=n
  - CRAMFS_BLOCKDEV=y
  - CRAMFS_MTD=y
  - INTEGRITY_TRUSTED_KEYRING=y
  - Crypto:
  - CRYPTO_SM3=m
  - SIGNED_PE_FILE_VERIFICATION=y
  - SYSTEM_TRUSTED_KEYS (empty)
  - SYSTEM_EXTRA_CERTIFICATE=n
  - SECONDARY_TRUSTED_KEYRING=n
  - LEDS:
  - LEDS_APU=m
  - LEDS_TRIGGER_ACTIVITY=m
  - RTC:
  - RTC_DRV_PCF85363=m
  - Xen:
  - XEN_PVCALLS_FRONTEND=n
  - Graphics:
  - DRM_AMD_DC=y
  - DRM_AMD_DC_PRE_VEGA=y
  - DRM_AMD_DC_FBC=y ?
  - DRM_AMD_DC_DCN1_0=y
  - DEBUG_KERNEL_DC=n
  - NOUVEAU_DEBUG_MMU=n
  - Storage:
  - NVME_MULTIPATH=y
  - IB:
  - MLX4_CORE_GEN2=y
  - Sound:
  - SND_SOC_INTEL_SST_TOPLEVEL=m
  - SND_SOC_INTEL_BAYTRAIL=m
  - Testing:
  - KCOV_ENABLE_COMPARISONS=y (syzkaller)
  - BOOTPARAM_LOCKDEP_CROSSRELEASE_FULLSTACK=n
  - PREEMPTIRQ_EVENTS=y
  - TEST_FIND_BIT=n
  - PKCS7_TEST_KEY=n
  - CHASH_SELFTEST=n
  - CHASH_STATS=n
- commit bc47c49
* Sun Nov 26 2017 afaerber@suse.de
- config: armv6hl: Enable 8250 irq sharing for RPi Zero W (boo#1069828)
- commit 01942c4
* Sat Nov 25 2017 mwilck@suse.com
- scsi: libfc: fix ELS request handling (bsc#1069801).
- commit 75312a6
* Sat Nov 25 2017 afaerber@suse.de
- config: armv6hl: Enable brcmfmac for RPi Zero W (boo#1069830)
- commit 56423d9
* Sat Nov 25 2017 afaerber@suse.de
- config: armv6hl: Enable 8250 serial console for RPi Zero W (boo#1069828)
- commit 3a3001a
* Fri Nov 24 2017 bp@suse.de
- dvb_frontend: don't use-after-free the frontend struct
  (bsc#1067087 CVE-2017-16648).
- media: dvb-core: always call invoke_release() in fe_free()
  (bsc#1067087).
- commit 2a04ad0
* Fri Nov 24 2017 tiwai@suse.de
- rpm/kernel-binary.spec.in: Correct supplements for recent SLE products (bsc#1067494)
- commit 8f05b9f
* Fri Nov 24 2017 jbeulich@suse.com
- supported:conf: Remove stale Xen driver entries.
- commit c46464b
* Fri Nov 24 2017 jslaby@suse.cz
- ipmi_si: fix memory leak on new_smi (git-fixes).
- commit 4ca3b35
* Fri Nov 24 2017 jslaby@suse.cz
- Linux 4.14.2 (bnc#1012628).
- af_netlink: ensure that NLMSG_DONE never fails in dumps
  (bnc#1012628).
- vxlan: fix the issue that neigh proxy blocks all icmpv6 packets
  (bnc#1012628).
- net: cdc_ncm: GetNtbFormat endian fix (bnc#1012628).
- fealnx: Fix building error on MIPS (bnc#1012628).
- net/sctp: Always set scope_id in sctp_inet6_skb_msgname
  (bnc#1012628).
- ima: do not update security.ima if appraisal status is not
  INTEGRITY_PASS (bnc#1012628).
- serial: omap: Fix EFR write on RTS deassertion (bnc#1012628).
- serial: 8250_fintek: Fix finding base_port with activated
  SuperIO (bnc#1012628).
- tpm-dev-common: Reject too short writes (bnc#1012628).
- rcu: Fix up pending cbs check in rcu_prepare_for_idle
  (bnc#1012628).
- mm/pagewalk.c: report holes in hugetlb ranges (bnc#1012628).
- ocfs2: fix cluster hang after a node dies (bnc#1012628).
- ocfs2: should wait dio before inode lock in ocfs2_setattr()
  (bnc#1012628).
- ipmi: fix unsigned long underflow (bnc#1012628).
- mm/page_alloc.c: broken deferred calculation (bnc#1012628).
- mm/page_ext.c: check if page_ext is not prepared (bnc#1012628).
- coda: fix 'kernel memory exposure attempt' in fsync
  (bnc#1012628).
- ipmi: Prefer ACPI system interfaces over SMBIOS ones
  (bnc#1012628).
- commit 295c90a
* Thu Nov 23 2017 jslaby@suse.cz
- apparmor: fix oops in audit_signal_cb hook (bnc#1069562).
- Refresh patches.suse/0001-AppArmor-basic-networking-rules.patch.
- commit d091ad8
* Thu Nov 23 2017 jslaby@suse.cz
- bio: ensure __bio_clone_fast copies bi_partno (bnc#1069605).
- commit 59c6ade
* Tue Nov 21 2017 jslaby@suse.cz
- Update config files.
  After renaming the UNWINDER config options, vanilla has the old names
  and they need to be in configs. For example, x86_64 default config
  has CONFIG_UNWINDER_ORC=y, vanilla has CONFIG_ORC_UNWINDER=y.
- commit d0dab46
* Tue Nov 21 2017 jslaby@suse.cz
- objtool: Print top level commands on incorrect usage
  (bnc#1058115).
- commit 6603336
* Tue Nov 21 2017 jslaby@suse.cz
- x86/unwind: Make CONFIG_UNWINDER_ORC=y the default in kconfig
  for 64-bit (bnc#1058115).
- Update config files.
- x86/unwind: Rename unwinder config options to
  'CONFIG_UNWINDER_*' (bnc#1058115).
- Refresh patches.suse/0001-orc-mark-it-as-reliable.patch.
- Update config files.
- x86/unwinder: Make CONFIG_UNWINDER_ORC=y the default in the
  64-bit defconfig (bnc#1058115).
- commit c81ce89
* Tue Nov 21 2017 jslaby@suse.cz
- x86/stacktrace: Avoid recording save_stack_trace() wrappers
  (bnc#1058115).
- commit fa72e96
* Tue Nov 21 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-objtool-Don-t-report-end-of-section-error-after-an-e.patch.
- Refresh
  patches.suse/0002-x86-head-Remove-confusing-comment.patch.
- Refresh
  patches.suse/0003-x86-head-Remove-unused-bad_address-code.patch.
- Refresh
  patches.suse/0004-x86-head-Fix-head-ELF-function-annotations.patch.
- Refresh
  patches.suse/0005-x86-boot-Annotate-verify_cpu-as-a-callable-function.patch.
- Refresh
  patches.suse/0006-x86-xen-Fix-xen-head-ELF-annotations.patch.
- Refresh
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-head-Add-unwind-hint-annotations.patch.
  Update upstream status.
- commit f655f80
* Tue Nov 21 2017 jslaby@suse.cz
- move all patches to patches.suse/
- commit 6fafae6
* Tue Nov 21 2017 jslaby@suse.cz
- Linux 4.14.1 (bnc#1012628).
- EDAC, sb_edac: Don't create a second memory controller if HA1
  is not present (bnc#1012628).
- dmaengine: dmatest: warn user when dma test times out
  (bnc#1012628).
- crypto: dh - Fix double free of ctx->p (bnc#1012628).
- crypto: dh - Don't permit 'p' to be 0 (bnc#1012628).
- crypto: dh - Don't permit 'key' or 'g' size longer than 'p'
  (bnc#1012628).
- crypto: brcm - Explicity ACK mailbox message (bnc#1012628).
- USB: early: Use new USB product ID and strings for DbC device
  (bnc#1012628).
- USB: usbfs: compute urb->actual_length for isochronous
  (bnc#1012628).
- USB: Add delay-init quirk for Corsair K70 LUX keyboards
  (bnc#1012628).
- usb: gadget: f_fs: Fix use-after-free in ffs_free_inst
  (bnc#1012628).
- USB: serial: metro-usb: stop I/O after failed open
  (bnc#1012628).
- USB: serial: Change DbC debug device binding ID (bnc#1012628).
- USB: serial: qcserial: add pid/vid for Sierra Wireless EM7355
  fw update (bnc#1012628).
- USB: serial: garmin_gps: fix I/O after failed probe and remove
  (bnc#1012628).
- USB: serial: garmin_gps: fix memory leak on probe errors
  (bnc#1012628).
- selftests/x86/protection_keys: Fix syscall NR redefinition
  warnings (bnc#1012628).
- x86/MCE/AMD: Always give panic severity for UC errors in kernel
  context (bnc#1012628).
- platform/x86: peaq-wmi: Add DMI check before binding to the
  WMI interface (bnc#1012628 bsc#1059807).
- platform/x86: peaq_wmi: Fix missing terminating entry for
  peaq_dmi_table (bnc#1012628).
- HID: cp2112: add HIDRAW dependency (bnc#1012628).
- HID: wacom: generic: Recognize WACOM_HID_WD_PEN as a type of
  pen collection (bnc#1012628).
- rpmsg: glink: Add missing MODULE_LICENSE (bnc#1012628).
- staging: wilc1000: Fix bssid buffer offset in Txq (bnc#1012628).
- staging: sm750fb: Fix parameter mistake in poke32 (bnc#1012628).
- staging: ccree: fix 64 bit scatter/gather DMA ops (bnc#1012628).
- staging: greybus: spilib: fix use-after-free after
  deregistration (bnc#1012628).
- staging: vboxvideo: Fix reporting invalid
  suggested-offset-properties (bnc#1012628).
- staging: rtl8188eu: Revert 4 commits breaking ARP (bnc#1012628).
- spi: fix use-after-free at controller deregistration
  (bnc#1012628).
- sparc32: Add cmpxchg64() (bnc#1012628).
- sparc64: mmu_context: Add missing include files (bnc#1012628).
- sparc64: Fix page table walk for PUD hugepages (bnc#1012628).
- commit b1ba0c0
* Tue Nov 21 2017 jslaby@suse.cz
- drm/bridge: analogix dp: Fix runtime PM state in get_modes()
  callback (bnc#1069146).
- commit 8354c2c
* Tue Nov 21 2017 jslaby@suse.cz
- Linux 4.14.1 (bnc#1012628).
- EDAC, sb_edac: Don't create a second memory controller if HA1
  is not present (bnc#1012628).
- dmaengine: dmatest: warn user when dma test times out
  (bnc#1012628).
- crypto: dh - Fix double free of ctx->p (bnc#1012628).
- crypto: dh - Don't permit 'p' to be 0 (bnc#1012628).
- crypto: dh - Don't permit 'key' or 'g' size longer than 'p'
  (bnc#1012628).
- crypto: brcm - Explicity ACK mailbox message (bnc#1012628).
- USB: early: Use new USB product ID and strings for DbC device
  (bnc#1012628).
- USB: usbfs: compute urb->actual_length for isochronous
  (bnc#1012628).
- USB: Add delay-init quirk for Corsair K70 LUX keyboards
  (bnc#1012628).
- usb: gadget: f_fs: Fix use-after-free in ffs_free_inst
  (bnc#1012628).
- USB: serial: metro-usb: stop I/O after failed open
  (bnc#1012628).
- USB: serial: Change DbC debug device binding ID (bnc#1012628).
- USB: serial: qcserial: add pid/vid for Sierra Wireless EM7355
  fw update (bnc#1012628).
- USB: serial: garmin_gps: fix I/O after failed probe and remove
  (bnc#1012628).
- USB: serial: garmin_gps: fix memory leak on probe errors
  (bnc#1012628).
- selftests/x86/protection_keys: Fix syscall NR redefinition
  warnings (bnc#1012628).
- x86/MCE/AMD: Always give panic severity for UC errors in kernel
  context (bnc#1012628).
- platform/x86: peaq_wmi: Fix missing terminating entry for
  peaq_dmi_table (bnc#1012628).
- HID: cp2112: add HIDRAW dependency (bnc#1012628).
- HID: wacom: generic: Recognize WACOM_HID_WD_PEN as a type of
  pen collection (bnc#1012628).
- rpmsg: glink: Add missing MODULE_LICENSE (bnc#1012628).
- staging: wilc1000: Fix bssid buffer offset in Txq (bnc#1012628).
- staging: sm750fb: Fix parameter mistake in poke32 (bnc#1012628).
- staging: ccree: fix 64 bit scatter/gather DMA ops (bnc#1012628).
- staging: greybus: spilib: fix use-after-free after
  deregistration (bnc#1012628).
- staging: vboxvideo: Fix reporting invalid
  suggested-offset-properties (bnc#1012628).
- staging: rtl8188eu: Revert 4 commits breaking ARP (bnc#1012628).
- spi: fix use-after-free at controller deregistration
  (bnc#1012628).
- sparc32: Add cmpxchg64() (bnc#1012628).
- sparc64: mmu_context: Add missing include files (bnc#1012628).
- sparc64: Fix page table walk for PUD hugepages (bnc#1012628).
- commit 5bbb894
* Mon Nov 20 2017 jslaby@suse.cz
- iwlwifi: mvm: support version 7 of the SCAN_REQ_UMAC FW command
  (bnc#1068838).
- commit 1d02750
* Mon Nov 20 2017 jslaby@suse.cz
- Revert "mmc: Delete bounce buffer handling" (bnc#1068877).
- commit ad8c19c
* Sat Nov 18 2017 schwab@suse.de
- ILP32
- commit e11ab6a
* Wed Nov 15 2017 rgoldwyn@suse.com
- apparmor: Fix quieting of audit messages for network mediation
  (FATE#300516, boo#1065536).
- apparmor: update apparmor-basic-networking-rules for 4.11-rc1
  (FATE#300516, boo#1065536).
- AppArmor: basic networking rules (FATE#300516, boo#1065536).
- commit fca1de8
* Wed Nov 15 2017 rgoldwyn@suse.com
- VFS: Handle lazytime in do_mount() (boo#1068256).
- commit 0f12060
* Mon Nov 13 2017 jeffm@suse.com
- Update to 4.14-final.
- commit c152297
* Thu Nov  9 2017 lpechacek@suse.com
- rpm/kernel-binary.spec.in: rename kGraft to KLP (fate#323682)
- commit 0ed191d
* Wed Nov  8 2017 tiwai@suse.de
- media: dib0700: fix invalid dvb_detach argument (CVE-2017-16646
  bsc#1067105).
- commit c6cd519
* Wed Nov  8 2017 tiwai@suse.de
- Input: ims-psu - check if CDC union descriptor is sane
  (CVE-2017-16645 bsc#1067132).
- commit 0cfe4b6
* Wed Nov  8 2017 tiwai@suse.de
- net: usb: asix: fill null-ptr-deref in asix_suspend
  (CVE-2017-16647 bsc#1067102).
- commit a088160
* Wed Nov  8 2017 jslaby@suse.cz
- Linux 4.13.12 (bnc#1012628).
- irqchip/irq-mvebu-gicp: Add missing spin_lock init
  (bnc#1012628).
- x86/mcelog: Get rid of RCU remnants (bnc#1012628).
- perf/cgroup: Fix perf cgroup hierarchy support (bnc#1012628).
- futex: Fix more put_pi_state() vs. exit_pi_state_list() races
  (bnc#1012628).
- powerpc/kprobes: Dereference function pointers only if the
  address does not belong to kernel text (bnc#1012628).
- x86: CPU: Fix up "cpu MHz" in /proc/cpuinfo (bnc#1012628).
- Revert "x86: do not use cpufreq_quick_get() for /proc/cpuinfo
  "cpu MHz"" (bnc#1012628).
- MIPS: SMP: Fix deadlock & online race (bnc#1012628).
- MIPS: microMIPS: Fix incorrect mask in insn_table_MM
  (bnc#1012628).
- MIPS: smp-cmp: Use right include for task_struct (bnc#1012628).
- MIPS: bpf: Fix a typo in build_one_insn() (bnc#1012628).
- Revert "powerpc64/elfv1: Only dereference function descriptor
  for non-text symbols" (bnc#1012628).
- drm/i915/edp: read edp display control registers unconditionally
  (bnc#1012628).
- drm/i915: Do not rely on wm preservation for ILK watermarks
  (bnc#1012628).
- mm, swap: fix race between swap count continuation operations
  (bnc#1012628).
- fs/hugetlbfs/inode.c: fix hwpoison reserve accounting
  (bnc#1012628).
- ocfs2: fstrim: Fix start offset of first cluster group during
  fstrim (bnc#1012628).
- userfaultfd: hugetlbfs: prevent UFFDIO_COPY to fill beyond
  the end of i_size (bnc#1012628).
- drm/amdgpu: allow harvesting check for Polaris VCE
  (bnc#1012628).
- drm/amdgpu: return -ENOENT from uvd 6.0 early init for
  harvesting (bnc#1012628).
- ARM: 8715/1: add a private asm/unaligned.h (bnc#1012628).
- ARM: dts: mvebu: pl310-cache disable double-linefill
  (bnc#1012628).
- arm/arm64: kvm: Disable branch profiling in HYP code
  (bnc#1012628).
- arm/arm64: KVM: set right LR register value for 32 bit guest
  when inject abort (bnc#1012628).
- KVM: arm64: its: Fix missing dynamic allocation check in
  scan_its_table (bnc#1012628).
- arm64: ensure __dump_instr() checks addr_limit (bnc#1012628).
- virtio_blk: Fix an SG_IO regression (bnc#1012628).
- ASoC: adau17x1: Workaround for noise bug in ADC (bnc#1012628).
- KEYS: fix out-of-bounds read during ASN.1 parsing (bnc#1012628).
- KEYS: trusted: fix writing past end of buffer in trusted_read()
  (bnc#1012628).
- KEYS: return full count in keyring_read() if buffer is too small
  (bnc#1012628).
- cifs: check MaxPathNameComponentLength != 0 before using it
  (bnc#1012628).
- ALSA: seq: Fix nested rwsem annotation for lockdep splat
  (bnc#1012628).
- ALSA: timer: Add missing mutex lock for compat ioctls
  (bnc#1012628).
- commit 19cf938
* Mon Nov  6 2017 jeffm@suse.com
- Update to 4.14-rc8.
- commit 0fbdeee
* Mon Nov  6 2017 tiwai@suse.de
- media: imon: Fix null-ptr-deref in imon_probe (CVE-2017-16537
  bsc#1066573).
- [media] cx231xx-cards: fix NULL-deref on missing association
  descriptor (CVE-2017-16536 bsc#1066606).
- media: imon: Fix null-ptr-deref in imon_probe (CVE-2017-16537
  bsc#1066573).
- [media] cx231xx-cards: fix NULL-deref on missing association
  descriptor (CVE-2017-16536 bsc#1066606).
- commit 0cd38c2
* Mon Nov  6 2017 jkosina@suse.cz
- rpm/kernel-binary.spec.in: add explicit dependency of kernel-*-devel on
  libelf-devel.
  Otherwise warning that got turned into error by upstream 3dd40cb3 ("objtool:
  Upgrade libelf-devel warning to error...") would trigger and cause any
  packages being built against kernel-*-devel (such as KMPs, crash) not to have
  the libelf dependency included, and fail to build.
- rpm/kernel-binary.spec.in: add explicit dependency of kernel-*-devel on
  libelf-devel. Otherwise warning that got turned into error by e683952999
  ("objtool: Upgrade libelf-devel warning to error...") would trigger and
  cause any packages being built against kernel-*-devel (such as KMPs,
  crash) not to have the libelf dependency included, and fail to build.
- commit f6c0f80
* Fri Nov  3 2017 mcgrof@suse.com
- mac80211: don't compare TKIP TX MIC key in reinstall prevention
  (bsc#1066472).
- commit a2a7106
* Fri Nov  3 2017 mcgrof@suse.com
- mac80211: use constant time comparison with keys (bsc#1066471).
- commit e2a3d57
* Thu Nov  2 2017 jslaby@suse.cz
- Linux 4.13.11 (bnc#1012628).
- powerpc/xive: Fix the size of the cpumask used in
  xive_find_target_in_mask() (bnc#1012628).
- regulator: fan53555: fix I2C device ids (bnc#1012628).
- ipsec: Fix aborted xfrm policy dump crash (bnc#1012628).
- cfg80211: fix connect/disconnect edge cases (bnc#1012628).
- can: kvaser_usb: Ignore CMD_FLUSH_QUEUE_REPLY messages
  (bnc#1012628).
- can: kvaser_usb: Correct return value in printout (bnc#1012628).
- can: sun4i: fix loopback mode (bnc#1012628).
- drm/i915/perf: fix perf enable/disable ioctls with 32bits
  userspace (bnc#1012628).
- drm/amd/powerplay: fix uninitialized variable (bnc#1012628).
- x86/cpu/AMD: Apply the Erratum 688 fix when the BIOS doesn't
  (bnc#1012628).
- scsi: sg: Re-fix off by one in sg_fill_request_table()
  (bnc#1012628).
- scsi: qla2xxx: Initialize Work element before requesting IRQs
  (bnc#1012628).
- scsi: aacraid: Fix controller initialization failure
  (bnc#1012628).
- scsi: zfcp: fix erp_action use-before-initialize in REC action
  trace (bnc#1012628).
- assoc_array: Fix a buggy node-splitting case (bnc#1012628).
- SMB3: Validate negotiate request must always be signed
  (bnc#1012628).
- Fix encryption labels and lengths for SMB3.1.1 (bnc#1012628).
- Input: gtco - fix potential out-of-bound access (bnc#1012628).
- Input: elan_i2c - add ELAN0611 to the ACPI table (bnc#1012628).
- CIFS: Fix NULL pointer deref on SMB2_tcon() failure
  (bnc#1012628).
- cifs: Select all required crypto modules (bnc#1012628).
- xen: fix booting ballooned down hvm guest (bnc#1012628).
- xen/gntdev: avoid out of bounds access in case of partial
  gntdev_mmap() (bnc#1012628).
- fuse: fix READDIRPLUS skipping an entry (bnc#1012628).
- ovl: do not cleanup unsupported index entries (bnc#1012628).
- ovl: handle ENOENT on index lookup (bnc#1012628).
- ovl: fix EIO from lookup of non-indexed upper (bnc#1012628).
- ovl: add NULL check in ovl_alloc_inode (bnc#1012628).
- spi: armada-3700: Fix failing commands with quad-SPI
  (bnc#1012628).
- spi: bcm-qspi: Fix use after free in bcm_qspi_probe() in error
  path (bnc#1012628).
- spi: a3700: Return correct value on timeout detection
  (bnc#1012628).
- spi: uapi: spidev: add missing ioctl header (bnc#1012628).
- nbd: handle interrupted sendmsg with a sndtimeo set
  (bnc#1012628).
- s390/kvm: fix detection of guest machine checks (bnc#1012628).
- KVM: PPC: Book3S: Protect kvmppc_gpa_to_ua() with SRCU
  (bnc#1012628).
- KVM: PPC: Book3S HV: POWER9 more doorbell fixes (bnc#1012628).
- KVM: PPC: Fix oops when checking KVM_CAP_PPC_HTM (bnc#1012628).
- Fix tracing sample code warning (bnc#1012628).
- ceph: unlock dangling spinlock in try_flush_caps()
  (bnc#1012628).
- ALSA: hda - fix headset mic problem for Dell machines with
  alc236 (bnc#1012628).
- ALSA: hda/realtek - Add support for ALC236/ALC3204
  (bnc#1012628).
- nvme-fc: fix iowait hang (bnc#1012628).
- workqueue: replace pool->manager_arb mutex with a flag
  (bnc#1012628).
- commit 5a48675
* Mon Oct 30 2017 neilb@suse.com
- REVERT:  md/bitmap: copy correct data for bitmap super
  (bsc#1062597).
- commit 9382440
* Mon Oct 30 2017 jslaby@suse.cz
- x86/unwind: Show function name+offset in ORC error messages
  (bnc#1058115).
- x86/entry: Fix idtentry unwind hint (bnc#1058115).
- objtool: Fix memory leak in decode_instructions() (bnc#1058115).
- x86/unwind: Disable unwinder warnings on 32-bit (bnc#1058115).
- x86/unwind: Align stack pointer in unwinder dump (bnc#1058115).
- x86/unwind: Use MSB for frame pointer encoding on 32-bit
  (bnc#1058115).
- x86/unwind: Fix dereference of untrusted pointer (bnc#1058115).
- x86/kvm: Move kvm_fastop_exception to .fixup section
  (bnc#1058115).
- objtool: Upgrade libelf-devel warning to error for
  CONFIG_ORC_UNWINDER (bnc#1058115).
- kprobes/x86: Set up frame pointer in kprobe trampoline
  (bnc#1058115).
- objtool: Support unoptimized frame pointer setup (bnc#1058115).
- objtool: Skip unreachable warnings for GCC 4.4 and older
  (bnc#1058115).
- commit dd8c5e5
* Mon Oct 30 2017 jeffm@suse.com
- Update to 4.14-rc7.
- commit dbf3e9b
* Sun Oct 29 2017 jslaby@suse.cz
- x86/unwind: Show function name+offset in ORC error messages
  (bnc#1058115).
- x86/entry: Fix idtentry unwind hint (bnc#1058115).
- commit 951f578
* Fri Oct 27 2017 jslaby@suse.cz
- Linux 4.13.10 final
- commit db36cf8
* Fri Oct 27 2017 jslaby@suse.cz
- scripts/stableids: revert unwanted change
- commit d6206ec
* Fri Oct 27 2017 jslaby@suse.cz
- futex: futex_wake_op, fix sign_extend32 sign bits (bnc#1064590).
- commit a6d946f
* Thu Oct 26 2017 neilb@suse.com
- VFS: expedite unmount (bsc#1024412).
- commit 10c4365
* Wed Oct 25 2017 jslaby@suse.cz
- Linux 4.13.10 (bnc#1012628).
- staging: bcm2835-audio: Fix memory corruption (bnc#1012628).
- USB: devio: Revert "USB: devio: Don't corrupt user memory"
  (bnc#1012628).
- USB: core: fix out-of-bounds access bug in
  usb_get_bos_descriptor() (bnc#1012628).
- USB: serial: metro-usb: add MS7820 device id (bnc#1012628).
- usb: cdc_acm: Add quirk for Elatec TWN3 (bnc#1012628).
- usb: quirks: add quirk for WORLDE MINI MIDI keyboard
  (bnc#1012628).
- usb: hub: Allow reset retry for USB2 devices on connect bounce
  (bnc#1012628).
- ALSA: usb-audio: Add native DSD support for Pro-Ject Pre Box
  S2 Digital (bnc#1012628).
- can: gs_usb: fix busy loop if no more TX context is available
  (bnc#1012628).
- scsi: qla2xxx: Fix uninitialized work element (bnc#1012628).
- nbd: don't set the device size until we're connected
  (bnc#1012628).
- s390/cputime: fix guest/irq/softirq times after CPU hotplug
  (bnc#1012628).
- parisc: Fix double-word compare and exchange in LWS code on
  32-bit kernels (bnc#1012628).
- parisc: Fix detection of nonsynchronous cr16 cycle counters
  (bnc#1012628).
- iio: dummy: events: Add missing break (bnc#1012628).
- usb: musb: sunxi: Explicitly release USB PHY on exit
  (bnc#1012628).
- USB: musb: fix session-bit runtime-PM quirk (bnc#1012628).
- USB: musb: fix late external abort on suspend (bnc#1012628).
- usb: musb: musb_cppi41: Fix the address of teardown and autoreq
  registers (bnc#1012628).
- usb: musb: musb_cppi41: Fix cppi41_set_dma_mode() for DA8xx
  (bnc#1012628).
- usb: musb: musb_cppi41: Configure the number of channels for
  DA8xx (bnc#1012628).
- usb: musb: Check for host-mode using is_host_active() on reset
  interrupt (bnc#1012628).
- xhci: Identify USB 3.1 capable hosts by their port protocol
  capability (bnc#1012628).
- xhci: Cleanup current_cmd in xhci_cleanup_command_queue()
  (bnc#1012628).
- usb: xhci: Reset halted endpoint if trb is noop (bnc#1012628).
- usb: xhci: Handle error condition in xhci_stop_device()
  (bnc#1012628).
- can: esd_usb2: Fix can_dlc value for received RTR, frames
  (bnc#1012628).
- can: af_can: can_pernet_init(): add missing error handling
  for kzalloc returning NULL (bnc#1012628).
- can: flexcan: fix state transition regression (bnc#1012628).
- can: flexcan: rename legacy error state quirk (bnc#1012628).
- can: flexcan: implement error passive state quirk (bnc#1012628).
- can: flexcan: fix i.MX6 state transition issue (bnc#1012628).
- can: flexcan: fix i.MX28 state transition issue (bnc#1012628).
- can: flexcan: fix p1010 state transition issue (bnc#1012628).
- KEYS: encrypted: fix dereference of NULL user_key_payload
  (bnc#1012628).
- mmc: sdhci-pci: Fix default d3_retune for Intel host controllers
  (bnc#1012628).
- drm/i915: Use bdw_ddi_translations_fdi for Broadwell
  (bnc#1012628).
- drm/nouveau/kms/nv50: fix oops during DP IRQ handling on
  non-MST boards (bnc#1012628).
- drm/nouveau/bsp/g92: disable by default (bnc#1012628).
- drm/nouveau/mmu: flush tlbs before deleting page tables
  (bnc#1012628).
- media: s5p-cec: add NACK detection support (bnc#1012628).
- media: cec: Respond to unregistered initiators, when applicable
  (bnc#1012628).
- media: dvb: i2c transfers over usb cannot be done from stack
  (bnc#1012628).
- tracing/samples: Fix creation and deletion of simple_thread_fn
  creation (bnc#1012628).
- ALSA: seq: Enable 'use' locking in all configurations
  (bnc#1012628).
- ALSA: hda: Remove superfluous '-' added by printk conversion
  (bnc#1012628).
- i2c: ismt: Separate I2C block read from SMBus block read
  (bnc#1012628).
- i2c: piix4: Fix SMBus port selection for AMD Family 17h chips
  (bnc#1012628).
- Revert "tools/power turbostat: stop migrating, unless '-m'"
  (bnc#1012628).
- Input: stmfts - fix setting ABS_MT_POSITION_* maximum size
  (bnc#1012628).
- brcmfmac: Add check for short event packets (bnc#1012628).
- brcmsmac: make some local variables 'static const' to reduce
  stack size (bnc#1012628).
- ARM: dts: sun6i: Fix endpoint IDs in second display pipeline
  (bnc#1012628).
- bus: mbus: fix window size calculation for 4GB windows
  (bnc#1012628).
- clockevents/drivers/cs5535: Improve resilience to spurious
  interrupts (bnc#1012628).
- rtlwifi: rtl8821ae: Fix connection lost problem (bnc#1012628).
- x86/microcode/intel: Disable late loading on model 79
  (bnc#1012628).
- lib/digsig: fix dereference of NULL user_key_payload
  (bnc#1012628).
- fscrypt: fix dereference of NULL user_key_payload (bnc#1012628).
- ecryptfs: fix dereference of NULL user_key_payload
  (bnc#1012628).
- KEYS: Fix race between updating and finding a negative key
  (bnc#1012628).
- FS-Cache: fix dereference of NULL user_key_payload
  (bnc#1012628).
- KEYS: don't let add_key() update an uninstantiated key
  (bnc#1012628).
- pkcs7: Prevent NULL pointer dereference, since sinfo is not
  always set (bnc#1012628).
- arm64: dts: rockchip: correct vqmmc voltage for rk3399 platforms
  (bnc#1012628).
- ALSA: hda - Fix incorrect TLV callback check introduced during
  set_fs() removal (bnc#1012628).
- iomap_dio_rw: Allocate AIO completion queue before submitting
  dio (bnc#1012628).
- xfs: don't unconditionally clear the reflink flag on zero-block
  files (bnc#1012628).
- xfs: evict CoW fork extents when performing finsert/fcollapse
  (bnc#1012628).
- fs/xfs: Use %%pS printk format for direct addresses
  (bnc#1012628).
- xfs: report zeroed or not correctly in xfs_zero_range()
  (bnc#1012628).
- xfs: update i_size after unwritten conversion in dio completion
  (bnc#1012628).
- xfs: perag initialization should only touch m_ag_max_usable
  for AG 0 (bnc#1012628).
- xfs: Capture state of the right inode in xfs_iflush_done
  (bnc#1012628).
- xfs: always swap the cow forks when swapping extents
  (bnc#1012628).
- xfs: handle racy AIO in xfs_reflink_end_cow (bnc#1012628).
- xfs: Don't log uninitialised fields in inode structures
  (bnc#1012628).
- xfs: move more RT specific code under CONFIG_XFS_RT
  (bnc#1012628).
- xfs: don't change inode mode if ACL update fails (bnc#1012628).
- xfs: reinit btree pointer on attr tree inactivation walk
  (bnc#1012628).
- xfs: handle error if xfs_btree_get_bufs fails (bnc#1012628
  bsc#1059863).
- xfs: cancel dirty pages on invalidation (bnc#1012628).
- xfs: trim writepage mapping to within eof (bnc#1012628).
- xfs: move two more RT specific functions into CONFIG_XFS_RT
  (bnc#1012628).
- scripts/stableids:
- commit e760ea6
* Mon Oct 23 2017 jeffm@suse.com
- Update to 4.14-rc6.
- Eliminated 2 patches.
- commit 8b364ca
* Mon Oct 23 2017 jslaby@suse.cz
- futex: do not fail on invalid op (bnc#1064590).
- commit e7d7106
* Sun Oct 22 2017 jslaby@suse.cz
- Linux 4.13.9 (bnc#1012628).
- vmbus: more host signalling avoidance (bnc#1012628).
- vmbus: eliminate duplicate cached index (bnc#1012628).
- vmbus: refactor hv_signal_on_read (bnc#1012628).
- vmbus: simplify hv_ringbuffer_read (bnc#1012628).
- Drivers: hv: vmbus: Fix bugs in rescind handling (bnc#1012628).
- Drivers: hv: vmbus: Fix rescind handling issues (bnc#1012628).
- HID: hid-elecom: extend to fix descriptor for HUGE trackball
  (bnc#1012628).
- mm: page_vma_mapped: ensure pmd is loaded with READ_ONCE
  outside of lock (bnc#1012628).
- perf pmu: Unbreak perf record for arm/arm64 with events with
  explicit PMU (bnc#1012628).
- x86/apic: Silence "FW_BUG TSC_DEADLINE disabled due to Errata"
  on hypervisors (bnc#1012628).
- x86/apic: Silence "FW_BUG TSC_DEADLINE disabled due to Errata"
  on CPUs without the feature (bnc#1012628).
- commit abdc07c
* Wed Oct 18 2017 mcgrof@suse.com
- mac80211: accept key reinstall without changing anything (CVE-2017-13080 bsc#1063667).
- commit 19d19fc
* Wed Oct 18 2017 tiwai@suse.de
- ALSA: hda: Abort capability probe at invalid register read
  (bsc#1064017).
- commit d1f5e26
* Wed Oct 18 2017 jslaby@suse.cz
- Linux 4.13.8 (bnc#1012628).
- USB: dummy-hcd: Fix deadlock caused by disconnect detection
  (bnc#1012628).
- MIPS: math-emu: Remove pr_err() calls from fpu_emu()
  (bnc#1012628).
- MIPS: bpf: Fix uninitialised target compiler error
  (bnc#1012628).
- mei: always use domain runtime pm callbacks (bnc#1012628).
- dmaengine: edma: Align the memcpy acnt array size with the
  transfer (bnc#1012628).
- dmaengine: ti-dma-crossbar: Fix possible race condition with
  dma_inuse (bnc#1012628).
- NFS: Fix uninitialized rpc_wait_queue (bnc#1012628).
- nfs/filelayout: fix oops when freeing filelayout segment
  (bnc#1012628).
- HID: usbhid: fix out-of-bounds bug (bnc#1012628).
- crypto: skcipher - Fix crash on zero-length input (bnc#1012628).
- crypto: shash - Fix zero-length shash ahash digest crash
  (bnc#1012628).
- KVM: MMU: always terminate page walks at level 1 (bnc#1012628).
- KVM: nVMX: fix guest CR4 loading when emulating L2 to L1 exit
  (bnc#1012628).
- usb: renesas_usbhs: Fix DMAC sequence for receiving zero-length
  packet (bnc#1012628).
- pinctrl/amd: Fix build dependency on pinmux code (bnc#1012628).
- iommu/amd: Finish TLB flush in amd_iommu_unmap() (bnc#1012628).
- device property: Track owner device of device property
  (bnc#1012628).
- Revert "vmalloc: back off when the current task is killed"
  (bnc#1012628).
- fs/mpage.c: fix mpage_writepage() for pages with buffers
  (bnc#1012628).
- ALSA: usb-audio: Kill stray URB at exiting (bnc#1012628).
- ALSA: seq: Fix copy_from_user() call inside lock (bnc#1012628).
- ALSA: caiaq: Fix stray URB at probe error path (bnc#1012628).
- ALSA: line6: Fix NULL dereference at podhd_disconnect()
  (bnc#1012628).
- ALSA: line6: Fix missing initialization before error path
  (bnc#1012628).
- ALSA: line6: Fix leftover URB at error-path during probe
  (bnc#1012628).
- drm/atomic: Unref duplicated drm_atomic_state in
  drm_atomic_helper_resume() (bnc#1012628).
- drm/i915/edp: Get the Panel Power Off timestamp after panel
  is off (bnc#1012628).
- drm/i915: Read timings from the correct transcoder in
  intel_crtc_mode_get() (bnc#1012628).
- drm/i915/bios: parse DDI ports also for CHV for HDMI DDC pin
  and DP AUX channel (bnc#1012628).
- drm/i915: Use crtc_state_is_legacy_gamma in intel_color_check
  (bnc#1012628).
- usb: gadget: configfs: Fix memory leak of interface directory
  data (bnc#1012628).
- usb: gadget: composite: Fix use-after-free in
  usb_composite_overwrite_options (bnc#1012628).
- PCI: aardvark: Move to struct pci_host_bridge IRQ mapping
  functions (bnc#1012628).
- Revert "PCI: tegra: Do not allocate MSI target memory"
  (bnc#1012628).
- direct-io: Prevent NULL pointer access in submit_page_section
  (bnc#1012628).
- fix unbalanced page refcounting in bio_map_user_iov
  (bnc#1012628).
- more bio_map_user_iov() leak fixes (bnc#1012628).
- bio_copy_user_iov(): don't ignore ->iov_offset (bnc#1012628).
- perf script: Add missing separator for "-F ip,brstack" (and
  brstackoff) (bnc#1012628).
- genirq/cpuhotplug: Enforce affinity setting on startup of
  managed irqs (bnc#1012628).
- genirq/cpuhotplug: Add sanity check for effective affinity mask
  (bnc#1012628).
- USB: serial: ftdi_sio: add id for Cypress WICED dev board
  (bnc#1012628).
- USB: serial: cp210x: fix partnum regression (bnc#1012628).
- USB: serial: cp210x: add support for ELV TFD500 (bnc#1012628).
- USB: serial: option: add support for TP-Link LTE module
  (bnc#1012628).
- USB: serial: qcserial: add Dell DW5818, DW5819 (bnc#1012628).
- USB: serial: console: fix use-after-free on disconnect
  (bnc#1012628).
- USB: serial: console: fix use-after-free after failed setup
  (bnc#1012628).
- RAS/CEC: Use the right length for "cec_disable" (bnc#1012628).
- x86/microcode: Do the family check first (bnc#1012628).
- x86/alternatives: Fix alt_max_short macro to really be a max()
  (bnc#1012628).
- KVM: nVMX: update last_nonleaf_level when initializing nested
  EPT (bnc#1012628).
- commit 569e26e
* Wed Oct 18 2017 mcgrof@suse.com
- xfs: handle error if xfs_btree_get_bufs fails (bsc#1059863).
- commit a1a185d
* Mon Oct 16 2017 jeffm@suse.com
- Update to 4.14-rc5.
- commit 39eecab
* Mon Oct 16 2017 jslaby@suse.cz
- futex: Remove duplicated code and fix undefined behaviour
  (bnc#1005915).
- commit b17692d
* Sun Oct 15 2017 jslaby@suse.cz
- Linux 4.13.7 (bnc#1012628).
- commit 031d6da
* Fri Oct 13 2017 msuchanek@suse.de
- Revert "rpm/constraints.in: Lower default disk space requirement from 25G to 24G"
  This reverts commit 406abda1467c038842febffe264faae1fa2e3c1d.
  ok, did not wait long enough to see the failure.
- commit ed99981
* Fri Oct 13 2017 msuchanek@suse.de
- rpm/constraints.in: Lower default disk space requirement from 25G to 24G
  25G is rejected by the build service on ARM.
- commit 406abda
* Fri Oct 13 2017 jslaby@suse.cz
- waitid(): Add missing access_ok() checks (bnc#1062473
  CVE-2017-5123).
- commit a8d2202
* Thu Oct 12 2017 jslaby@suse.cz
- Linux 4.13.6 (bnc#1012628).
- imx-media-of: avoid uninitialized variable warning
  (bnc#1012628).
- usb: dwc3: ep0: fix DMA starvation by assigning req->trb on ep0
  (bnc#1012628).
- mlxsw: spectrum: Fix EEPROM access in case of SFP/SFP+
  (bnc#1012628).
- net: bonding: Fix transmit load balancing in balance-alb mode
  if specified by sysfs (bnc#1012628).
- openvswitch: Fix an error handling path in
  'ovs_nla_init_match_and_action()' (bnc#1012628).
- mlxsw: spectrum: Prevent mirred-related crash on removal
  (bnc#1012628).
- net: bonding: fix tlb_dynamic_lb default value (bnc#1012628).
- net_sched: gen_estimator: fix scaling error in bytes/packets
  samples (bnc#1012628).
- net: sched: fix use-after-free in tcf_action_destroy and
  tcf_del_walker (bnc#1012628).
- sctp: potential read out of bounds in
  sctp_ulpevent_type_enabled() (bnc#1012628).
- tcp: update skb->skb_mstamp more carefully (bnc#1012628).
- bpf/verifier: reject BPF_ALU64|BPF_END (bnc#1012628).
- tcp: fix data delivery rate (bnc#1012628).
- udpv6: Fix the checksum computation when HW checksum does not
  apply (bnc#1012628).
- ip6_gre: skb_push ipv6hdr before packing the header in
  ip6gre_header (bnc#1012628).
- net: phy: Fix mask value write on gmii2rgmii converter speed
  register (bnc#1012628).
- ip6_tunnel: do not allow loading ip6_tunnel if ipv6 is disabled
  in cmdline (bnc#1012628).
- net/sched: cls_matchall: fix crash when used with classful qdisc
  (bnc#1012628).
- bpf: do not disable/enable BH in bpf_map_free_id()
  (bnc#1012628).
- tcp: fastopen: fix on syn-data transmit failure (bnc#1012628).
- net: emac: Fix napi poll list corruption (bnc#1012628).
- net: ipv6: fix regression of no RTM_DELADDR sent after DAD
  failure (bnc#1012628).
- packet: hold bind lock when rebinding to fanout hook
  (bnc#1012628).
- bpf: one perf event close won't free bpf program attached by
  another perf event (bnc#1012628).
- net: change skb->mac_header when Generic XDP calls adjust_head
  (bnc#1012628).
- isdn/i4l: fetch the ppp_write buffer in one shot (bnc#1012628).
- net_sched: always reset qdisc backlog in qdisc_reset()
  (bnc#1012628).
- net: stmmac: Cocci spatch "of_table" (bnc#1012628).
- net: qcom/emac: specify the correct size when mapping a DMA
  buffer (bnc#1012628).
- vti: fix use after free in vti_tunnel_xmit/vti6_tnl_xmit
  (bnc#1012628).
- l2tp: fix race condition in l2tp_tunnel_delete (bnc#1012628).
- tun: bail out from tun_get_user() if the skb is empty
  (bnc#1012628).
- net: dsa: mv88e6xxx: Allow dsa and cpu ports in multiple vlans
  (bnc#1012628).
- net: dsa: Fix network device registration order (bnc#1012628).
- packet: in packet_do_bind, test fanout with bind_lock held
  (bnc#1012628).
- packet: only test po->has_vnet_hdr once in packet_snd
  (bnc#1012628).
- net: dsa: mv88e6xxx: lock mutex when freeing IRQs (bnc#1012628).
- net: Set sk_prot_creator when cloning sockets to the right proto
  (bnc#1012628).
- net/mlx5e: IPoIB, Fix access to invalid memory address
  (bnc#1012628).
- netlink: do not proceed if dump's start() errs (bnc#1012628).
- ip6_gre: ip6gre_tap device should keep dst (bnc#1012628).
- ip6_tunnel: update mtu properly for ARPHRD_ETHER tunnel device
  in tx path (bnc#1012628).
- IPv4: early demux can return an error code (bnc#1012628).
- tipc: use only positive error codes in messages (bnc#1012628).
- l2tp: fix l2tp_eth module loading (bnc#1012628).
- socket, bpf: fix possible use after free (bnc#1012628).
- net: rtnetlink: fix info leak in RTM_GETSTATS call
  (bnc#1012628).
- bpf: fix bpf_tail_call() x64 JIT (bnc#1012628).
- usb: gadget: core: fix ->udc_set_speed() logic (bnc#1012628).
- USB: gadgetfs: Fix crash caused by inadequate synchronization
  (bnc#1012628).
- USB: gadgetfs: fix copy_to_user while holding spinlock
  (bnc#1012628).
- usb: gadget: udc: atmel: set vbus irqflags explicitly
  (bnc#1012628).
- usb: gadget: udc: renesas_usb3: fix for no-data control transfer
  (bnc#1012628).
- usb: gadget: udc: renesas_usb3: fix Pn_RAMMAP.Pn_MPKT value
  (bnc#1012628).
- usb: gadget: udc: renesas_usb3: Fix return value of
  usb3_write_pipe() (bnc#1012628).
- usb-storage: unusual_devs entry to fix write-access regression
  for Seagate external drives (bnc#1012628).
- usb-storage: fix bogus hardware error messages for ATA pass-thru
  devices (bnc#1012628).
- usb: renesas_usbhs: fix the BCLR setting condition for non-DCP
  pipe (bnc#1012628).
- usb: renesas_usbhs: fix usbhsf_fifo_clear() for RX direction
  (bnc#1012628).
- ALSA: usb-audio: Check out-of-bounds access by corrupted buffer
  descriptor (bnc#1012628).
- usb: pci-quirks.c: Corrected timeout values used in handshake
  (bnc#1012628).
- USB: cdc-wdm: ignore -EPIPE from GetEncapsulatedResponse
  (bnc#1012628).
- USB: dummy-hcd: fix connection failures (wrong speed)
  (bnc#1012628).
- USB: dummy-hcd: fix infinite-loop resubmission bug
  (bnc#1012628).
- USB: dummy-hcd: Fix erroneous synchronization change
  (bnc#1012628).
- USB: devio: Prevent integer overflow in proc_do_submiturb()
  (bnc#1012628).
- USB: devio: Don't corrupt user memory (bnc#1012628).
- USB: g_mass_storage: Fix deadlock when driver is unbound
  (bnc#1012628).
- USB: uas: fix bug in handling of alternate settings
  (bnc#1012628).
- USB: core: harden cdc_parse_cdc_header (bnc#1012628).
- usb: Increase quirk delay for USB devices (bnc#1012628).
- USB: fix out-of-bounds in usb_set_configuration (bnc#1012628).
- usb: xhci: Free the right ring in xhci_add_endpoint()
  (bnc#1012628).
- xhci: fix finding correct bus_state structure for USB 3.1 hosts
  (bnc#1012628).
- xhci: fix wrong endpoint ESIT value shown in tracing
  (bnc#1012628).
- usb: host: xhci-plat: allow sysdev to inherit from ACPI
  (bnc#1012628).
- xhci: Fix sleeping with spin_lock_irq() held in ASmedia 1042A
  workaround (bnc#1012628).
- xhci: set missing SuperSpeedPlus Link Protocol bit in roothub
  descriptor (bnc#1012628).
- Revert "xhci: Limit USB2 port wake support for AMD Promontory
  hosts" (bnc#1012628).
- iio: adc: twl4030: Fix an error handling path in
  'twl4030_madc_probe()' (bnc#1012628).
- iio: adc: twl4030: Disable the vusb3v1 rugulator in the error
  handling path of 'twl4030_madc_probe()' (bnc#1012628).
- iio: ad_sigma_delta: Implement a dedicated reset function
  (bnc#1012628).
- staging: iio: ad7192: Fix - use the dedicated reset function
  avoiding dma from stack (bnc#1012628).
- iio: core: Return error for failed read_reg (bnc#1012628).
- IIO: BME280: Updates to Humidity readings need ctrl_reg
  write! (bnc#1012628).
- iio: trigger: stm32-timer: preset shouldn't be buffered
  (bnc#1012628).
- iio: trigger: stm32-timer: fix a corner case to write preset
  (bnc#1012628).
- iio: ad7793: Fix the serial interface reset (bnc#1012628).
- iio: adc: stm32: fix bad error check on max_channels
  (bnc#1012628).
- iio: adc: mcp320x: Fix readout of negative voltages
  (bnc#1012628).
- iio: adc: mcp320x: Fix oops on module unload (bnc#1012628).
- uwb: properly check kthread_run return value (bnc#1012628).
- uwb: ensure that endpoint is interrupt (bnc#1012628).
- staging: vchiq_2835_arm: Fix NULL ptr dereference in
  free_pagelist (bnc#1012628).
- ksm: fix unlocked iteration over vmas in cmp_and_merge_page()
  (bnc#1012628).
- mm, hugetlb, soft_offline: save compound page order before
  page migration (bnc#1012628).
- mm, oom_reaper: skip mm structs with mmu notifiers
  (bnc#1012628).
- mm: fix RODATA_TEST failure "rodata_test: test data was not
  read only" (bnc#1012628).
- mm: avoid marking swap cached page as lazyfree (bnc#1012628).
- mm: fix data corruption caused by lazyfree page (bnc#1012628).
- userfaultfd: non-cooperative: fix fork use after free
  (bnc#1012628).
- lib/ratelimit.c: use deferred printk() version (bnc#1012628).
- lsm: fix smack_inode_removexattr and xattr_getsecurity memleak
  (bnc#1012628).
- ALSA: compress: Remove unused variable (bnc#1012628).
- Revert "ALSA: echoaudio: purge contradictions between dimension
  matrix members and total number of members" (bnc#1012628).
- ALSA: usx2y: Suppress kernel warning at page allocation failures
  (bnc#1012628).
- powerpc/powernv: Increase memory block size to 1GB on radix
  (bnc#1012628).
- powerpc: Fix action argument for cpufeatures-based TLB flush
  (bnc#1012628).
- powerpc/64s: Use emergency stack for kernel TM Bad Thing
  program checks (bnc#1012628).
- powerpc/tm: Fix illegal TM state in signal handler
  (bnc#1012628).
- percpu: make this_cpu_generic_read() atomic w.r.t. interrupts
  (bnc#1012628).
- intel_th: pci: Add Lewisburg PCH support (bnc#1012628).
- driver core: platform: Don't read past the end of
  "driver_override" buffer (bnc#1012628).
- cgroup: Reinit cgroup_taskset structure before
  cgroup_migrate_execute() returns (bnc#1012628).
- Drivers: hv: fcopy: restore correct transfer length
  (bnc#1012628).
- vmbus: don't acquire the mutex in
  vmbus_hvsock_device_unregister() (bnc#1012628).
- stm class: Fix a use-after-free (bnc#1012628).
- auxdisplay: charlcd: properly restore atomic counter on error
  path (bnc#1012628).
- ftrace: Fix kmemleak in unregister_ftrace_graph (bnc#1012628).
- ovl: fix error value printed in ovl_lookup_index()
  (bnc#1012628).
- ovl: fix dput() of ERR_PTR in ovl_cleanup_index() (bnc#1012628).
- ovl: fix dentry leak in ovl_indexdir_cleanup() (bnc#1012628).
- ovl: fix missing unlock_rename() in ovl_do_copy_up()
  (bnc#1012628).
- ovl: fix regression caused by exclusive upper/work dir
  protection (bnc#1012628).
- arm64: dt marvell: Fix AP806 system controller size
  (bnc#1012628).
- HID: rmi: Make sure the HID device is opened on resume
  (bnc#1012628).
- HID: i2c-hid: allocate hid buffers for real worst case
  (bnc#1012628).
- HID: wacom: leds: Don't try to control the EKR's read-only LEDs
  (bnc#1012628).
- HID: wacom: Properly report negative values from Intuos Pro
  2 Bluetooth (bnc#1012628).
- HID: wacom: Correct coordinate system of touchring and pen twist
  (bnc#1012628).
- HID: wacom: generic: Send MSC_SERIAL and ABS_MISC when leaving
  prox (bnc#1012628).
- HID: wacom: generic: Clear ABS_MISC when tool leaves proximity
  (bnc#1012628).
- HID: wacom: Always increment hdev refcount within
  wacom_get_hdev_data (bnc#1012628).
- HID: wacom: bits shifted too much for 9th and 10th buttons
  (bnc#1012628).
- btrfs: avoid overflow when sector_t is 32 bit (bnc#1012628).
- Btrfs: fix overlap of fs_info::flags values (bnc#1012628).
- rocker: fix rocker_tlv_put_* functions for KASAN (bnc#1012628).
- netlink: fix nla_put_{u8,u16,u32} for KASAN (bnc#1012628).
- dm crypt: reject sector_size feature if device length is not
  aligned to it (bnc#1012628).
- dm ioctl: fix alignment of event number in the device list
  (bnc#1012628).
- dm crypt: fix memory leak in crypt_ctr_cipher_old()
  (bnc#1012628).
- KVM: PPC: Book3S: Fix server always zero from
  kvmppc_xive_get_xive() (bnc#1012628).
- kvm/x86: Avoid async PF preempting the kernel incorrectly
  (bnc#1012628).
- iwlwifi: mvm: use IWL_HCMD_NOCOPY for MCAST_FILTER_CMD
  (bnc#1012628).
- scsi: sd: Implement blacklist option for WRITE SAME w/ UNMAP
  (bnc#1012628).
- scsi: sd: Do not override max_sectors_kb sysfs setting
  (bnc#1012628).
- brcmfmac: add length check in brcmf_cfg80211_escan_handler()
  (bnc#1012628).
- brcmfmac: setup passive scan if requested by user-space
  (bnc#1012628).
- drm/i915: always update ELD connector type after get modes
  (bnc#1012628).
- drm/i915/bios: ignore HDMI on port A (bnc#1012628).
- bsg-lib: fix use-after-free under memory-pressure (bnc#1012628).
- nvme-pci: Use PCI bus address for data/queues in CMB
  (bnc#1012628).
- mmc: core: add driver strength selection when selecting hs400es
  (bnc#1012628).
- nl80211: Define policy for packet pattern attributes
  (bnc#1012628).
- clk: samsung: exynos4: Enable VPLL and EPLL clocks for
  suspend/resume cycle (bnc#1012628).
- udp: perform source validation for mcast early demux
  (bnc#1012628).
- udp: fix bcast packet reception (bnc#1012628).
- base: arch_topology: fix section mismatch build warnings
  (bnc#1012628).
- commit 5a88d59
* Wed Oct 11 2017 tiwai@suse.de
- ALSA: seq: Fix use-after-free at creating a port
  (CVE-2017-15265, bsc#1062520).
- commit fe07a5d
* Mon Oct  9 2017 mbrugger@suse.com
- arm64: Ensure fpsimd support is ready before userspace is active
  (bsc#1061188).
- arm64: Ensure the instruction emulation is ready for userspace
  (bsc#1061188).
- commit d9ee625
* Mon Oct  9 2017 jeffm@suse.com
- Update to 4.14-rc4.
- commit 879f297
* Fri Oct  6 2017 mwilck@suse.com
- watchdog: Revert "iTCO_wdt: all versions count down twice"
  (bsc#1061556).
- commit c6bc876
* Fri Oct  6 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: add the kernel-binary dependencies to
  kernel-binary-base (bsc#1060333).
- commit 955681c
* Fri Oct  6 2017 pmladek@suse.com
- Delete
  patches.suse/ftrace-x86-xen-use-kernel-identity-mapping-only-when.patch.
  The change is not longer needed with PVOPS Xen (bsc#873195).
- commit 8366b6a
* Thu Oct  5 2017 jeffm@suse.com
- Delete patches.rpmify/cloneconfig.diff.
- commit 437d08e
* Thu Oct  5 2017 jeffm@suse.com
- Only use patches.suse for patches.
  This eliminates patches.arch, patches.drivers, and patches.fixes, and moves
  the patches contained in them to patches.suse.
  Also update feedback for Patch-mainline tags.
- commit 343996e
* Thu Oct  5 2017 jslaby@suse.cz
- Linux 4.13.5 (bnc#1012628).
- cifs: check rsp for NULL before dereferencing in SMB2_open
  (bnc#1012628).
- cifs: release cifs root_cred after exit_cifs (bnc#1012628).
- cifs: release auth_key.response for reconnect (bnc#1012628).
- nvme-pci: fix host memory buffer allocation fallback
  (bnc#1012628).
- nvme-pci: use appropriate initial chunk size for HMB allocation
  (bnc#1012628).
- nvme-pci: propagate (some) errors from host memory buffer setup
  (bnc#1012628).
- dax: remove the pmem_dax_ops->flush abstraction (bnc#1012628).
- dm integrity: do not check integrity for failed read operations
  (bnc#1012628).
- mmc: block: Fix incorrectly initialized requests (bnc#1012628).
- fs/proc: Report eip/esp in /prod/PID/stat for coredumping
  (bnc#1012628).
- scsi: scsi_transport_fc: fix NULL pointer dereference in
  fc_bsg_job_timeout (bnc#1012628).
- SMB3: Add support for multidialect negotiate (SMB2.1 and later)
  (bnc#1012628).
- mac80211: fix VLAN handling with TXQs (bnc#1012628).
- mac80211_hwsim: Use proper TX power (bnc#1012628).
- mac80211: flush hw_roc_start work before cancelling the ROC
  (bnc#1012628).
- mac80211: fix deadlock in driver-managed RX BA session start
  (bnc#1012628).
- genirq: Make sparse_irq_lock protect what it should protect
  (bnc#1012628).
- genirq/msi: Fix populating multiple interrupts (bnc#1012628).
- genirq: Fix cpumask check in __irq_startup_managed()
  (bnc#1012628).
- KVM: PPC: Book3S HV: Hold kvm->lock around call to
  kvmppc_update_lpcr (bnc#1012628).
- KVM: PPC: Book3S HV: Fix bug causing host SLB to be restored
  incorrectly (bnc#1012628).
- KVM: PPC: Book3S HV: Don't access XIVE PIPR register using
  byte accesses (bnc#1012628).
- tracing: Fix trace_pipe behavior for instance traces
  (bnc#1012628).
- tracing: Erase irqsoff trace with empty write (bnc#1012628).
- tracing: Remove RCU work arounds from stack tracer
  (bnc#1012628).
- md/raid5: fix a race condition in stripe batch (bnc#1012628).
- md/raid5: preserve STRIPE_ON_UNPLUG_LIST in
  break_stripe_batch_list (bnc#1012628).
- scsi: scsi_transport_iscsi: fix the issue that iscsi_if_rx
  doesn't parse nlmsg properly (bnc#1012628).
- scsi: aacraid: Fix 2T+ drives on SmartIOC-2000 (bnc#1012628).
- scsi: aacraid: Add a small delay after IOP reset (bnc#1012628).
- drm/exynos: Fix locking in the suspend/resume paths
  (bnc#1012628).
- drm/i915/gvt: Fix incorrect PCI BARs reporting (bnc#1012628).
- Revert "drm/i915/bxt: Disable device ready before shutdown
  command" (bnc#1012628).
- drm/radeon: disable hard reset in hibernate for APUs
  (bnc#1012628).
- crypto: drbg - fix freeing of resources (bnc#1012628).
- crypto: talitos - Don't provide setkey for non hmac hashing algs
  (bnc#1012628).
- crypto: talitos - fix sha224 (bnc#1012628).
- crypto: talitos - fix hashing (bnc#1012628).
- security/keys: properly zero out sensitive key material in
  big_key (bnc#1012628).
- security/keys: rewrite all of big_key crypto (bnc#1012628).
- KEYS: fix writing past end of user-supplied buffer in
  keyring_read() (bnc#1012628).
- KEYS: prevent creating a different user's keyrings
  (bnc#1012628).
- KEYS: prevent KEYCTL_READ on negative key (bnc#1012628).
- libnvdimm, namespace: fix btt claim class crash (bnc#1012628).
- powerpc/eeh: Create PHB PEs after EEH is initialized
  (bnc#1012628).
- powerpc/pseries: Fix parent_dn reference leak in add_dt_node()
  (bnc#1012628).
- powerpc/tm: Flush TM only if CPU has TM feature (bnc#1012628).
- MIPS: Fix perf event init (bnc#1012628).
- s390/perf: fix bug when creating per-thread event (bnc#1012628).
- s390/mm: make pmdp_invalidate() do invalidation only
  (bnc#1012628).
- s390/mm: fix write access check in gup_huge_pmd() (bnc#1012628).
- PM: core: Fix device_pm_check_callbacks() (bnc#1012628).
- Revert "IB/ipoib: Update broadcast object if PKey value was
  changed in index 0" (bnc#1012628).
- Fix SMB3.1.1 guest authentication to Samba (bnc#1012628).
- SMB3: Fix endian warning (bnc#1012628).
- SMB3: Warn user if trying to sign connection that authenticated
  as guest (bnc#1012628).
- SMB: Validate negotiate (to protect against downgrade) even
  if signing off (bnc#1012628).
- SMB3: handle new statx fields (bnc#1012628).
- SMB3: Don't ignore O_SYNC/O_DSYNC and O_DIRECT flags
  (bnc#1012628).
- vfs: Return -ENXIO for negative SEEK_HOLE / SEEK_DATA offsets
  (bnc#1012628).
- libceph: don't allow bidirectional swap of pg-upmap-items
  (bnc#1012628).
- brd: fix overflow in __brd_direct_access (bnc#1012628).
- gfs2: Fix debugfs glocks dump (bnc#1012628).
- bsg-lib: don't free job in bsg_prepare_job (bnc#1012628).
- iw_cxgb4: drop listen destroy replies if no ep found
  (bnc#1012628).
- iw_cxgb4: remove the stid on listen create failure
  (bnc#1012628).
- iw_cxgb4: put ep reference in pass_accept_req() (bnc#1012628).
- rcu: Allow for page faults in NMI handlers (bnc#1012628).
- mmc: sdhci-pci: Fix voltage switch for some Intel host
  controllers (bnc#1012628).
- extable: Consolidate *kernel_text_address() functions
  (bnc#1012628).
- extable: Enable RCU if it is not watching in
  kernel_text_address() (bnc#1012628).
- selftests/seccomp: Support glibc 2.26 siginfo_t.h (bnc#1012628).
- seccomp: fix the usage of get/put_seccomp_filter() in
  seccomp_get_filter() (bnc#1012628).
- arm64: Make sure SPsel is always set (bnc#1012628).
- arm64: mm: Use READ_ONCE when dereferencing pointer to pte table
  (bnc#1012628).
- arm64: fault: Route pte translation faults via
  do_translation_fault (bnc#1012628).
- KVM: VMX: extract __pi_post_block (bnc#1012628).
- KVM: VMX: avoid double list add with VT-d posted interrupts
  (bnc#1012628).
- KVM: VMX: simplify and fix vmx_vcpu_pi_load (bnc#1012628).
- KVM: nVMX: fix HOST_CR3/HOST_CR4 cache (bnc#1012628).
- kvm/x86: Handle async PF in RCU read-side critical sections
  (bnc#1012628).
- KVM: VMX: Do not BUG() on out-of-bounds guest IRQ (bnc#1012628).
- kvm: nVMX: Don't allow L2 to access the hardware CR8
  (bnc#1012628).
- xfs: validate bdev support for DAX inode flag (bnc#1012628).
- fix infoleak in waitid(2) (bnc#1012628).
- sched/sysctl: Check user input value of sysctl_sched_time_avg
  (bnc#1012628).
- irq/generic-chip: Don't replace domain's name (bnc#1012628).
- mtd: Fix partition alignment check on multi-erasesize devices
  (bnc#1012628).
- mtd: nand: atmel: fix buffer overflow in atmel_pmecc_user
  (bnc#1012628).
- etnaviv: fix submit error path (bnc#1012628).
- etnaviv: fix gem object list corruption (bnc#1012628).
- futex: Fix pi_state->owner serialization (bnc#1012628).
- md: fix a race condition for flush request handling
  (bnc#1012628).
- md: separate request handling (bnc#1012628).
- PCI: Fix race condition with driver_override (bnc#1012628).
- btrfs: fix NULL pointer dereference from free_reloc_roots()
  (bnc#1012628).
- btrfs: clear ordered flag on cleaning up ordered extents
  (bnc#1012628).
- btrfs: finish ordered extent cleaning if no progress is found
  (bnc#1012628).
- btrfs: propagate error to btrfs_cmp_data_prepare caller
  (bnc#1012628).
- btrfs: prevent to set invalid default subvolid (bnc#1012628).
- PM / OPP: Call notifier without holding opp_table->lock
  (bnc#1012628).
- x86/mm: Fix fault error path using unsafe vma pointer
  (bnc#1012628).
- x86/fpu: Don't let userspace set bogus xcomp_bv (bnc#1012628).
- KVM: VMX: do not change SN bit in vmx_update_pi_irte()
  (bnc#1012628).
- KVM: VMX: remove WARN_ON_ONCE in
  kvm_vcpu_trigger_posted_interrupt (bnc#1012628).
- KVM: VMX: use cmpxchg64 (bnc#1012628).
- video: fbdev: aty: do not leak uninitialized padding in clk
  to userspace (bnc#1012628).
- Update config files.
- commit 3fd9659
* Thu Oct  5 2017 tiwai@suse.de
- Refresh QXL fixes: they've been upstreamed
  patches.drivers/qxl-fix-pinning.patch
  patches.drivers/qxl-fix-primary-surface-handling.patch
- commit 7034d64
* Thu Oct  5 2017 tiwai@suse.de
- platform/x86: peaq-wmi: Add DMI check before binding to the
  WMI interface (bsc#1059807).
- commit a6a03ea
* Wed Oct  4 2017 jeffm@suse.com
- Delete patches.suse/suse-hv-storvsc-sg_tablesize.patch.
  Per Olaf Hering, this is no longer needed.
- commit 83b19a6
* Wed Oct  4 2017 jslaby@suse.cz
- orc: mark it as reliable (bnc#1058115).
- Update config files.
- commit 3cbbf06
* Wed Oct  4 2017 jslaby@suse.cz
- x86/asm: Use register variable to get stack pointer value
  (bnc#1058115).
- commit a5d4692
* Wed Oct  4 2017 jslaby@suse.cz
- x86/asm: Fix inline asm call constraints for GCC 4.4
  (bnc#1058115).
- commit 034c016
* Wed Oct  4 2017 hare@suse.de
- Delete patches.fixes/sd_liberal_28_sense_invalid.diff.
- Delete patches.suse/dm-emulate-blkrrpart-ioctl.
- Delete patches.suse/scsi-netlink-ml.
- commit b8f0083
* Wed Oct  4 2017 agraf@suse.de
- Delete patches.arch/arm-OMAP-Fix-missing-usb.h-include.patch.
  (no longer needed)
- Delete patches.arch/arm-arndale-usb.patch. (no longer needed)
- Delete
  patches.arch/arm64-0006-arm64-Select-reboot-driver-for-X-Gene-platform.patch.
  (not needed, our config already includes the driver)
- Delete patches.arch/ppc64le-build-vmlinux.patch. (no longer needed)
- commit 2b9d327
* Tue Oct  3 2017 jeffm@suse.com
- Disable patches.suse/binutils2_26.patch for testing.
  The issue addressed by this patch should be handled via upstream
  commit 6d92bc9d483 (x86/build: Build compressed x86 kernels as PIE).
- commit f27997b
* Tue Oct  3 2017 neilb@suse.com
- Delete
  patches.fixes/0001-Revert-SUNRPC-xs_sock_mark_closed-does-not-need-to-t.patch.
  Not needed, bug was fixed some other way since that patch
  was created.
- commit d55ee70
* Tue Oct  3 2017 mgorman@suse.de
- Delete patches.suse/connector-read-mostly.
- commit 8ae100a
* Tue Oct  3 2017 jeffm@suse.com
- series.conf: remove commented out lines for removed patches
- commit 7ea9bcc
* Tue Oct  3 2017 jeffm@suse.com
- Delete patches.arch/arm-refresh-mach-types.diff.
  It was marked for refresh in 12/2016 and hasn't been updated.
- commit 8e357d7
* Mon Oct  2 2017 jeffm@suse.com
- Remove s390 message catalog patches.
- Delete patches.arch/kmsg-fix-parameter-limitations.
- Delete patches.arch/s390-message-catalog.diff.
- commit 865e88d
* Mon Oct  2 2017 jeffm@suse.com
- Refresh patches.suse/dm-mpath-accept-failed-paths.
- commit 04a0a7a
* Mon Oct  2 2017 jeffm@suse.com
- Moved powerpc-Blacklist-GCC-5.4-6.1-and-6.2.patch to patches.rpmify.
  It's a compiler blacklist addition and should be applied to vanilla too.
- commit e34eae8
* Mon Oct  2 2017 jeffm@suse.com
- Update to 4.14-rc3.
- Eliminated 2 patches.
- Config changes:
  - Crypto:
  - Crypto changes brought by Kconfig changes:
  - CONFIG_CRYPTO_GHASH=y (Kconfig dependency change)
  - CONFIG_CRYPTO_GCM=y (Kconfig dependency change)
  - armv7hl:
  - DRM_SUN4I_HDMI_CEC=y
  - CONFIG_CEC_PIN=y (dependency)
  - s390x/zfcpdump:
  - Crypto changes brought by Kconfig changes, consistent with other configs:
  - CRYPTO_MANAGER_DISABLE_TESTS=n
  - CRYPTO_DRBG_HASH=y
  - CRYPTO_DRBG_CTR=y
  - Lots of dependencies
- commit 37f329b
* Mon Oct  2 2017 jslaby@suse.cz
- platform/x86: fujitsu-laptop: Don't oops when FUJ02E3 is not
  presnt (bnc#1058814).
- commit 80338f6
* Mon Oct  2 2017 jslaby@suse.cz
- ORC crypto patches: Update upstream status.
- commit 01974c6
* Mon Oct  2 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-objtool-Don-t-report-end-of-section-error-after-an-e.patch.
- Refresh
  patches.suse/0002-x86-head-Remove-confusing-comment.patch.
- Refresh
  patches.suse/0003-x86-head-Remove-unused-bad_address-code.patch.
- Refresh
  patches.suse/0004-x86-head-Fix-head-ELF-function-annotations.patch.
- Refresh
  patches.suse/0005-x86-boot-Annotate-verify_cpu-as-a-callable-function.patch.
- Refresh
  patches.suse/0006-x86-xen-Fix-xen-head-ELF-annotations.patch.
- Refresh
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-head-Add-unwind-hint-annotations.patch.
- Delete
  patches.suse/0002-dwarf-do-not-throw-away-unwind-info.patch.
  Update upstream status and drop the dwarf remainder.
- commit c3e0cbe
* Thu Sep 28 2017 jeffm@suse.com
- Update to 4.14-rc2.
- Eliminated 21 patches.
- commit b61ed0c
* Wed Sep 27 2017 jslaby@suse.cz
- Linux 4.13.4 (bnc#1012628).
- orangefs: Don't clear SGID when inheriting ACLs (bnc#1012628).
- <linux/uaccess.h>: Fix copy_in_user() declaration (bnc#1012628).
- IB/hfi1: Revert egress pkey check enforcement (bnc#1012628).
- IB/{qib, hfi1}: Avoid flow control testing for RDMA write
  operation (bnc#1012628).
- IB/mlx5: Fix cached MR allocation flow (bnc#1012628).
- srcu: Provide ordering for CPU not involved in grace period
  (bnc#1012628).
- smp/hotplug: Handle removal correctly in cpuhp_store_callbacks()
  (bnc#1012628).
- Input: xpad - validate USB endpoint type during probe
  (bnc#1012628).
- drm/amdgpu: read reg in each iterator of psp_wait_for loop
  (bnc#1012628).
- tty: improve tty_insert_flip_char() fast path (bnc#1012628).
- tty: improve tty_insert_flip_char() slow path (bnc#1012628).
- tty: fix __tty_insert_flip_char regression (bnc#1012628).
- pinctrl: samsung: Fix invalid register offset used for
  Exynos5433 external interrupts (bnc#1012628).
- pinctrl: samsung: Fix NULL pointer exception on external
  interrupts on S3C24xx (bnc#1012628).
- pinctrl/amd: save pin registers over suspend/resume
  (bnc#1012628).
- Input: i8042 - add Gigabyte P57 to the keyboard reset table
  (bnc#1012628).
- MIPS: math-emu: <MAX|MAXA|MIN|MINA>.<D|S>: Fix quiet NaN
  propagation (bnc#1012628).
- MIPS: math-emu: <MAX|MAXA|MIN|MINA>.<D|S>: Fix cases of both
  inputs zero (bnc#1012628).
- MIPS: math-emu: <MAX|MIN>.<D|S>: Fix cases of both inputs
  negative (bnc#1012628).
- MIPS: math-emu: <MAXA|MINA>.<D|S>: Fix cases of input values
  with opposite signs (bnc#1012628).
- MIPS: math-emu: <MAXA|MINA>.<D|S>: Fix cases of both infinite
  inputs (bnc#1012628).
- MIPS: math-emu: MINA.<D|S>: Fix some cases of infinity and
  zero inputs (bnc#1012628).
- MIPS: math-emu: <MADDF|MSUBF>.<D|S>: Fix NaN propagation
  (bnc#1012628).
- MIPS: math-emu: <MADDF|MSUBF>.<D|S>: Fix some cases of infinite
  inputs (bnc#1012628).
- MIPS: math-emu: <MADDF|MSUBF>.<D|S>: Fix some cases of zero
  inputs (bnc#1012628).
- MIPS: math-emu: <MADDF|MSUBF>.<D|S>: Clean up "maddf_flags"
  enumeration (bnc#1012628).
- MIPS: math-emu: <MADDF|MSUBF>.S: Fix accuracy (32-bit case)
  (bnc#1012628).
- MIPS: math-emu: <MADDF|MSUBF>.D: Fix accuracy (64-bit case)
  (bnc#1012628).
- docs: disable KASLR when debugging kernel (bnc#1012628).
- crypto: ccp - Fix XTS-AES-128 support on v5 CCPs (bnc#1012628).
- crypto: scompress - don't sleep with preemption disabled
  (bnc#1012628).
- crypto: caam/qi - fix typo in authenc alg driver name
  (bnc#1012628).
- crypto: caam/qi - properly set IV after {en,de}crypt
  (bnc#1012628).
- crypto: AF_ALG - remove SGL terminator indicator when chaining
  (bnc#1012628).
- regulator: cpcap: Fix standby mode (bnc#1012628).
- wcn36xx: Introduce mutual exclusion of fw configuration
  (bnc#1012628).
- ext4: in ext4_seek_{hole,data}, return -ENXIO for negative
  offsets (bnc#1012628).
- ext4: fix incorrect quotaoff if the quota feature is enabled
  (bnc#1012628).
- ext4: fix quota inconsistency during orphan cleanup for
  read-only mounts (bnc#1012628).
- cxl: Fix driver use count (bnc#1012628).
- powerpc/powernv/npu: Move tlb flush before launching ATSD
  (bnc#1012628).
- powerpc/pseries: Don't attempt to acquire drc during memory
  hot add for assigned lmbs (bnc#1012628).
- powerpc: Fix DAR reporting when alignment handler faults
  (bnc#1012628).
- block: Relax a check in blk_start_queue() (bnc#1012628).
- block: directly insert blk-mq request from
  blk_insert_cloned_request() (bnc#1012628).
- md/bitmap: copy correct data for bitmap super (bnc#1012628).
- md/bitmap: disable bitmap_resize for file-backed bitmaps
  (bnc#1012628).
- skd: Avoid that module unloading triggers a use-after-free
  (bnc#1012628).
- skd: Submit requests to firmware before triggering the doorbell
  (bnc#1012628).
- scsi: zfcp: fix queuecommand for scsi_eh commands when DIX
  enabled (bnc#1012628).
- scsi: zfcp: add handling for FCP_RESID_OVER to the fcp ingress
  path (bnc#1012628).
- scsi: zfcp: fix capping of unsuccessful GPN_FT SAN response
  trace records (bnc#1012628).
- scsi: zfcp: fix passing fsf_req to SCSI trace on TMF to
  correlate with HBA (bnc#1012628).
- scsi: zfcp: fix missing trace records for early returns in
  TMF eh handlers (bnc#1012628).
- scsi: zfcp: fix payload with full FCP_RSP IU in SCSI trace
  records (bnc#1012628).
- scsi: zfcp: trace HBA FSF response by default on dismiss or
  timedout late response (bnc#1012628).
- scsi: zfcp: trace high part of "new" 64 bit SCSI LUN
  (bnc#1012628).
- scsi: qedi: off by one in qedi_get_cmd_from_tid() (bnc#1012628).
- scsi: aacraid: Fix command send race condition (bnc#1012628).
- scsi: megaraid_sas: mismatch of allocated MFI frame size and
  length exposed in MFI MPT pass through command (bnc#1012628).
- scsi: megaraid_sas: set minimum value of resetwaittime to be
  1 secs (bnc#1012628).
- scsi: megaraid_sas: Check valid aen class range to avoid kernel
  panic (bnc#1012628).
- scsi: megaraid_sas: Return pended IOCTLs with cmd_status
  MFI_STAT_WRONG_STATE in case adapter is dead (bnc#1012628).
- scsi: storvsc: fix memory leak on ring buffer busy
  (bnc#1012628).
- scsi: sg: factor out sg_fill_request_table() (bnc#1012628).
- scsi: sg: fixup infoleak when using SG_GET_REQUEST_TABLE
  (bnc#1012628).
- scsi: qla2xxx: Update fw_started flags at qpair creation
  (bnc#1012628).
- scsi: qla2xxx: Correction to vha->vref_count timeout
  (bnc#1012628).
- scsi: qla2xxx: Fix target multiqueue configuration
  (bnc#1012628).
- scsi: qla2xxx: Use BIT_6 to acquire FAWWPN from switch
  (bnc#1012628).
- scsi: qla2xxx: Use fabric name for Get Port Speed command
  (bnc#1012628).
- mailbox: bcm-flexrm-mailbox: Fix mask used in
  CMPL_START_ADDR_VALUE() (bnc#1012628).
- ftrace: Fix debug preempt config name in
  stack_tracer_{en,dis}able (bnc#1012628).
- ftrace: Fix selftest goto location on error (bnc#1012628).
- ftrace: Fix memleak when unregistering dynamic ops when tracing
  disabled (bnc#1012628).
- tracing: Add barrier to trace_printk() buffer nesting
  modification (bnc#1012628).
- tracing: Fix clear of RECORDED_TGID flag when disabling trace
  event (bnc#1012628).
- tracing: Apply trace_clock changes to instance max buffer
  (bnc#1012628).
- ARC: Re-enable MMU upon Machine Check exception (bnc#1012628).
- PCI: shpchp: Enable bridge bus mastering if MSI is enabled
  (bnc#1012628).
- PCI: pciehp: Report power fault only once until we clear it
  (bnc#1012628).
- net/netfilter/nf_conntrack_core: Fix net_conntrack_lock()
  (bnc#1012628).
- s390/mm: fix local TLB flushing vs. detach of an mm address
  space (bnc#1012628).
- s390/mm: fix race on mm->context.flush_mm (bnc#1012628).
- media: v4l2-compat-ioctl32: Fix timespec conversion
  (bnc#1012628).
- media: Revert "[media] lirc_dev: remove superfluous
  get/put_device() calls" (bnc#1012628).
- media: venus: fix copy/paste error in return_buf_error
  (bnc#1012628).
- media: uvcvideo: Prevent heap overflow when accessing mapped
  controls (bnc#1012628).
- media: adv7180: add missing adv7180cp, adv7180st i2c device IDs
  (bnc#1012628).
- PM / devfreq: Fix memory leak when fail to register device
  (bnc#1012628).
- ALSA: seq: Cancel pending autoload work at unbinding device
  (bnc#1012628).
- bcache: initialize dirty stripes in flash_dev_run()
  (bnc#1012628).
- bcache: Fix leak of bdev reference (bnc#1012628).
- bcache: do not subtract sectors_to_gc for bypassed IO
  (bnc#1012628).
- bcache: correct cache_dirty_target in __update_writeback_rate()
  (bnc#1012628).
- bcache: Correct return value for sysfs attach errors
  (bnc#1012628).
- bcache: fix sequential large write IO bypass (bnc#1012628).
- bcache: fix for gc and write-back race (bnc#1012628).
- bcache: fix bch_hprint crash and improve output (bnc#1012628).
- sched/cpuset/pm: Fix cpuset vs. suspend-resume bugs
  (bnc#1012628).
- iwlwifi: add workaround to disable wide channels in 5GHz
  (bnc#1012628).
- commit c028f76
* Wed Sep 27 2017 jslaby@suse.cz
- usb: quirks: add delay init quirk for Corsair Strafe RGB
  keyboard (bnc#1012628).
- USB: serial: option: add support for D-Link DWM-157 C1
  (bnc#1012628).
- usb: Add device quirk for Logitech HD Pro Webcam C920-C
  (bnc#1012628).
- usb:xhci:Fix regression when ATI chipsets detected
  (bnc#1012628).
- USB: musb: fix external abort on suspend (bnc#1012628).
- ANDROID: binder: add padding to binder_fd_array_object
  (bnc#1012628).
- ANDROID: binder: add hwbinder,vndbinder to BINDER_DEVICES
  (bnc#1012628).
- USB: core: Avoid race of async_completed() w/ usbdev_release()
  (bnc#1012628).
- staging/rts5208: fix incorrect shift to extract upper nybble
  (bnc#1012628).
- staging: ccree: save ciphertext for CTS IV (bnc#1012628).
- staging: fsl-dpaa2/eth: fix off-by-one FD ctrl bitmaks
  (bnc#1012628).
- iio: adc: ti-ads1015: fix incorrect data rate setting update
  (bnc#1012628).
- iio: adc: ti-ads1015: fix scale information for ADS1115
  (bnc#1012628).
- iio: adc: ti-ads1015: enable conversion when CONFIG_PM is not
  set (bnc#1012628).
- iio: adc: ti-ads1015: avoid getting stale result after runtime
  resume (bnc#1012628).
- iio: adc: ti-ads1015: don't return invalid value from buffer
  setup callbacks (bnc#1012628).
- iio: adc: ti-ads1015: add adequate wait time to get correct
  conversion (bnc#1012628).
- driver core: bus: Fix a potential double free (bnc#1012628).
- HID: wacom: Do not completely map WACOM_HID_WD_TOUCHRINGSTATUS
  usage (bnc#1012628).
- binder: free memory on error (bnc#1012628).
- crypto: caam/qi - fix compilation with
  CONFIG_DEBUG_FORCE_WEAK_PER_CPU=y (bnc#1012628).
- crypto: caam/qi - fix compilation with DEBUG enabled
  (bnc#1012628).
- thunderbolt: Fix reset response_type (bnc#1012628).
- fpga: altera-hps2fpga: fix multiple init of l3_remap_lock
  (bnc#1012628).
- intel_th: pci: Add Cannon Lake PCH-H support (bnc#1012628).
- intel_th: pci: Add Cannon Lake PCH-LP support (bnc#1012628).
- ath10k: fix memory leak in rx ring buffer allocation
  (bnc#1012628).
- drm/vgem: Pin our pages for dmabuf exports (bnc#1012628).
- drm/ttm: Fix accounting error when fail to get pages for pool
  (bnc#1012628).
- drm/dp/mst: Handle errors from
  drm_atomic_get_private_obj_state() correctly (bnc#1012628).
- rtlwifi: rtl_pci_probe: Fix fail path of _rtl_pci_find_adapter
  (bnc#1012628).
- Bluetooth: Add support of 13d3:3494 RTL8723BE device
  (bnc#1012628).
- iwlwifi: pci: add new PCI ID for 7265D (bnc#1012628).
- dlm: avoid double-free on error path in
  dlm_device_{register,unregister} (bnc#1012628).
- mwifiex: correct channel stat buffer overflows (bnc#1012628).
- MCB: add support for SC31 to mcb-lpc (bnc#1012628).
- s390/mm: avoid empty zero pages for KVM guests to avoid postcopy
  hangs (bnc#1012628).
- drm/nouveau/pci/msi: disable MSI on big-endian platforms by
  default (bnc#1012628).
- drm/nouveau: Fix error handling in nv50_disp_atomic_commit
  (bnc#1012628).
- workqueue: Fix flag collision (bnc#1012628).
- ahci: don't use MSI for devices with the silly Intel NVMe
  remapping scheme (bnc#1012628).
- cs5536: add support for IDE controller variant (bnc#1012628).
- scsi: sg: protect against races between mmap() and
  SG_SET_RESERVED_SIZE (bnc#1012628).
- scsi: sg: recheck MMAP_IO request length with lock held
  (bnc#1012628).
- of/device: Prevent buffer overflow in of_device_modalias()
  (bnc#1012628).
- rtlwifi: Fix memory leak when firmware request fails
  (bnc#1012628).
- rtlwifi: Fix fallback firmware loading (bnc#1012628).
- Linux 4.13.1 (bnc#1012628).
- mtd: nand: make Samsung SLC NAND usable again (bnc#1012628).
- mtd: nand: hynix: add support for 20nm NAND chips (bnc#1012628).
- mtd: nand: mxc: Fix mxc_v1 ooblayout (bnc#1012628).
- mtd: nand: qcom: fix read failure without complete bootchain
  (bnc#1012628).
- mtd: nand: qcom: fix config error for BCH (bnc#1012628).
- nvme-fabrics: generate spec-compliant UUID NQNs (bnc#1012628).
- btrfs: resume qgroup rescan on rw remount (bnc#1012628).
- rtlwifi: btcoexist: Fix breakage of ant_sel for rtl8723be
  (bnc#1012628).
- rtlwifi: btcoexist: Fix antenna selection code (bnc#1012628).
- radix-tree: must check __radix_tree_preload() return value
  (bnc#1012628).
- brcmfmac: feature check for multi-scheduled scan fails on
  bcm4345 devices (bnc#1012628).
- kselftests: timers: leap-a-day: Change default arguments to
  help test runs (bnc#1012628).
- selftests: timers: Fix run_destructive_tests target to handle
  skipped tests (bnc#1012628).
- selftests/x86/fsgsbase: Test selectors 1, 2, and 3
  (bnc#1012628).
- mm: kvfree the swap cluster info if the swap file is
  unsatisfactory (bnc#1012628).
- mm/swapfile.c: fix swapon frontswap_map memory leak on error
  (bnc#1012628).
- mm/sparse.c: fix typo in online_mem_sections (bnc#1012628).
- mm/memory.c: fix mem_cgroup_oom_disable() call missing
  (bnc#1012628).
- KVM: SVM: Limit PFERR_NESTED_GUEST_PAGE error_code check to
  L1 guest (bnc#1012628).
- Revert "firmware: add sanity check on shutdown/suspend"
  (bnc#1012628).
- rt2800: fix TX_PIN_CFG setting for non MT7620 chips (bnc#1012628
  bnc#1055826).
- Bluetooth: Properly check L2CAP config option output buffer
  length (bnc#1012628).
- ARM64: dts: marvell: armada-37xx: Fix GIC maintenance interrupt
  (bnc#1012628).
- ARM: 8692/1: mm: abort uaccess retries upon fatal signal
  (bnc#1012628).
- NFS: Fix 2 use after free issues in the I/O code (bnc#1012628).
- NFS: Sync the correct byte range during synchronous writes
  (bnc#1012628).
- NFSv4: Fix up mirror allocation (bnc#1012628).
- xfs: XFS_IS_REALTIME_INODE() should be false if no rt device
  present (bnc#1012628).
- Linux 4.13.2 (bnc#1012628).
- Revert "net: use lib/percpu_counter API for fragmentation mem
  accounting" (bnc#1012628).
- Revert "net: fix percpu memory leaks" (bnc#1012628).
- gianfar: Fix Tx flow control deactivation (bnc#1012628).
- vhost_net: correctly check tx avail during rx busy polling
  (bnc#1012628).
- ip6_gre: update mtu properly in ip6gre_err (bnc#1012628).
- udp: drop head states only when all skb references are gone
  (bnc#1012628).
- ipv6: fix memory leak with multiple tables during netns
  destruction (bnc#1012628).
- ipv6: fix typo in fib6_net_exit() (bnc#1012628).
- sctp: fix missing wake ups in some situations (bnc#1012628).
- tcp: fix a request socket leak (bnc#1012628).
- ip_tunnel: fix setting ttl and tos value in collect_md mode
  (bnc#1012628).
- f2fs: let fill_super handle roll-forward errors (bnc#1012628).
- f2fs: check hot_data for roll-forward recovery (bnc#1012628).
- thunderbolt: Remove superfluous check (bnc#1012628).
- thunderbolt: Make key root-only accessible (bnc#1012628).
- thunderbolt: Allow clearing the key (bnc#1012628).
- x86/fsgsbase/64: Fully initialize FS and GS state in
  start_thread_common (bnc#1012628).
- x86/fsgsbase/64: Report FSBASE and GSBASE correctly in core
  dumps (bnc#1012628).
- x86/switch_to/64: Rewrite FS/GS switching yet again to fix
  AMD CPUs (bnc#1012628).
- x86/mm, mm/hwpoison: Clear PRESENT bit for kernel 1:1 mappings
  of poison pages (bnc#1012628).
- ovl: fix false positive ESTALE on lookup (bnc#1012628).
- fuse: allow server to run in different pid_ns (bnc#1012628).
- idr: remove WARN_ON_ONCE() when trying to replace negative ID
  (bnc#1012628).
- libnvdimm, btt: check memory allocation failure (bnc#1012628).
- libnvdimm: fix integer overflow static analysis warning
  (bnc#1012628).
- xfs: write unmount record for ro mounts (bnc#1012628).
- xfs: toggle readonly state around xfs_log_mount_finish
  (bnc#1012628).
- xfs: Add infrastructure needed for error propagation during
  buffer IO failure (bnc#1012628).
- xfs: Properly retry failed inode items in case of error during
  buffer writeback (bnc#1012628).
- xfs: fix recovery failure when log record header wraps log end
  (bnc#1012628).
- xfs: always verify the log tail during recovery (bnc#1012628).
- xfs: fix log recovery corruption error due to tail overwrite
  (bnc#1012628).
- xfs: handle -EFSCORRUPTED during head/tail verification
  (bnc#1012628).
- xfs: stop searching for free slots in an inode chunk when
  there are none (bnc#1012628).
- xfs: evict all inodes involved with log redo item (bnc#1012628).
- xfs: check for race with xfs_reclaim_inode() in
  xfs_ifree_cluster() (bnc#1012628).
- xfs: open-code xfs_buf_item_dirty() (bnc#1012628).
- xfs: remove unnecessary dirty bli format check for ordered bufs
  (bnc#1012628).
- xfs: ordered buffer log items are never formatted (bnc#1012628).
- xfs: refactor buffer logging into buffer dirtying helper
  (bnc#1012628).
- xfs: don't log dirty ranges for ordered buffers (bnc#1012628).
- xfs: skip bmbt block ino validation during owner change
  (bnc#1012628).
- xfs: move bmbt owner change to last step of extent swap
  (bnc#1012628).
- xfs: disallow marking previously dirty buffers as ordered
  (bnc#1012628).
- xfs: relog dirty buffers during swapext bmbt owner change
  (bnc#1012628).
- xfs: disable per-inode DAX flag (bnc#1012628).
- xfs: fix incorrect log_flushed on fsync (bnc#1012628).
- xfs: don't set v3 xflags for v2 inodes (bnc#1012628).
- xfs: open code end_buffer_async_write in
  xfs_finish_page_writeback (bnc#1012628).
- xfs: use kmem_free to free return value of kmem_zalloc
  (bnc#1012628).
- md/raid1/10: reset bio allocated from mempool (bnc#1012628).
- md/raid5: release/flush io in raid5_do_work() (bnc#1012628).
- xfs: fix compiler warnings (bnc#1012628).
- Linux 4.13.3 (bnc#1012628).
- Delete patches.kernel.org/patch-4.13.1.
- Delete patches.kernel.org/patch-4.13.1-2.
- Delete patches.kernel.org/patch-4.13.2-3.
  Replace stable all-in-one patches by expanded patches.
- commit 8e0ee21
* Mon Sep 25 2017 jslaby@suse.cz
- x86/asm: Fix inline asm call constraints for Clang
  (bnc#1058115).
- objtool: Handle another GCC stack pointer adjustment bug
  (bnc#1058115).
- x86/asm: Fix inline asm call constraints for Clang
  (bnc#1058115).
- objtool: Handle another GCC stack pointer adjustment bug
  (bnc#1058115).
- commit 8e680d0
* Mon Sep 25 2017 jslaby@suse.cz
- scripts/stableids: generate one file per commit
- commit c82ad0e
* Mon Sep 25 2017 mkubecek@suse.cz
- 8139too: revisit napi_complete_done() usage (bsc#1042208).
- commit 99343bb
* Sun Sep 24 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: only rewrite modules.dep if non-zero in size
  (bsc#1056979).
- commit 75691fd
* Fri Sep 22 2017 jslaby@suse.cz
- crypto: x86/blowfish - Fix RBP usage (bnc#1058115).
- crypto: x86/camellia - Fix RBP usage (bnc#1058115).
- crypto: x86/cast5 - Fix RBP usage (bnc#1058115).
- crypto: x86/cast6 - Fix RBP usage (bnc#1058115).
- crypto: x86/des3_ede - Fix RBP usage (bnc#1058115).
- crypto: x86/sha1-avx2 - Fix RBP usage (bnc#1058115).
- crypto: x86/sha1-ssse3 - Fix RBP usage (bnc#1058115).
- crypto: x86/sha256-avx - Fix RBP usage (bnc#1058115).
- crypto: x86/sha256-avx2 - Fix RBP usage (bnc#1058115).
- crypto: x86/sha256-ssse3 - Fix RBP usage (bnc#1058115).
- crypto: sha512-avx2 - Fix RBP usage (bnc#1058115).
- crypto: x86/twofish - Fix RBP usage (bnc#1058115).
  Update upstream status.
- commit e890e3e
* Thu Sep 21 2017 jeffm@suse.com
- drm/tegra: trace: Fix path to include (build fix).
- commit aecd9be
* Wed Sep 20 2017 afaerber@suse.de
- config: armv7hl: Update to 4.14-rc1
- commit 9d284f8
* Wed Sep 20 2017 afaerber@suse.de
- config: armv6hl: Update to 4.14-rc1
- commit 0c2764f
* Wed Sep 20 2017 afaerber@suse.de
- config: arm64: Update to 4.14-rc1
- commit d6909a3
* Wed Sep 20 2017 jeffm@suse.com
- Revert "KVM: Don't accept obviously wrong gsi values via
  KVM_IRQFD" (build fix).
- commit f436aa0
* Wed Sep 20 2017 mcgrof@suse.com
- nl80211: check for the required netlink attributes presence
  (bsc#1058410 CVE-2017-12153).
- commit 8afa5c8
* Wed Sep 20 2017 mcgrof@suse.com
- nl80211: check for the required netlink attributes presence
  (bsc#1058410 CVE-2017-12153).
- commit 6d93561
* Wed Sep 20 2017 tiwai@suse.de
- qxl: fix pinning (bsc#1057241,bsc#1057123).
- qxl: fix primary surface handling (bsc#1057241,bsc#1057123).
- commit b3d7f33
* Wed Sep 20 2017 jslaby@suse.cz
- Linux 4.13.3 (bnc#1012628).
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- commit 76ecbd3
* Tue Sep 19 2017 lduncan@suse.com
- Fix incorrect backport of compatibility patch (bsc#1053501)
  This fixes commit fe56e414dcf9, which incorrectly placed
  the back-ported macros in libc-compat.h in the wrong place.
  It is important for __UAPI_DEF_IOVEC to be defined
  correctly with and without GLIBC being defined.
- commit 102e6e3
* Tue Sep 19 2017 jslaby@suse.cz
- objtool: Fix object file corruption (bnc#1058115).
- objtool: Do not retrieve data from empty sections (bnc#1058115).
- objtool: Fix memory leak in elf_create_rela_section()
  (bnc#1058115).
- objtool: Fix object file corruption (bnc#1058115).
- objtool: Do not retrieve data from empty sections (bnc#1058115).
- objtool: Fix memory leak in elf_create_rela_section()
  (bnc#1058115).
- commit 5a29d69
* Tue Sep 19 2017 jslaby@suse.cz
- x86/crypto: Fix RBP usage in twofish-avx-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in sha512-avx2-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha256-ssse3-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha256-avx2-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha256-avx-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha1_ssse3_asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha1_avx2_x86_64_asm.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in des3_ede-asm_64.S (bnc#1058115).
- x86/crypto: Fix RBP usage in cast6-avx-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in cast5-avx-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in camellia-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in blowfish-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in twofish-avx-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in sha512-avx2-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha256-ssse3-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha256-avx2-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha256-avx-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha1_ssse3_asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha1_avx2_x86_64_asm.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in des3_ede-asm_64.S (bnc#1058115).
- x86/crypto: Fix RBP usage in cast6-avx-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in cast5-avx-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in camellia-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in blowfish-x86_64-asm_64.S
  (bnc#1058115).
- commit 38f3021
* Tue Sep 19 2017 jeffm@suse.com
- Update to 4.14-rc1.
- Eliminated 17 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - HMM_MIRROR=n
  - DEVICE_PRIVATE=n
  - DEVICE_PUBLIC=n
  - SQUASHFS_ZSTD=y
  - ZRAM_WRITEBACK=y
  - x86:
  - INTEL_RDT=y (renamed option)
  - XEN_PVCALLS_BACKEND=y
  - X86_5LEVEL=n (will only boot on systems that support it)
  - AMD_MEM_ENCRYPT=y
  - AMD_MEM_ENCRYPT_ACTIVE_BY_DEFAULT=n
  - ppc:
  - PPC_MEMTRACE=y
  - PPC_VAS=y
  - s390:
  - CMA_DEBUG=n
  - CMA_DEBUGFS=n
  - CMA_AREAS=7 (default)
  - DMA_CMA=n
  - VMCP_CMA_SIZE=4 (default)
  - Netfilter:
  - NFT_FIB_NETDEV
  - Hyperv:
  - HYPERV_VSOCKETS
  - Network:
  - NET_NSH
  - BPF_STREAM_PARSER=y (build fix)
  - BNXT_FLOWER_OFFLOAD=y
  - HINIC
  - MLX5_MPFS=y
  - MLX5_ESWITCH=y
  - RMNET=n
  - ROCKCHIP_PHY
  - WIL6210_DEBUGFS=n
  - ATH10K_USB
  - Bluetooth:
  - BT_LEGACY_IOCTL=y (default)
  - SPI:
  - SPI_INTEL_SPI_PCI
  - Misc:
  - INPUT_PWM_VIBRA=m
  - SERIO_GPIO_PS2=m
  - PINCTRL_DENVERTON
  - PINCTRL_LEWISBURG
  - W1_SLAVE_DS2805
  - BATTERY_BQ27XXX_HDQ=m
  - BATTERY_MAX1721X
  - SENSORS_IBM_CFFPS
  - SENSORS_TPS53679
  - CLOCK_THERMAL=y
  - DEVFREQ_THERMAL=y
  - MFD_BD9571MWV=n
  - INTEL_SOC_PMIC_CHTWC=y
  - MFD_TPS68470=n
  - IR_GPIO_TX=n
  - IR_PWM_TX=n
  - DVB_DDBRIDGE
  - DVB_DDBRIDGE_MSIENABLE=n
  - TINYDRM_REPAPER=n
  - TINYDRM_ST7586=n
  - SND_SOC_CS43130=n
  - SND_SOC_WM8524=n
  - MMC_SPI
  - LEDS_AS3645A=n
  - LEDS_PCA955X_GPIO=y
  - INFINIBAND_EXP_USER_ACCESS=y [?]
  - CONFIG_ALTERA_MSGDMA
  - R8822BE
  - PI433=n
  - CLK_HSDK=n
  - EXTCON_USBC_CROS_EC
  - DLN2_ADC=m
  - LTC2471=n
  - CCS811=n
  - RESET_HSDK_V1=n
  - FPGA_MGR_ALTERA_CVP=m
  - FPGA_MGR_ALTERA_PS_SPI=m
  - CRYPTO_DEV_SP_CCP=y
  - I2C_CHT_WC=m
  - RESET_ATTACK_MITIGATION=y
- commit 08ca987
* Tue Sep 19 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-objtool-Don-t-report-end-of-section-error-after-an-e.patch.
- Refresh
  patches.suse/0002-x86-head-Remove-confusing-comment.patch.
- Refresh
  patches.suse/0003-x86-head-Remove-unused-bad_address-code.patch.
- Refresh
  patches.suse/0004-x86-head-Fix-head-ELF-function-annotations.patch.
- Refresh
  patches.suse/0005-x86-boot-Annotate-verify_cpu-as-a-callable-function.patch.
- Refresh
  patches.suse/0006-x86-xen-Fix-xen-head-ELF-annotations.patch.
- Refresh
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-head-Add-unwind-hint-annotations.patch.
- Delete
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations-fix.patch.
  Update to the submitted v2.
- commit 27de3c0
* Sun Sep 17 2017 jdelvare@suse.de
- drm/amdgpu: revert tile table update for oland (boo#1027378,
  boo#1039806, bko#194761).
- Delete
  patches.fixes/drm-amdgpu-revert-update-tile-table-for-oland-hainan.patch.
- commit 51745cf
* Thu Sep 14 2017 jslaby@suse.cz
- Linux 4.13.2 (bnc#1012628 bsc#1055826).
- Delete
  patches.drivers/rt2800-fix-TX_PIN_CFG-setting-for-non-MT7620-chips.
- Delete
  patches.fixes/Bluetooth-validate-output-buffer-length-for-config-r.patch.
- commit 96d9efa
* Wed Sep 13 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix a thinko for xmlto buildreq condition
- commit 0ef59d3
* Wed Sep 13 2017 jslaby@suse.cz
- Bluetooth: validate output buffer length for config requests
  and responses (bnc#1057389 CVE-2017-1000251).
- commit c0b7e1f
* Tue Sep 12 2017 jslaby@suse.cz
- fix annotations of xen-head.S (bnc#1058115).
- commit d4c88a5
* Tue Sep 12 2017 msuchanek@suse.de
- rpm/kernel-docs.spec.in: make unpack scripts executable
- commit 1ba3766
* Tue Sep 12 2017 jslaby@suse.cz
- x86/head: Add unwind hint annotations (bnc#1058115).
- x86/xen: Add unwind hint annotations (bnc#1058115).
- x86/xen: Fix xen head ELF annotations (bnc#1058115).
- x86/boot: Annotate verify_cpu() as a callable function
  (bnc#1058115).
- x86/head: Fix head ELF function annotations (bnc#1058115).
- x86/head: Remove unused 'bad_address' code (bnc#1058115).
- x86/head: Remove confusing comment (bnc#1058115).
- objtool: Don't report end of section error after an empty
  unwind hint (bnc#1058115).
- commit 53af152
* Tue Sep 12 2017 jslaby@suse.cz
- objtool: Assume unannotated UD2 instructions are dead ends
  (bnc#1058115).
- objtool: Fix gcov check for older versions of GCC (bnc#1058115).
- objtool: Fix objtool fallthrough detection with function padding
  (bnc#1058115).
- objtool: Fix validate_branch() return codes (bnc#1058115).
- objtool: Handle GCC stack pointer adjustment bug (bnc#1058115).
- x86/asm: Add ASM_UNREACHABLE (bnc#1058115).
- x86/asm: Fix UNWIND_HINT_REGS macro for older binutils
  (bnc#1058115).
- x86/asm: Make objtool unreachable macros independent from GCC
  version (bnc#1058115).
- objtool: Skip unreachable warnings for 'alt' instructions
  (bnc#1058115).
- objtool: Track DRAP separately from callee-saved registers
  (bnc#1058115).
- Refresh patches.suse/0001-x86-unwind-Add-the-ORC-unwinder.patch.
  Take all ORC upstream patches. This will go to stable & SLE15 too.
- commit 831ca01
* Mon Sep 11 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- Refresh patches.suse/0001-x86-unwind-Add-the-ORC-unwinder.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
- Refresh
  patches.suse/0002-x86-kconfig-Make-it-easier-to-switch-to-the-new-ORC-.patch.
- Refresh
  patches.suse/0003-x86-dumpstack-Fix-occasionally-missing-registers.patch.
- Refresh
  patches.suse/0003-x86-kconfig-Consolidate-unwinders-into-multiple-choi.patch.
- Refresh
  patches.suse/0004-x86-dumpstack-Fix-interrupt-and-exception-stack-boun.patch.
- Refresh
  patches.suse/0005-objtool-Add-ORC-unwind-table-generation.patch.
- Refresh
  patches.suse/0006-objtool-x86-Add-facility-for-asm-code-to-provide-unw.patch.
- Refresh
  patches.suse/0007-x86-entry-64-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-asm-Add-unwind-hint-annotations-to-sync_core.patch.
- Delete
  patches.suse/0001-linkage-new-macros-for-assembler-symbols.patch.
- Delete
  patches.suse/0003-DWARF-EH-frame-based-stack-unwinding.patch.
- Delete patches.suse/stack-unwind-disable-kasan.patch.
  Update upstream status of ORC and drop already-disabled DWARF unwinder.
- commit 2e9b944
* Mon Sep 11 2017 jslaby@suse.cz
- rpm/constraints.in: build ARM on at least 2 cpus
- commit b7edeaf
* Mon Sep 11 2017 jslaby@suse.cz
- rpm/constraints.in: increase memory for kernel-syzkaller
  And see if it helps. If so, push it to packaging...
- commit 7193e65
* Sun Sep 10 2017 afaerber@suse.de
- config: arm64: Enable legacy instruction emulation (boo#1029158)
  Needed for execution of older e.g. ARMv6 code.
- commit a4e05e8
* Sun Sep 10 2017 afaerber@suse.de
- config: arm64: Enable ACPI_DOCK for consistency
- commit cec354f
* Sun Sep 10 2017 afaerber@suse.de
- config: arm64: Enable some network options
- Marvell Armada 7K/8K Ethernet driver
- Microchip ENC28J60 and related SPI Ethernet drivers
- Micrel KS8851 SPI Ethernet driver
- MMIO MDIO mux driver
- commit cf926f4
* Sun Sep 10 2017 jslaby@suse.cz
- rpm/constraints.in: set physical memory
  Not memory.
- rpm/constraints.in: increase memory for kernel-syzkaller
  And see if it helps. If so, push it to packaging...
- commit 0d725b5
* Sun Sep 10 2017 jslaby@suse.cz
- Linux 4.13.1 (bnc#1012628).
- commit 8740849
* Fri Sep  8 2017 jslaby@suse.cz
- rpm/kernel-binary.spec.in: package ftrace-mod.o on arm64
  It is needed for building modules since 4.13:
  CC [M]  /suse/jslaby/a/aaa.o
  Building modules, stage 2.
  MODPOST 1 modules
  CC      /suse/jslaby/a/aaa.mod.o
  LD [M]  /suse/jslaby/a/aaa.ko
  ld: cannot find ./arch/arm64/kernel/ftrace-mod.o: No such file or directory
  ...
- commit 07da115
* Thu Sep  7 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Expand kernel tree directly from sources (bsc#1057199)
- commit a61b4d9
* Thu Sep  7 2017 jslaby@suse.cz
- Linux 4.12.11 (bnc#1012628).
- commit bf7fb08
* Wed Sep  6 2017 mcgrof@suse.com
- supported.conf: add test_syctl to new kselftests-kmp package FATE#323821
  As per FATE#323821 we will require new FATE requests per each
  new selftest driver. We don't want to support these module on
  production runs but we do want to support them for QA / testing
  uses. The compromise is to package them into its own package,
  this will be the kselftests-kmp package.
  Selftests can also be used as proof of concept vehicle for issues
  by customers or ourselves.
  Vanilla kernels do not get test_sysctl given that driver was
  using built-in defaults, this also means we cannot run sefltests
  on config/s390x/zfcpdump which does not enable modules.
  Likeweise, since we had to *change* the kernel for test_syctl, it
  it also means we can't test test_syctl with vanilla kernels. It
  should be possible with other selftests drivers if they are
  present in vanilla kernels though.
- commit ae8069f
* Wed Sep  6 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Re-add xmlto buildreq conditionally for SLE15 & co
- commit 259b49e
* Wed Sep  6 2017 mchandras@suse.de
- rpm/group-source-files.pl: Add arch/*/tools/* files to the devel package
  Commit b71c9ffb1405 ("powerpc: Add arch/powerpc/tools directory")
  introduced in v4.12-rc1 release, moved the scripts into the tools
  directory. However, this location is not considered for the kernel devel
  package and the following error occurs when building a kmp for powerpc
  make[2]: /usr/src/linux-4.12.9-1/arch/powerpc/tools/gcc-check-mprofile-kernel.sh: Command not found
- commit 5f1ff53
* Tue Sep  5 2017 jeffm@suse.com
- Update to 4.13-final.
- commit 3fdcb17
* Thu Aug 31 2017 tiwai@suse.de
- rt2800: fix TX_PIN_CFG setting for non MT7620 chips
  (bsc#1055826).
- commit 8116757
* Thu Aug 31 2017 jeffm@suse.com
- Update to 4.13-rc7.
- Eliminate 2 patches.
- commit dd00417
* Thu Aug 31 2017 jthumshirn@suse.de
- scsi: qla2xxx: Fix an integer overflow in sysfs code
  (bsc#1056588, CVE-2017-14051).
- commit 4fafb75
* Thu Aug 31 2017 jthumshirn@suse.de
- scsi: qla2xxx: Fix an integer overflow in sysfs code
  (bsc#1056588, CVE-2017-14051).
- commit aacb454
* Wed Aug 30 2017 jslaby@suse.cz
- Linux 4.12.10 (bnc#1012628 bnc#1014351 bnc#1048935 bsc#1020657
  bsc#1050582).
- Delete
  patches.drivers/ALSA-hda-Add-stereo-mic-quirk-for-Lenovo-G50-70-17aa.
- Delete
  patches.fixes/Bluetooth-hidp-fix-possible-might-sleep-error-in-hid.patch.
- Delete
  patches.fixes/Input-ALPS-Fix-Alps-Touchpad-two-finger-scroll-does-.
- Delete
  patches.fixes/netfilter-expect-fix-crash-when-putting-uninited-exp.patch.
- commit 030062c
* Tue Aug 29 2017 tiwai@suse.de
- Refresh patches.suse/iwlwifi-expose-default-fallback-ucode-api.
  The latest firmware matches for iwl7xxx/3168 series, so dropped the changes.
- commit 1447668
* Tue Aug 29 2017 tiwai@suse.de
- Update config files: enable CONFIG_SPI_PXA2XX for MacBook (bsc#1055817)
- commit 3ce18e9
* Mon Aug 28 2017 tiwai@suse.de
- rpm/kernel-binary.spec.in: Update drm-kmp obsolete for SLE12-SP3/Leap-42.3
- commit 77ccbd0
* Mon Aug 28 2017 tiwai@suse.de
- Refresh patch tags of patches.fixes/Input-ALPS-Fix-Alps-Touchpad-two-finger-scroll-does-
- commit 0b3ef4c
* Mon Aug 28 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Disable PDF build again
  ... due to the breakage with the recent TeXLive 2017.
  Also add the missing dependency on texlive-varwidth.
- commit 9f682b5
* Fri Aug 25 2017 jslaby@suse.cz
- Linux 4.12.9 (bnc#1012628 bsc#1052580 bnc#1049599).
- Delete
  patches.drivers/ALSA-usb-audio-Apply-sample-rate-quirk-to-Sennheiser.
- Delete patches.fixes/debug-fix-WARN_ON_ONCE-for-modules.patch.
- Update config files.
- commit f2ab6ba
* Wed Aug 23 2017 tiwai@suse.de
- ALSA: hda - Add stereo mic quirk for Lenovo G50-70 (17aa:3978)
  (bsc#1020657).
- commit 3f6a0b2
* Wed Aug 23 2017 tiwai@suse.de
- ALSA: hda - Add stereo mic quirk for Lenovo G50-70 (17aa:3978)
  (bsc#1020657).
- commit d300598
* Wed Aug 23 2017 jslaby@suse.cz
- Bluetooth: hidp: fix possible might sleep error in
  hidp_session_thread (bnc#1014351).
- commit fa3a4f0
* Tue Aug 22 2017 tiwai@suse.de
- ALSA: ice1712: Add support for STAudio ADCIII (bsc#1048934).
- commit 99a99ef
* Tue Aug 22 2017 tiwai@suse.de
- ALSA: ice1712: Add support for STAudio ADCIII (bsc#1048934).
- commit 53a20a8
* Tue Aug 22 2017 tiwai@suse.de
- ALSA: hda - Implement mic-mute LED mode enum (bsc#1055013).
- commit a3c362f
* Tue Aug 22 2017 tiwai@suse.de
- ALSA: hda - Implement mic-mute LED mode enum (bsc#1055013).
- commit b870486
* Mon Aug 21 2017 jeffm@suse.com
- Update to 4.13-rc6.
- commit ee50b89
* Fri Aug 18 2017 msuchanek@suse.de
- Do not ship firmware (bsc#1054239).
  Pull firmware from kernel-firmware instead.
- commit 0b0b5c9
* Thu Aug 17 2017 jeffm@suse.com
- supported.conf: clear mistaken external support flag for cifs.ko (bsc#1053802).
- commit 75e287e
* Thu Aug 17 2017 jeffm@suse.com
- supported.conf: mark reiserfs unsupported (FATE#323394).
  ReiserFS is not supported in SLE15.  ReiserFS file systems must be
  transferred or converted before installing.
- commit 8a547c5
* Thu Aug 17 2017 jeffm@suse.com
- Update to 4.13-rc5.
- commit c3fb699
* Thu Aug 17 2017 jslaby@suse.cz
- Linux 4.12.8 (bnc#1012628).
- commit 4d7933a
* Tue Aug 15 2017 hare@suse.de
- Delete patches.fixes/scsi-dh-queuedata-accessors.
- commit ee998ab
* Tue Aug 15 2017 hare@suse.de
- Delete patches.suse/dm-mpath-detach-existing-hardware-handler.
- commit a8291cd
* Tue Aug 15 2017 hare@suse.de
- Delete patches.suse/no-partition-scan (FATE#323406)
- commit e1cccca
* Tue Aug 15 2017 tiwai@suse.de
- ALSA: usb-audio: Apply sample rate quirk to Sennheiser headset
  (bsc#1052580).
- commit a8251af
* Sun Aug 13 2017 jslaby@suse.cz
- Linux 4.12.7 (bnc#1012628).
- commit 7dae241
* Sun Aug 13 2017 jslaby@suse.cz
- Refresh
  patches.fixes/netfilter-expect-fix-crash-when-putting-uninited-exp.patch.
  Update upstream status.
- commit cdb9f49
* Sat Aug 12 2017 jslaby@suse.cz
- Linux 4.12.6 (CVE-2017-7542 CVE-2017-8831 bnc#1012628
  bsc#1037994 bsc#1049882).
- Delete
  patches.fixes/ipv6-avoid-overflow-of-offset-in-ip6_find_1stfragopt.patch.
- Delete
  patches.fixes/media-saa7164-fix-double-fetch-PCIe-access-condition.
- commit 29b7412
* Sat Aug 12 2017 lduncan@suse.com
- uapi: add a compatibility layer between linux/uio.h and glibc
  (bsc#1053501).
- commit fe56e41
* Thu Aug 10 2017 msuchanek@suse.de
- Refresh vanilla config.
- commit ae18928
* Thu Aug 10 2017 msuchanek@suse.de
- rpm/modules.fips include module list from dracut
- commit f70bab5
* Wed Aug  9 2017 ohering@suse.de
- Delete stale patches.fixes/scsi-ibmvscsi-module_alias.patch.
- Delete stale patches.suse/suse-ppc64-branding.
- commit 1c8934b
* Wed Aug  9 2017 tiwai@suse.de
- [media] saa7164: fix double fetch PCIe access condition
  (CVE-2017-8831 bsc#1037994).
- commit 4d38c27
* Tue Aug  8 2017 jeffm@suse.com
- Update to 4.13-rc4.
- commit 94b098f
* Mon Aug  7 2017 jslaby@suse.cz
- Linux 4.12.5 (bnc#1012628 bsc#1049483 bsc#1049599).
- Delete patches.fixes/dentry-name-snapshots.patch.
- Delete
  patches.suse/0001-md-remove-idx-from-struct-resync_pages.patch.
- commit e6109ef
* Wed Aug  2 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix package list and enable building PDFs
  Finally it works!  Added some missing pieces (ImageMagick, some texlive
  subpkgs) in addition to use explicitly python3-Sphinx stuff.
- commit c117a0c
* Tue Aug  1 2017 agraf@suse.de
- Clean up upstreamed patches list. Annotate the remaining ones
  with their current status.
- Delete patches.arch/arm-exynos-dwmmc-modalias.patch.
- Delete
  patches.arch/arm64-Relocate-screen_info.lfb_base-on-PCI-BAR-alloc.patch.
- commit 3f654d5
* Mon Jul 31 2017 jeffm@suse.com
- Update to 4.13-rc3.
- commit 4ef483a
* Fri Jul 28 2017 jslaby@suse.cz
- Update config files.
  Fix vanillas after the orc update.
- commit 2a27bf2
* Fri Jul 28 2017 jslaby@suse.cz
- Linux 4.12.4 (bnc#1012628).
- commit f2e2c0a
* Thu Jul 27 2017 mkubecek@suse.cz
- ipv6: avoid overflow of offset in ip6_find_1stfragopt
  (CVE-2017-7542 bsc#1049882).
- commit 00c5961
* Thu Jul 27 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-md-remove-idx-from-struct-resync_pages.patch.
- commit b11fd5b
* Thu Jul 27 2017 jslaby@suse.cz
- objtool: Fix sibling call detection logic (bnc#1018348).
- x86/kconfig: Make it easier to switch to the new ORC unwinder
  (bnc#1018348).
- x86/kconfig: Consolidate unwinders into multiple choice
  selection (bnc#1018348).
- Refresh
- Refresh patches.suse/0001-x86-unwind-Add-the-ORC-unwinder.patch.
- Refresh
  patches.suse/0002-dwarf-do-not-throw-away-unwind-info.patch.
- Refresh
  patches.suse/0002-objtool-x86-Add-several-functions-and-files-to-the-o.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
- Refresh
  patches.suse/0002-x86-kconfig-Make-it-easier-to-switch-to-the-new-ORC-.patch.
- Refresh
  patches.suse/0003-objtool-Implement-stack-validation-2.0.patch.
- Refresh
  patches.suse/0003-x86-kconfig-Consolidate-unwinders-into-multiple-choi.patch.
- Refresh
  patches.suse/0007-x86-entry-64-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-asm-Add-unwind-hint-annotations-to-sync_core.patch.
- Update config files.
  Update to version from -tip. ORC is in -tip completely. So make sure
  we use the upstream version.
- x86/kconfig: Make it easier to switch to the new ORC unwinder
  (bnc#1018348).
- x86/kconfig: Consolidate unwinders into multiple choice
  selection (bnc#1018348).
- Update config files.
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- Refresh
  patches.suse/0002-dwarf-do-not-throw-away-unwind-info.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
  Update to version from -tip. ORC is in -tip completely. So make sure
  we use the upstream version.
- commit 34dd0f5
* Wed Jul 26 2017 mcgrof@suse.com
- Refresh
  patches.suse/0001-mm-kmemleak-slightly-reduce-the-size-of-some-structu.patch.
- Refresh
  patches.suse/0002-mm-kmemleak-factor-object-reference-updating-out-of-.patch.
- Refresh
  patches.suse/0003-mm-kmemleak-treat-vm_struct-as-alternative-reference.patch.
- commit f7ebe40
* Wed Jul 26 2017 mcgrof@suse.com
- Refresh
  patches.suse/0001-mm-kmemleak-slightly-reduce-the-size-of-some-structu.patch.
- Refresh
  patches.suse/0002-mm-kmemleak-factor-object-reference-updating-out-of-.patch.
- Refresh
  patches.suse/0003-mm-kmemleak-treat-vm_struct-as-alternative-reference.patch.
- commit eb41516
* Wed Jul 26 2017 jeffm@suse.com
- Update to 4.13-rc2.
- Eliminated 1 patch.
- Config changes:
  - DRM_VBOXVIDEO=m
- commit b545b87
* Wed Jul 26 2017 tiwai@suse.de
- Input: ALPS - Fix Alps Touchpad two finger scroll does not
  work on right side (bsc#1050582).
- commit 474729b
* Sun Jul 23 2017 stefan.bruens@rwth-aachen.de
- config: arm64: Enable RTC and SPI on Allwinner A64/H5
  A64 and H5 share the RTC and SPI functional blocks with older SoCs,
  enable the corresponding drivers.
- commit b5bf58a
* Fri Jul 21 2017 colyli@suse.de
- md: remove 'idx' from 'struct resync_pages' (bsc#1049599).
- commit 515f14e
* Fri Jul 21 2017 jslaby@suse.cz
- Linux 4.12.3 (CVE-2017-7541 bnc#1012628 bsc#1049645).
- Refresh patches.suse/pstore-backend-autoaction.
- Delete
  patches.fixes/brcmfmac-fix-possible-buffer-overflow-in-brcmf_cfg80.
- commit 409edbf
* Thu Jul 20 2017 jack@suse.cz
- dentry name snapshots (bsc#1049483).
- commit 76ea0ca
* Thu Jul 20 2017 jslaby@suse.cz
- debug: fix WARN_ON_ONCE() for modules (bnc#1049599).
- commit b1e9bab
* Thu Jul 20 2017 tiwai@suse.de
- brcmfmac: fix possible buffer overflow in
  brcmf_cfg80211_mgmt_tx() (CVE-2017-7541,bsc#1049645).
- commit 823a643
* Wed Jul 19 2017 mmarek@suse.cz
- rpm/kernel-binary.spec.in: find-debuginfo.sh should not touch build-id
  This needs rpm-4.14+ (bsc#964063).
- commit f622d60
* Tue Jul 18 2017 afaerber@suse.de
- config: armv7hl: Update to v4.13-rc1
- commit 1d72b01
* Tue Jul 18 2017 afaerber@suse.de
- config: armv6hl: Update to v4.13-rc1
- commit 5ede81f
* Tue Jul 18 2017 afaerber@suse.de
- config: arm64: Update to v4.13-rc1
- commit 7d005f8
* Tue Jul 18 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
- Refresh
  patches.suse/0003-x86-dumpstack-fix-occasionally-missing-registers.patch.
- Refresh
  patches.suse/0004-x86-dumpstack-fix-interrupt-and-exception-stack-boun.patch.
- Refresh
  patches.suse/0005-objtool-add-ORC-unwind-table-generation.patch.
- Refresh
  patches.suse/0006-objtool-x86-add-facility-for-asm-code-to-provide-unw.patch.
- Refresh
  patches.suse/0007-x86-entry-64-add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-asm-add-unwind-hint-annotations-to-sync_core.patch.
  Update upstream information.
- commit 8db850a
* Tue Jul 18 2017 tiwai@suse.de
- Delete patches.fixes/drm-i915-Fix-S4-resume-breakage.
  The workaround wasn't merged to upstream, and it seems becoming
  superfluous with the recent i915 driver, so let's drop this one.
- commit f6f228c
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Drop unnecessary xmlto for 4.13+
- commit e47dc84
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Correct kernel-docs package summary/description
- commit 697b763
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: refresh dependencies for PDF build (bsc#1048129)
  But it still doesn't work with Tex Live 2017, thus disabled yet.
  Also add texlive-anyfontsize for HTML math handling.
- commit ead44a1
* Tue Jul 18 2017 jslaby@suse.cz
- Delete patches.rpmify/drm-i915-disable-KASAN-for-handlers.patch.
  It was never accepted, is under discussion. But we disabled
  CONFIG_DRM_I915_WERROR in commit 5fc7b327348b, so we are safe anyway.
- commit 09fc05f
* Tue Jul 18 2017 jslaby@suse.cz
- Delete patches.rpmify/get_builtin_firmware-gcc-7.patch.
  This was never accepted. Instead this seems to be fixed in gcc.
- commit c486b10
* Mon Jul 17 2017 jeffm@suse.com
- Updated to 4.13-rc1.
- Eliminated 13 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - SLAB_MERGE_DEFAULT=y (current behavior)
  - REFCOUNT_FULL=n (current behavior)
  - PERCPU_STATS=n (default)
  - FORTIFY_SOURCE=n (needs performance analysis)
  - WARN_ALL_UNSEEDED_RANDOM=n
  - TRACE_EVAL_MAP_FILE=n
  - TEST_SYSCTL=n
  - TEST_KMOD=n
  - Storage:
  - DM_ZONED=m
  - IB:
  - Options for MLX5:
  - MLX5_FPGA
  - MLX5_EN_IPSEC=y
  - MLXFW=m
  - SECURITY_INFINIBAND=y
  - Network:
  - Options for NFP:
  - NFP_APP_FLOWER=y
  - CORTINA_PHY=n (intended for embedded apps)
  - ATH10K_SDIO=m
  - QTNFMAC_PEARL_PCIE=m
  - DRM:
  - DRM_I915_SW_FENCE_CHECK_DAG=n
  - Sound:
  - SND_SOC_INTEL_BYT_CHT_ES8316_MACH=m
  - SND_SOC_INTEL_KBL_RT5663_MAX98927_MACH=m
  - SND_SOC_INTEL_KBL_RT5663_RT5514_MAX98927_MACH=m
  - SND_SOC_ZX_AUD96P22=n
  - HID:
  - HID_ITE=n
  - HID_RETRODE=m
  - USB:
  - TYPEC_UCSI=m
  - UCSI_ACPI=m
  - Misc:
  - RTC_NVMEM=y
  - RTC_DRV_DS3232_HWMON=y
  - WMI_BMOF=m
  - PEAQ_WMI=m
  - INTEL_INT0002_VGPIO=m
  - CROS_EC_LPC_MEC=y
  - EXTCON_INTEL_CHT_WC=m
  - NTB_IDT=m
  - MULTIPLEXER=m
  - KEYBOARD_DLINK_DIR685=n
  - TOUCHSCREEN_STMFTS=n
  - I2C_DESIGNWARE_SLAVE=n
  - SPI_SLAVE=n
  - PINCTRL_MCP23S08=n
  - PINCTRL_CANNONLAKE=m
  - GPIO_XRA1403=n
  - BATTERY_BQ27XXX_DT_UPDATES_NVM=n
  - CHARGER_LTC3651=n
  - SENSORS_IR35221=n
  - WATCHDOG_HANDLE_BOOT_ENABLED=y (default)
  - File Systems:
  - OVERLAY_FS_INDEX=n (mounting on an older kernel read-write will cause unexpected results)
  - CIFS_DEBUG_DUMP_KEYS=n
  - Crypto:
  - CRC4=m
  - X86:
  - INTEL_SOC_PMIC_CHTWC=m
  - CHT_WC_PMIC_OPREGION=y
  - ppc64/ppc64le:
  - CONFIG_IRQ_TIME_ACCOUNTING=n
  - CONFIG_LD_HEAD_STUB_CATCH=n
  - ZONE_DEVICE=y
  - ppc64le:
  - STRICT_KERNEL_RWX=y
  - s390x:
  - CRYPTO_PAES_S390=m
- commit d418532
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.drivers/ppc64-adb.
  This hardware was discontinued in 2006 and the patch was never accepted
  upstream.
- commit 995698b
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.arch/ppc-prom-nodisplay.patch.
  We no longer support 32-bit ppc and this hardware only existed with a
  32-bit CPU.
- commit d94ed1e
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.arch/ppc-pegasos-console-autodetection.patch.
  We no longer support 32-bit ppc and this hardware only existed with a
  32-bit CPU.
- commit b42ddc6
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.suse/ppc-powerbook-usb-fn-key-default.patch.
  We no longer support 32-bit ppc and there were no 64-bit powerbooks.
- commit 9e9a512
* Mon Jul 17 2017 jeffm@suse.com
- Disable patches.suse/pstore-backend-autoaction.
  It needs updating and there now exists a mount option instead of a module
  parameter.
- commit 87a5ab7
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.fixes/block-copy-bi_vcnt-in-_bio_clone_fast.
  This was obsoleted by 764f612c6c3c ("blk-merge: don't compute
  bi_phys_segments from bi_vcnt for cloned bio").
- commit f0c2642
* Mon Jul 17 2017 jslaby@suse.cz
- netfilter: expect: fix crash when putting uninited expectation
  (bnc#1048935).
- netfilter: expect: fix crash when putting uninited expectation
  (bnc#1048935).
- Delete
  patches.fixes/netfilter-nf_ct_expect-fix-expect-removal.patch.
  Replace by upstream fix (from a subsys repo).
- commit cc9efac
* Mon Jul 17 2017 jslaby@suse.cz
- netfilter: nf_ct_expect: fix expect removal (bnc#1048935).
- commit 28fe876
* Mon Jul 17 2017 mmarek@suse.cz
- Drop multiversion(kernel) from the KMP template (fate#323189)
- commit 71504d8
* Tue Jul 11 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix and cleanup for 4.13 doc build (bsc#1048129)
  The whole DocBook stuff has been deleted.  The PDF build still non-working
  thus the sub-packaging disabled so far.
- commit 8e7de10
* Mon Jun 19 2017 mcgrof@suse.com
- mm: kmemleak: treat vm_struct as alternative reference to vmalloc'ed objects (bsc#1027456).
- mm: kmemleak: factor object reference updating out of scan_block() (bsc#1027456).
- mm: kmemleak: slightly reduce the size of some structures on 64-bit architectures (bsc#1027456).
- commit 880dbd7
* Fri Jun  2 2017 afaerber@suse.de
- rpm/dtb.spec.in.in: Fix new include path
  Commit 89de3db69113d58cdab14d2c777de6080eac49dc ("rpm/dtb.spec.in.in:
  Update include path for dt-bindings") introduced an additional include
  path for 4.12. The commit message had it correct, but the spec file
  template lacked a path component, breaking the aarch64 build while
  succeeding on armv7hl. Fix that.
- commit c8d853a
* Wed May 31 2017 afaerber@suse.de
- rpm/dtb.spec.in.in: Update include path for dt-bindings
  Kernels before 4.12 had arch/{arm,arm64}/boot/dts/include/ directories
  with a symlink to include/dt-bindings/.
  In 4.12 those include/ directories were dropped.
  Therefore use include/ directly.
  Additionally some cross-architecture .dtsi reuse was introduced, which
  requires scripts/dtc/include-prefixes/ that didn't exist on older kernels.
- commit 466f108
* Fri Jan  6 2017 afaerber@suse.de
- rpm: Add arm64 dtb-zte subpackage
  4.9 added arch/arm64/boot/dts/zte/.
- commit 073d831
* Fri Jan  6 2017 afaerber@suse.de
- rpm: Add arm64 dtb-allwinner subpackage
  4.10 added arch/arm64/boot/dts/allwinner/.
- commit dfeb94a
* Tue Dec 20 2016 xxxxxmichl@googlemail.com
- added De0-Nanos-SoC board support (and others based on Altera SOC).
- commit 9278339
